UDocAnnotationKind enum

Inheritance
Available extensions

Values

highlight → const UDocAnnotationKind
underline → const UDocAnnotationKind
strikeOut → const UDocAnnotationKind
squiggly → const UDocAnnotationKind
ink → const UDocAnnotationKind
text → const UDocAnnotationKind
freeText → const UDocAnnotationKind
line → const UDocAnnotationKind
square → const UDocAnnotationKind
circle → const UDocAnnotationKind
polygon → const UDocAnnotationKind
polyLine → const UDocAnnotationKind
stamp → const UDocAnnotationKind
caret → const UDocAnnotationKind
fileAttachment → const UDocAnnotationKind
sound → const UDocAnnotationKind
movie → const UDocAnnotationKind
widget → const UDocAnnotationKind
screen → const UDocAnnotationKind
redact → const UDocAnnotationKind
unknown → const UDocAnnotationKind

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UDocAnnotationKind>
A constant List of the values in this enum, in order of their declaration.