UDocController class abstract

Inheritance
Implementers

Constructors

UDocController()

Properties

documentId → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isDisposed → bool
no setter
kind → UDocKind
no setter
liveHits → ValueNotifier<List<UDocSearchHit>>
final
pageCount → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → UDocViewSettings
no setter
stateStream → Stream<UDocValue>
no setter
value ↔ UDocValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearSearch() → void
clearSelection() → void
close() → Future<void>
dispose() → void
Discards any resources used by the object.
override
emit(UDocValue next) → void
failWith(UDocError error) → void
goToPage(int pageIndex) → void
nextHit() → void
nextPage() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pageInfo(int pageIndex) → UDocPageInfo
previousHit() → void
previousPage() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
renderPage(int pageIndex, {double scale = 1, Rect? clip}) → Future<Picture?>
renderThumbnail(int pageIndex, {int maxSize = 240}) → Future<Image?>
setColorMode(UDocColorMode mode) → void
setCropMargins(bool crop) → void
setDim(double dim) → void
setDirection(UDocDirection direction) → void
setFit(UDocFit fit) → void
setScrollMode(UDocScrollMode mode) → void
setSelection(UDocSelection selection) → void
setSpread(UDocSpread spread) → void
setZoom(double zoom) → void
textPage(int pageIndex) → Future<UDocTextPage>
toString() → String
A string representation of this object.
inherited
updateSettings(UDocViewSettings settings) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited