UDocCursor class

Constructors

UDocCursor(Uint8List bytes, {int base = 0, int start = 0, int? end})

Properties

absolute → int
no setter
base → int
final
bytes → Uint8List
final
end → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
peek → int
no setter
position → int
no setter
remaining → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ascii(int count) → String
canRead(int count) → bool
f2dot14() → double
fixed1616() → double
guarded(int declared, {int cap = uDocMaxAllocation}) → int
i16() → int
i32() → int
indexOf(List<int> pattern, {int from = -1}) → int
lastIndexOf(List<int> pattern, {int from = -1}) → int
matches(List<int> pattern, {int delta = 0}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peekAt(int delta) → int
require(int count) → void
seek(int offset) → void
seekAbsolute(int offset) → void
skip(int count) → void
take(int count) → Uint8List
takeGuarded(int declared, {int cap = uDocMaxAllocation}) → Uint8List
toString() → String
A string representation of this object.
inherited
u16() → int
u24() → int
u32() → int
u8() → int

Operators

operator ==(Object other) → bool
The equality operator.
inherited