UDocDestination class

Constructors

UDocDestination({required int pageIndex, double? left, double? top, double? zoom, UDocFit? fitMode, String? anchor})
const
UDocDestination.fromJson(Map<String, Object?> json)
factory

Properties

anchor → String?
final
fitMode → UDocFit?
final
hashCode → int
The hash code for this object.
no setterinherited
left → double?
final
pageIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double?
final
zoom → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited