UDocGlyph class

Constructors

UDocGlyph({required String text, required Rect rect, required bool rtl, double fontSize = 0, bool spaceAfter = false})
const

Properties

fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
rect → Rect
final
rtl → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaceAfter → bool
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited