UDocMetadata class

Constructors

UDocMetadata({String? title, String? author, String? subject, String? keywords, String? creator, String? producer, DateTime? creationDate, DateTime? modificationDate, String? language, String? publisher, String? identifier, String? series, double? seriesIndex, int pageCount = 0, String? version, bool tagged = false, bool linearized = false, bool encrypted = false, Map<String, String> custom = const <String, String>{}})
const
UDocMetadata.fromJson(Map<String, Object?> json)
factory

Properties

author → String?
final
creationDate → DateTime?
final
creator → String?
final
custom → Map<String, String>
final
displayTitle → String
no setter
encrypted → bool
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
final
keywords → String?
final
language → String?
final
linearized → bool
final
modificationDate → DateTime?
final
pageCount → int
final
producer → String?
final
publisher → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → String?
final
seriesIndex → double?
final
subject → String?
final
tagged → bool
final
title → String?
final
version → String?
final

Methods

copyWith({String? title, String? author, String? subject, String? keywords, String? creator, String? producer, DateTime? creationDate, DateTime? modificationDate, String? language, String? publisher, String? identifier, String? series, double? seriesIndex, int? pageCount, String? version, bool? tagged, bool? linearized, bool? encrypted, Map<String, String>? custom}) → UDocMetadata
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited