UDocOutlineNode class

Constructors

UDocOutlineNode({required String title, UDocDestination? destination, String? uri, List<UDocOutlineNode> children = const <UDocOutlineNode>[], bool expanded = false, Color? color, bool bold = false, bool italic = false})
const

Properties

bold → bool
final
children → List<UDocOutlineNode>
final
color → Color?
final
descendantCount → int
no setter
destination → UDocDestination?
final
expanded → bool
final
hasChildren → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
italic → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
uri → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited