UDocPageInfo class

Constructors

UDocPageInfo({required int index, required Size size, int rotation = 0, String? label, Rect? cropBox, Rect? mediaBox, bool hasText = true, bool isScanned = false})
const

Properties

aspectRatio → double
no setter
cropBox → Rect?
final
hashCode → int
The hash code for this object.
no setterinherited
hasText → bool
final
index → int
final
isScanned → bool
final
label → String?
final
mediaBox → Rect?
final
rotatedSize → Size
no setter
rotation → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited