UDocPermissions class
Constructors
-
UDocPermissions({Set<
UDocPermission> granted = const <UDocPermission>{}, bool ownerUnlocked = false}) -
const
Properties
-
granted
→ Set<
UDocPermission> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ownerUnlocked → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allows(
UDocPermission permission) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- all → const UDocPermissions