UDocPictureCache class

Constructors

UDocPictureCache({int maxBytes = uDocPictureCacheBytes})

Properties

bytes → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
evictDocument(String documentId) → void
evictPage(String documentId, int pageIndex) → void
get(String cacheKey) → Picture?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String cacheKey, Picture picture) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → UDocPictureCache
final

Static Methods

key(String documentId, int pageIndex, double scale) → String