UDocSearchHit class

Constructors

UDocSearchHit({required int pageIndex, required int start, required int end, required String snippet, required List<Rect> rects, int matchIndex = 0})
const

Properties

bounds → Rect
no setter
end → int
final
hashCode → int
The hash code for this object.
no setterinherited
matchIndex → int
final
pageIndex → int
final
rects → List<Rect>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet → String
final
start → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited