UDocSearchOptions class

Constructors

UDocSearchOptions({bool caseSensitive = false, bool wholeWord = false, bool regex = false, bool normalizePersian = true, int maxHits = 5000, int startPage = 0, int endPage = -1})
const

Properties

caseSensitive → bool
final
endPage → int
final
hashCode → int
The hash code for this object.
no setterinherited
maxHits → int
final
normalizePersian → bool
final
regex → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startPage → int
final
wholeWord → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited