UDocSelection class

Constructors

UDocSelection({required int pageIndex, required int start, required int end, required String text, List<Rect> rects = const <Rect>[]})
const

Properties

end → int
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
pageIndex → int
final
rects → List<Rect>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const UDocSelection