UDocSources class abstract

Constructors

UDocSources()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

blobBuilder ↔ UDocBlobSourceBuilder?
getter/setter pair

Static Methods

fingerprint(UDocByteSource source) → Future<String>
open({String? path, String? url, Uint8List? bytes, String? asset, Object? blob, Map<String, String>? headers, int cacheBytes = uDocSourceCacheBytes}) → Future<UCachedByteSource>
sniff(Uint8List head) → UDocKind