UDocText class abstract

Constructors

UDocText()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

collapseWhitespace(String text) → String
decodeBytes(Uint8List bytes, {String? charset}) → String
dehyphenate(String text) → String
direction(String text) → UDocDirection
findAll(String haystack, String needle, {bool wholeWord = false}) → List<int>
forSearch(String text) → String
isNeutralCode(int code) → bool
isRtl(String text) → bool
isRtlCode(int code) → bool
normalize(String text) → String
unfoldPresentationForms(String text) → String