UDocTextIndex class

Properties

fingerprint → String
final
hashCode → int
The hash code for this object.
no setterinherited
indexedPages → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
close() → Future<void>
hasPage(int pageIndex) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPage(int pageIndex) → Future<String?>
toString() → String
A string representation of this object.
inherited
writePage(int pageIndex, String text) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

open(String fingerprint) → Future<UDocTextIndex>