UDocTextPage class

Constructors

UDocTextPage({required int pageIndex, required List<UDocTextRun> runs, required String text, required Size size})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
pageIndex → int
final
runs → List<UDocTextRun>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rectForRange(int start, int end) → Rect?
rectsForRange(int start, int end) → List<Rect>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const UDocTextPage