UDocTextRun class

Constructors

UDocTextRun({required String text, required Rect rect, required bool rtl, required List<UDocGlyph> glyphs, String? fontName, double fontSize = 0, int lineIndex = 0, int blockIndex = 0})
const

Properties

blockIndex → int
final
fontName → String?
final
fontSize → double
final
glyphs → List<UDocGlyph>
final
hashCode → int
The hash code for this object.
no setterinherited
lineIndex → int
final
rect → Rect
final
rtl → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited