UDocValue class

Constructors

UDocValue({UDocState state = UDocState.idle, UDocKind kind = UDocKind.unknown, int pageCount = 0, int pageIndex = 0, UDocMetadata metadata = const UDocMetadata(), UDocPermissions permissions = UDocPermissions.all, UDocViewSettings settings = const UDocViewSettings(), UDocSelection selection = UDocSelection.none, String searchQuery = "", List<UDocSearchHit> searchHits = const <UDocSearchHit>[], int searchHitIndex = -1, bool isSearching = false, bool isBusy = false, double loadedPercent = 0, bool hasUnsavedChanges = false, UDocError? error})
const

Properties

currentHit → UDocSearchHit?
no setter
error → UDocError?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasUnsavedChanges → bool
final
isBusy → bool
final
isReady → bool
no setter
isSearching → bool
final
kind → UDocKind
final
loadedPercent → double
final
metadata → UDocMetadata
final
pageCount → int
final
pageIndex → int
final
permissions → UDocPermissions
final
progress → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchHitIndex → int
final
searchHits → List<UDocSearchHit>
final
searchQuery → String
final
selection → UDocSelection
final
settings → UDocViewSettings
final
state → UDocState
final

Methods

copyWith({UDocState? state, UDocKind? kind, int? pageCount, int? pageIndex, UDocMetadata? metadata, UDocPermissions? permissions, UDocViewSettings? settings, UDocSelection? selection, String? searchQuery, List<UDocSearchHit>? searchHits, int? searchHitIndex, bool? isSearching, bool? isBusy, double? loadedPercent, bool? hasUnsavedChanges, UDocError? error, bool clearError = false}) → UDocValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited