UDocViewSettings class

Constructors

UDocViewSettings({UDocScrollMode scrollMode = UDocScrollMode.verticalContinuous, UDocSpread spread = UDocSpread.none, UDocDirection direction = UDocDirection.ltr, UDocFit fit = UDocFit.width, UDocColorMode colorMode = UDocColorMode.normal, double zoom = 1, double minZoom = 0.25, double maxZoom = 12, double dim = 0, double pageGap = 12, bool cropMargins = false, double tileThreshold = 2.5, double maxRenderScale = 4, int renderAhead = 2, bool keepScreenOn = false, bool showAnnotations = true, bool showForms = true, List<double>? customMatrix})
const

Properties

colorFilter → ColorFilter?
no setter
colorMode → UDocColorMode
final
cropMargins → bool
final
customMatrix → List<double>?
final
dim → double
final
direction → UDocDirection
final
fit → UDocFit
final
hashCode → int
The hash code for this object.
no setterinherited
isHorizontal → bool
no setter
isPaged → bool
no setter
isRtl → bool
no setter
keepScreenOn → bool
final
maxRenderScale → double
final
maxZoom → double
final
minZoom → double
final
pageGap → double
final
renderAhead → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollMode → UDocScrollMode
final
showAnnotations → bool
final
showForms → bool
final
spread → UDocSpread
final
tileThreshold → double
final
zoom → double
final

Methods

copyWith({UDocScrollMode? scrollMode, UDocSpread? spread, UDocDirection? direction, UDocFit? fit, UDocColorMode? colorMode, double? zoom, double? minZoom, double? maxZoom, double? dim, double? pageGap, bool? cropMargins, double? tileThreshold, double? maxRenderScale, int? renderAhead, bool? keepScreenOn, bool? showAnnotations, bool? showForms, List<double>? customMatrix}) → UDocViewSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited