UFileByteSource class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
no setteroverride
isSeekable → bool
no setterinherited
kind → UDocSourceKind
no setteroverride
length → int
no setteroverride
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clampCount(int offset, int count) → int
inherited
close() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int offset, int count) → Future<Uint8List>
override
readAll({int cap = uDocMaxAllocation}) → Future<Uint8List>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

open(String path) → Future<UFileByteSource>