ULruCache<K, V> class

Constructors

ULruCache({required int maxBytes, required int sizeOf(V value), void onEvict(K key, V value)?})

Properties

bytes → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
keys → Iterable<K>
no setter
length → int
no setter
maxBytes → int
final
onEvict → void Function(K key, V value)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeOf → int Function(V value)
final

Methods

clear() → void
containsKey(K key) → bool
get(K key) → V?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek(K key) → V?
put(K key, V value) → void
remove(K key) → V?
removeWhere(bool test(K key)) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited