UMemoryByteSource class
- Inheritance
-
- Object
- UDocByteSource
- UMemoryByteSource
Constructors
- UMemoryByteSource(Uint8List bytes, {String? id})
Properties
- bytes → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isSeekable → bool
-
no setterinherited
- kind → UDocSourceKind
-
no setteroverride
- length → int
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clampCount(
int offset, int count) → int -
inherited
-
close(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
int offset, int count) → Future< Uint8List> -
override
-
readAll(
{int cap = uDocMaxAllocation}) → Future< Uint8List> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited