UEpubBook class

Properties

archive → UEpubArchive
final
chapterCount → int
no setter
coverHref ↔ String?
getter/setter pair
direction ↔ UDocDirection
getter/setter pair
fingerprint → String
final
fixedLayout ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ UDocMetadata
getter/setter pair
final
obfuscatedFonts → Map<String, String>
final
opfDirectory ↔ String
getter/setter pair
opfPath ↔ String
getter/setter pair
resources → Map<String, UEpubResource>
final
resourcesByHref → Map<String, UEpubResource>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spine → List<UEpubSpineItem>
final

Methods

chapter(int index) → Future<UEpubChapter>
close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String href) → String
resource(String href) → Future<Uint8List>
spineIndexFor(String href) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

open({String? path, String? url, Uint8List? bytes, String? asset, Object? blob, Map<String, String>? headers}) → Future<UEpubBook>