UEpubChapter class

Constructors

UEpubChapter({required int spineIndex, required String href, required List<UEpubBlock> blocks, required String title, required String text})
const

Properties

blocks → List<UEpubBlock>
final
hashCode → int
The hash code for this object.
no setterinherited
href → String
final
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spineIndex → int
final
text → String
final
title → String
final

Methods

anchorBlock(String anchor) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited