UEpubController class

Inheritance

Constructors

UEpubController()

Properties

book → UEpubBook?
no setter
documentId → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
highlights → List<UEpubHighlight>
final
isDisposed → bool
no setterinherited
kind → UDocKind
no setteroverride
liveHits → ValueNotifier<List<UDocSearchHit>>
finalinherited
outline ↔ List<UDocOutlineNode>
getter/setter pair
pageCount → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → UDocViewSettings
no setterinherited
stateStream → Stream<UDocValue>
no setterinherited
typography ↔ UEpubTypography
getter/setter pair
value ↔ UDocValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addHighlight(UEpubHighlight highlight) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
chapter(int index) → Future<UEpubChapter>
clearSearch() → void
inherited
clearSelection() → void
inherited
close() → Future<void>
override
dispose() → void
Discards any resources used by the object.
override
emit(UDocValue next) → void
inherited
failWith(UDocError error) → void
inherited
goToPage(int pageIndex) → void
inherited
image(String href) → Future<Uint8List?>
loadTypography() → Future<void>
nextHit() → void
inherited
nextPage() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
open({String? path, String? url, Uint8List? bytes, String? asset, Object? blob, Map<String, String>? headers}) → Future<void>
pageInfo(int pageIndex) → UDocPageInfo
override
previousHit() → void
inherited
previousPage() → void
inherited
removeHighlight(String id) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
renderPage(int pageIndex, {double scale = 1, Rect? clip}) → Future<Picture?>
override
renderThumbnail(int pageIndex, {int maxSize = 240}) → Future<Image?>
override
saveHighlights() → Future<void>
saveProgress({double percent = 0, String? position}) → void
setColorMode(UDocColorMode mode) → void
inherited
setCropMargins(bool crop) → void
inherited
setDim(double dim) → void
inherited
setDirection(UDocDirection direction) → void
inherited
setFit(UDocFit fit) → void
inherited
setScrollMode(UDocScrollMode mode) → void
inherited
setSelection(UDocSelection selection) → void
inherited
setSpread(UDocSpread spread) → void
inherited
setTypography(UEpubTypography next) → void
setZoom(double zoom) → void
inherited
textPage(int pageIndex) → Future<UDocTextPage>
override
toString() → String
A string representation of this object.
inherited
updateSettings(UDocViewSettings settings) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited