UEpubHighlight class

Constructors

UEpubHighlight({required String id, required UEpubPosition position, required String text, required DateTime createdAt, String note = "", int color = 0xFFFFEB3B})
const
UEpubHighlight.fromJson(Map<String, Object?> json)
factory

Properties

color → int
final
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
note → String
final
position → UEpubPosition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited