UEpubPage class

Constructors

UEpubPage({required int spineIndex, required int pageIndex, required List<UEpubBlock> blocks, required int startBlock})
const

Properties

blocks → List<UEpubBlock>
final
hashCode → int
The hash code for this object.
no setterinherited
pageIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spineIndex → int
final
startBlock → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited