UEpubResource class

Constructors

UEpubResource({required String id, required String href, required String mediaType, String properties = ""})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
href → String
final
id → String
final
isContent → bool
no setter
isFont → bool
no setter
isImage → bool
no setter
isStyle → bool
no setter
mediaType → String
final
properties → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited