UEpubSelectorPart class

Constructors

UEpubSelectorPart({String tag = "", String className = "", String id = ""})
const

Properties

className → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
final

Methods

matches(UEpubNode node) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited