UEpubSpan class

Constructors

UEpubSpan({required String text, bool bold = false, bool italic = false, bool underline = false, bool strike = false, bool monospace = false, bool superscript = false, bool subscript = false, Color? color, Color? background, double sizeFactor = 1, String? href, String? anchorId, String? fontFamily})
const

Properties

anchorId → String?
final
background → Color?
final
bold → bool
final
color → Color?
final
fontFamily → String?
final
hashCode → int
The hash code for this object.
no setterinherited
href → String?
final
italic → bool
final
monospace → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeFactor → double
final
strike → bool
final
subscript → bool
final
superscript → bool
final
text → String
final
underline → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited