UEpubStyleSheet class

Constructors

UEpubStyleSheet()

Properties

fontFaces → Map<String, Map<String, String>>
final
hashCode → int
The hash code for this object.
no setterinherited
rules → List<UEpubRule>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

declarationsFor(List<UEpubNode> chain) → Map<String, String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String source) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited