UEpubTypography class

Constructors

UEpubTypography({double fontScale = 1, double lineHeight = 1.6, String? fontFamily, double horizontalMargin = 20, double verticalMargin = 16, bool justify = true, double paragraphSpacing = 8, double letterSpacing = 0, double wordSpacing = 0, bool hyphenate = false})
const
UEpubTypography.fromJson(Map<String, Object?> json)
factory

Properties

baseFontSize → double
no setter
fontFamily → String?
final
fontScale → double
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalMargin → double
final
hyphenate → bool
final
justify → bool
final
letterSpacing → double
final
lineHeight → double
final
paragraphSpacing → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalMargin → double
final
wordSpacing → double
final

Methods

copyWith({double? fontScale, double? lineHeight, String? fontFamily, double? horizontalMargin, double? verticalMargin, bool? justify, double? paragraphSpacing, double? letterSpacing, double? wordSpacing, bool? hyphenate}) → UEpubTypography
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited