UJbig2 class abstract
Constructors
- UJbig2()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Uint8List data, {required int width, required int height, Uint8List? globals}) → Uint8List? -
parseSegments(
Uint8List data) → List< UJbig2Segment>
Constants
- typeImmediateGenericRegion → const int
- typeImmediateLosslessGenericRegion → const int
- typeIntermediateGenericRegion → const int
- typePageInformation → const int