UJbig2Bitmap class

Constructors

UJbig2Bitmap(int width, int height, {int fill = 0})

Properties

data → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

combine(UJbig2Bitmap other, int x0, int y0, int operation) → void
get(int x, int y) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(int x, int y, int value) → void
toPackedRows({bool blackIsOne = true}) → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited