UJbig2GenericRegion class

Constructors

UJbig2GenericRegion({required int width, required int height, required int template, required List<int> at, bool tpgdon = false})

Properties

at → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → int
final
tpgdon → bool
final
width → int
final

Methods

contextFor(UJbig2Bitmap bitmap, int x, int y) → int
decode(UJbig2ArithmeticDecoder decoder, Uint8List contexts) → UJbig2Bitmap
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited