UJbig2Segment class

Constructors

UJbig2Segment({required int number, required int type, required int dataStart, required int dataEnd, required List<int> referred})
const

Properties

dataEnd → int
final
dataStart → int
final
hashCode → int
The hash code for this object.
no setterinherited
number → int
final
referred → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited