UPdfAes class

Constructors

UPdfAes(Uint8List key)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decryptCbc(Uint8List data, {Uint8List? iv, bool stripPadding = true}) → Uint8List
decryptCbcNoPadding(Uint8List data, Uint8List iv) → Uint8List
decryptEcbNoPadding(Uint8List data) → Uint8List
encryptCbc(Uint8List data, Uint8List iv) → Uint8List
encryptCbcNoPadding(Uint8List data, Uint8List iv) → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

inverseSbox → Uint8List
no setter
sbox → Uint8List
no setter