UPdfCodecs class abstract

Constructors

UPdfCodecs()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

ascii85(Uint8List input) → Uint8List
asciiHex(Uint8List input) → Uint8List
deflate(Uint8List input) → Uint8List
inflate(Uint8List input) → Uint8List
lzw(Uint8List input, {int earlyChange = 1}) → Uint8List
predictor(Uint8List data, {required int predictor, required int colors, required int bitsPerComponent, required int columns}) → Uint8List
runLength(Uint8List input) → Uint8List