UPdfDict class

Constructors

UPdfDict(Map<String, Object?> entries)
UPdfDict.empty()

Properties

entries → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
keys → Iterable<String>
no setter
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → UPdfDict
has(String key) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String key) → Object?
operator []=(String key, Object? value) → void