UPdfDocument class

Available extensions

Properties

catalog ↔ UPdfDict?
getter/setter pair
encryption ↔ UPdfEncryption?
getter/setter pair
fingerprint → String
final
firstId ↔ Uint8List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
info ↔ UPdfDict?
getter/setter pair
isEncrypted → bool
no setter
linearized ↔ bool
getter/setter pair
overlay → Map<int, Object?>
final
pageCount → int
no setter
permissions → UDocPermissions
no setter
rebuilt ↔ bool
getter/setter pair
revision ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → UCachedByteSource
final
startXrefOffset ↔ int
getter/setter pair
version ↔ String
getter/setter pair
xref → UPdfXref
final

Methods

clearStaged() → void
close() → Future<void>
decodeStream(UPdfStream stream, {bool decrypt = true}) → Future<UPdfDecodedStream>
destination(Object? value, {int depth = 0}) → Future<UDocDestination?>

Available on UPdfDocument, provided by the UPdfDocumentPages extension

Available on UPdfDocument, provided by the UPdfDocumentPages extension

metadata() → Future<UDocMetadata>

Available on UPdfDocument, provided by the UPdfDocumentPages extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notePageCount(int count) → void
object(UPdfRef ref, {bool decrypt = true}) → Future<Object?>
outline() → Future<List<UDocOutlineNode>>

Available on UPdfDocument, provided by the UPdfDocumentPages extension

page(int index) → Future<UPdfPage?>

Available on UPdfDocument, provided by the UPdfDocumentPages extension

pageContent(UPdfPage page) → Future<Uint8List>

Available on UPdfDocument, provided by the UPdfDocumentPages extension

pageLabel(int index) → Future<String?>

Available on UPdfDocument, provided by the UPdfDocumentPages extension

rawStreamBytes(UPdfStream stream) → Future<Uint8List>
resolve(Object? value, {int depth = 0}) → Future<Object?>
stage(int number, Object? value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromSource(UCachedByteSource source, {String password = ""}) → Future<UPdfDocument>
open({String? path, String? url, Uint8List? bytes, String? asset, Object? blob, Map<String, String>? headers, String password = ""}) → Future<UPdfDocument>