UPdfStream class

Constructors

UPdfStream({required UPdfDict dict, required int rawOffset, required int rawLength, Uint8List? rawBytes, int objectNumber = 0, int generation = 0})

Properties

decoded ↔ Uint8List?
getter/setter pair
dict → UPdfDict
final
generation → int
final
hashCode → int
The hash code for this object.
no setterinherited
objectNumber → int
final
rawBytes → Uint8List?
final
rawLength → int
final
rawOffset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited