UPdfString class

Constructors

UPdfString(Uint8List bytes, {bool hex = false})
const

Properties

bytes → Uint8List
final
date → DateTime?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hex → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited