UPdfXref class

Constructors

UPdfXref()

Properties

entries → Map<int, UPdfXrefEntry>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailer ↔ UPdfDict?
getter/setter pair

Methods

merge(Map<int, UPdfXrefEntry> other) → void
mergeTrailer(UPdfDict? other) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited