UPdfAnnotationInfo class

Constructors

UPdfAnnotationInfo({required int objectNumber, required int pageIndex, required String subtype, required Rect rect, String contents = "", String author = "", DateTime? modified, Color? color})
const

Properties

author → String
final
color → Color?
final
contents → String
final
hashCode → int
The hash code for this object.
no setterinherited
modified → DateTime?
final
objectNumber → int
final
pageIndex → int
final
rect → Rect
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited