UPdfAnnotationSpec class

Constructors

UPdfAnnotationSpec({required UPdfAnnotationStyle style, required Rect rect, List<Rect> quads = const <Rect>[], List<List<Offset>> inkPaths = const <List<Offset>>[], Color color = const Color(0xFFFFEB3B), Color? borderColor, double opacity = 1, double borderWidth = 2, String contents = "", String author = "", String title = "", double fontSize = 12, Color textColor = const Color(0xFF000000), Uint8List? imageBytes, bool rtl = false})
const

Properties

author → String
final
borderColor → Color?
final
borderWidth → double
final
color → Color
final
contents → String
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
imageBytes → Uint8List?
final
inkPaths → List<List<Offset>>
final
opacity → double
final
quads → List<Rect>
final
rect → Rect
final
rtl → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → UPdfAnnotationStyle
final
textColor → Color
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited