UPdfAnnotationStyle enum

Inheritance
Available extensions

Values

highlight → const UPdfAnnotationStyle
underline → const UPdfAnnotationStyle
strikeOut → const UPdfAnnotationStyle
squiggly → const UPdfAnnotationStyle
ink → const UPdfAnnotationStyle
note → const UPdfAnnotationStyle
freeText → const UPdfAnnotationStyle
square → const UPdfAnnotationStyle
circle → const UPdfAnnotationStyle
line → const UPdfAnnotationStyle
arrow → const UPdfAnnotationStyle
stamp → const UPdfAnnotationStyle
redact → const UPdfAnnotationStyle

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UPdfAnnotationStyle>
A constant List of the values in this enum, in order of their declaration.