UPdfComposer class

Constructors

UPdfComposer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageCount → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBlankPage({Size size = const Size(595.28, 841.89)}) → void
addComposedPage(Size size, String content, Map<String, Object?> xobjects) → void
addImagePage(Uint8List encoded, {Size? size, double margin = 0}) → Future<int?>
addPage(UPdfDocument source, int index, {Rect? crop, int? rotate}) → Future<int?>
allocate() → int
build({UDocMetadata? metadata}) → Uint8List
copyForeign(UPdfDocument source, Object? value, Map<int, int> map) → Future<Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(int number, Object? value) → void
streamFor(Uint8List data, {Map<String, Object?> extra = const <String, Object?>{}}) → UPdfStream
toString() → String
A string representation of this object.
inherited
writeTo(String path, {UDocMetadata? metadata}) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited