UPdfEdit class

Available extensions

Constructors

UPdfEdit(UPdfDocument document)

Properties

document → UPdfDocument
final
hasChanges → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
pending → Map<int, Object?>
no setter
pendingCount → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAnnotation(int pageIndex, UPdfAnnotationSpec spec) → Future<int>
addPageNumbers({double fontSize = 10, Color color = const Color(0xFF000000), double margin = 24, int startAt = 1, bool rightAligned = true}) → Future<void>
addTextWatermark(String text, {double fontSize = 48, Color color = const Color(0x33000000), double rotation = 45, List<int>? pages}) → Future<void>
allocate() → int
annotations(int pageIndex) → Future<List<UPdfAnnotationInfo>>
appendContent(int pageIndex, String operators, {Map<String, Object?> extraResources = const <String, Object?>{}}) → Future<void>
buildIncrement() → Future<Uint8List>
buildStream(Uint8List data, {Map<String, Object?> extra = const <String, Object?>{}, bool compress = true}) → UPdfStream
composeCurrent({List<int>? pages, UDocMetadata? metadata}) → Future<Uint8List?>

Available on UPdfEdit, provided by the UPdfEditDocumentOps extension

current(UPdfRef ref) → Future<Object?>
deletePages(List<int> indices) → Future<bool>
discard() → void
duplicatePage(int index) → Future<bool>
exportXfdf() → Future<String>

Available on UPdfEdit, provided by the UPdfEditDocumentOps extension

flattenAnnotations({List<int>? pages, bool widgetsOnly = false}) → Future<int>

Available on UPdfEdit, provided by the UPdfEditDocumentOps extension

flattenPageTree() → Future<List<UPdfRef>>
formFields() → Future<List<UPdfFormField>>
importXfdf(String xml) → Future<int>

Available on UPdfEdit, provided by the UPdfEditDocumentOps extension

insertBlankPage(int at, {Size size = const Size(595.28, 841.89)}) → Future<bool>
missingRequiredFields() → Future<List<String>>

Available on UPdfEdit, provided by the UPdfEditDocumentOps extension

movePage(int from, int to) → Future<bool>
mutablePage(int index) → Future<UPdfDict?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageRef(int index) → Future<UPdfRef?>
peek(int number) → Object?
put(int number, Object? value) → void
putImageObject(Uint8List rgba, int width, int height) → Future<int>
rebuildAppearance(UPdfAnnotationSpec spec) → Future<UPdfStream?>
removeAnnotation(int pageIndex, int objectNumber) → Future<bool>
resetForm() → Future<int>

Available on UPdfEdit, provided by the UPdfEditDocumentOps extension

rotatePage(int index, int degrees) → Future<void>
saveIncrementalTo(String path) → Future<bool>
saveOptimizedTo(String path, {List<int>? pages, UDocMetadata? metadata}) → Future<bool>

Available on UPdfEdit, provided by the UPdfEditDocumentOps extension

saveToBytes({int cap = 256 * 1024 * 1024}) → Future<Uint8List?>
setCropBox(int index, Rect box) → Future<void>
setFieldValue(UPdfFormField field, Object? value) → Future<bool>
setMetadata(UDocMetadata metadata) → Future<void>
setPageOrder(List<UPdfRef> order) → Future<bool>
specOf(int pageIndex, int objectNumber) → Future<UPdfAnnotationSpec?>

Available on UPdfEdit, provided by the UPdfEditAnnotations extension

toString() → String
A string representation of this object.
inherited
updateAnnotation(int pageIndex, int objectNumber, {Rect? rect, Color? color, double? opacity, String? contents, double? borderWidth, double? fontSize}) → Future<bool>

Available on UPdfEdit, provided by the UPdfEditAnnotations extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dateString(DateTime time) → UPdfString
isWinAnsiSafe(String text) → bool
rasterizeImage(Uint8List encoded, {int maxSize = 2048}) → Future<UPdfRaster?>
rasterizeText(String text, {required double width, required double height, double fontSize = 14, Color color = const Color(0xFF000000), bool rtl = false, String? fontFamily, double pixelRatio = 2.5, TextAlign align = TextAlign.start}) → Future<UPdfRaster?>
textString(String value) → UPdfString