UPdfExport class abstract

Constructors

UPdfExport()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

pageImage(UPdfController controller, int pageIndex, {double dpi = 150, bool png = true}) → Future<Uint8List?>
pageImages(UPdfController controller, {List<int>? pages, double dpi = 150}) → Future<List<Uint8List>>
printablePdf(UPdfController controller, {List<int>? pages, double dpi = 150}) → Future<Uint8List?>
shareImages(UPdfController controller, {List<int>? pages, double dpi = 150}) → Future<bool>
sharePrintable(UPdfController controller, {List<int>? pages, double dpi = 150, String fileName = "print.pdf"}) → Future<bool>