UPdfFormField class

Constructors

UPdfFormField({required int objectNumber, required String name, required UDocFieldKind kind, required int pageIndex, required Rect rect, Object? value, List<String> options = const <String>[], bool readOnly = false, bool required = false, int maxLength = 0})
const

Properties

displayValue → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
kind → UDocFieldKind
final
maxLength → int
final
name → String
final
objectNumber → int
final
options → List<String>
final
pageIndex → int
final
readOnly → bool
final
rect → Rect
final
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited