UPdfSerializer class abstract

Constructors

UPdfSerializer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hexString(Uint8List bytes) → List<int>
literalString(Uint8List bytes) → List<int>
name(String value) → String
number(num value) → String
write(BytesBuilder out, Object? value, {UPdfEncryption? encryption, int objectNumber = 0, int generation = 0, int depth = 0}) → void