UPdfCcittDecoder class

Constructors

UPdfCcittDecoder({required int columns, required int rows, required int k, required bool blackIs1, required bool byteAlign})

Properties

blackIs1 → bool
final
byteAlign → bool
final
columns → int
final
hashCode → int
The hash code for this object.
no setterinherited
k → int
final
rows → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List input) → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

blackTable → Map<String, int>
no setter
whiteTable → Map<String, int>
no setter