UPdfCff class

Implemented types

Properties

fontMatrix → List<double>
no setter
glyphCount → int
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isCid → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitsPerEm → int
no setteroverride

Methods

advance(int glyphId) → double
override
glyphForCid(int cid) → int
override
glyphForName(String name) → int
override
glyphForStandardCode(int code) → int
glyphForUnicode(int codePoint) → int
override
glyphPath(int glyphId) → Path?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(Uint8List bytes) → UPdfCff?