UPdfCodespace class

Constructors

UPdfCodespace(int byteLength, int low, int high)
const

Properties

byteLength → int
final
hashCode → int
The hash code for this object.
no setterinherited
high → int
final
low → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(int code) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited