UPdfFont class

Properties

ascent ↔ double
getter/setter pair
baseFont → String
final
charProcs ↔ Map<int, UPdfStream>
getter/setter pair
cidToGid ↔ Map<int, int>?
getter/setter pair
defaultWidth → double
final
descent ↔ double
getter/setter pair
embedded ↔ bool
getter/setter pair
encodingCMap ↔ UPdfCMap?
getter/setter pair
encodingNames ↔ List<String>
getter/setter pair
fontMatrix → List<double>
final
glyphs ↔ UPdfGlyphSource?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isType0 → bool
final
isType3 → bool
final
italicAngle ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → String
final
symbolic → bool
final
type3Resources ↔ UPdfDict?
getter/setter pair
unicodeMap ↔ Map<int, String>
getter/setter pair
vertical ↔ bool
getter/setter pair
widths ↔ Map<int, double>
getter/setter pair

Methods

decode(Uint8List bytes) → List<UPdfCodePoint>
glyphIdFor(UPdfCodePoint point) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathFor(UPdfCodePoint point) → Path?
toString() → String
A string representation of this object.
inherited
unicodeFor(UPdfCodePoint point) → String
widthFor(UPdfCodePoint point) → double

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearCache() → void
load(UPdfDocument document, UPdfDict dict, {String cacheKey = ""}) → Future<UPdfFont>