UPdfFunction class abstract

Implementers

Constructors

UPdfFunction()

Properties

domain → List<double>
no setter
hashCode → int
The hash code for this object.
no setterinherited
range → List<double>?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(List<double> inputs) → List<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

load(UPdfDocument document, Object? value, {int depth = 0}) → Future<UPdfFunction?>