UPdfFunctionArray class

Implemented types

Constructors

UPdfFunctionArray(List<UPdfFunction> functions)
const

Properties

domain → List<double>
no setteroverride
functions → List<UPdfFunction>
final
hashCode → int
The hash code for this object.
no setterinherited
range → List<double>?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(List<double> inputs) → List<double>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited