UPdfGlyphSource class abstract

Implementers

Constructors

UPdfGlyphSource()

Properties

glyphCount → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitsPerEm → int
no setter

Methods

advance(int glyphId) → double
glyphForCid(int cid) → int
glyphForName(String name) → int
glyphForUnicode(int codePoint) → int
glyphPath(int glyphId) → Path?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited