UPdfIndex class

Constructors

UPdfIndex(List<int> offsets, Uint8List data, int endOffset)
const

Properties

count → int
no setter
data → Uint8List
final
endOffset → int
final
hashCode → int
The hash code for this object.
no setterinherited
offsets → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → Uint8List

Static Methods

read(UDocCursor cursor) → UPdfIndex