UPdfPageRenderer class

Constructors

UPdfPageRenderer(UPdfDocument document)

Properties

document → UPdfDocument
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractText(UPdfPage page) → Future<UDocTextPage>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(UPdfPage page, {UPdfRenderOptions options = const UPdfRenderOptions()}) → Future<UPdfRenderResult>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited