UPdfRenderOptions class

Constructors

UPdfRenderOptions({double scale = 1, bool collectText = true, bool drawAnnotations = true, int maxOperations = 2000000, Set<int> hiddenOptionalGroups = const <int>{}})
const

Properties

collectText → bool
final
drawAnnotations → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hiddenOptionalGroups → Set<int>
final
maxOperations → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited