onFilesChanged property
Called with the newly picked files whenever they change.
Implementation
final ValueChanged<List<UFileData>>? onFilesChanged;
Called with the newly picked files whenever they change.
final ValueChanged<List<UFileData>>? onFilesChanged;