UByteReader class

Constructors

UByteReader(Uint8List bytes, {int start = 0, int? end})

Properties

end → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
position → int
no setter
remaining → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ascii(int count) → String
canRead(int count) → bool
guardedLength(int declared, {int cap = uMaxTagAllocation}) → int
indexOfByte(int value, {int from = -1}) → int
latin1Trimmed(int count) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek(int count) → Uint8List
seek(int absolute) → void
skip(int count) → void
syncSafe32() → int
take(int count) → Uint8List
takeGuarded(int declared, {int cap = uMaxTagAllocation}) → Uint8List
toString() → String
A string representation of this object.
inherited
u16be() → int
u16le() → int
u24be() → int
u32be() → int
u32le() → int
u64be() → int
u8() → int
window(int count) → UByteReader

Operators

operator ==(Object other) → bool
The equality operator.
inherited