UBytesSource class final

Inheritance

Constructors

UBytesSource(Uint8List data, {String? id, String? mimeType, UMediaMetadata? metadata})

Properties

data → Uint8List
final
drm → UDrmConfig?
finalinherited
endPosition → Duration?
finalinherited
externalSubtitles → List<UExternalSubtitle>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
kind → UMediaSourceKind
no setteroverride
metadata → UMediaMetadata?
finalinherited
mimeType → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startPosition → Duration?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited