UDashAdaptationSet class

Constructors

UDashAdaptationSet({required List<UDashRepresentation> representations, String? contentType, String? mimeType, String? language, List<String> roles = const <String>[], List<UDashContentProtection> protections = const <UDashContentProtection>[], UDashSegmentTemplate? template, String? baseUrl})
const

Properties

baseUrl → String?
final
contentType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
language → String?
final
mimeType → String?
final
protections → List<UDashContentProtection>
final
representations → List<UDashRepresentation>
final
roles → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → UDashSegmentTemplate?
final
trackType → UMediaTrackType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited