UDashContentProtection class
Constructors
- UDashContentProtection({required String schemeIdUri, String? value, String? defaultKid, String? pssh})
-
const
Properties
- defaultKid → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pssh → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → UDrmScheme?
-
no setter
- schemeIdUri → String
-
final
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited