UDashSegmentRef class

Constructors

UDashSegmentRef({required String url, required Duration start, required Duration duration, int? number, int? rangeStart, int? rangeEnd})
const

Properties

duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
number → int?
final
rangeEnd → int?
final
rangeStart → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Duration
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited