UMediaController class

Inheritance

Constructors

UMediaController({UMediaKind kind = UMediaKind.video, UMediaConfig config = const UMediaConfig()})

Properties

activeCues → ValueNotifier<List<USubtitleCue>>
final
audioSpectrum → ValueNotifier<List<double>>
final
config → UMediaConfig
no setter
currentIndex → int
no setter
currentSource → UMediaSource?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasNext → bool
no setter
hasPrevious → bool
no setter
isCreated → bool
no setter
kind → UMediaKind
final
playerId → int?
no setter
positionStream → Stream<Duration>
no setter
queue → List<UMediaSource>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateStream → Stream<UMediaValue>
no setter
subtitleDelay → Duration
no setter
subtitles → USubtitleData?
no setter
textureId → int?
no setter
value ↔ UMediaValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addToQueue(UMediaSource source) → Future<void>
applyDuck(bool ducking) → Future<void>
clearSubtitles() → void
dispose() → void
Discards any resources used by the object.
override
enterPip({double? aspectRatio}) → Future<void>
exitPip() → Future<void>
insertNext(UMediaSource source) → Future<void>
jumpTo(int index) → Future<void>
loadSubtitle(UExternalSubtitle subtitle) → Future<void>
loadSubtitleData(USubtitleData data) → Future<void>
moveInQueue(int from, int to) → Future<void>
next() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
open(UMediaSource source, {bool autoPlay = false}) → Future<void>
openQueue(List<UMediaSource> sources, {int startIndex = 0, bool autoPlay = false}) → Future<void>
pause() → Future<void>
pauseForInterruption() → Future<void>
play() → Future<void>
playPause() → Future<void>
previous({Duration restartThreshold = const Duration(seconds: 3)}) → Future<void>
removeAt(int index) → Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resumeAfterInterruption() → Future<void>
screenshot() → Future<Uint8List?>
seek(Duration position, {bool precise = true}) → Future<void>
seekBy(Duration delta, {bool precise = true}) → Future<void>
seekToProgress(double progress) → Future<void>
selectTrack(UMediaTrack track) → Future<void>
setAudioDelay(Duration delay) → Future<void>
setAutoQuality() → Future<void>
setMaxHeight(int height) → Future<void>
setMuted(bool muted) → Future<void>
setNotification({required UMediaMetadata metadata, bool showSeekBar = true}) → Future<void>
setRepeat(URepeatMode mode) → Future<void>
setShuffle(bool enabled) → Future<void>
setSpeed(double speed, {bool preservePitch = true}) → Future<void>
setSubtitleDelay(Duration delay) → void
setSubtitleScale(double scale) → void
setSubtitlesEnabled(bool enabled) → void
setVolume(double volume) → Future<void>
startVisualizer({int bands = 48}) → Future<void>
stepFrame({int frames = 1}) → Future<void>
stop() → Future<void>
stopVisualizer() → Future<void>
toggleMute() → Future<void>
toggleShuffle() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited