UMediaError class

Implemented types

Constructors

UMediaError({required UMediaErrorCode code, required String message, String? detail, String? platformCode, String? sourceId})
const
UMediaError.fromMap(Map<Object?, Object?> map)
factory

Properties

code → UMediaErrorCode
final
detail → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isRecoverable → bool
no setter
message → String
final
platformCode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited