UMediaLibrary class

Inheritance

Properties

albums → List<String>
no setter
artists → List<String>
no setter
count → int
no setter
favorites → Set<String>
no setter
favoriteTracks → List<UTrackRecord>
no setter
folders → List<String>
no setter
genres → List<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isLoaded → bool
no setter
isScanning → bool
no setter
mostPlayed → List<UTrackRecord>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scannedCount → int
no setter
scanTotal → int
no setter
tracks → List<UTrackRecord>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
byAlbum(String album) → List<UTrackRecord>
byArtist(String artist) → List<UTrackRecord>
byFolder(String folder) → List<UTrackRecord>
clear() → Future<void>
dispose() → void
Discards any resources used by the object.
inherited
groupValues(String selector(UTrackRecord record)) → List<String>
isFavorite(String path) → bool
load() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
playCount(String path) → int
registerPlay(String path) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
save() → Future<void>
scan(List<String> roots, {bool replace = true, void onProgress(int scanned, int total)?}) → Future<void>
sorted(List<UTrackRecord> input, ULibrarySort sort, {bool descending = false}) → List<UTrackRecord>
toggleFavorite(String path) → void
toString() → String
A string representation of this object.
inherited
where(bool test(UTrackRecord record)) → List<UTrackRecord>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → UMediaLibrary
final