UMediaSession class abstract final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

controllers → List<UMediaController>
no setter
holder → UMediaController?
no setter

Static Methods

abandonFocus(UMediaController controller) → Future<void>
pauseAll() → Future<void>
register(UMediaController controller) → void
requestFocus(UMediaController requester) → Future<bool>
unregister(UMediaController controller) → void