UXmlNode class

Constructors

UXmlNode(String name, Map<String, String> attributes, List<UXmlNode> children, String text)

Properties

attributes → Map<String, String>
final
children → List<UXmlNode>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

attr(String key) → String?
child(String childName) → UXmlNode?
childrenNamed(String childName) → List<UXmlNode>
descendants(String childName) → Iterable<UXmlNode>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited