UMediaNotes class abstract final

Shortcuts for media notes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

addAtCurrentTime(UMediaNotesController notes, UMediaController controller, {bool pause = true}) → Future<UMediaNote?>
Pauses (optionally), asks for the note text and pins it to the current position.
showPanel(UMediaNotesController notes, UMediaController controller) → Future<void>
Opens the notes panel in a bottom sheet.