onChanged property
Called with the new value when the user changes it.
Implementation
final void Function(UMediaNotesController controller)? onChanged;
Called with the new value when the user changes it.
final void Function(UMediaNotesController controller)? onChanged;