UProcessController class
Constructors
- UProcessController({VoidCallback? onCompleted})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCompleted → VoidCallback?
-
final
- processId ↔ String
-
getter/setter pair
-
processStep
→ Rxn<
UProcessStepGet> -
final
- processStepSend ↔ UProcessStepSend
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → RxState
-
final
Methods
-
dismiss(
) → void -
init(
{required String processId}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → void -
send(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited