UArExperiences class abstract

Constructors

UArExperiences()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

captureObject({UArObjectCaptureDetail detail = UArObjectCaptureDetail.reduced}) → Future<UArObjectCaptureResult?>
codes({required Widget cardBuilder(BuildContext context, String code, UArProjection projection)}) → Future<void>
images({required List<UArImageTarget> targets}) → Future<void>
measure({UArMeasureUnit unit = UArMeasureUnit.metric, bool closeShape = false}) → Future<void>
place({required List<UArPlaceable> items, int initialItem = 0, UArConfig config = const UArConfig(reticle: true), UArSceneOptions options = const UArSceneOptions(), List<UArOverlay> overlays = const <UArOverlay>[], UArLabels labels = const UArLabels(), UArStyle style = const UArStyle(), void onPlaced(UArPlacedItem placed)?}) → Future<void>
Lets the user place products / furniture / art in their space.
places({required List<UArPlace> places, void onPlaceTap(UArPlace place)?, double maxDistance = 800}) → Future<void>
scanRoom() → Future<UArRoomScanResult?>
tryOn({required List<UArTryOnItem> items, int initialIndex = 0}) → Future<void>
viewProduct({required UArSource source, UArSource? iosSource, String? title, List<UArHotspot> hotspots = const <UArHotspot>[], UArLabels labels = const UArLabels()}) → Future<void>
A full-screen 3D product viewer with a "View in AR" button.