showCloseButton property
Shows a close button over the error screens, which otherwise cover the page.
Implementation
final bool showCloseButton;
Shows a close button over the error screens, which otherwise cover the page.
final bool showCloseButton;