UArHotspot class

A point of interest on a model, placed in fractions of its bounding box: (0, 0.5, 0) is the top centre, (-0.5, 0, 0.5) the middle of the front-left edge.

Constructors

UArHotspot({required String id, required UArVector3 position, required Widget builder(BuildContext context, UArProjection projection), VoidCallback? onTap})
const

Properties

builder → Widget Function(BuildContext context, UArProjection projection)
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
onTap → VoidCallback?
final
position → UArVector3
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited