UArLabels class
Optional label overrides; anything left null falls back to l10n.
Constructors
- UArLabels({String? unsupported, String? installRequired, String? install, String? permission, String? locationPermission, String? openSettings, String? startAr, String? viewInYourSpace, String? viewInAr, String? loadingModel, String? loadFailed, String? scanning, String? tooFast, String? moreDetail, String? tooDark, String? relocalizing, String? findSurface, String? tapToPlace, String? gestures, String? chooseItem, String? noPlaces, String? waitingForLocation, String? calibrateCompass, String? tapToAddPoint, String? lookAtCamera, String? pointAtImage, String? pointAtCode, String? recording})
-
const
Properties
- calibrateCompass → String?
-
final
- chooseItem → String?
-
final
- findSurface → String?
-
final
- gestures → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- install → String?
-
final
- installRequired → String?
-
final
- loadFailed → String?
-
final
- loadingModel → String?
-
final
- locationPermission → String?
-
final
- lookAtCamera → String?
-
final
- moreDetail → String?
-
final
- noPlaces → String?
-
final
- openSettings → String?
-
final
- permission → String?
-
final
- pointAtCode → String?
-
final
- pointAtImage → String?
-
final
- recording → String?
-
final
- relocalizing → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanning → String?
-
final
- startAr → String?
-
final
- tapToAddPoint → String?
-
final
- tapToPlace → String?
-
final
- tooDark → String?
-
final
- tooFast → String?
-
final
- unsupported → String?
-
final
- viewInAr → String?
-
final
- viewInYourSpace → String?
-
final
- waitingForLocation → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited