onChanged property
Called with the new value when the user changes it.
Implementation
final void Function(List<UArVector3> points, double total, double area)? onChanged;
Called with the new value when the user changes it.
final void Function(List<UArVector3> points, double total, double area)? onChanged;