UArPlace class

Constructors

UArPlace({required String id, required double latitude, required double longitude, required String title, String? subtitle, String? imageUrl, IconData? icon, double heightAboveGround = 2, UArSource? model, double modelSize = 1.5, Map<String, Object?> data = const <String, Object?>{}})
const

Properties

data → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
heightAboveGround → double
Where the card floats, in metres above the ground.
final
icon → IconData?
final
id → String
final
imageUrl → String?
final
latitude → double
final
longitude → double
final
model → UArSource?
Optional 3D pin or sign drawn at the place.
final
modelSize → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → String?
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited