onSurfaceTap property
Called for taps on surfaces when nothing is being placed.
Implementation
final void Function(UArHitResult hit)? onSurfaceTap;
Called for taps on surfaces when nothing is being placed.
final void Function(UArHitResult hit)? onSurfaceTap;