overlayBuilder property
Anything else drawn over the view, below the built-in chrome.
Implementation
final Widget Function(BuildContext context, UArController controller)? overlayBuilder;
Anything else drawn over the view, below the built-in chrome.
final Widget Function(BuildContext context, UArController controller)? overlayBuilder;