shareSnapshots property
Opens the share sheet after a snapshot or recording when no callback is given.
Implementation
final bool shareSnapshots;
Opens the share sheet after a snapshot or recording when no callback is given.
final bool shareSnapshots;