UArStyle class

Colours and shapes of the built-in chrome. Null values follow the app theme.

Constructors

UArStyle({Color? accentColor, Color? surfaceColor, Color? onSurfaceColor, Color? hintBackground, Color? hintForeground, double borderRadius = 16, EdgeInsets padding = const EdgeInsets.all(16), bool blur = true})
const

Properties

accentColor → Color?
final
blur → bool
final
borderRadius → double
final
hashCode → int
The hash code for this object.
no setterinherited
hintBackground → Color?
final
hintForeground → Color?
final
onSurfaceColor → Color?
final
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surfaceColor → Color?
final

Methods

accent(BuildContext context) → Color
hintBg(BuildContext context) → Color
hintFg(BuildContext context) → Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSurface(BuildContext context) → Color
surface(BuildContext context) → Color
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited