UArTryOnItem class

Constructors

UArTryOnItem({required String id, required String title, required UArSource source, UArSource? iosSource, Widget? thumbnail, UArVector3 position = UArVector3.zero, UArQuaternion rotation = UArQuaternion.identity, double? fitSize, UArVector3 scale = UArVector3.one})
const

Properties

fitSize → double?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
iosSource → UArSource?
final
position → UArVector3
Offset from the centre of the head: +Y up, -Z out of the face on both platforms.
final
rotation → UArQuaternion
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → UArVector3
final
source → UArSource
final
thumbnail → Widget?
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited