isEmpty property
Decides "no data"; lists, maps and strings are checked automatically when null.
Implementation
final bool Function(T data)? isEmpty;
Decides "no data"; lists, maps and strings are checked automatically when null.
final bool Function(T data)? isEmpty;