Barcode1D class abstract

Inheritance
Implementers

Constructors

Barcode1D()
const

Properties

charSet Iterable<int>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
maxLength int
no setterinherited
minLength int
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(int data, int count) Iterable<bool>
convert(String data) Iterable<bool>
getHeight(int index, int count, double width, double height, double fontHeight, double textPadding, bool drawText) double
getText(String data) String
isValid(String data) bool
inherited
isValidBytes(Uint8List data) bool
inherited
make(String data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
inherited
makeBytes(Uint8List data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
override
makeText(String data, double width, double height, double fontHeight, double textPadding, double lineWidth) Iterable<BarcodeElement>
marginLeft(bool drawText, double width, double height, double fontHeight, double textPadding) double
marginRight(bool drawText, double width, double height, double fontHeight, double textPadding) double
marginTop(bool drawText, double width, double height, double fontHeight, double textPadding) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHex(String data) String
toString() String
A string representation of this object.
inherited
toSvg(String data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
inherited
toSvgBytes(Uint8List data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
inherited
verify(String data) → void
inherited
verifyBytes(Uint8List data) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultTextPadding → const double