Barcode2DMatrix class

Constructors

Barcode2DMatrix(int width, int height, double ratio, Iterable<bool> pixels)
const
Barcode2DMatrix.fromXY(int width, int height, double ratio, bool isDark(int x, int y))
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
pixels Iterable<bool>
final
ratio double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited