BarcodeElement class

Implementers

Constructors

BarcodeElement({required double left, required double top, required double width, required double height})
const

Properties

bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
final
left double
final
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited