BarcodePDF417 class

Inheritance

Constructors

BarcodePDF417(Pdf417SecurityLevel securityLevel, double moduleHeight, double preferredRatio)
const

Properties

charSet Iterable<int>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
maxLength int
no setteroverride
minLength int
no setterinherited
moduleHeight double
final
name String
no setteroverride
preferredRatio double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityLevel Pdf417SecurityLevel
final

Methods

convert(Uint8List data) Barcode2DMatrix
override
isValid(String data) bool
inherited
isValidBytes(Uint8List data) bool
inherited
make(String data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
inherited
makeBytes(Uint8List data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHex(String data) String
inherited
toString() String
A string representation of this object.
inherited
toSvg(String data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
inherited
toSvgBytes(Uint8List data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
inherited
verify(String data) → void
inherited
verifyBytes(Uint8List data) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited