BarcodeType enum

Inheritance
Available extensions

Values

codeITF16 → const BarcodeType
codeITF14 → const BarcodeType
codeEAN13 → const BarcodeType
codeEAN8 → const BarcodeType
codeEAN5 → const BarcodeType
codeEAN2 → const BarcodeType
codeISBN → const BarcodeType
code39 → const BarcodeType
code93 → const BarcodeType
codeUPCA → const BarcodeType
codeUPCE → const BarcodeType
code128 → const BarcodeType
gS128 → const BarcodeType
telepen → const BarcodeType
qrCode → const BarcodeType
codabar → const BarcodeType
pdf417 → const BarcodeType
dataMatrix → const BarcodeType
aztec → const BarcodeType
rm4scc → const BarcodeType
postnet → const BarcodeType
itf → const BarcodeType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BarcodeType>
A constant List of the values in this enum, in order of their declaration.