BarcodeUpcE class

Inheritance

Constructors

BarcodeUpcE(bool fallback)
const

Properties

charSet Iterable<int>
no setterinherited
fallback bool
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int
no setteroverride
minLength int
no setteroverride
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(int data, int count) Iterable<bool>
inherited
checkLength(String data, int length) String
inherited
checkSumModulo10(String data) String
inherited
checkSumModulo11(String data) String
inherited
convert(String data) Iterable<bool>
override
getHeight(int index, int count, double width, double height, double fontHeight, double textPadding, bool drawText) double
override
getText(String data) String
inherited
isValid(String data) bool
inherited
isValidBytes(Uint8List data) bool
inherited
make(String data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
inherited
makeBytes(Uint8List data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
inherited
makeText(String data, double width, double height, double fontHeight, double textPadding, double lineWidth) Iterable<BarcodeElement>
override
marginLeft(bool drawText, double width, double height, double fontHeight, double textPadding) double
override
marginRight(bool drawText, double width, double height, double fontHeight, double textPadding) double
override
marginTop(bool drawText, double width, double height, double fontHeight, double textPadding) double
inherited
normalize(String data) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHex(String data) String
inherited
toString() String
A string representation of this object.
inherited
toSvg(String data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
inherited
toSvgBytes(Uint8List data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
inherited
upcaToUpce(String data) String
upceToUpca(String data) String
verify(String data) → void
inherited
verifyBytes(Uint8List data) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited