MeCard class

Constructors

MeCard({String type = "MECARD", List<MeTuple> fields = const <MeTuple>[]})
const
MeCard.contact({String? name, String? reading, String? tel, List<String>? tels, String? videophone, String? email, List<String>? emails, String? memo, DateTime? birthday, String? address, String? url, List<String>? urls, String? nickname})
factory
MeCard.wifi({required String ssid, String type = "WPA", String? password, bool hidden = false})
factory

Properties

fields List<MeTuple>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited