MeTuple class

Constructors

MeTuple(String key, String val)
const
MeTuple.bool(String key, bool val)
factory
MeTuple.date(String key, DateTime val)
factory
MeTuple.sub(String key, Iterable<String> val)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
val String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited