Pdf417SecurityLevel enum

Inheritance
Available extensions

Values

level0 → const Pdf417SecurityLevel
level1 → const Pdf417SecurityLevel
level2 → const Pdf417SecurityLevel
level3 → const Pdf417SecurityLevel
level4 → const Pdf417SecurityLevel
level5 → const Pdf417SecurityLevel
level6 → const Pdf417SecurityLevel
level7 → const Pdf417SecurityLevel
level8 → const Pdf417SecurityLevel

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Pdf417SecurityLevel>
A constant List of the values in this enum, in order of their declaration.