QrAlphaNumeric class final

Implemented types

Constructors

QrAlphaNumeric.fromString(String alphaNumeric)
factory

Properties

bitLength int
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
length int
no setteroverride
mode QrMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(QrBitBuffer buffer) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

encodeArray List<int?>
final
validationRegex RegExp
final

Constants

alphaNumTable → const String