QrCode class final

Constructors

QrCode({required QrPayload payload, QrErrorCorrectLevel errorCorrectLevel = QrErrorCorrectLevel.medium, int minTypeNumber = 1})
factory

Properties

errorCorrectLevel → QrErrorCorrectLevel
final
hashCode → int
The hash code for this object.
no setterinherited
moduleCount → int
final
payload → QrPayload
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeNumber → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited