QrDatum class abstract interface

Implementers

Properties

bitLength int
no setter
hashCode int
The hash code for this object.
no setterinherited
length int
no setter
mode QrMode
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(QrBitBuffer buffer) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toDatums(String data) List<QrDatum>