QrMode enum

Inheritance
Available extensions

Values

numeric → const QrMode
const QrMode(1)
alphaNumeric → const QrMode
const QrMode(2)
byte → const QrMode
const QrMode(4)
kanji → const QrMode
const QrMode(8)
eci → const QrMode
const QrMode(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

getLengthBits(int type) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QrMode>
A constant List of the values in this enum, in order of their declaration.