QrPayload class final

Available extensions

Constructors

QrPayload()
QrPayload.fromString(String data)
factory
QrPayload.fromTypedData(TypedData data)
factory

Properties

dataList List<QrDatum>

Available on QrPayload, provided by the QrPayloadInternal extension

no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAlphaNumeric(String alphaNumeric) → void
addECI(QrEciValue eciValue) → void
addNumeric(String numberString) → void
addString(String data) → void
addTypedData(TypedData data) → void
calculateRequiredBits(int typeNumber) int

Available on QrPayload, provided by the QrPayloadInternal extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited