QrPolynomial class final

Constructors

QrPolynomial(List<int> thing, int shift)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

mod(QrPolynomial e) → QrPolynomial
multiply(QrPolynomial e) → QrPolynomial
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → int