QrRsBlock class final

Properties

dataCount → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getRSBlocks(int typeNumber, QrErrorCorrectLevel errorCorrectLevel) → List<QrRsBlock>
getTotalDataBits(int typeNumber, QrErrorCorrectLevel errorCorrectLevel) → int