QrValidationResult class final
Constructors
- QrValidationResult.fromPayload({required QrPayload payload, required int typeNumber, required QrErrorCorrectLevel errorCorrectLevel})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
no setter
- qrCode → QrCode?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validErrorCorrectLevels
→ List<
QrErrorCorrectLevel> -
final
-
validTypeNumbers
→ List<
int> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited