UBarcode class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- UBarcode
- Available extensions
Constructors
-
UBarcode({required String value, UBarcodeType type = UBarcodeType.qrCode, Color? barColor, Color? backgroundColor, List<
Color> ? gradientColors, AlignmentGeometry gradientBegin = Alignment.centerLeft, AlignmentGeometry gradientEnd = Alignment.centerRight, UBarcodeModuleShape moduleShape = UBarcodeModuleShape.square, double cornerRadiusRatio = 0.3, bool showValue = false, double textSpacing = 8, TextStyle? textStyle, double quietZone = 0, UErrorCorrectionLevel? errorCorrectionLevel, int? qrCodeVersion, int? module, bool? enableCheckSum, Uint8List? logoBytes, double logoSizeRatio = 0.2, double? width, double? height, Key? key}) -
const
Properties
- backgroundColor → Color?
-
final
- barColor → Color?
-
final
- cornerRadiusRatio → double
-
final
- enableCheckSum → bool?
-
final
- errorCorrectionLevel → UErrorCorrectionLevel?
-
final
- gradientBegin → AlignmentGeometry
-
final
-
gradientColors
→ List<
Color> ? -
final
- gradientEnd → AlignmentGeometry
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- logoBytes → Uint8List?
-
final
- logoSizeRatio → double
-
final
- module → int?
-
final
- moduleShape → UBarcodeModuleShape
-
final
- qrCodeVersion → int?
-
final
- quietZone → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showValue → bool
-
final
- textSpacing → double
-
final
- textStyle → TextStyle?
-
final
- type → UBarcodeType
-
final
- value → String
-
final
- width → double?
-
final
Methods
-
alignAtBottomCenter(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtBottomLeft(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtBottomRight(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtCenter(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtCenterLeft(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtCenterRight(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtLERP(
Alignment a, Alignment b, double t, {Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtTopCenter(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtTopLeft(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignAtTopRight(
{Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
alignXY(
double x, double y, {Key? key, double? heightFactor, double? widthFactor}) → Align -
Available on Widget, provided by the WidgetsExtension extension
-
card(
{Color? backgroundColor, double? elevation, EdgeInsets? margin}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
container(
{double? width, double? height, Alignment? alignment, Color? backgroundColor, double borderWidth = 1, double radius = 1, Color borderColor = Colors.transparent, EdgeInsets? padding, EdgeInsets? margin, BoxConstraints? constraints}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< UBarcode> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
fadeSlideIn(
{int milliseconds = 1000, double offset = 24}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
fit(
{Alignment alignment = Alignment.center}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
form(
GlobalKey< FormState> key) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
ltr(
) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDoubleTap(
GestureTapCallback? onPressed) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
onLongPress(
GestureTapCallback? onPressed) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
onPress(
VoidCallback onTap, {double pressedScale = 0.9, Duration duration = const Duration(milliseconds: 120)}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
onTap(
GestureTapCallback? onPressed) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
onTapInk(
GestureTapCallback? onPressed) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
pAll(
double padding) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
pOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
position(
{double? left, double? top, double? right, double? bottom, double? width, double? height}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
pSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
rotate(
double scale) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
rtl(
) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
safeArea(
) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
scale(
double scale) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
scrollable(
{Axis scrollDirection = Axis.vertical}) → Widget -
Available on Widget, provided by the WidgetsExtension extension
-
showMenus(
List< PopupMenuEntry< items) → Widgetint> > -
Available on Widget, provided by the WidgetsExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
translate(
Offset offset) → Widget -
Available on Widget, provided by the WidgetsExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isValid(
String value, UBarcodeType type) → bool -
toPng(
{required String value, UBarcodeType type = UBarcodeType.qrCode, double width = 512, double height = 512, double pixelRatio = 1, Color barColor = const Color(0xFF000000), Color background = const Color(0xFFFFFFFF), List< Color> ? gradientColors, AlignmentGeometry gradientBegin = Alignment.centerLeft, AlignmentGeometry gradientEnd = Alignment.centerRight, UBarcodeModuleShape moduleShape = UBarcodeModuleShape.square, double cornerRadiusRatio = 0.3, bool showValue = false, double textSpacing = 8, double quietZone = 0, UErrorCorrectionLevel errorCorrectionLevel = UErrorCorrectionLevel.low, int? qrCodeVersion}) → Future<Uint8List?> -
toSvg(
{required String value, UBarcodeType type = UBarcodeType.qrCode, double width = 200, double height = 80, bool showValue = false, UErrorCorrectionLevel errorCorrectionLevel = UErrorCorrectionLevel.low, int? qrCodeVersion}) → String