UCandle class

One open/high/low/close candle for financial charts.

Constructors

UCandle({required double open, required double high, required double low, required double close, String? label})
const

Properties

bullish bool
no setter
close double
final
hashCode int
The hash code for this object.
no setterinherited
high double
final
label String?
final
low double
final
open double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited