UChartPoint class

One (x, y) point; size sets the bubble size in bubble charts. UChartPoint(x: 1, y: 3)

Constructors

UChartPoint({required double x, required double y, double? size})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
Bubble size (bubble charts only).
final
x → double
X value.
final
y → double
Y value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited