UPointSeries class
A named collection of free points sharing color, for scatter/bubble charts.
Constructors
-
UPointSeries({required List<
UChartPoint> points, String? name, Color? color}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited