UEpub class abstract

EPUB shortcuts: metadata, cover image and full text; pure Dart, all platforms. await UEpub.cover(url: url)

Constructors

UEpub()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

cover({String? filePath, Uint8List? bytes, String? url}) → Future<Uint8List?>
Cover image bytes.
extractText({String? filePath, Uint8List? bytes, String? url}) → Future<String>
All text of the book.
info({String? filePath, Uint8List? bytes, String? url}) → Future<UDocMetadata?>
Title, author, language and other metadata.
show({String? filePath, Uint8List? bytes, String? url, String? asset, int initialChapter = 0, String? title, String? annotationData, void onAnnotationsChanged(String href)?, bool allowCopy = true, bool secure = false, UDocWatermark? watermark}) → Future<void>
Pushes a full-screen reader with every feature enabled.