enableDrawing property
Pen, highlighter, shapes, text boxes and notes drawn over paragraphs; saved in the annotation string.
Implementation
final bool enableDrawing;
Pen, highlighter, shapes, text boxes and notes drawn over paragraphs; saved in the annotation string.
final bool enableDrawing;