UGaugeStyle class

Shared look of every gauge; null fields follow the theme.

Constructors

UGaugeStyle({Color? trackColor, Color? fillColor, Color? needleColor, Color? tickColor, Color? labelColor, Color? valueColor, double? thickness, bool showTicks = true, bool showLabels = true, bool showValue = true, bool animate = true, Duration animationDuration = const Duration(milliseconds: 1100), Curve animationCurve = Curves.easeOutCubic})
const

Properties

animate → bool
Animates changes.
final
animationCurve → Curve
Needle/fill animation curve.
final
animationDuration → Duration
Length of the animation.
final
fillColor → Color?
Fill color.
final
hashCode → int
The hash code for this object.
no setterinherited
labelColor → Color?
Label color.
final
needleColor → Color?
Needle color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLabels → bool
Draws tick labels.
final
showTicks → bool
Draws ticks.
final
showValue → bool
Shows the value text.
final
thickness → double?
Track thickness.
final
tickColor → Color?
Tick color.
final
trackColor → Color?
Background track color.
final
valueColor → Color?
Color of the value text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited