UCropAspectRatio class

Aspect ratio option shown in the cropper toolbar. A null ratio means the crop box can be resized freely.

Constructors

UCropAspectRatio(String label, double? ratio)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
final
ratio double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited