components/u_list_editor library

Classes

UListEditor<T>
Edits a list of items: one card per item with a text field per fields entry, a delete button and an add button. toItem builds an item from a row's trimmed texts (in fields order); returning null leaves the row out.
UListEditorField<T>
One text field of a UListEditor row.