UEqualizerState class

Constructors

UEqualizerState({bool available = false, bool enabled = false, List<UEqualizerBand> bands = const <UEqualizerBand>[], List<String> presets = const <String>[], String? preset, double bassBoost = 0, double virtualizer = 0, double loudness = 0})
const
UEqualizerState.fromMap(Map<Object?, Object?> map)
factory

Properties

available → bool
final
bands → List<UEqualizerBand>
final
bassBoost → double
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
loudness → double
final
preset → String?
final
presets → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
virtualizer → double
final

Methods

copyWith({bool? enabled, List<UEqualizerBand>? bands, String? preset, double? bassBoost, double? virtualizer, double? loudness}) → UEqualizerState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited