UNumericKeyboardAction class

An extra button on the numeric keyboard (e.g. "Pay").

Constructors

UNumericKeyboardAction({required VoidCallback onTap, VoidCallback? onLongPress, String? label, IconData? icon, Widget? child, int flex = 1, Color? backgroundColor, Color? foregroundColor, double? borderRadius, double? fontSize, FontWeight? fontWeight, bool enabled = true})
const

Properties

backgroundColor → Color?
Background color.
final
borderRadius → double?
Corner radius.
final
child → Widget?
The widget inside.
final
enabled → bool
False disables interaction and greys it out.
final
flex → int
Width share among action buttons.
final
fontSize → double?
Font size.
final
fontWeight → FontWeight?
Font weight.
final
foregroundColor → Color?
Text/icon color.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
Icon shown with it.
final
label → String?
Label text.
final
onLongPress → VoidCallback?
Called on long press.
final
onTap → VoidCallback
Called when tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited