UPdf class abstract

Constructors

UPdf()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

extractText({String? filePath, Uint8List? bytes, String? url, String password = "", int startPage = 0, int endPage = -1}) → Future<String>
info({String? filePath, Uint8List? bytes, String? url, String password = ""}) → Future<UDocMetadata?>
open({String? base64Pdf, Uint8List? bytes, String? url, String? filePath, String? asset, String password = "", int initialPage = 0}) → Future<void>
show({String? base64Pdf, Uint8List? bytes, String? url, String? filePath, String? asset, String password = "", int initialPage = 0}) → Future<void>