annotationData property
Previously exported annotations (e.g. from a server); the newest of this and the local copy wins.
Implementation
final String? annotationData;
Previously exported annotations (e.g. from a server); the newest of this and the local copy wins.
final String? annotationData;