drawController property
Tool/style state for drawing. Created internally when null; pass one with an active tool to open the viewer in drawing mode.
Implementation
final UDocDrawController? drawController;
Tool/style state for drawing. Created internally when null; pass one with an active tool to open the viewer in drawing mode.
final UDocDrawController? drawController;