enableDrawing property
Pen, highlighter, shapes, text boxes and sticky notes drawn over the pages. They are saved in the annotation string with the highlights.
Implementation
final bool enableDrawing;
Pen, highlighter, shapes, text boxes and sticky notes drawn over the pages. They are saved in the annotation string with the highlights.
final bool enableDrawing;