geometryKey constant
String
const geometryKey
Markups whose rects were computed with older text geometry are re-placed from their text.
Implementation
static const String geometryKey = "gv";
Markups whose rects were computed with older text geometry are re-placed from their text.
static const String geometryKey = "gv";