activeLink method
The href active at the current selection, or null.
Implementation
String? activeLink() => activeValue(UInlineAttr.link) as String?;
The href active at the current selection, or null.
String? activeLink() => activeValue(UInlineAttr.link) as String?;