pending property
Formatting queued for the next typed character while the selection is collapsed (so pressing bold then typing produces bold text).
Implementation
final Map<UInlineAttr, Object?> pending = <UInlineAttr, Object?>{};
Formatting queued for the next typed character while the selection is collapsed (so pressing bold then typing produces bold text).
final Map<UInlineAttr, Object?> pending = <UInlineAttr, Object?>{};