onCodes property
Called with every symbol in each detection, with geometry and metadata.
Implementation
final ValueChanged<List<UCode>>? onCodes;
Called with every symbol in each detection, with geometry and metadata.
final ValueChanged<List<UCode>>? onCodes;