onCodes property
Called with every code found in a frame (format, corners, raw bytes).
Implementation
final ValueChanged<List<UCode>>? onCodes;
Called with every code found in a frame (format, corners, raw bytes).
final ValueChanged<List<UCode>>? onCodes;