UCarouselController class

Moves a UCarousel from code and controls auto play.

Constructors

UCarouselController()

Properties

currentPage → int
Current page index.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAutoPlaying → bool
True while auto playing.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

animateToPage(int page, {bool animate = true}) → void
Goes to a page.
next() → void
Next page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previous() → void
Previous page.
startAutoPlay() → void
Starts auto play.
stopAutoPlay() → void
Stops auto play.
toggleAutoPlay() → void
Starts/stops auto play.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited