UTab class

One tab of UTabBar: id, title, icon, badge. UTab(id: "users", title: "Users", icon: Icons.people)

Constructors

UTab({required String id, required String title, IconData? icon, Widget? badge})
const

Properties

badge → Widget?
Small widget after the title (e.g. a count).
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
Icon shown with it.
final
id → String
Unique id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Title text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited