UPhoneNumberData class

What UTextFieldPhoneNumber reports: full number, number without code and the country's details.

Constructors

UPhoneNumberData({required String countryCode, required String phoneNumber, required String phoneWithoutCode, required String countryName, required String capital, required String continent, required String primaryReligion, required String currency, required String primaryLanguage})
Phone number with country details.

Properties

capital → String
Capital city.
final
continent → String
Continent.
final
countryCode → String
Dial code, e.g. "+98".
final
countryName → String
Country name.
final
currency → String
Currency.
final
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String
Full international number, e.g. "+989121234567".
final
phoneWithoutCode → String
National number without dial code.
final
primaryLanguage → String
Main language.
final
primaryReligion → String
Main religion.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited