onChanged property
void Function(T)
onChanged
final
Called with the new value when the user changes it.
Implementation
final void Function(T) onChanged;
Called with the new value when the user changes it.
final void Function(T) onChanged;