UCurrencyInputFormatter class

Inheritance

Constructors

UCurrencyInputFormatter({String thousandSeparator = ",", String decimalSeparator = ".", int maxDigits = 24})

Properties

decimalSeparator String
final
hashCode int
The hash code for this object.
no setterinherited
maxDigits int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thousandSeparator String
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited