UNumberInputFormatter class

Keeps only digits (Persian digits converted), up to maxDigits. UTextField(formatters: [UNumberInputFormatter(maxDigits: 10)])

Inheritance

Constructors

UNumberInputFormatter({int maxDigits = 24})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxDigits → int
Most digits allowed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited