notes property
Time-stamped notes: shown on the seek bar, as overlays and via the add-note button.
Implementation
final UMediaNotesController? notes;
Time-stamped notes: shown on the seek bar, as overlays and via the add-note button.
final UMediaNotesController? notes;