UVideoFullscreen class abstract final

Opens a controller full screen (landscape, hides system bars).

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

open(BuildContext context, {required UMediaController controller, UVideoSettings? settings, String? title, List<UVideoMarker> markers = const <UVideoMarker>[], UMediaNotesController? notes, UVideoGestureConfig gestures = const UVideoGestureConfig(), Color? accentColor, Widget thumbnailBuilder(BuildContext context, Duration position)?, UDocWatermark? watermark, Duration seekStep = const Duration(seconds: 10), bool forceLandscape = true}) → Future<void>
Opens controller full screen. UVideoFullscreen.open(context, controller: c)