UVideoSettings class

Per-player view settings: fit, zoom, rotation, mirror, color filters, subtitle style/delay, A-B repeat, sleep timer.

Inheritance

Constructors

UVideoSettings({UMediaFit fit = UMediaFit.contain, USubtitleStyleConfig subtitleStyle = const USubtitleStyleConfig()})

Properties

brightness ↔ double
Picture brightness filter (0 = normal).
getter/setter pair
contrast ↔ double
Picture contrast filter (1 = normal).
getter/setter pair
fit ↔ UMediaFit
How the video fills the screen (contain, cover, 16:9…).
getter/setter pair
hasAbRepeat → bool
True when A-B repeat is set.
no setter
hasFilters → bool
True when any color filter is changed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hue ↔ double
Picture hue shift in degrees.
getter/setter pair
mirrored ↔ bool
Mirrors the picture.
getter/setter pair
repeatEnd → Duration?
B point of A-B repeat.
no setter
repeatStart → Duration?
A point of A-B repeat.
no setter
rotation ↔ int
Rotation in quarter turns.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturation ↔ double
Picture saturation filter (1 = normal).
getter/setter pair
screenBrightness ↔ double
Screen brightness override while playing (0-1).
getter/setter pair
showStats ↔ bool
Shows the technical stats overlay.
getter/setter pair
sleepAt → DateTime?
When the sleep timer stops playback.
no setter
subtitleDelay → Duration
Subtitle timing shift.
no setter
subtitleScale ↔ double
Subtitle size multiplier.
getter/setter pair
subtitleStyle ↔ USubtitleStyleConfig
Subtitle font, colors and outline.
getter/setter pair
zoom ↔ double
Zoom level (1 = none).
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
cancelSleepTimer() → void
Cancels the sleep timer.
clearRepeat() → void
Turns A-B repeat off.
cycleFit() → void
Switches to the next fit mode.
dispose() → void
Discards any resources used by the object.
override
markRepeatEnd(Duration position) → void
Sets the B point of A-B repeat.
markRepeatStart(Duration position) → void
Sets the A point of A-B repeat.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resetFilters() → void
Resets brightness/contrast/saturation/hue.
resetView() → void
Resets zoom, rotation and mirror.
rotateQuarter() → void
Rotates 90°.
setSubtitleDelay(UMediaController controller, Duration value) → void
Shifts subtitles on controller by value.
startSleepTimer(Duration duration, VoidCallback onElapsed) → void
Calls onElapsed after duration (e.g. pause).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited