UVideoSheet class abstract final

Opens a player full-width inside a bottom sheet. Accepts the same sources as UVideoPlayer.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

show({String? url, String? base64, Uint8List? bytes, String? filePath, String? assetPath, String? title, bool autoPlay = true}) → Future<void>