UWebView class

Inheritance
Available extensions

Constructors

UWebView({required String initialUrl, Key? key, Map<String, String>? initialHeaders, Color? backgroundColor, OnUrlChanged? onUrlChanged, void onPageStarted(String url)?, void onPageFinished(String url)?, void onWebResourceError(WebResourceError error)?, void onWebViewCreated(WebViewController controller)?, bool onNavigationRequest(String url)?, bool showTopBar = false, bool showUrlBar = false, bool showBackButton = false, bool showForwardButton = false, bool showRefreshButton = false, bool showHomeButton = false, bool showProgressBar = false, bool showMoreMenu = false, bool showShareAction = false, bool showOpenInBrowserAction = false, bool showCopyLinkAction = false, bool showDesktopModeAction = false, bool showZoomActions = false, void onShareRequested(String url)?, void onOpenInBrowserRequested(String url)?, bool enableJavaScript = true, bool enablePinchZoom = false, bool enableJavaScriptDialogs = true, String? userAgent, String desktopUserAgent = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 " "(KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36", bool restrictToAllowedHosts = false, List<String> allowedHosts = const <String>[], Future<void> onPermissionRequest(WebViewPermissionRequest request)?, bool autoGrantMediaPermissions = true, Map<String, void Function(String message)>? javaScriptChannels, Widget errorBuilder(BuildContext context, String message, VoidCallback retry)?, Widget? loadingIndicator})
const

Properties

allowedHosts → List<String>
final
autoGrantMediaPermissions → bool
final
backgroundColor → Color?
final
desktopUserAgent → String
final
enableJavaScript → bool
final
enableJavaScriptDialogs → bool
final
enablePinchZoom → bool
final
errorBuilder → Widget Function(BuildContext context, String message, VoidCallback retry)?
final
hashCode → int
The hash code for this object.
no setterinherited
initialHeaders → Map<String, String>?
final
initialUrl → String
final
javaScriptChannels → Map<String, void Function(String message)>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingIndicator → Widget?
final
onNavigationRequest → bool Function(String url)?
final
onOpenInBrowserRequested → void Function(String url)?
final
onPageFinished → void Function(String url)?
final
onPageStarted → void Function(String url)?
final
onPermissionRequest → Future<void> Function(WebViewPermissionRequest request)?
final
onShareRequested → void Function(String url)?
final
onUrlChanged → OnUrlChanged?
final
onWebResourceError → void Function(WebResourceError error)?
final
onWebViewCreated → void Function(WebViewController controller)?
final
restrictToAllowedHosts → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBackButton → bool
final
showCopyLinkAction → bool
final
showDesktopModeAction → bool
final
showForwardButton → bool
final
showHomeButton → bool
final
showMoreMenu → bool
final
showOpenInBrowserAction → bool
final
showProgressBar → bool
final
showRefreshButton → bool
final
showShareAction → bool
final
showTopBar → bool
final
showUrlBar → bool
final
showZoomActions → bool
final
userAgent → String?
final

Methods

alignAtBottomCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtBottomLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtBottomRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtCenterLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtCenterRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtLERP(Alignment a, Alignment b, double t, {Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtTopCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtTopLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignAtTopRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

alignXY(double x, double y, {Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the WidgetsExtension extension

card({Color? backgroundColor, double? elevation, EdgeInsets? margin}) → Widget

Available on Widget, provided by the WidgetsExtension extension

container({double? width, double? height, Alignment? alignment, Color? backgroundColor, double borderWidth = 1, double radius = 1, Color borderColor = Colors.transparent, EdgeInsets? padding, EdgeInsets? margin, BoxConstraints? constraints}) → Widget

Available on Widget, provided by the WidgetsExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<UWebView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) → Widget

Available on Widget, provided by the WidgetsExtension extension

fadeSlideIn({int milliseconds = 1000, double offset = 24}) → Widget

Available on Widget, provided by the WidgetsExtension extension

fit({Alignment alignment = Alignment.center}) → Widget

Available on Widget, provided by the WidgetsExtension extension

form(GlobalKey<FormState> key) → Widget

Available on Widget, provided by the WidgetsExtension extension

ltr() → Widget

Available on Widget, provided by the WidgetsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTap(GestureTapCallback? onPressed) → Widget

Available on Widget, provided by the WidgetsExtension extension

onLongPress(GestureTapCallback? onPressed) → Widget

Available on Widget, provided by the WidgetsExtension extension

onPress(VoidCallback onTap, {double pressedScale = 0.9, Duration duration = const Duration(milliseconds: 120)}) → Widget

Available on Widget, provided by the WidgetsExtension extension

onTap(GestureTapCallback? onPressed) → Widget

Available on Widget, provided by the WidgetsExtension extension

onTapInk(GestureTapCallback? onPressed) → Widget

Available on Widget, provided by the WidgetsExtension extension

pAll(double padding) → Widget

Available on Widget, provided by the WidgetsExtension extension

pOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetsExtension extension

position({double? left, double? top, double? right, double? bottom, double? width, double? height}) → Widget

Available on Widget, provided by the WidgetsExtension extension

pSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetsExtension extension

rotate(double scale) → Widget

Available on Widget, provided by the WidgetsExtension extension

rtl() → Widget

Available on Widget, provided by the WidgetsExtension extension

safeArea() → Widget

Available on Widget, provided by the WidgetsExtension extension

scale(double scale) → Widget

Available on Widget, provided by the WidgetsExtension extension

scrollable({Axis scrollDirection = Axis.vertical}) → Widget

Available on Widget, provided by the WidgetsExtension extension

showMenus(List<PopupMenuEntry<int>> items) → Widget

Available on Widget, provided by the WidgetsExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
translate(Offset offset) → Widget

Available on Widget, provided by the WidgetsExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited