AccountingService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
report(
{required UAccountingReportParams p, required dynamic onOk(UResponse< UAccountingReportResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) → Future<(UResponse< UAccountingReportResponse> ?, UEmptyResponse?, String?)> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited