AppSettingsService class

Constructors

AppSettingsService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({required UAppSettingsReadParams p, required dynamic onOk(UResponse<UAppSettingsResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UAppSettingsResponse>?, UEmptyResponse?, String?)>
readAll({required dynamic onOk(UResponse<UAppSettings> r), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UResponse<UAppSettings>?, UEmptyResponse?, String?)>
toString() String
A string representation of this object.
inherited
update({required UAppSettingsUpdateParams p, required dynamic onOk(UEmptyResponse e), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>

Operators

operator ==(Object other) bool
The equality operator.
inherited