ApproveResponse class

Constructors

ApproveResponse({int? reserve, String? serverDateTime, bool? status, int? code, String? message, int? reference, String? serial, String? pin, String? traceId, String? help, String? messageSource, String? extCode})
ApproveResponse.fromJson(String str)
factory
ApproveResponse.fromMap(Map<String, dynamic> json)
factory

Properties

code int?
final
extCode String?
final
hashCode int
The hash code for this object.
no setterinherited
help String?
final
message String?
final
messageSource String?
final
pin String?
final
reference int?
final
reserve int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String?
final
serverDateTime String?
final
status bool?
final
traceId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited