BlogSelectorArgs class

Constructors

BlogSelectorArgs({UserSelectorArgs? creator, MediaSelectorArgs? media, CategorySelectorArgs? category, CommentSelectorArgs? comments, bool? commentsCount})
const
BlogSelectorArgs.fromJson(String str)
factory
BlogSelectorArgs.fromMap(Map<String, dynamic> json)
factory

Properties

category CategorySelectorArgs?
final
comments CommentSelectorArgs?
final
commentsCount bool?
final
creator UserSelectorArgs?
final
hashCode int
The hash code for this object.
no setterinherited
media MediaSelectorArgs?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited