CategorySelectorArgs class

Constructors

CategorySelectorArgs({UserSelectorArgs? creator, MediaSelectorArgs? media, CategorySelectorArgs? children, int? childrenDebt})
const
CategorySelectorArgs.fromJson(String str)
factory
CategorySelectorArgs.fromMap(Map<String, dynamic> json)
factory

Properties

children CategorySelectorArgs?
final
childrenDebt int?
final
creator UserSelectorArgs?
final
hashCode int
The hash code for this object.
no setterinherited
media MediaSelectorArgs?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited