ChargeInternetService class

Constructors

ChargeInternetService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

echo({required UBaseParams p, required dynamic onOk(UResponse<EchoResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<EchoResponse>?, UEmptyResponse?, String?)>
getBalance({required UBaseParams p, required dynamic onOk(UResponse<GetBalanceResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<GetBalanceResponse>?, UEmptyResponse?, String?)>
getStatus({required GetStatusParams p, required dynamic onOk(UResponse<GetStatusResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<GetStatusResponse>?, UEmptyResponse?, String?)>
internetList({required InternetListParams p, required dynamic onOk(UResponse<UInternetPackageResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UInternetPackageResponse>?, UEmptyResponse?, String?)>
internetReserve({required InternetReserveParams p, required dynamic onOk(UResponse<ChargeInternetReserveResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<ChargeInternetReserveResponse>?, UEmptyResponse?, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pin({required ReserveChargeParams p, required dynamic onOk(UResponse<ChargeInternetReserveResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<ChargeInternetReserveResponse>?, UEmptyResponse?, String?)>
topup({required TopupChargeParams p, required dynamic onOk(UResponse<ChargeInternetReserveResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<ChargeInternetReserveResponse>?, UEmptyResponse?, String?)>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited