CommentSelectorArgs class

Constructors

CommentSelectorArgs({UserSelectorArgs? creator, CommentSelectorArgs? children, UserSelectorArgs? user, MediaSelectorArgs? media})
const
CommentSelectorArgs.fromJson(String str)
factory
CommentSelectorArgs.fromMap(Map<String, dynamic> json)
factory

Properties

children CommentSelectorArgs?
final
creator UserSelectorArgs?
final
hashCode int
The hash code for this object.
no setterinherited
media MediaSelectorArgs?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user UserSelectorArgs?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited