ContractSelectorArgs class
Constructors
- ContractSelectorArgs({UserSelectorArgs? creator, UserSelectorArgs? user, DormBedSelectorArgs? bed, ProductSelectorArgs? product, InvoiceSelectorArgs? invoice})
-
const
- ContractSelectorArgs.fromJson(String str)
-
factory
-
ContractSelectorArgs.fromMap(Map<
String, dynamic> json) -
factory
Properties
- bed → DormBedSelectorArgs?
-
final
- creator → UserSelectorArgs?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoice → InvoiceSelectorArgs?
-
final
- product → ProductSelectorArgs?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → UserSelectorArgs?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited