DynamicOptionsConfig class

Dynamic options loaded from API

Constructors

DynamicOptionsConfig({required String apiUrl, String? responsePath, String valueField = "value", String textField = "text", bool enableSearch = false, int minCharsForSearch = 2})
DynamicOptionsConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiUrl String
final
enableSearch bool
final
hashCode int
The hash code for this object.
no setterinherited
minCharsForSearch int
final
responsePath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textField String
final
valueField String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited