EchoResponse class

Constructors

EchoResponse({int? reserve, String? serverDateTime, bool? status, int? code, String? message, bool? mciTopup, bool? mtn, bool? rightel, bool? shatel, bool? mciInternet})
EchoResponse.fromJson(String str)
factory
EchoResponse.fromMap(Map<String, dynamic> json)
factory

Properties

code int?
final
hashCode int
The hash code for this object.
no setterinherited
mciInternet bool?
final
mciTopup bool?
final
message String?
final
mtn bool?
final
reserve int?
final
rightel bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverDateTime String?
final
shatel bool?
final
status bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited