FieldGroup class

Group multiple fields together in a visual section

Constructors

FieldGroup({required String groupId, required String title, required List<String> fieldNames, String? description, String? layout, int? columns})
FieldGroup.fromJson(Map<String, dynamic> json)
factory

Properties

columns int?
final
description String?
final
fieldNames List<String>
final
groupId String
final
hashCode int
The hash code for this object.
no setterinherited
layout String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited