FieldType enum

Inheritance
Available extensions

Values

text → const FieldType
textarea → const FieldType
number → const FieldType
email → const FieldType
tel → const FieldType
password → const FieldType
url → const FieldType
select → const FieldType
multiSelect → const FieldType
radio → const FieldType
radioCard → const FieldType
checkbox → const FieldType
checkboxGroup → const FieldType
date → const FieldType
dateTime → const FieldType
time → const FieldType
month → const FieldType
week → const FieldType
range → const FieldType
color → const FieldType
file → const FieldType
multiFile → const FieldType
location → const FieldType
addressAutocomplete → const FieldType
phoneWithCountry → const FieldType
rating → const FieldType
toggle → const FieldType
button → const FieldType
creditCard → const FieldType
expiryDate → const FieldType
cvv → const FieldType
nationalCode → const FieldType
postalCode → const FieldType
iban → const FieldType
hidden → const FieldType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FieldType>
A constant List of the values in this enum, in order of their declaration.