FileManagerService class

Constructors

FileManagerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

browse({required UFileManagerBrowseParams p, required dynamic onOk(UResponse<UFileManagerListResponse> r), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UResponse<UFileManagerListResponse>?, UEmptyResponse?, String?)>
createFolder({required UFileManagerCreateFolderParams p, required dynamic onOk(UEmptyResponse e), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
delete({required UFileManagerDeleteParams p, required dynamic onOk(UEmptyResponse e), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
downloadUrl(String path) String
fetchText({required String url, required dynamic onOk(String e), required dynamic onException(String e)}) Future<void>
move({required UFileManagerMoveParams p, required dynamic onOk(UEmptyResponse e), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename({required UFileManagerRenameParams p, required dynamic onOk(UEmptyResponse e), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
toString() String
A string representation of this object.
inherited
upload({required UFileManagerUploadParams p, required dynamic onOk(UResponse<String> r), required dynamic onError(UEmptyResponse e), required dynamic onException(String e)}) Future<(UResponse<String>?, UEmptyResponse?, String?)>

Operators

operator ==(Object other) bool
The equality operator.
inherited