HotelReservationSelectorArgs class
Constructors
- HotelReservationSelectorArgs({UserSelectorArgs? creator, UserSelectorArgs? user, HotelRoomSelectorArgs? room, HotelSelectorArgs? hotel, HotelInvoiceSelectorArgs? invoice})
-
const
- HotelReservationSelectorArgs.fromJson(String str)
-
factory
-
HotelReservationSelectorArgs.fromMap(Map<
String, dynamic> json) -
factory
Properties
- creator → UserSelectorArgs?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hotel → HotelSelectorArgs?
-
final
- invoice → HotelInvoiceSelectorArgs?
-
final
- room → HotelRoomSelectorArgs?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → UserSelectorArgs?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited