HotelSelectorArgs class

Constructors

HotelSelectorArgs({UserSelectorArgs? creator, HotelRoomSelectorArgs? rooms, HotelReservationSelectorArgs? reservations, MediaSelectorArgs? media})
const
HotelSelectorArgs.fromJson(String str)
factory
HotelSelectorArgs.fromMap(Map<String, dynamic> json)
factory

Properties

creator UserSelectorArgs?
final
hashCode int
The hash code for this object.
no setterinherited
media MediaSelectorArgs?
final
reservations HotelReservationSelectorArgs?
final
rooms HotelRoomSelectorArgs?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited