InquiryService class

Constructors

InquiryService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

billInfo({required UBillInfoParams p, required dynamic onOk(UResponse<UBillInfoResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UBillInfoResponse>?, UEmptyResponse?, String?)>
cacheStatus({required UInquiryCacheStatusParams p, required dynamic onOk(UResponse<UInquiryCacheStatusResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UInquiryCacheStatusResponse>?, UEmptyResponse?, String?)>
drivingLicenceDetail({required UDrivingLicenceDetailParams p, required dynamic onOk(UResponse<UDrivingLicenceDetailResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UDrivingLicenceDetailResponse>?, UEmptyResponse?, String?)>
drivingLicenceNegativePoint({required UDrivingLicenceNegativePointParams p, required dynamic onOk(UResponse<UDrivingLicenceNegativePointResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UDrivingLicenceNegativePointResponse>?, UEmptyResponse?, String?)>
freewayTolls({required UFreewayTollsParams p, required dynamic onOk(UResponse<UFreewayTollsResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UFreewayTollsResponse>?, UEmptyResponse?, String?)>
iBanToBankAccountDetail({required UIBanToBankAccountDetailParams p, required dynamic onOk(UResponse<UIBanToBankAccountDetailResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UIBanToBankAccountDetailResponse>?, UEmptyResponse?, String?)>
licencePlateDetail({required ULicencePlateDetailParams p, required dynamic onOk(UResponse<ULicencePlateDetailResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<ULicencePlateDetailResponse>?, UEmptyResponse?, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
vehicleViolationDetail({required UVehicleViolationDetailParams p, required dynamic onOk(UResponse<UVehicleViolationDetailResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UVehicleViolationDetailResponse>?, UEmptyResponse?, String?)>
zipCodeToAddressDetail({required UZipCodeToAddressDetailParams p, required dynamic onOk(UResponse<UZipCodeToAddressDetailResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UZipCodeToAddressDetailResponse>?, UEmptyResponse?, String?)>

Operators

operator ==(Object other) bool
The equality operator.
inherited