InternetReserveParams class

Constructors

InternetReserveParams({required String subscriber, required String operatorId, required String packageId, required String amount, required String device, String? bank})
InternetReserveParams.fromJson(String str)
factory
InternetReserveParams.fromMap(Map<String, dynamic> json)
factory

Properties

amount String
final
bank String?
final
device String
final
hashCode int
The hash code for this object.
no setterinherited
operatorId String
final
packageId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriber String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited