IpgService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
pay({required UIpgSaleParams p, required dynamic onOk(UResponse<UIpgPayResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UResponse<UIpgPayResponse>?, UEmptyResponse?, String?)>
-
-
status({required UIpgVerifyParams p, required dynamic onOk(UResponse<UIpgVerifyResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UResponse<UIpgVerifyResponse>?, UEmptyResponse?, String?)>
-
-
toString()
→ String
-
A string representation of this object.
inherited