MerchantJsonData class

Constructors

MerchantJsonData({String? detail1, String? detail2, String? businessTitle, String? address, String? ownerPhoneNumber, int? definitionTemplate, int? settlementCurrency, String? ownerName})
MerchantJsonData.fromJson(String str)
factory
MerchantJsonData.fromMap(Map<String, dynamic> json)
factory

Properties

address String?
final
businessTitle String?
final
definitionTemplate int?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
ownerName String?
final
ownerPhoneNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settlementCurrency int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited