MerchantSelectorArgs class

Constructors

MerchantSelectorArgs({UserSelectorArgs? creator, UserSelectorArgs? user, TerminalSelectorArgs? terminal})
const
MerchantSelectorArgs.fromJson(String str)
factory
MerchantSelectorArgs.fromMap(Map<String, dynamic> json)
factory

Properties

creator UserSelectorArgs?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal TerminalSelectorArgs?
final
user UserSelectorArgs?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited