ParkingReportSelectorArgs class
Constructors
- ParkingReportSelectorArgs({UserSelectorArgs? creator, VehicleSelectorArgs? vehicle, ParkingSelectorArgs? parking})
-
const
- ParkingReportSelectorArgs.fromJson(String str)
-
factory
-
ParkingReportSelectorArgs.fromMap(Map<
String, dynamic> json) -
factory
Properties
- creator → UserSelectorArgs?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parking → ParkingSelectorArgs?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vehicle → VehicleSelectorArgs?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited