ParkingService class

Constructors

ParkingService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createParking({required UParkingCreateParams p, required dynamic onOk(UResponse<String> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<String>?, UEmptyResponse?, String?)>
createParkingReport({required UParkingReportCreateParams p, required dynamic onOk(UResponse<String> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<String>?, UEmptyResponse?, String?)>
createParkingUser({required UParkingUserCreateParams p, required dynamic onOk(UResponse<String> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<String>?, UEmptyResponse?, String?)>
deleteParking({required UIdParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
deleteParkingReport({required UIdParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readParking({required UParkingReadParams p, required dynamic onOk(UResponse<List<UParkingResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<List<UParkingResponse>>?, UEmptyResponse?, String?)>
readParkingReport({required UParkingReportReadParams p, required dynamic onOk(UResponse<List<UParkingReportResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<List<UParkingReportResponse>>?, UEmptyResponse?, String?)>
readParkingUsers({required UParkingUserReadParams p, required dynamic onOk(UResponse<List<UUserResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<List<UUserResponse>>?, UEmptyResponse?, String?)>
removeParkingUser({required UParkingUserDeleteParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
toString() String
A string representation of this object.
inherited
updateParking({required UParkingUpdateParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
updateParkingReport({required UParkingReportUpdateParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>

Operators

operator ==(Object other) bool
The equality operator.
inherited