PredefinedValidationPatterns class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- creditCard → const String
- email → const String
- iban → const String
- iranianMobilePhone → const String
- iranianNationalCode → const String
- iranianPhoneNumber → const String
- iranianPostalCode → const String
- url → const String