ProcessService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get({required String processId, required dynamic onOk(UResponse<UProcessStepGet> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UResponse<UProcessStepGet>?, UEmptyResponse?, String?)>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
send({required UProcessStepSend p, required dynamic onOk(UResponse<UProcessStepGet> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UResponse<UProcessStepGet>?, UEmptyResponse?, String?)>
-
-
toString()
→ String
-
A string representation of this object.
inherited