ProductSelectorArgs class

Constructors

ProductSelectorArgs({UserSelectorArgs? creator, String? userId, ProductSelectorArgs? children, CategorySelectorArgs? category, MediaSelectorArgs? media, bool? childrenCount, bool? commentsCount, bool? isFollowing, int? childrenDebt})
const
ProductSelectorArgs.fromJson(String str)
factory
ProductSelectorArgs.fromMap(Map<String, dynamic> json)
factory

Properties

category CategorySelectorArgs?
final
children ProductSelectorArgs?
final
childrenCount bool?
final
childrenDebt int?
final
commentsCount bool?
final
creator UserSelectorArgs?
final
hashCode int
The hash code for this object.
no setterinherited
isFollowing bool?
final
media MediaSelectorArgs?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited