ProductService class

Constructors

ProductService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bulkCreate({required List<UProductCreateParams> p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
create({required UProductCreateParams p, required dynamic onOk(UResponse<String> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<String>?, UEmptyResponse?, String?)>
delete({required UIdParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
deleteRange({required UIdListParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({required UProductReadParams p, required dynamic onOk(UResponse<List<UProductResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<List<UProductResponse>>?, UEmptyResponse?, String?)>
readById({required UIdParams p, required dynamic onOk(UResponse<UProductResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<UProductResponse>?, UEmptyResponse?, String?)>
toString() String
A string representation of this object.
inherited
update({required UProductUpdateParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>

Operators

operator ==(Object other) bool
The equality operator.
inherited