StepNavigation class

Configuration for step navigation

Constructors

StepNavigation({String? enableNextCondition, String? nextButtonLabel, String? previousButtonLabel, String? conditionalNextStep, String? conditionalNextCondition})
StepNavigation.fromJson(Map<String, dynamic> json)
factory

Properties

conditionalNextCondition String?
final
conditionalNextStep String?
final
enableNextCondition String?
final
hashCode int
The hash code for this object.
no setterinherited
nextButtonLabel String?
final
previousButtonLabel String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited