UAccountingReportParams class

Constructors

UAccountingReportParams({String? userId, DateTime? fromDate, DateTime? toDate})
UAccountingReportParams.fromJson(String str)
factory
UAccountingReportParams.fromMap(Map<String, dynamic> json)
factory

Properties

fromDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate DateTime?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited