UAccountingReportResponse class
Constructors
-
UAccountingReportResponse({required double totalIn, required double totalOut, required double net, required double totalWalletBalance, required int walletTxnCount, required int txnCount, required List<
UAccountingBreakdownItem> incomeByType, required List<UAccountingBreakdownItem> spendingByType, required List<UAccountingBreakdownItem> gatewayByType, required List<UAccountingTimelineItem> timeline}) - UAccountingReportResponse.fromJson(String str)
-
factory
-
UAccountingReportResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
gatewayByType
→ List<
UAccountingBreakdownItem> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
incomeByType
→ List<
UAccountingBreakdownItem> -
final
- net → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spendingByType
→ List<
UAccountingBreakdownItem> -
final
-
timeline
→ List<
UAccountingTimelineItem> -
final
- totalIn → double
-
final
- totalOut → double
-
final
- totalWalletBalance → double
-
final
- txnCount → int
-
final
- walletTxnCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited