UAccountingTimelineItem class

Constructors

UAccountingTimelineItem({required DateTime date, required double inAmount, required double outAmount})
UAccountingTimelineItem.fromJson(String str)
factory
UAccountingTimelineItem.fromMap(Map<String, dynamic> json)
factory

Properties

date DateTime
final
hashCode int
The hash code for this object.
no setterinherited
inAmount double
final
outAmount double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited