UAddressReadParams class

Constructors

UAddressReadParams({required AddressSelectorArgs? selectorArgs, int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? creatorId, int? orderBy, String? zipCode})
UAddressReadParams.fromJson(String str)
factory
UAddressReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs AddressSelectorArgs?
final
tags List<int>?
final
toCreatedAt DateTime?
final
zipCode String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited