UAddressResponse class

Constructors

UAddressResponse({required String id, required List<int> tags, required UAddressResponseJsonData jsonData, required List<String> adminUserIds, DateTime? createdAt, String? zipCode, UUserResponse? creator, String? creatorId})
UAddressResponse.fromJson(String str)
factory
UAddressResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
createdAt DateTime?
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UAddressResponseJsonData
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
zipCode String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited