UApiCallCosts class

Constructors

UApiCallCosts({required double mobileAndNationalCodeVerification, required double zipCodeToAddressDetail, required double vehicleViolationsDetail, required double drivingLicenceStatus, required double freewayToll, required double licencePlateDetail, required double drivingLicenceNegativePoint, required double iBanToBankAccountDetail})
UApiCallCosts.fromJson(String str)
factory
UApiCallCosts.fromMap(Map<String, dynamic> json)
factory

Properties

drivingLicenceNegativePoint double
final
drivingLicenceStatus double
final
freewayToll double
final
hashCode int
The hash code for this object.
no setterinherited
iBanToBankAccountDetail double
final
licencePlateDetail double
final
mobileAndNationalCodeVerification double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vehicleViolationsDetail double
final
zipCodeToAddressDetail double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited