UApiLogBucketResponse class

Constructors

UApiLogBucketResponse({required DateTime time, required int count, required int errorCount, required double averageDurationMs})
UApiLogBucketResponse.fromJson(String str)
factory
UApiLogBucketResponse.fromMap(Map<String, dynamic> json)
factory

Properties

averageDurationMs double
final
count int
final
errorCount int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited