UApiLogJson class

Constructors

UApiLogJson({required String method, String? queryString, String? requestBody, String? responseBody, String? requestHeaders, String? responseHeaders, String? userAgent, String? host, String? userName, String? userEmail, String? userRoles, String? exceptionType, String? exceptionMessage, String? stackTrace, int requestSizeBytes = 0, int responseSizeBytes = 0, String? detail1, String? detail2})
UApiLogJson.fromJson(String str)
factory
UApiLogJson.fromMap(Map<String, dynamic> json)
factory

Properties

detail1 String?
final
detail2 String?
final
exceptionMessage String?
final
exceptionType String?
final
hashCode int
The hash code for this object.
no setterinherited
host String?
final
method String
final
queryString String?
final
requestBody String?
final
requestHeaders String?
final
requestSizeBytes int
final
responseBody String?
final
responseHeaders String?
final
responseSizeBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
final
userAgent String?
final
userEmail String?
final
userName String?
final
userRoles String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited