UApiLogReadParams class

Constructors

UApiLogReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, int? orderBy, String? pathContains, int? statusCode, int? minDurationMs, int? maxDurationMs, String? userId, String? ipAddress, bool? onlyErrors, String? creatorId, dynamic selectorArgs})
UApiLogReadParams.fromJson(String str)
factory
UApiLogReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
ipAddress String?
final
maxDurationMs int?
final
minDurationMs int?
final
onlyErrors bool?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
pathContains String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs → dynamic
final
statusCode int?
final
tags List<int>?
final
toCreatedAt DateTime?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited