UApiLogStatsParams class
Constructors
- UApiLogStatsParams({DateTime? fromCreatedAt, DateTime? toCreatedAt, String bucket = "hour"})
- UApiLogStatsParams.fromJson(String str)
-
factory
-
UApiLogStatsParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- bucket → String
-
final
- fromCreatedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toCreatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited