UApiLogStatsResponse class

Constructors

UApiLogStatsResponse({required int totalCount, required int successCount, required int errorCount, required double averageDurationMs, required double p50DurationMs, required double p95DurationMs, required double p99DurationMs, required List<UApiLogBucketResponse> timeline, required List<UApiLogEndpointResponse> slowestEndpoints, required List<UApiLogEndpointResponse> failingEndpoints, required List<UApiLogResponse> slowestRequests})
UApiLogStatsResponse.fromJson(String str)
factory
UApiLogStatsResponse.fromMap(Map<String, dynamic> json)
factory

Properties

averageDurationMs double
final
errorCount int
final
failingEndpoints List<UApiLogEndpointResponse>
final
hashCode int
The hash code for this object.
no setterinherited
p50DurationMs double
final
p95DurationMs double
final
p99DurationMs double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slowestEndpoints List<UApiLogEndpointResponse>
final
slowestRequests List<UApiLogResponse>
final
successCount int
final
timeline List<UApiLogBucketResponse>
final
totalCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited