UBankAccountCreateParams class

Constructors

UBankAccountCreateParams({required List<int> tags, String? cardNumber, String? id, String? accountNumber, String? bankName, String? ownerName, String? iBanNumber, String? detail1, String? detail2, String? creatorId, List<String>? adminUserIds})
UBankAccountCreateParams.fromJson(String str)
factory
UBankAccountCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

accountNumber String?
final
adminUserIds List<String>?
final
bankName String?
final
cardNumber String?
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
iBanNumber String?
final
id String?
final
ownerName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited