UBankAccountResponse class

Constructors

UBankAccountResponse({required List<int> tags, required UBaseJson jsonData, required DateTime createdAt, required List<String> adminUserIds, String? cardNumber, String? id, String? accountNumber, String? bankName, String? ownerName, String? iBanNumber, UUserResponse? creator, String? creatorId})
UBankAccountResponse.fromJson(String str)
factory
UBankAccountResponse.fromMap(Map<String, dynamic> json)
factory

Properties

accountNumber String?
final
adminUserIds List<String>
final
bankName String?
final
cardNumber String?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
iBanNumber String?
final
id String?
final
jsonData UBaseJson
final
ownerName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited