UBlogCreateParams class

Constructors

UBlogCreateParams({required List<int> tags, required String title, String? detail1, String? detail2, String? id, String? creatorId, List<String>? adminUserIds, String? subtitle, String? slug, String? content, String? metaTitle, String? metaDescription, String? source, List<String>? categories, List<String>? media, String? code, String? description, String? type, String? actionType, String? actionTitle, String? actionUri, double? latitude, double? longitude, String? parentId, List<String>? relatedBlogs, List<UBlogCreateParams>? children})
UBlogCreateParams.fromJson(String str)
factory
UBlogCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

actionTitle String?
final
actionType String?
final
actionUri String?
final
adminUserIds List<String>?
final
categories List<String>?
final
children List<UBlogCreateParams>?
final
code String?
final
content String?
final
creatorId String?
final
description String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
latitude double?
final
longitude double?
final
media List<String>?
final
metaDescription String?
final
metaTitle String?
final
parentId String?
final
relatedBlogs List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
final
source String?
final
subtitle String?
final
tags List<int>
final
title String
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited