UBlogJson class

Constructors

UBlogJson({String? metaTitle, String? metaDescription, String? source, String? detail1, String? detail2, String? actionType, String? actionTitle, String? actionUri, List<String>? relatedBlogs})
UBlogJson.fromJson(String str)
factory
UBlogJson.fromMap(Map<String, dynamic> json)
factory

Properties

actionTitle String?
final
actionType String?
final
actionUri String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
metaDescription String?
final
metaTitle String?
final
relatedBlogs List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited