UBlogReadParams class

Constructors

UBlogReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? creatorId, String? query, String? title, String? slug, List<String>? categories, BlogSelectorArgs? selectorArgs, int? orderBy, String? code, String? parentId})
UBlogReadParams.fromJson(String str)
factory
UBlogReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

categories List<String>?
final
code String?
final
creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
parentId String?
final
query String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs BlogSelectorArgs?
final
slug String?
final
tags List<int>?
final
title String?
final
toCreatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited