UBlogResponse class

Constructors

UBlogResponse({required String id, required DateTime createdAt, required UBlogJson jsonData, required List<int> tags, required String title, List<String> adminUserIds = const <String>[], UUserResponse? creator, String? creatorId, String? subtitle, String? slug, String? content, List<UMediaResponse>? media, List<UCategoryResponse>? categories, List<UCommentResponse>? comments, int? commentCount, String? code, String? description, String? type, double? latitude, double? longitude, String? parentId, List<UBlogResponse>? children, int? childrenCount})
UBlogResponse.fromJson(String str)
factory
UBlogResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
categories List<UCategoryResponse>?
final
children List<UBlogResponse>?
final
childrenCount int?
final
code String?
final
commentCount int?
final
comments List<UCommentResponse>?
final
content String?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UBlogJson
final
latitude double?
final
longitude double?
final
media List<UMediaResponse>?
final
parentId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
final
subtitle String?
final
tags List<int>
final
title String
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited