UCategoryResponse class

Constructors

UCategoryResponse({required String id, required DateTime createdAt, required UCategoryJson jsonData, required List<int> tags, required String title, required List<String> adminUserIds, String? code, String? parentId, int? order, List<UCategoryResponse>? children, List<UMediaResponse>? media, UUserResponse? creator, String? creatorId})
UCategoryResponse.fromJson(String str)
factory
UCategoryResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
children List<UCategoryResponse>?
final
code String?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UCategoryJson
final
media List<UMediaResponse>?
final
order int?
final
parentId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited