UChargeInternet class
Constructors
-
UChargeInternet({required int operator, required String title, required String logo, required List<
UChargeInternetPreDefinedAmounts> preDefinedAmountsList}) - UChargeInternet.fromJson(String str)
-
factory
-
UChargeInternet.fromMap(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logo → String
-
final
- operator → int
-
final
-
preDefinedAmountsList
→ List<
UChargeInternetPreDefinedAmounts> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited