UCommentReadParams class

Constructors

UCommentReadParams({String? creatorId, String? productId, String? blogId, String? userId, int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, CommentSelectorArgs? selectorArgs, int? orderBy, List<String>? ids})
UCommentReadParams.fromJson(String str)
factory
UCommentReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

blogId String?
final
creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
productId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs CommentSelectorArgs?
final
tags List<int>?
final
toCreatedAt DateTime?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited