UCommentResponse class

Constructors

UCommentResponse({required String id, required DateTime createdAt, required UCommentJson jsonData, required List<int> tags, required double score, required String description, required String userId, required List<String> adminUserIds, String? parentId, UUserResponse? user, UUserResponse? creator, String? creatorId, String? productId, String? blogId, List<UCommentResponse>? children, List<UMediaResponse>? media})
UCommentResponse.fromJson(String str)
factory
UCommentResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
blogId String?
final
children List<UCommentResponse>?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UCommentJson
final
media List<UMediaResponse>?
final
parentId String?
final
productId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
final
tags List<int>
final
user UUserResponse?
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited