UDbAdminDeleteRowParams class
Constructors
- UDbAdminDeleteRowParams({required String table, required String primaryKeyColumn, required String primaryKeyValue, String schema = "public"})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryKeyColumn → String
-
final
- primaryKeyValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → String
-
final
- table → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited