UDbIndexResponse class

Constructors

UDbIndexResponse({required String name, required String definition, required bool isUnique, required bool isPrimary})
UDbIndexResponse.fromMap(Map<String, dynamic> json)
factory

Properties

definition String
final
hashCode int
The hash code for this object.
no setterinherited
isPrimary bool
final
isUnique bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited