UDbTableResponse class
Constructors
- UDbTableResponse({required String schema, required String name, required int estimatedRows, required int columnCount, String? size})
-
UDbTableResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- columnCount → int
-
final
- estimatedRows → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → String
-
final
- size → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited