UDormBedContractReadParams class

Constructors

UDormBedContractReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? userId, String? creatorId, DateTime? startDate, DateTime? endDate, String? userName, String? bedId, String? dormId, bool? activeOnly, bool? upcomingOnly, bool? expiredOnly, int? expiringWithinDays, ContractSelectorArgs? selectorArgs, int? orderBy})
UDormBedContractReadParams.fromJson(String str)
factory
UDormBedContractReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

activeOnly bool?
final
bedId String?
final
creatorId String?
final
dormId String?
final
endDate DateTime?
final
expiredOnly bool?
final
expiringWithinDays int?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs ContractSelectorArgs?
final
startDate DateTime?
final
tags List<int>?
final
toCreatedAt DateTime?
final
upcomingOnly bool?
final
userId String?
final
userName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited