UDormBedContractResponse class

Constructors

UDormBedContractResponse({required String id, required DateTime createdAt, required UBaseJson jsonData, required List<int> tags, required DateTime startDate, required DateTime endDate, required double deposit, required double rent, required String userId, required String bedId, required bool isActive, required List<String> adminUserIds, UUserResponse? user, UDormBedResponse? bed, UUserResponse? creator, String? creatorId, List<UDormBedInvoiceResponse>? invoices})
UDormBedContractResponse.fromJson(String str)
factory
UDormBedContractResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds → List<String>
final
bed → UDormBedResponse?
final
bedId → String
final
createdAt → DateTime
final
creator → UUserResponse?
final
creatorId → String?
final
deposit → double
final
endDate → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
invoices → List<UDormBedInvoiceResponse>?
final
isActive → bool
final
jsonData → UBaseJson
final
rent → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → DateTime
final
tags → List<int>
final
user → UUserResponse?
final
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited