UDormBedContractUpdateParams class

Constructors

UDormBedContractUpdateParams({required String id, List<int>? addTags, List<int>? removeTags, List<int>? tags, DateTime? startDate, DateTime? endDate, double? deposit, double? rent, String? detail1, String? detail2, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UDormBedContractUpdateParams.fromJson(String str)
factory
UDormBedContractUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
deposit double?
final
detail1 String?
final
detail2 String?
final
endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
rent double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
final
tags List<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited