UDormBedCreateParams class

Constructors

UDormBedCreateParams({required List<int> tags, required String title, required double deposit, required double monthlyRent, required String roomId, String? detail1, String? detail2, String? id, String? creatorId, List<String>? adminUserIds})
UDormBedCreateParams.fromJson(String str)
factory
UDormBedCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
creatorId String?
final
deposit double
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
monthlyRent double
final
roomId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited