UDormBedInvoiceChartResponse class

Constructors

UDormBedInvoiceChartResponse({required String month, required double totalDebt, required double totalPaid, required double totalPenalty, required double totalRemaining, required int invoiceCount})
UDormBedInvoiceChartResponse.fromJson(String str)
factory
UDormBedInvoiceChartResponse.fromMap(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
invoiceCount int
final
month String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDebt double
final
totalPaid double
final
totalPenalty double
final
totalRemaining double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited