UDormBedInvoiceCreateParams class

Constructors

UDormBedInvoiceCreateParams({required List<int> tags, required double debtAmount, required double creditorAmount, required double paidAmount, required double penaltyAmount, required String contractId, required DateTime dueDate, String? id, int? penaltyPrecentEveryDate, String? detail1, String? detail2, String? creatorId, List<String>? adminUserIds})
UDormBedInvoiceCreateParams.fromJson(String str)
factory
UDormBedInvoiceCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
contractId String
final
creatorId String?
final
creditorAmount double
final
debtAmount double
final
detail1 String?
final
detail2 String?
final
dueDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
paidAmount double
final
penaltyAmount double
final
penaltyPrecentEveryDate int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited