UDormBedInvoiceReadParams class

Constructors

UDormBedInvoiceReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? userId, InvoiceSelectorArgs? selectorArgs, String? contractId, String? dormId, bool? isPaid, bool? isOverdue, DateTime? minDueDate, DateTime? maxDueDate, double? minDebtAmount, double? maxDebtAmount, String? creatorId, int? orderBy})
UDormBedInvoiceReadParams.fromJson(String str)
factory
UDormBedInvoiceReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

contractId String?
final
creatorId String?
final
dormId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
isOverdue bool?
final
isPaid bool?
final
maxDebtAmount double?
final
maxDueDate DateTime?
final
minDebtAmount double?
final
minDueDate DateTime?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs InvoiceSelectorArgs?
final
tags List<int>?
final
toCreatedAt DateTime?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited