UDormBedInvoiceResponse class

Available extensions

Constructors

UDormBedInvoiceResponse({required String id, required DateTime createdAt, required UDormBedInvoiceJson jsonData, required List<int> tags, required DateTime dueDate, required double debtAmount, required double creditorAmount, required double paidAmount, required double penaltyAmount, required List<String> adminUserIds, UDormBedContractResponse? contract, UUserResponse? creator, String? creatorId})
UDormBedInvoiceResponse.fromJson(String str)
factory
UDormBedInvoiceResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
contract UDormBedContractResponse?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
creditorAmount double
final
debtAmount double
final
dueDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isOverdue bool

Available on UDormBedInvoiceResponse, provided by the UInvoiceStatusX extension

no setter
isPaid bool

Available on UDormBedInvoiceResponse, provided by the UInvoiceStatusX extension

no setter
jsonData UDormBedInvoiceJson
final
netDue double

Available on UDormBedInvoiceResponse, provided by the UInvoiceStatusX extension

no setter
paidAmount double
final
penaltyAmount double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited