UDormBedInvoiceUpdateParams class

Constructors

UDormBedInvoiceUpdateParams({String? id, List<int>? addTags, List<int>? removeTags, List<int>? tags, double? debtAmount, double? creditorAmount, double? paidAmount, double? penaltyAmount, String? userId, String? contractId, int? penaltyPrecentEveryDate, DateTime? dueDate, String? detail1, String? detail2, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UDormBedInvoiceUpdateParams.fromJson(String str)
factory
UDormBedInvoiceUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
contractId String?
final
creditorAmount double?
final
debtAmount double?
final
detail1 String?
final
detail2 String?
final
dueDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
paidAmount double?
final
penaltyAmount double?
final
penaltyPrecentEveryDate int?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited