UDormBedReadParams class
Constructors
-
UDormBedReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<
int> ? tags, List<String> ? ids, String? creatorId, String? title, String? roomId, String? dormId, double? minDeposit, double? maxDeposit, double? minMonthlyRent, double? maxMonthlyRent, DormBedSelectorArgs? selectorArgs, int? orderBy}) - UDormBedReadParams.fromJson(String str)
-
factory
-
UDormBedReadParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- creatorId → String?
-
final
- dormId → String?
-
final
- fromCreatedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ids
→ List<
String> ? -
final
- maxDeposit → double?
-
final
- maxMonthlyRent → double?
-
final
- minDeposit → double?
-
final
- minMonthlyRent → double?
-
final
- orderBy → int?
-
final
- pageNumber → int?
-
final
- pageSize → int?
-
final
- roomId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectorArgs → DormBedSelectorArgs?
-
final
-
final
- title → String?
-
final
- toCreatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited