UDormBedResponse class
Constructors
-
UDormBedResponse({required String id, required DateTime createdAt, required UBaseJson jsonData, required List<
int> tags, required String title, required double deposit, required double monthlyRent, required String roomId, required List<String> adminUserIds, UUserResponse? creator, String? creatorId, UDormRoomResponse? room, List<UMediaResponse> ? media, List<UDormBedContractResponse> ? contracts}) - UDormBedResponse.fromJson(String str)
-
factory
-
UDormBedResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> -
final
-
contracts
→ List<
UDormBedContractResponse> ? -
final
- createdAt → DateTime
-
final
- creator → UUserResponse?
-
final
- creatorId → String?
-
final
- deposit → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- jsonData → UBaseJson
-
final
-
media
→ List<
UMediaResponse> ? -
final
- monthlyRent → double
-
final
- room → UDormRoomResponse?
-
final
- roomId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited