UDormBedUpdateParams class

Constructors

UDormBedUpdateParams({required String id, String? detail1, String? detail2, List<int>? addTags, List<int>? removeTags, List<int>? tags, String? title, double? deposit, double? monthlyRent, String? roomId, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UDormBedUpdateParams.fromJson(String str)
factory
UDormBedUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
deposit double?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
monthlyRent double?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
roomId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited