UDormRoomCreateParams class

Constructors

UDormRoomCreateParams({required List<int> tags, required String title, required String dormId, String? detail1, String? detail2, String? id, String? creatorId, List<String>? adminUserIds})
UDormRoomCreateParams.fromJson(String str)
factory
UDormRoomCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
dormId String
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited