UDormRoomResponse class

Constructors

UDormRoomResponse({required String id, required DateTime createdAt, required UBaseJson jsonData, required List<int> tags, required String title, required String dormId, required List<String> adminUserIds, UUserResponse? creator, String? creatorId, UDormResponse? dorm, List<UDormBedResponse>? beds, List<UMediaResponse>? media})
UDormRoomResponse.fromJson(String str)
factory
UDormRoomResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
beds List<UDormBedResponse>?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
dorm UDormResponse?
final
dormId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UBaseJson
final
media List<UMediaResponse>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited