UDrivingLicenceNegativePointResponse class

Constructors

UDrivingLicenceNegativePointResponse({String? point, bool? allowable, String? ruleId, bool isCached = false, DateTime? cachedAt, DateTime? cacheExpiresAt})
UDrivingLicenceNegativePointResponse.fromJson(String str)
factory
UDrivingLicenceNegativePointResponse.fromMap(Map<String, dynamic> json)
factory

Properties

allowable bool?
final
cachedAt DateTime?
final
cacheExpiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
isCached bool
final
point String?
final
ruleId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited