UFileConfig class

Constructors

UFileConfig({required TagFileFieldType type, List<String>? allowedExtensions, bool isCamera = false, bool isSelfieCamera = false})
UFileConfig.fromJson(String str)
factory
UFileConfig.fromMap(Map<String, dynamic> json)
factory

Properties

allowedExtensions List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
isCamera bool
final
isSelfieCamera bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TagFileFieldType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited