UFileManagerRenameParams class

Constructors

UFileManagerRenameParams({required String path, required String newName})
UFileManagerRenameParams.fromJson(String str)
factory
UFileManagerRenameParams.fromMap(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
newName String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited