UFinancialOpsDashboardResponse class

Constructors

UFinancialOpsDashboardResponse({required DateTime generatedAt, required DateTime fromDate, required DateTime toDate, required int usersCount, required int newUsersCount, required int merchantsCount, required int newMerchantsCount, required int terminalsCount, required int terminalsAssignedCount, required int terminalsUnassignedCount, required int txnCount, required int newTxnCount, required int walletsCount, required double totalWalletBalance, required double totalIn, required double totalOut, required double net, required List<UAccountingBreakdownItem> txnByStatus, required List<UAccountingBreakdownItem> txnByMethod, required List<UAccountingBreakdownItem> terminalsByType, required List<UAccountingTimelineItem> dailyTimeline, required List<UTopMerchantItem> topMerchants, required List<URecentTxnItem> recentTransactions, required List<URecentMerchantItem> recentMerchants, required List<URecentUserItem> recentUsers})
UFinancialOpsDashboardResponse.fromJson(String str)
factory
UFinancialOpsDashboardResponse.fromMap(Map<String, dynamic> json)
factory

Properties

dailyTimeline List<UAccountingTimelineItem>
final
fromDate DateTime
final
generatedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
merchantsCount int
final
net double
final
newMerchantsCount int
final
newTxnCount int
final
newUsersCount int
final
recentMerchants List<URecentMerchantItem>
final
recentTransactions List<URecentTxnItem>
final
recentUsers List<URecentUserItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalsAssignedCount int
final
terminalsByType List<UAccountingBreakdownItem>
final
terminalsCount int
final
terminalsUnassignedCount int
final
toDate DateTime
final
topMerchants List<UTopMerchantItem>
final
totalIn double
final
totalOut double
final
totalWalletBalance double
final
txnByMethod List<UAccountingBreakdownItem>
final
txnByStatus List<UAccountingBreakdownItem>
final
txnCount int
final
usersCount int
final
walletsCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited