UFreewayTollsItem class

Constructors

UFreewayTollsItem({String? id, String? date, String? price, String? gateway, String? freeway})
UFreewayTollsItem.fromJson(String str)
factory
UFreewayTollsItem.fromMap(Map<String, dynamic> json)
factory

Properties

date String?
final
freeway String?
final
gateway String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
price String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited