UGoldReadOrdersParams class
Constructors
- UGoldReadOrdersParams({String? cursor, int limit = 20, String? idempotencyKey})
- UGoldReadOrdersParams.fromJson(String str)
-
factory
-
UGoldReadOrdersParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- cursor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotencyKey → String?
-
final
- limit → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited