UGoldTxnJson class

Constructors

UGoldTxnJson({String? detail1, String? detail2, double? feeAmount, String? feeAsset, double? requestedGoldAmount, double? requestedAmount, double? reservedAmount, double? reservedGoldAmount, String? providerStatus, String? error})
UGoldTxnJson.fromJson(String str)
factory
UGoldTxnJson.fromMap(Map<String, dynamic>? json)
factory

Properties

detail1 → String?
final
detail2 → String?
final
error → String?
final
feeAmount → double?
final
feeAsset → String?
final
hashCode → int
The hash code for this object.
no setterinherited
providerStatus → String?
final
requestedAmount → double?
final
requestedGoldAmount → double?
final
reservedAmount → double?
final
reservedGoldAmount → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited