UHotelCreateParams class

Constructors

UHotelCreateParams({required List<int> tags, required String title, required String cityCode, int stars = 0, String? address, String? phoneNumber, String? email, String? description, String? policies, String? checkInTime, String? checkOutTime, List<String>? amenities, String? detail1, String? detail2, String? id, String? creatorId, List<String>? adminUserIds})
UHotelCreateParams.fromJson(String str)
factory
UHotelCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

address String?
final
adminUserIds List<String>?
final
amenities List<String>?
final
checkInTime String?
final
checkOutTime String?
final
cityCode String
final
creatorId String?
final
description String?
final
detail1 String?
final
detail2 String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
phoneNumber String?
final
policies String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int
final
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited