UHotelInvoiceUpdateParams class

Constructors

UHotelInvoiceUpdateParams({required String id, String? detail1, String? detail2, List<int>? addTags, List<int>? removeTags, List<int>? tags, double? debtAmount, double? creditorAmount, double? paidAmount, double? penaltyAmount, int? penaltyPrecentEveryDate, DateTime? dueDate, String? reservationId, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UHotelInvoiceUpdateParams.fromJson(String str)
factory
UHotelInvoiceUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
creditorAmount double?
final
debtAmount double?
final
detail1 String?
final
detail2 String?
final
dueDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
paidAmount double?
final
penaltyAmount double?
final
penaltyPrecentEveryDate int?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
reservationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited