UHotelJson class
Constructors
-
UHotelJson({String? detail1, String? detail2, String? description, String? policies, String? checkInTime, String? checkOutTime, List<
String> amenities = const <String>[]}) - UHotelJson.fromJson(String str)
-
factory
-
UHotelJson.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
amenities
→ List<
String> -
final
- checkInTime → String?
-
final
- checkOutTime → String?
-
final
- description → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- policies → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited