UHotelReservationCreateParams class

Constructors

UHotelReservationCreateParams({required List<int> tags, required DateTime checkInDate, required DateTime checkOutDate, required int guestCount, required String userId, required String roomId, double? totalPrice, String? guestName, String? guestPhone, String? notes, int? penaltyPrecentEveryDate, String? detail1, String? detail2, String? id, String? creatorId, List<String>? adminUserIds})
UHotelReservationCreateParams.fromJson(String str)
factory
UHotelReservationCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
checkInDate DateTime
final
checkOutDate DateTime
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
guestCount int
final
guestName String?
final
guestPhone String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
notes String?
final
penaltyPrecentEveryDate int?
final
roomId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
totalPrice double?
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited