UHotelReservationReadParams class

Constructors

UHotelReservationReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? creatorId, String? userId, String? userName, String? roomId, String? hotelId, DateTime? checkInDate, DateTime? checkOutDate, bool? activeOnly, bool? upcomingOnly, bool? pastOnly, int? orderBy, HotelReservationSelectorArgs? selectorArgs})
UHotelReservationReadParams.fromJson(String str)
factory
UHotelReservationReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

activeOnly bool?
final
checkInDate DateTime?
final
checkOutDate DateTime?
final
creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
hotelId String?
final
ids List<String>?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
pastOnly bool?
final
roomId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs HotelReservationSelectorArgs?
final
tags List<int>?
final
toCreatedAt DateTime?
final
upcomingOnly bool?
final
userId String?
final
userName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited