UHotelReservationUpdateParams class

Constructors

UHotelReservationUpdateParams({required String id, String? detail1, String? detail2, List<int>? addTags, List<int>? removeTags, List<int>? tags, DateTime? checkInDate, DateTime? checkOutDate, int? guestCount, double? totalPrice, String? guestName, String? guestPhone, String? notes, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UHotelReservationUpdateParams.fromJson(String str)
factory
UHotelReservationUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
checkInDate DateTime?
final
checkOutDate DateTime?
final
detail1 String?
final
detail2 String?
final
guestCount int?
final
guestName String?
final
guestPhone String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
notes String?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>?
final
totalPrice double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited