UHotelRoomReadParams class

Constructors

UHotelRoomReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? creatorId, String? title, String? hotelId, double? minPrice, double? maxPrice, bool? availableOnly, HotelRoomSelectorArgs? selectorArgs, int? orderBy, int? minCapacity, int? maxCapacity})
UHotelRoomReadParams.fromJson(String str)
factory
UHotelRoomReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

availableOnly bool?
final
creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
hotelId String?
final
ids List<String>?
final
maxCapacity int?
final
maxPrice double?
final
minCapacity int?
final
minPrice double?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs HotelRoomSelectorArgs?
final
tags List<int>?
final
title String?
final
toCreatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited