UHotelRoomResponse class

Constructors

UHotelRoomResponse({required String id, required DateTime createdAt, required UHotelRoomJson jsonData, required List<int> tags, required String title, required int capacity, required double pricePerNight, required String hotelId, required List<String> adminUserIds, String? roomNumber, int quantity = 1, bool isAvailable = true, UUserResponse? creator, String? creatorId, UHotelResponse? hotel, List<UHotelReservationResponse>? reservations, List<UMediaResponse>? media})
UHotelRoomResponse.fromJson(String str)
factory
UHotelRoomResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
capacity int
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
hotel UHotelResponse?
final
hotelId String
final
id String
final
isAvailable bool
final
jsonData UHotelRoomJson
final
media List<UMediaResponse>?
final
pricePerNight double
final
quantity int
final
reservations List<UHotelReservationResponse>?
final
roomNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited