UHotelRoomUpdateParams class

Constructors

UHotelRoomUpdateParams({required String id, String? detail1, String? detail2, List<int>? addTags, List<int>? removeTags, List<int>? tags, String? title, int? capacity, double? pricePerNight, String? hotelId, String? roomNumber, int? quantity, bool? isAvailable, String? description, String? bedType, double? sizeSquareMeters, int? floor, List<String>? amenities, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UHotelRoomUpdateParams.fromJson(String str)
factory
UHotelRoomUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
amenities List<String>?
final
bedType String?
final
capacity int?
final
description String?
final
detail1 String?
final
detail2 String?
final
floor int?
final
hashCode int
The hash code for this object.
no setterinherited
hotelId String?
final
id String
final
isAvailable bool?
final
pricePerNight double?
final
quantity int?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
roomNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeSquareMeters double?
final
tags List<int>?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited