UHotelUpdateParams class

Constructors

UHotelUpdateParams({required String id, String? detail1, String? detail2, List<int>? addTags, List<int>? removeTags, List<int>? tags, String? title, String? cityCode, int? stars, String? address, String? phoneNumber, String? email, String? description, String? policies, String? checkInTime, String? checkOutTime, List<String>? amenities, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UHotelUpdateParams.fromJson(String str)
factory
UHotelUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
address String?
final
addTags List<int>?
final
adminUserIds List<String>?
final
amenities List<String>?
final
checkInTime String?
final
checkOutTime String?
final
cityCode String?
final
description String?
final
detail1 String?
final
detail2 String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
phoneNumber String?
final
policies String?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int?
final
tags List<int>?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited