UIBanToBankAccountDetailResponse class

Constructors

UIBanToBankAccountDetailResponse({String? depositNumber, String? iBanType, String? bankCode, String? bankName, String? ownerName, bool isCached = false, DateTime? cachedAt, DateTime? cacheExpiresAt})
UIBanToBankAccountDetailResponse.fromJson(String str)
factory
UIBanToBankAccountDetailResponse.fromMap(Map<String, dynamic> json)
factory

Properties

bankCode String?
final
bankName String?
final
cachedAt DateTime?
final
cacheExpiresAt DateTime?
final
depositNumber String?
final
hashCode int
The hash code for this object.
no setterinherited
iBanType String?
final
isCached bool
final
ownerName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited