UInquiryCacheStatusResponse class

Constructors

UInquiryCacheStatusResponse({UCacheStatusItem? vehicleViolation, UCacheStatusItem? drivingLicence, UCacheStatusItem? licencePlate, UCacheStatusItem? freewayTolls})
UInquiryCacheStatusResponse.fromJson(String str)
factory
UInquiryCacheStatusResponse.fromMap(Map<String, dynamic> json)
factory

Properties

drivingLicence UCacheStatusItem?
final
freewayTolls UCacheStatusItem?
final
hashCode int
The hash code for this object.
no setterinherited
licencePlate UCacheStatusItem?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vehicleViolation UCacheStatusItem?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited