UInternetPackageItem class

Constructors

UInternetPackageItem({String? id, String? title, int? amount, int? simType, String? duration, String? offerCode, int? packageDType, String? capacity})
UInternetPackageItem.fromJson(String str)
factory
UInternetPackageItem.fromMap(Map<String, dynamic> json)
factory

Properties

amount int?
final
capacity String?
final
duration String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
offerCode String?
final
packageDType int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simType int?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited