UIpgBrowserController class

Constructors

UIpgBrowserController({required String url, required UIpgAdditionalData additionalData})

Properties

additionalData → UIpgAdditionalData
final
finished ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

cancel() → void
check({bool showPending = false}) → Future<void>
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited