UIpgSaleParams class

Constructors

UIpgSaleParams({required double amount, TagTxn? tag, String? invoiceId})
UIpgSaleParams.fromJson(String str)
factory
UIpgSaleParams.fromMap(Map<String, dynamic> json)
factory

Properties

amount double
final
hashCode int
The hash code for this object.
no setterinherited
invoiceId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag TagTxn?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited