UIpgVerifyResponse class

Constructors

UIpgVerifyResponse({required bool paid, required bool failed, required double balance})
UIpgVerifyResponse.fromJson(String str)
factory
UIpgVerifyResponse.fromMap(Map<String, dynamic> json)
factory

Properties

balance double
final
failed bool
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited