ULicencePlateDetailParams class

Constructors

ULicencePlateDetailParams({required String nationalCode, required String licencePlate, bool refresh = false})
ULicencePlateDetailParams.fromJson(String str)
factory
ULicencePlateDetailParams.fromMap(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
licencePlate → String
final
nationalCode → String
final
refresh → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited