ULicencePlateDetailResponse class
Constructors
-
ULicencePlateDetailResponse({String? status, String? tracePlate, List<
ULicencePlateHistoryItem> ? items, bool isCached = false, DateTime? cachedAt, DateTime? cacheExpiresAt}) - ULicencePlateDetailResponse.fromJson(String str)
-
factory
-
ULicencePlateDetailResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- cachedAt → DateTime?
-
final
- cacheExpiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCached → bool
-
final
-
items
→ List<
ULicencePlateHistoryItem> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
- tracePlate → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited