ULicencePlateHistoryItem class

Constructors

ULicencePlateHistoryItem({String? system, String? type, String? installDate, String? model})
ULicencePlateHistoryItem.fromJson(String str)
factory
ULicencePlateHistoryItem.fromMap(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
installDate String?
final
model String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
system String?
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited