UMediaCreateParams class

Constructors

UMediaCreateParams({required FileData file, required int tag1, int? tag2, int? tag3, String? userId, String? contentId, String? commentId, String? categoryId, String? productId, String? blogId, String? title, String? description, String? creatorId, String? hotelId, String? hotelRoomId, String? dormId, String? dormRoomId, String? dormBedId})

Properties

blogId String?
final
categoryId String?
final
commentId String?
final
contentId String?
final
creatorId String?
final
description String?
final
dormBedId String?
final
dormId String?
final
dormRoomId String?
final
file FileData
final
hashCode int
The hash code for this object.
no setterinherited
hotelId String?
final
hotelRoomId String?
final
productId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag1 int
final
tag2 int?
final
tag3 int?
final
title String?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited