UMediaReadParams class

Constructors

UMediaReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, int? orderBy})
UMediaReadParams.fromJson(String str)
factory
UMediaReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
orderBy int?
final
pageNumber int?
final
pageSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>?
final
toCreatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited