UMediaService class

Constructors

UMediaService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required UMediaCreateParams p, required dynamic onOk(UResponse<String> r)?, required dynamic onError(UEmptyResponse r), required dynamic onException(String e)}) → Future<(UResponse<String>?, UEmptyResponse?, String?)>
delete({required UIdParams p, required dynamic onOk(UEmptyResponse r), required dynamic onError(UEmptyResponse r), required dynamic onException(String e)}) → Future<(UEmptyResponse?, UEmptyResponse?, String?)>
deleteRange({required UIdListParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) → Future<(UEmptyResponse?, UEmptyResponse?, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({required UMediaReadParams p, required dynamic onOk(UResponse<List<UMediaResponse>> r), required dynamic onError(UEmptyResponse r), required dynamic onException(String e)}) → Future<(UResponse<List<UMediaResponse>>?, UEmptyResponse?, String?)>
syncGallery(UFilePickerController photos, {required List<UMediaResponse> existing, String? hotelId, String? hotelRoomId, String? dormId, String? dormRoomId, String? dormBedId}) → Future<void>
Saves a UFilePicker.gallery: deletes removed photos, uploads new ones (category = first tag) and moves the cover mark.
toString() → String
A string representation of this object.
inherited
update({required UMediaUpdateParams p, required dynamic onOk(UEmptyResponse r), required dynamic onError(UEmptyResponse r), required dynamic onException(String e)}) → Future<(UEmptyResponse?, UEmptyResponse?, String?)>

Operators

operator ==(Object other) → bool
The equality operator.
inherited