UMerchantReadParams class

Constructors

UMerchantReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? creatorId, String? zipCode, String? userId, String? cityCode, String? phoneNumber, String? title, String? landline, String? nationalCode, String? bankAccountId, String? mcc, String? merchantId, String? insId, int? orderBy, MerchantSelectorArgs? selectorArgs})
UMerchantReadParams.fromJson(String str)
factory
UMerchantReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

bankAccountId String?
final
cityCode String?
final
creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
insId String?
final
landline String?
final
mcc String?
final
merchantId String?
final
nationalCode String?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
phoneNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs MerchantSelectorArgs?
final
tags List<int>?
final
title String?
final
toCreatedAt DateTime?
final
userId String?
final
zipCode String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited