UMerchantResponse class

Constructors

UMerchantResponse({required String id, required DateTime createdAt, required MerchantJsonData jsonData, required List<int> tags, required String zipCode, required String cityCode, required String phoneNumber, required String title, required String landline, required String nationalCode, required String mcc, required String userId, required List<String> adminUserIds, UUserResponse? creator, String? creatorId, String? bankAccountId, String? merchantId, String? insId, UUserResponse? user, List<UTerminalResponse>? terminals})
UMerchantResponse.fromJson(String str)
factory
UMerchantResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
bankAccountId String?
final
cityCode String
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
insId String?
final
jsonData MerchantJsonData
final
landline String
final
mcc String
final
merchantId String?
final
nationalCode String
final
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
terminals List<UTerminalResponse>?
final
title String
final
user UUserResponse?
final
userId String
final
zipCode String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited