UMoadiCreateParams class
Constructors
-
UMoadiCreateParams({required List<
int> tags, required String name, required String economicCode, required String legalEntity, required String uniqueTaxCode, required String ownerName, required String ownerMobile, required String ownerNationalCode, String? detail1, String? detail2, String? id, String? creatorId, String? userId, String? nationalCode, String? postalCode, String? registrationDate, String? registrationNumber, String? address, int? startInvoiceNumber, String? introductionCode, List<String> ? adminUserIds}) - UMoadiCreateParams.fromJson(String str)
-
factory
-
UMoadiCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- address → String?
-
final
-
adminUserIds
→ List<
String> ? -
final
- creatorId → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- economicCode → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- introductionCode → String?
-
final
- legalEntity → String
-
final
- name → String
-
final
- nationalCode → String?
-
final
- ownerMobile → String
-
final
- ownerName → String
-
final
- ownerNationalCode → String
-
final
- postalCode → String?
-
final
- registrationDate → String?
-
final
- registrationNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startInvoiceNumber → int?
-
final
-
final
- uniqueTaxCode → String
-
final
- userId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited