UMoadiResponse class

Constructors

UMoadiResponse({required String id, required DateTime createdAt, required MoadiJsonData jsonData, required List<int> tags, required String name, required String economicCode, required String legalEntity, required String uniqueTaxCode, required String ownerName, required String ownerMobile, required String ownerNationalCode, required String userId, required List<String> adminUserIds, UUserResponse? creator, String? creatorId, String? nationalCode, String? postalCode, String? registrationDate, String? registrationNumber, String? address, int? startInvoiceNumber, String? introductionCode, UUserResponse? user})
UMoadiResponse.fromJson(String str)
factory
UMoadiResponse.fromMap(Map<String, dynamic> json)
factory

Properties

address String?
final
adminUserIds List<String>
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
economicCode String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
introductionCode String?
final
jsonData MoadiJsonData
final
legalEntity String
final
name String
final
nationalCode String?
final
ownerMobile String
final
ownerName String
final
ownerNationalCode String
final
postalCode String?
final
registrationDate String?
final
registrationNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startInvoiceNumber int?
final
tags List<int>
final
uniqueTaxCode String
final
user UUserResponse?
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited