UMoadiUpdateParams class

Constructors

UMoadiUpdateParams({required String id, String? name, String? economicCode, String? legalEntity, String? uniqueTaxCode, String? nationalCode, String? postalCode, String? registrationDate, String? registrationNumber, String? address, int? startInvoiceNumber, String? introductionCode, String? ownerName, String? ownerMobile, String? ownerNationalCode, List<int>? tags, List<int>? addTags, List<int>? removeTags, String? detail1, String? detail2, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UMoadiUpdateParams.fromJson(String str)
factory
UMoadiUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
address String?
final
addTags List<int>?
final
adminUserIds List<String>?
final
detail1 String?
final
detail2 String?
final
economicCode String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
introductionCode String?
final
legalEntity String?
final
name String?
final
nationalCode String?
final
ownerMobile String?
final
ownerName String?
final
ownerNationalCode String?
final
postalCode String?
final
registrationDate String?
final
registrationNumber String?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startInvoiceNumber int?
final
tags List<int>?
final
uniqueTaxCode String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited