UNotificationResponse class

Constructors

UNotificationResponse({required String id, required DateTime createdAt, required UBaseJson jsonData, required List<int> tags, required String userId, required List<String> adminUserIds, UUserResponse? user, UUserResponse? creator, String? creatorId, String? zipCode})
UNotificationResponse.fromJson(String str)
factory
UNotificationResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UBaseJson
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
user UUserResponse?
final
userId String
final
zipCode String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited