UOsMetricsResponse class
Constructors
- UOsMetricsResponse({required DateTime generatedAt, required String osName, required String osDescription, required String osArchitecture, required String processArchitecture, required String frameworkDescription, required String machineName, required bool is64BitOperatingSystem, required bool is64BitProcess, required int processorCount, required double systemUptimeSeconds, required double processUptimeSeconds, required DateTime processStartedAt, required double cpuUsagePercent, required double memoryTotalGb, required double memoryUsedGb, required double memoryFreeGb, required double memoryUsagePercent, required double diskTotalGb, required double diskUsedGb, required double diskFreeGb, required double diskUsagePercent, double? loadAverage1Min, double? loadAverage5Min, double? loadAverage15Min})
- UOsMetricsResponse.fromJson(String str)
-
factory
-
UOsMetricsResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- cpuUsagePercent → double
-
final
- diskFreeGb → double
-
final
- diskTotalGb → double
-
final
- diskUsagePercent → double
-
final
- diskUsedGb → double
-
final
- frameworkDescription → String
-
final
- generatedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- is64BitOperatingSystem → bool
-
final
- is64BitProcess → bool
-
final
- loadAverage15Min → double?
-
final
- loadAverage1Min → double?
-
final
- loadAverage5Min → double?
-
final
- machineName → String
-
final
- memoryFreeGb → double
-
final
- memoryTotalGb → double
-
final
- memoryUsagePercent → double
-
final
- memoryUsedGb → double
-
final
- osArchitecture → String
-
final
- osDescription → String
-
final
- osName → String
-
final
- processArchitecture → String
-
final
- processorCount → int
-
final
- processStartedAt → DateTime
-
final
- processUptimeSeconds → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemUptimeSeconds → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited