UOverdueInvoiceItem class

Constructors

UOverdueInvoiceItem({required String id, required double debtAmount, required double paidAmount, required double penaltyAmount, required DateTime dueDate, required int daysOverdue, String? userName})
UOverdueInvoiceItem.fromJson(String str)
factory
UOverdueInvoiceItem.fromMap(Map<String, dynamic> json)
factory

Properties

daysOverdue int
final
debtAmount double
final
dueDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
paidAmount double
final
penaltyAmount double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited