UParkingReportCreateParams class
Constructors
-
UParkingReportCreateParams({required String parkingId, required DateTime startDate, required String numberPlate, required List<
int> tags, DateTime? endDate, double? amount, String? detail1, String? detail2, String? id, String? creatorId, List<String> ? adminUserIds}) - UParkingReportCreateParams.fromJson(String str)
-
factory
-
UParkingReportCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> ? -
final
- amount → double?
-
final
- creatorId → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- endDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- numberPlate → String
-
final
- parkingId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime
-
final
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited