UParkingReportReadParams class

Constructors

UParkingReportReadParams({int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? vehicleId, String? parkingId, DateTime? startDate, DateTime? endDate, ParkingReportSelectorArgs? selectorArgs, int? orderBy, String? creatorId})
UParkingReportReadParams.fromJson(String str)
factory
UParkingReportReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

creatorId String?
final
endDate DateTime?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
parkingId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs ParkingReportSelectorArgs?
final
startDate DateTime?
final
tags List<int>?
final
toCreatedAt DateTime?
final
vehicleId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited