UParkingReportResponse class

Constructors

UParkingReportResponse({required String id, required DateTime createdAt, required UBaseJson jsonData, required List<int> tags, required DateTime startDate, required String vehicleId, required String parkingId, required List<String> adminUserIds, DateTime? endDate, double? amount, UVehicleResponse? vehicle, UParkingResponse? parking, UUserResponse? creator, String? creatorId})
UParkingReportResponse.fromJson(String str)
factory
UParkingReportResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
amount double?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UBaseJson
final
parking UParkingResponse?
final
parkingId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime
final
tags List<int>
final
vehicle UVehicleResponse?
final
vehicleId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited