UParkingResponse class

Constructors

UParkingResponse({required String id, required DateTime createdAt, required UBaseJson jsonData, required List<int> tags, required String title, required List<String> adminUserIds, required double entrancePrice, required double hourlyPrice, required double dailyPrice, UUserResponse? creator, String? creatorId})
UParkingResponse.fromJson(String str)
factory
UParkingResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
dailyPrice double
final
entrancePrice double
final
hashCode int
The hash code for this object.
no setterinherited
hourlyPrice double
final
id String
final
jsonData UBaseJson
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited