UParkingUpdateParams class

Constructors

UParkingUpdateParams({required String id, double? entrancePrice, double? hourlyPrice, double? dailyPrice, List<int>? addTags, List<int>? removeTags, String? detail1, String? detail2, List<int>? tags, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UParkingUpdateParams.fromJson(String str)
factory
UParkingUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
dailyPrice double?
final
detail1 String?
final
detail2 String?
final
entrancePrice double?
final
hashCode int
The hash code for this object.
no setterinherited
hourlyPrice double?
final
id String
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited