UParkingUserCreateParams class
Constructors
- UParkingUserCreateParams({required String parkingId, required String userName, required String password, String? firstName, String? lastName, String? phoneNumber})
- UParkingUserCreateParams.fromJson(String str)
-
factory
-
UParkingUserCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String?
-
final
- parkingId → String
-
final
- password → String
-
final
- phoneNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited