UPaymentRequest class

Constructors

UPaymentRequest({required String title, required int amount, required Future<bool> onPay(), List<UPaymentLine> lines = const <UPaymentLine>[]})

Properties

amount int
final
hashCode int
The hash code for this object.
no setterinherited
lines List<UPaymentLine>
final
onPay Future<bool> Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited