UProcessItem class

Constructors

UProcessItem({required String id, required String title, required String description, required String icon, required TagProcessStatus status})
UProcessItem.fromJson(String str)
factory
UProcessItem.fromMap(Map<String, dynamic> json)
factory

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
icon String
final
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TagProcessStatus
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited