UProductResponse class

Constructors

UProductResponse({required String id, required DateTime createdAt, required UProductJson jsonData, required List<int> tags, required String title, required int point, required String creatorId, required List<String> adminUserIds, required int order, String? code, String? subtitle, String? description, String? slug, String? type, String? content, double? latitude, double? longitude, int? stock, String? parentId, UUserResponse? creator, List<UProductResponse>? children, List<UMediaResponse>? media, List<UCategoryResponse>? categories, int? commentCount, bool? isFollowing, int? childrenCount})
UProductResponse.fromJson(String str)
factory
UProductResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
categories List<UCategoryResponse>?
final
children List<UProductResponse>?
final
childrenCount int?
final
code String?
final
commentCount int?
final
content String?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isFollowing bool?
final
jsonData UProductJson
final
latitude double?
final
longitude double?
final
media List<UMediaResponse>?
final
order int
final
parentId String?
final
point int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
final
stock int?
final
subtitle String?
final
tags List<int>
final
title String
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited