UProductUpdateParams class

Constructors

UProductUpdateParams({required String id, String? title, String? code, String? subtitle, String? description, String? slug, String? type, String? content, double? latitude, double? longitude, int? stock, String? parentId, String? creatorId, String? actionType, String? actionTitle, String? actionUri, String? details, List<String>? relatedProducts, List<String>? addRelatedProducts, List<String>? removeRelatedProducts, List<String>? addCategories, List<String>? categories, List<String>? removeCategories, List<int>? addTags, List<int>? removeTags, List<int>? tags, int? point, String? phoneNumber, String? address, String? detail1, String? detail2, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds, int? order, List<String>? media})
UProductUpdateParams.fromJson(String str)
factory
UProductUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

actionTitle String?
final
actionType String?
final
actionUri String?
final
addAdminUserIds List<String>?
final
addCategories List<String>?
final
addRelatedProducts List<String>?
final
address String?
final
addTags List<int>?
final
adminUserIds List<String>?
final
categories List<String>?
final
code String?
final
content String?
final
creatorId String?
final
description String?
final
detail1 String?
final
detail2 String?
final
details String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
latitude double?
final
longitude double?
final
media List<String>?
final
order int?
final
parentId String?
final
phoneNumber String?
final
point int?
final
relatedProducts List<String>?
final
removeAdminUserIds List<String>?
final
removeCategories List<String>?
final
removeRelatedProducts List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
final
stock int?
final
subtitle String?
final
tags List<int>?
final
title String?
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited