URecentMerchantItem class

Constructors

URecentMerchantItem({required String id, required String title, required String cityCode, required int terminalCount, required DateTime createdAt})
URecentMerchantItem.fromJson(String str)
factory
URecentMerchantItem.fromMap(Map<String, dynamic> json)
factory

Properties

cityCode String
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalCount int
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited