USettingsChargeInternet class
Constructors
-
USettingsChargeInternet({required TagSimOperator operator, required String title, required String logo, required List<
USettingsChargeAmount> preDefinedAmountsList}) - USettingsChargeInternet.fromJson(String str)
-
factory
-
USettingsChargeInternet.fromMap(Map<
String, dynamic> j) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logo ↔ String
-
getter/setter pair
- operator ↔ TagSimOperator
-
getter/setter pair
-
preDefinedAmountsList
↔ List<
USettingsChargeAmount> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited