USettingsCosts class

Constructors

USettingsCosts({required double mobileAndNationalCodeVerification, required double zipCodeToAddressDetail, required double vehicleViolationsDetail, required double drivingLicenceStatus, required double freewayToll, required double licencePlateDetail, required double drivingLicenceNegativePoint, required double iBanToBankAccountDetail})
USettingsCosts.fromJson(String str)
factory
USettingsCosts.fromMap(Map<String, dynamic> j)
factory

Properties

drivingLicenceNegativePoint double
getter/setter pair
drivingLicenceStatus double
getter/setter pair
freewayToll double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iBanToBankAccountDetail double
getter/setter pair
licencePlateDetail double
getter/setter pair
mobileAndNationalCodeVerification double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vehicleViolationsDetail double
getter/setter pair
zipCodeToAddressDetail double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited