USettingsItHub class

Constructors

USettingsItHub({required String clientId, required String clientSecret, required String userName, required String password})
USettingsItHub.fromJson(String str)
factory
USettingsItHub.fromMap(Map<String, dynamic> j)
factory

Properties

clientId String
getter/setter pair
clientSecret String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
password String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited