USettingsJwt class
Constructors
- USettingsJwt({required String key, required String issuer, required String audience, required String expires})
- USettingsJwt.fromJson(String str)
-
factory
-
USettingsJwt.fromMap(Map<
String, dynamic> j) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited