USettingsMiddleware class
Constructors
- USettingsMiddleware({required bool requireApiKey, required bool requireRefreshToken, required bool log, required bool logSuccess, required bool logHeaders})
- USettingsMiddleware.fromJson(String str)
-
factory
-
USettingsMiddleware.fromMap(Map<
String, dynamic> j) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- log ↔ bool
-
getter/setter pair
- logHeaders ↔ bool
-
getter/setter pair
- logSuccess ↔ bool
-
getter/setter pair
- requireApiKey ↔ bool
-
getter/setter pair
- requireRefreshToken ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited