USettingsSms class

Constructors

USettingsSms({required TagSmsPanel tag, required String loginOtpPattern, required String supportPasswordOtp, required String apiKey})
USettingsSms.fromJson(String str)
factory
USettingsSms.fromMap(Map<String, dynamic> j)
factory

Properties

apiKey String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loginOtpPattern String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportPasswordOtp String
getter/setter pair
tag TagSmsPanel
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited