USimCardCreateParams class

Constructors

USimCardCreateParams({required String number, required List<int> tags, String? id, String? serial, String? detail1, String? detail2, String? creatorId, List<String>? adminUserIds})
USimCardCreateParams.fromJson(String str)
factory
USimCardCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
number String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String?
final
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited