USimCardResponse class
Constructors
-
USimCardResponse({required String id, required String createdAt, required UBaseJson jsonData, required List<
int> tags, required String number, required String userId, required List<String> adminUserIds, UUserResponse? creator, String? creatorId, String? serial, UUserResponse? user}) - USimCardResponse.fromJson(String str)
-
factory
-
USimCardResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> -
final
- createdAt → String
-
final
- creator → UUserResponse?
-
final
- creatorId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- jsonData → UBaseJson
-
final
- number → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serial → String?
-
final
-
final
- user → UUserResponse?
-
final
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited