UTerminalBrokerJson class

Constructors

UTerminalBrokerJson({String? detail1, String? detail2, String? registrationNumber, String? nationalCode, String? representative, String? address, String? postalCode, String? phoneNumber, String? sign1Base64, String? sign1Owner, String? sign2Base64, String? sign2Owner, String? logoBase64})
UTerminalBrokerJson.fromJson(String str)
factory
UTerminalBrokerJson.fromMap(Map<String, dynamic> json)
factory

Properties

address → String?
final
detail1 → String?
final
detail2 → String?
final
hashCode → int
The hash code for this object.
no setterinherited
logoBase64 → String?
final
nationalCode → String?
final
phoneNumber → String?
final
postalCode → String?
final
registrationNumber → String?
final
representative → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sign1Base64 → String?
final
sign1Owner → String?
final
sign2Base64 → String?
final
sign2Owner → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited