UTerminalCreateParams class
Constructors
-
UTerminalCreateParams({required List<
int> tags, required String serial, String? id, String? simCardNumber, String? simCardSerial, String? imei, String? terminalId, String? detail1, String? detail2, String? creatorId, List<String> ? adminUserIds, String? insId, String? agreement, String? merchantId}) - UTerminalCreateParams.fromJson(String str)
-
factory
-
UTerminalCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> ? -
final
- agreement → String?
-
final
- creatorId → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- imei → String?
-
final
- insId → String?
-
final
- merchantId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serial → String
-
final
- simCardNumber → String?
-
final
- simCardSerial → String?
-
final
-
final
- terminalId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited