UTerminalReadParams class

Constructors

UTerminalReadParams({required TerminalSelectorArgs? selectorArgs, int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, List<String>? ids, String? creatorId, String? serial, String? merchantId, int? orderBy, String? simCardNumber, String? simCardSerial, String? imei, String? terminalId, String? insId})
UTerminalReadParams.fromJson(String str)
factory
UTerminalReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

creatorId String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
imei String?
final
insId String?
final
merchantId String?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs TerminalSelectorArgs?
final
serial String?
final
simCardNumber String?
final
simCardSerial String?
final
tags List<int>?
final
terminalId String?
final
toCreatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited