UTerminalResponse class

Constructors

UTerminalResponse({required List<int> tags, required UBaseJson jsonData, required String serial, required DateTime createdAt, required String id, required List<String> adminUserIds, String? terminalId, String? simCardNumber, String? simCardSerial, String? agreement, String? imei, UMerchantResponse? merchant, UUserResponse? creator, String? creatorId, String? merchantId})
UTerminalResponse.fromJson(String str)
factory
UTerminalResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
agreement String?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
imei String?
final
jsonData UBaseJson
final
merchant UMerchantResponse?
final
merchantId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String
final
simCardNumber String?
final
simCardSerial String?
final
tags List<int>
final
terminalId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited