UTicketResponse class

Constructors

UTicketResponse({required String id, required DateTime createdAt, required UTicketJson jsonData, required List<int> tags, required String creatorId, required List<String> adminUserIds, UUserResponse? creator, List<UMediaResponse>? media})
UTicketResponse.fromJson(String str)
factory
UTicketResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UTicketJson
final
media List<UMediaResponse>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited