UTxnResponse class

Constructors

UTxnResponse({required String id, required UBaseJson jsonData, required List<int> tags, required double amount, required String userId, required String? trackingNumber, required List<String> adminUserIds, UUserResponse? user, String? createdAt, String? creatorId, UUserResponse? creator})
UTxnResponse.fromJson(String str)
factory
UTxnResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
amount double
final
createdAt String?
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UBaseJson
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
trackingNumber String?
final
user UUserResponse?
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited