UVehicleCreateParams class

Constructors

UVehicleCreateParams({required String licencePlate, required List<int> tags, String? id, String? title, String? brand, String? color, String? detail1, String? detail2, String? creatorId, List<String>? adminUserIds})
UVehicleCreateParams.fromJson(String str)
factory
UVehicleCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
brand String?
final
color String?
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
licencePlate String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited