UVehicleResponse class

Constructors

UVehicleResponse({required String licencePlate, required List<int> tags, required String id, required UBaseJson jsonData, required DateTime createdAt, required List<String> adminUserIds, String? brand, String? title, String? color, UUserResponse? creator, String? creatorId})
UVehicleResponse.fromJson(String str)
factory
UVehicleResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
brand String?
final
color String?
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UBaseJson
final
licencePlate String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited