UVehicleUpdateParams class

Constructors

UVehicleUpdateParams({required String id, List<int>? addTags, List<int>? removeTags, List<int>? tags, String? brand, String? color, String? detail1, String? detail2, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds, String? licencePlate})
UVehicleUpdateParams.fromJson(String str)
factory
UVehicleUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
brand String?
final
color String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
licencePlate String?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited