UVehicleViolationDetailItem class

Constructors

UVehicleViolationDetailItem({String? serialNo, String? date, String? type, String? address, String? violationType, String? finalPrice, String? paperId, String? paymentId, String? warningId, String? investigationAbility, bool? hasImage})
UVehicleViolationDetailItem.fromJson(String str)
factory
UVehicleViolationDetailItem.fromMap(Map<String, dynamic> json)
factory

Properties

address → String?
final
date → String?
final
finalPrice → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hasImage → bool?
final
investigationAbility → String?
final
paperId → String?
final
paymentId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNo → String?
final
type → String?
final
violationType → String?
final
warningId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited