UVehicleViolationDetailResponse class

Constructors

UVehicleViolationDetailResponse({required List<UVehicleViolationDetailItem> items, String? plateDictation, String? plateChar, String? complaintStatus, String? complaint, String? dateTime, String? priceStatus, String? traceId, String? paperId, String? paymentId, String? warningPrice, String? inquirePrice, String? ejrInquireNo, String? warningId, String? inquirePriceDictation, bool isCached = false, DateTime? cachedAt, DateTime? cacheExpiresAt})
UVehicleViolationDetailResponse.fromJson(String str)
factory
UVehicleViolationDetailResponse.fromMap(Map<String, dynamic> json)
factory

Properties

cachedAt → DateTime?
final
cacheExpiresAt → DateTime?
final
complaint → String?
final
complaintStatus → String?
final
dateTime → String?
final
ejrInquireNo → String?
final
hashCode → int
The hash code for this object.
no setterinherited
inquirePrice → String?
final
inquirePriceDictation → String?
final
isCached → bool
final
items → List<UVehicleViolationDetailItem>
final
paperId → String?
final
paymentId → String?
final
plateChar → String?
final
plateDictation → String?
final
priceStatus → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traceId → String?
final
warningId → String?
final
warningPrice → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited