UZipCodeToAddressDetailResponse class

Constructors

UZipCodeToAddressDetailResponse({required String? buildingName, required String? description, required String? floor, required String? houseNumber, required String? localityName, required String? localityType, required String? zipCode, required String? province, required String? sideFloor, required String? street, required String? street2, required String? subLocality, required String? townShip, required String? traceId, required String? village, bool isCached = false, DateTime? cachedAt, DateTime? cacheExpiresAt})
UZipCodeToAddressDetailResponse.fromJson(String str)
factory
UZipCodeToAddressDetailResponse.fromMap(Map<String, dynamic> json)
factory

Properties

buildingName String?
final
cachedAt DateTime?
final
cacheExpiresAt DateTime?
final
description String?
final
floor String?
final
hashCode int
The hash code for this object.
no setterinherited
houseNumber String?
final
isCached bool
final
localityName String?
final
localityType String?
final
province String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sideFloor String?
final
street String?
final
street2 String?
final
subLocality String?
final
townShip String?
final
traceId String?
final
village String?
final
zipCode String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited