UserFlowField class

Represents a single form field with complete configuration

Constructors

UserFlowField({required String fieldName, required String label, required FieldType type, bool isRequired = true, String? hint, String? placeholder, String? defaultValue, bool isDisabled = false, bool isReadOnly = false, bool isHidden = false, ValidationRules? validation, List<SelectOption>? options, DynamicOptionsConfig? dynamicOptions, DependencyRule? dependency, VisibilityRule? visibility, String? apiEndpoint, String? httpMethod = "PUT", Map<String, String>? apiHeaders, ApiAction? onApiResponse, int? debounceMs, bool autoSave = true, String? cssClass, FieldWidth width = FieldWidth.full, int order = 0})
UserFlowField.fromJson(Map<String, dynamic> json)
factory

Properties

apiEndpoint String?
final
apiHeaders Map<String, String>?
final
autoSave bool
final
cssClass String?
final
debounceMs int?
final
defaultValue String?
final
dependency DependencyRule?
final
dynamicOptions DynamicOptionsConfig?
final
fieldName String
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
httpMethod String?
final
isDisabled bool
final
isHidden bool
final
isReadOnly bool
final
isRequired bool
final
label String
final
onApiResponse ApiAction?
final
options List<SelectOption>?
final
order int
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type FieldType
final
validation ValidationRules?
final
visibility VisibilityRule?
final
width FieldWidth
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited