UserFlowFileRequirement class

File upload configuration

Constructors

UserFlowFileRequirement({required String fileKey, required String label, required UFileType allowedFileType, required String uploadApiEndpoint, int maxFileSizeMB = 5, List<String>? allowedExtensions, bool isRequired = true, int? maxCount = 1, int? minCount, String? uploadMethod = "POST", Map<String, String>? additionalFormData, bool compressImage = false, double? imageQuality, int? resizeToWidth, int? resizeToHeight, String? cropAspectRatio, bool useCamera = false, String? deleteApiEndpoint, String? previewUrlTemplate})
UserFlowFileRequirement.fromJson(Map<String, dynamic> json)
factory

Properties

additionalFormData Map<String, String>?
final
allowedExtensions List<String>?
final
allowedFileType UFileType
final
compressImage bool
final
cropAspectRatio String?
final
deleteApiEndpoint String?
final
fileKey String
final
hashCode int
The hash code for this object.
no setterinherited
imageQuality double?
final
isRequired bool
final
label String
final
maxCount int?
final
maxFileSizeMB int
final
minCount int?
final
previewUrlTemplate String?
final
resizeToHeight int?
final
resizeToWidth int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uploadApiEndpoint String
final
uploadMethod String?
final
useCamera bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited