UserSelectorArgs class

Constructors

UserSelectorArgs({CategorySelectorArgs? category, MediaSelectorArgs? media, TxnSelectorArgs? txns, AddressSelectorArgs? address, WalletSelectorArgs? wallet, MerchantSelectorArgs? merchant, BankAccountSelectorArgs? bankAccount, SimSelectorArgs? simCard, bool? nationalCardFront, bool? nationalCardBack, bool? birthCertificateFirst, bool? birthCertificateSecond, bool? birthCertificateThird, bool? birthCertificateForth, bool? birthCertificateFifth, bool? visualAuthentication, bool? eSignature})
const
UserSelectorArgs.fromJson(String str)
factory
UserSelectorArgs.fromMap(Map<String, dynamic> json)
factory

Properties

address AddressSelectorArgs?
final
bankAccount BankAccountSelectorArgs?
final
birthCertificateFifth bool?
final
birthCertificateFirst bool?
final
birthCertificateForth bool?
final
birthCertificateSecond bool?
final
birthCertificateThird bool?
final
category CategorySelectorArgs?
final
eSignature bool?
final
hashCode int
The hash code for this object.
no setterinherited
media MediaSelectorArgs?
final
merchant MerchantSelectorArgs?
final
nationalCardBack bool?
final
nationalCardFront bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simCard SimSelectorArgs?
final
txns TxnSelectorArgs?
final
visualAuthentication bool?
final
wallet WalletSelectorArgs?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited