WalletService class

Constructors

WalletService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

charge({required UWalletChargeParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purchase({required UWalletPurchaseParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>
read({required UWalletReadParams p, required dynamic onOk(UResponse<List<UWalletResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<List<UWalletResponse>>?, UEmptyResponse?, String?)>
readByUserId({required UIdParams p, required dynamic onOk(UResponse<List<UWalletResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<List<UWalletResponse>>?, UEmptyResponse?, String?)>
readTxn({required UWalletTxnReadParams p, required dynamic onOk(UResponse<List<UWalletTxnResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UResponse<List<UWalletTxnResponse>>?, UEmptyResponse?, String?)>
toString() String
A string representation of this object.
inherited
transfer({required UWalletTransferParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?}) Future<(UEmptyResponse?, UEmptyResponse?, String?)>

Operators

operator ==(Object other) bool
The equality operator.
inherited