NumericIdentifiable mixin

Properties

hashCode int
The hash code for this object.
no setterinherited
localizedTitle String
no setter
number int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleEn String
no setter
titleFa String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited