TagBlog enum

Inheritance
Mixed-in types
Available extensions

Values

draft → const TagBlog
const TagBlog("پیش‌نویس", "Draft", 101)
published → const TagBlog
const TagBlog("منتشر شده", "Published", 102)
archived → const TagBlog
const TagBlog("بایگانی شده", "Archived", 103)
const TagBlog("ویژه", "Featured", 201)
pinned → const TagBlog
const TagBlog("سنجاق شده", "Pinned", 202)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle String
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleEn String
final
titleFa String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TagBlog>
A constant List of the values in this enum, in order of their declaration.