TagCategory enum

Inheritance
Mixed-in types
Available extensions

Values

category → const TagCategory
const TagCategory("دسته‌بندی", "Category", 101)
exam → const TagCategory
const TagCategory("پرسشنامه", "Exam", 102)
user → const TagCategory
const TagCategory("کاربران", "User", 103)
const TagCategory("منو", "Menu", 104)
speciality → const TagCategory
const TagCategory("تخصص", "Speciality", 105)
dorm → const TagCategory
const TagCategory("خوابگاه", "Dorm", 106)
room → const TagCategory
const TagCategory("اتاق", "Room", 107)
bed → const TagCategory
const TagCategory("تخت", "Bed", 108)
enabled → const TagCategory
const TagCategory("فعال", "Enabled", 201)
disabled → const TagCategory
const TagCategory("غیر فعال", "Disabled", 202)
hidden → const TagCategory
const TagCategory("مخفی", "Hidden", 203)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle → String
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleEn → String
final
titleFa → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TagCategory>
A constant List of the values in this enum, in order of their declaration.