TagContent enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- aboutUs → const TagContent
-
const TagContent("درباره ما", "About Us", 101) - terms → const TagContent
-
const TagContent("قوانین و مقررات", "Terms", 102) - contactUs → const TagContent
-
const TagContent("تماس با ما", "Contact Us", 103) - homeSlider1 → const TagContent
-
const TagContent("اسلایدر اصلی ۱", "Home Slider 1", 201) - homeSlider2 → const TagContent
-
const TagContent("اسلایدر اصلی ۲", "Home Slider 2", 202) - aboutSection → const TagContent
-
const TagContent("بخش درباره ما", "About Section", 301) - servicesCarousel → const TagContent
-
const TagContent("اسلایدر خدمات", "Services Carousel", 302) - heroBanner → const TagContent
-
const TagContent("بنر اصلی", "Hero Banner", 303) -
const TagContent("فوتر", "Footer", 304) - latestBlogPosts → const TagContent
-
const TagContent("آخرین مطالب بلاگ", "Latest Blog Posts", 305)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagContent> - A constant List of the values in this enum, in order of their declaration.