TagDormBed enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- single → const TagDormBed
-
const TagDormBed("تک نفره", "Single", 101) - double_ → const TagDormBed
-
const TagDormBed("دو نفره", "Double", 102) - bunkBottom → const TagDormBed
-
const TagDormBed("تخت پایین", "Bottom bunk", 201) - bunkTop → const TagDormBed
-
const TagDormBed("تخت بالا", "Top bunk", 202) - desk → const TagDormBed
-
const TagDormBed("میز مطالعه", "Desk", 501) - locker → const TagDormBed
-
const TagDormBed("قفسه شخصی", "Locker", 502) - readingLamp → const TagDormBed
-
const TagDormBed("چراغ مطالعه", "Reading lamp", 503) - privacyCurtain → const TagDormBed
-
const TagDormBed("پرده حریم", "Privacy curtain", 504) - powerOutlet → const TagDormBed
-
const TagDormBed("پریز برق", "Power outlet", 505) - shelf → const TagDormBed
-
const TagDormBed("طبقه", "Shelf", 506)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagDormBed> - A constant List of the values in this enum, in order of their declaration.