TagGoldTxn enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- buy → const TagGoldTxn
-
const TagGoldTxn("خرید طلا", "Buy Gold", 101) - sell → const TagGoldTxn
-
const TagGoldTxn("فروش طلا", "Sell Gold", 102) - pending → const TagGoldTxn
-
const TagGoldTxn("در انتظار", "Pending", 201) - filled → const TagGoldTxn
-
const TagGoldTxn("انجامشده", "Filled", 202) - failed → const TagGoldTxn
-
const TagGoldTxn("ناموفق", "Failed", 203) - cancelled → const TagGoldTxn
-
const TagGoldTxn("لغوشده", "Cancelled", 204)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagGoldTxn> - A constant List of the values in this enum, in order of their declaration.