TagHotelInvoice enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- full → const TagHotelInvoice
-
const TagHotelInvoice("کامل", "Full", 101) - paid → const TagHotelInvoice
-
const TagHotelInvoice("پرداخت شده", "Paid", 201) - paidOnline → const TagHotelInvoice
-
const TagHotelInvoice("پرداخت آنلاین", "Paid Online", 202) - paidManual → const TagHotelInvoice
-
const TagHotelInvoice("پرداخت دستی", "Paid Manual", 203) - notPaid → const TagHotelInvoice
-
const TagHotelInvoice("پرداخت نشده", "Not Paid", 204)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagHotelInvoice> - A constant List of the values in this enum, in order of their declaration.