TagHotelReservation enum

Inheritance
Mixed-in types
Available extensions

Values

pending → const TagHotelReservation
const TagHotelReservation("در انتظار", "Pending", 101)
confirmed → const TagHotelReservation
const TagHotelReservation("تایید شده", "Confirmed", 102)
checkedIn → const TagHotelReservation
const TagHotelReservation("پذیرش شده", "Checked In", 103)
checkedOut → const TagHotelReservation
const TagHotelReservation("تسویه شده", "Checked Out", 104)
cancelled → const TagHotelReservation
const TagHotelReservation("لغو شده", "Cancelled", 201)
noShow → const TagHotelReservation
const TagHotelReservation("عدم حضور", "No Show", 202)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle String
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleEn String
final
titleFa String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TagHotelReservation>
A constant List of the values in this enum, in order of their declaration.