TagInquiryHistory enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- validateNationalCodeAndPhoneNumber → const TagInquiryHistory
-
const TagInquiryHistory("اعتبارسنجی کد ملی و شماره تلفن", "Validate National Code And Phone Number", 101) - zipCodeToAddressDetail → const TagInquiryHistory
-
const TagInquiryHistory("کد پستی به آدرس", "Zip Code To Address Detail", 201) - vehicleViolationsDetail → const TagInquiryHistory
-
const TagInquiryHistory("جزئیات تخلفات وسیله نقلیه", "Vehicle Violations Detail", 301) - drivingLicenceDetail → const TagInquiryHistory
-
const TagInquiryHistory("جزئیات گواهینامه", "Driving Licence Detail", 302) - licencePlateDetail → const TagInquiryHistory
-
const TagInquiryHistory("جزئیات پلاک", "Licence Plate Detail", 303) - drivingLicenceNegativePoint → const TagInquiryHistory
-
const TagInquiryHistory("امتیاز منفی گواهینامه", "Driving Licence Negative Point", 304) - freewayTolls → const TagInquiryHistory
-
const TagInquiryHistory("عوارض آزادراه", "Freeway Tolls", 305) - iBanToBankAccountDetail → const TagInquiryHistory
-
const TagInquiryHistory("IBan به جزئیات حساب بانکی", "IBan To Bank Account Detail", 501) - verified → const TagInquiryHistory
-
const TagInquiryHistory("تایید شده", "Verified", 601) - notVerified → const TagInquiryHistory
-
const TagInquiryHistory("تایید نشده", "Not Verified", 602) - error → const TagInquiryHistory
-
const TagInquiryHistory("خطا", "Error", 603) - itHub → const TagInquiryHistory
-
const TagInquiryHistory("آی تی هاب", "It Hub", 701)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagInquiryHistory> - A constant List of the values in this enum, in order of their declaration.