TagMedia enum

Inheritance
Mixed-in types
Available extensions

Values

image → const TagMedia
const TagMedia("تصویر", "Image", 101)
profile → const TagMedia
const TagMedia("پروفایل", "Profile", 102)
cover → const TagMedia

The main photo of a hotel / dorm / room (shown first).

const TagMedia("عکس اصلی", "Cover", 201)
exterior → const TagMedia

Gallery categories of hotel and dorm photos.

const TagMedia("نما و محوطه", "Exterior", 301)
interior → const TagMedia
const TagMedia("فضای داخلی", "Interior", 302)
room → const TagMedia
const TagMedia("اتاق‌ها", "Rooms", 303)
bathroom → const TagMedia
const TagMedia("سرویس بهداشتی", "Bathroom", 304)
dining → const TagMedia
const TagMedia("غذاخوری", "Dining", 305)
facility → const TagMedia
const TagMedia("امکانات", "Facilities", 306)
surroundings → const TagMedia
const TagMedia("اطراف", "Surroundings", 307)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle → String
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleEn → String
final
titleFa → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TagMedia>
A constant List of the values in this enum, in order of their declaration.