TagParkingStaff enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- registerEntryExit → const TagParkingStaff
-
const TagParkingStaff("ثبت ورود و خروج", "Register entry and exit", 101) - applyManualDiscount → const TagParkingStaff
-
const TagParkingStaff("اعمال تخفیف دستی", "Apply manual discount", 102) - manageSubscriptions → const TagParkingStaff
-
const TagParkingStaff("ثبت و تمدید اشتراک", "Manage subscriptions", 103) - changeTariff → const TagParkingStaff
-
const TagParkingStaff("تغییر تعرفه", "Change tariff", 104) - viewFinancialReports → const TagParkingStaff
-
const TagParkingStaff("مشاهده گزارشهای مالی", "View financial reports", 105) - disabled → const TagParkingStaff
-
const TagParkingStaff("غیرفعال", "Disabled", 106)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagParkingStaff> - A constant List of the values in this enum, in order of their declaration.