TagRoom enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- single → const TagRoom
-
const TagRoom("یک تخته", "Single", 101) - double_ → const TagRoom
-
const TagRoom("دو تخته", "Double", 102) - triple → const TagRoom
-
const TagRoom("سه تخته", "Triple", 103) - twin → const TagRoom
-
const TagRoom("دو تخته توئین", "Twin", 104) - suite → const TagRoom
-
const TagRoom("سوئیت", "Suite", 105) - family → const TagRoom
-
const TagRoom("خانوادگی", "Family", 106) - deluxe → const TagRoom
-
const TagRoom("دلوکس", "Deluxe", 107) - available → const TagRoom
-
const TagRoom("در دسترس", "Available", 201) - outOfService → const TagRoom
-
const TagRoom("خارج از سرویس", "Out Of Service", 202)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited