TagTxn enum

Inheritance
Mixed-in types
Available extensions

Values

creditCard → const TagTxn
const TagTxn("کارت اعتباری", "Credit Card", 101)
cash → const TagTxn
const TagTxn("نقدی", "Cash", 102)
pending → const TagTxn
const TagTxn("در انتظار", "Pending", 201)
const TagTxn("پرداخت شده", "Paid", 202)
failed → const TagTxn
const TagTxn("ناموفق", "Failed", 203)
refunded → const TagTxn
const TagTxn("بازگشت داده شده", "Refunded", 204)
chargeWallet → const TagTxn
const TagTxn("شارژ کیف پول", "Charge Wallet", 301)
merchantCreationFee → const TagTxn
const TagTxn("هزینه ایجاد پذیرنده", "Merchant Creation Fee", 302)
dormInvoice → const TagTxn
const TagTxn("پرداخت قبض خوابگاه", "Dorm Invoice", 303)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle String
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleEn String
final
titleFa String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TagTxn>
A constant List of the values in this enum, in order of their declaration.