TagTxnErrorCodes enum

Inheritance
Mixed-in types
Available extensions

Values

lowBalance → const TagTxnErrorCodes
const TagTxnErrorCodes("موجودی کم", "Low Balance", 101)
unauthorized → const TagTxnErrorCodes
const TagTxnErrorCodes("غیرمجاز", "Unauthorized", 102)
senderWalletNotFound → const TagTxnErrorCodes
const TagTxnErrorCodes("کیف پول فرستنده یافت نشد", "Sender Wallet Not Found", 103)
receiverWalletNotFound → const TagTxnErrorCodes
const TagTxnErrorCodes("کیف پول گیرنده یافت نشد", "Receiver Wallet Not Found", 104)
securityError → const TagTxnErrorCodes
const TagTxnErrorCodes("خطای امنیتی", "Security Error", 105)
ok → const TagTxnErrorCodes
const TagTxnErrorCodes("تایید", "Ok", 201)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle String
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleEn String
final
titleFa String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TagTxnErrorCodes>
A constant List of the values in this enum, in order of their declaration.