TagUser enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- male → const TagUser
-
const TagUser("مرد", "Male", 101) - female → const TagUser
-
const TagUser("زن", "Female", 102) - unspecified → const TagUser
-
const TagUser("نامشخص", "Unspecified", 103) - superAdmin → const TagUser
-
const TagUser("سوپر ادمین", "Super Admin", 201) - guest → const TagUser
-
const TagUser("مهمان", "Guest", 202) - systemAdmin → const TagUser
-
const TagUser("سیستم ادمین", "System Admin", 203) - systemUser → const TagUser
-
const TagUser("کاربر سیستمی", "System User", 204) - sunUser → const TagUser
-
const TagUser("کاربر سان", "Sun User", 205) - subAdmin → const TagUser
-
const TagUser("زیرمجموعه ادمین", "Sub Admin", 206) - awaitingVerification → const TagUser
-
const TagUser("در انتظار تایید", "Awaiting Verification", 301) - verified → const TagUser
-
const TagUser("تایید شده", "Verified", 302) - nationalCardFrontVerified → const TagUser
-
const TagUser("کارت ملی جلو تایید شده", "National Card Front Verified", 401) - nationalCardBackVerified → const TagUser
-
const TagUser("کارت ملی پشت تایید شده", "National Card Back Verified", 402) - birthCertificateFirstVerified → const TagUser
-
const TagUser("شناسنامه صفحه اول تایید شده", "Birth Certificate First Verified", 403) - birthCertificateSecondVerified → const TagUser
-
const TagUser("شناسنامه صفحه دوم تایید شده", "Birth Certificate Second Verified", 404) - birthCertificateThirdVerified → const TagUser
-
const TagUser("شناسنامه صفحه سوم تایید شده", "Birth Certificate Third Verified", 405) - birthCertificateForthVerified → const TagUser
-
const TagUser("شناسنامه صفحه چهارم تایید شده", "Birth Certificate Forth Verified", 406) - birthCertificateFifthVerified → const TagUser
-
const TagUser("شناسنامه صفحه پنجم تایید شده", "Birth Certificate Fifth Verified", 407) - visualAuthenticationVerified → const TagUser
-
const TagUser("احراز هویت تصویری تایید شده", "Visual Authentication Verified", 408) - eSignatureVerified → const TagUser
-
const TagUser("امضای الکترونیکی تایید شده", "E-Signature Verified", 409) - nationalCardFrontAwaitingVerification → const TagUser
-
const TagUser("کارت ملی جلو در انتظار تایید", "National Card Front Awaiting Verification", 501) - nationalCardBackAwaitingVerification → const TagUser
-
const TagUser("کارت ملی پشت در انتظار تایید", "National Card Back Awaiting Verification", 502) - birthCertificateFirstAwaitingVerification → const TagUser
-
const TagUser("شناسنامه صفحه اول در انتظار تایید", "Birth Certificate First Awaiting Verification", 503) - birthCertificateSecondAwaitingVerification → const TagUser
-
const TagUser("شناسنامه صفحه دوم در انتظار تایید", "Birth Certificate Second Awaiting Verification", 504) - birthCertificateThirdAwaitingVerification → const TagUser
-
const TagUser("شناسنامه صفحه سوم در انتظار تایید", "Birth Certificate Third Awaiting Verification", 505) - birthCertificateForthAwaitingVerification → const TagUser
-
const TagUser("شناسنامه صفحه چهارم در انتظار تایید", "Birth Certificate Forth Awaiting Verification", 506) - birthCertificateFifthAwaitingVerification → const TagUser
-
const TagUser("شناسنامه صفحه پنجم در انتظار تایید", "Birth Certificate Fifth Awaiting Verification", 507) - visualAuthenticationAwaitingVerification → const TagUser
-
const TagUser("احراز هویت تصویری در انتظار تایید", "Visual Authentication Awaiting Verification", 508) - eSignatureAwaitingVerification → const TagUser
-
const TagUser("امضای الکترونیکی در انتظار تایید", "E-Signature Awaiting Verification", 509) - permissionManageHotels → const TagUser
-
const TagUser("مدیریت هتلها", "Manage Hotels", 601) - permissionDeleteHotels → const TagUser
-
const TagUser("حذف هتلها", "Delete Hotels", 602) - permissionManageDorms → const TagUser
-
const TagUser("مدیریت خوابگاهها", "Manage Dorms", 603) - permissionDeleteDorms → const TagUser
-
const TagUser("حذف خوابگاهها", "Delete Dorms", 604) - permissionManageContracts → const TagUser
-
const TagUser("مدیریت قراردادها", "Manage Contracts", 605) - permissionDeleteContracts → const TagUser
-
const TagUser("حذف قراردادها", "Delete Contracts", 606) - permissionManageInvoices → const TagUser
-
const TagUser("مدیریت فاکتورها", "Manage Invoices", 607) - permissionDeleteInvoices → const TagUser
-
const TagUser("حذف فاکتورها", "Delete Invoices", 608) - permissionPayInvoices → const TagUser
-
const TagUser("ثبت پرداخت فاکتور", "Pay Invoices", 609) - permissionManageUsers → const TagUser
-
const TagUser("مدیریت کاربران", "Manage Users", 610) - permissionDeleteUsers → const TagUser
-
const TagUser("حذف کاربران", "Delete Users", 611) - permissionManageReservations → const TagUser
-
const TagUser("مدیریت رزروها", "Manage Reservations", 612) - permissionDeleteReservations → const TagUser
-
const TagUser("حذف رزروها", "Delete Reservations", 613)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
isMale(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited