TagVehicle enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- motorcycle → const TagVehicle
-
const TagVehicle("موتورسیکلت", "Motorcycle", 101) - car → const TagVehicle
-
const TagVehicle("سواری", "Car", 102) - van → const TagVehicle
-
const TagVehicle("ون", "Van", 103) - truck → const TagVehicle
-
const TagVehicle("کامیون", "Truck", 104) - bus → const TagVehicle
-
const TagVehicle("اتوبوس", "Bus", 105)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagVehicle> - A constant List of the values in this enum, in order of their declaration.