Usc enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- success → const Usc
-
const Usc("موفقیت", "Success", 200) - created → const Usc
-
const Usc("ایجاد شده", "Created", 201) - deleted → const Usc
-
const Usc("حذف شده", "Deleted", 211) - processCompleted → const Usc
-
const Usc("پردازش کامل شد", "Process Completed", 212) - badRequest → const Usc
-
const Usc("درخواست نامعتبر", "Bad Request", 400) - unAuthorized → const Usc
-
const Usc("احراز هویت نشده", "Unauthorized", 401) - forbidden → const Usc
-
const Usc("دسترسی ممنوع", "Forbidden", 403) - notFound → const Usc
-
const Usc("یافت نشد", "Not Found", 404) - conflict → const Usc
-
const Usc("تداخل", "Conflict", 409) - payloadTooLarge → const Usc
-
const Usc("حجم بار بیش از حد", "Payload Too Large", 413) - mediaTypeNotSupported → const Usc
-
const Usc("نوع رسانه پشتیبانی نمیشود", "Media Type Not Supported", 451) - securityError → const Usc
-
const Usc("خطای امنیتی", "Security Error", 452) - internalServerError → const Usc
-
const Usc("خطای داخلی سرور", "Internal Server Error", 500) - thirdPartyError → const Usc
-
const Usc("خطای شخص ثالث", "Third Party Error", 600) - wrongVerificationCode → const Usc
-
const Usc("کد تایید اشتباه", "Wrong Verification Code", 601) - maximumLimitReached → const Usc
-
const Usc("حداکثر تعداد رسیده", "Maximum Limit Reached", 602) - userNotFound → const Usc
-
const Usc("کاربر یافت نشد", "User Not Found", 603) - expiredToken → const Usc
-
const Usc("توکن منقضی شده", "Expired Token", 604) - shahkarException → const Usc
-
const Usc("استثنای شهکار", "Shahkar Exception", 605) - shahkarError → const Usc
-
const Usc("خطای شهکار", "Shahkar Error", 606) - balanceIsLow → const Usc
-
const Usc("موجودی کم است", "Balance Is Low", 701) - inquiryNotCached → const Usc
-
const Usc("استعلام قبلی موجود نیست", "Inquiry Not Cached", 702)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited