U class abstract

Constructors

U()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

apiKey String
getter/setter pair
baseUrl String
getter/setter pair
categories List<UCategoryResponse>
getter/setter pair
contents List<UContentResponse>
getter/setter pair
s AppLocalizations
no setter
tabController TabController?
getter/setter pair
tabs RxList<TabData>
final
user UUserResponse
getter/setter pair

Static Methods

addOrSwitchTab(String title, Widget page) → void
addTab(String title, Widget page) → void
removeTab(int index) → void
replaceTab(String title, Widget page) → void
updateTabController() → void