length property
int
get
length
The index of the highest set bit plus one, or 0 when nothing is set.
Implementation
int get length => _bits.isEmpty ? 0 : _bits.reduce((int a, int b) => a > b ? a : b) + 1;
The index of the highest set bit plus one, or 0 when nothing is set.
int get length => _bits.isEmpty ? 0 : _bits.reduce((int a, int b) => a > b ? a : b) + 1;