EnPanEntryMode enum

How the card was read. The value goes into ISO field 22 as-is.

Inheritance
Available extensions

Values

manual → const EnPanEntryMode
const EnPanEntryMode("01")
magneticStripRead → const EnPanEntryMode
const EnPanEntryMode("02")
barCodeRead → const EnPanEntryMode
const EnPanEntryMode("03")
ocrCodingRead → const EnPanEntryMode
const EnPanEntryMode("04")
smartCard → const EnPanEntryMode
const EnPanEntryMode("05")
nfc → const EnPanEntryMode
const EnPanEntryMode("07")
merchantQr → const EnPanEntryMode
const EnPanEntryMode("78")
consumerQr → const EnPanEntryMode
const EnPanEntryMode("79")
fallback → const EnPanEntryMode
const EnPanEntryMode("80")

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<EnPanEntryMode>
A constant List of the values in this enum, in order of their declaration.