IsoBinaryFieldPackager class

Inheritance
Implementers

Constructors

IsoBinaryFieldPackager(int length, String description, {IsoInterpreter<Uint8List>? interpreter, IsoPadder<Uint8List>? padder, IsoPrefixer? prefixer})

Properties

description → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
interpreter ↔ IsoInterpreter<Uint8List>?
getter/setter pairinherited
length ↔ int
getter/setter pairinherited
padder ↔ IsoPadder<Uint8List>?
getter/setter pairinherited
prefixer ↔ IsoPrefixer?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkLength(int value, int maxLength) → void
inherited
createComponent() → IsoComponent<Object>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(IsoComponent<Object> component, IsoBuffer buffer) → void
inherited
toString() → String
A string representation of this object.
inherited
unpack(IsoComponent<Object> component, IsoBuffer buffer) → void
inherited
valueLength(Uint8List value) → int
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited