IsoComponentPackagerBase<V extends Object> class abstract

Shared pack/unpack pipeline: pad, prefix the length, interpret.

Implemented types
Implementers

Constructors

IsoComponentPackagerBase(int _length, String _description, {IsoInterpreter<V>? interpreter, IsoPadder<V>? padder, IsoPrefixer? prefixer})

Properties

description → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
interpreter ↔ IsoInterpreter<V>?
getter/setter pair
length ↔ int
getter/setter pairoverride-getter
padder ↔ IsoPadder<V>?
getter/setter pair
prefixer ↔ IsoPrefixer?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkLength(int value, int maxLength) → void
createComponent() → IsoComponent<Object>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(IsoComponent<Object> component, IsoBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited
unpack(IsoComponent<Object> component, IsoBuffer buffer) → void
override
valueLength(V value) → int

Operators

operator ==(Object other) → bool
The equality operator.
inherited