IfaBitmap class

ASCII-hex bitmap. IFA_BITMAP in the Java.

Inheritance

Constructors

IfaBitmap(int length, String description)

Properties

description → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
interpreter ↔ IsoInterpreter<IsoBitSet>?
getter/setter pairinherited
length ↔ int
getter/setter pairinherited
padder ↔ IsoPadder<IsoBitSet>?
getter/setter pairinherited
prefixer ↔ IsoPrefixer?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkLength(int value, int maxLength) → void
inherited
createComponent() → IsoComponent<Object>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(IsoComponent<Object> component, IsoBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited
unpack(IsoComponent<Object> component, IsoBuffer buffer) → void
override
valueLength(IsoBitSet value) → int
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited