IfaVarBinary class

IFA_LBINARY, IFA_LLBINARY, IFA_LLLBINARY, IFA_LLLLBINARY.

Inheritance

Constructors

IfaVarBinary(int length, String description, AsciiPrefixer prefixer, int maxLength)
IfaVarBinary.l(int length, String description)
factory
IfaVarBinary.ll(int length, String description)
factory
IfaVarBinary.lll(int length, String description)
factory
IfaVarBinary.llll(int length, String description)
factory

Properties

description → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
interpreter ↔ IsoInterpreter<Uint8List>?
getter/setter pairinherited
length ↔ int
getter/setter pairinherited
padder ↔ IsoPadder<Uint8List>?
getter/setter pairinherited
prefixer ↔ IsoPrefixer?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkLength(int value, int maxLength) → void
inherited
createComponent() → IsoComponent<Object>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(IsoComponent<Object> component, IsoBuffer buffer) → void
inherited
toString() → String
A string representation of this object.
inherited
unpack(IsoComponent<Object> component, IsoBuffer buffer) → void
inherited
valueLength(Uint8List value) → int
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited