IfbNumeric class
Fixed-length BCD digits, zero padded on the left. IFB_NUMERIC.
- Inheritance
-
- Object
- IsoComponentPackagerBase<
String> - IsoStringFieldPackager
- IfbNumeric
Constructors
- IfbNumeric(int length, String description, {bool leftPadded = true})
Properties
- description → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interpreter
↔ IsoInterpreter<
String> ? -
getter/setter pairinherited
- length ↔ int
-
getter/setter pairinherited
-
padder
↔ IsoPadder<
String> ? -
getter/setter pairinherited
- prefixer ↔ IsoPrefixer?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkLength(
int value, int maxLength) → void -
inherited
-
createComponent(
) → IsoComponent< Object> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pack(
IsoComponent< Object> component, IsoBuffer buffer) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unpack(
IsoComponent< Object> component, IsoBuffer buffer) → void -
inherited
-
valueLength(
String value) → int -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited