iso8583/host_config library

Classes

HostConfig
Everything about this terminal's relationship with the acquirer that does not change per transaction. Ported from HostConfig.
TerminalInitKeySetting
PED slots holding the terminal master key and the key that MACs an init logon. Ported from TerminalInitKeySetting.
TerminalSessionKeyIndexSetting
PED slots the session keys returned by logon are written into. Ported from TerminalSessionKeyIndexSetting.

Exceptions / Errors

HostConfigException