TerminalSessionKeyIndexSetting class

PED slots the session keys returned by logon are written into. Ported from TerminalSessionKeyIndexSetting.

Constructors

TerminalSessionKeyIndexSetting({required int mpkIndex, required int ppkIndex, required int dpkIndex})
const
TerminalSessionKeyIndexSetting.fromJson(Map<String, dynamic> json)
factory

Properties

dpkIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
mpkIndex → int
final
ppkIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited