HostContext class

Mutable state that survives a transaction: which keys are loaded, who the terminal is, what the host called it. Ported from HostContext.

Constructors

HostContext({TerminalDeviceInfo deviceInfo = const TerminalDeviceInfo(), HostStateStore? stateStore})

Properties

deviceInfo ↔ TerminalDeviceInfo
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
injectKtm ↔ bool
getter/setter pair
injectSessionKeys ↔ bool
getter/setter pair
ktmGroup ↔ String?
getter/setter pair
logonMacIndexKey ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateStore ↔ HostStateStore?
getter/setter pair
terminalLogicalInfo ↔ TerminalLogicalInfo?
getter/setter pair

Methods

applyJson(Map<String, dynamic> json) → void
load() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → Future<void>
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited