TerminalDeviceInfo class

Hardware identity of this terminal, sent as TLV tags C0 and D0.

Constructors

TerminalDeviceInfo({String? serialNumber, String? simSerial})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String?
final
simSerial → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited