BcdInterpreter class

Packed decimal, two digits per byte.

Implemented types

Properties

fPadded → bool
final
hashCode → int
The hash code for this object.
no setterinherited
leftPadded → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

interpret(String data, IsoBuffer buffer) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packedLength(int dataUnits) → int
toBytes(String data) → Uint8List
toString() → String
A string representation of this object.
inherited
uninterpret(IsoBuffer buffer, int length) → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited