HexInterpreter class
Like BcdInterpreter but every nibble is a hex digit, so A-F survive.
- Implemented types
Properties
- fPadded → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftPadded → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
interpret(
String data, IsoBuffer buffer) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
packedLength(
int dataUnits) → int -
toString(
) → String -
A string representation of this object.
inherited
-
uninterpret(
IsoBuffer buffer, int length) → String -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- leftPaddedFInstance → const HexInterpreter
- leftPaddedInstance → const HexInterpreter
- rightPaddedFInstance → const HexInterpreter
- rightPaddedInstance → const HexInterpreter