IsoInterpreter<T> class abstract

Turns a field value into bytes and back. T is String for character fields and Uint8List for binary ones.

Implementers

Constructors

IsoInterpreter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

interpret(T data, IsoBuffer buffer) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
uninterpret(IsoBuffer buffer, int length) → T

Operators

operator ==(Object other) → bool
The equality operator.
inherited