IsoComponent<T> class abstract

Anything that can sit in an IsoMsg field slot: a string field, a binary field, a bitmap, or a nested message.

Implementers

Constructors

IsoComponent()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter
value ↔ T?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited