IsoTraceEntry class

Constructors

IsoTraceEntry(IsoTraceKind kind, String message, {String? hex})

Properties

at → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
hex → String?
final
kind → IsoTraceKind
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited