RightTruncatingPadder class

Right padder that truncates instead of throwing when the value is too long.

Inheritance

Constructors

RightTruncatingPadder(String padCharacter)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
padCharacter → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pad(String data, int maxLength) → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

spacePadder → const RightTruncatingPadder