TlvMsg class

One tag-length-value item. value holds a String while the message is being built and a Uint8List (or a nested TlvList) once packed.

Constructors

TlvMsg(int tag, Object? value)
TlvMsg.bytes(int tag, Uint8List value)
TlvMsg.list(int tag, TlvList value)
TlvMsg.number(int tag, int value)
TlvMsg.text(int tag, String value)

Properties

asBytes → Uint8List?
no setter
asInt → int
no setter
asList → TlvList?
no setter
asSignedNumber → num
Reads a C/+ or D/- prefixed signed amount.
no setter
asString → String?
no setter
completeTagString → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
parent ↔ TlvMsg?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ int
getter/setter pair
value ↔ Object?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toTlv(int capacity) → Uint8List

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encodeLength(int length) → Uint8List
BER length bytes for length.
isConstructedTag(int tag) → bool
tagString(int tag) → String