IsoLinkEvents class abstract

Progress callbacks while a message is in flight. Optional.

Constructors

IsoLinkEvents()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConnectionEvent(String event, Object? error) → void
onReceiveTimeout() → void
onWaitForReceive() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited