IsoSessionKey class

One secret key as the host sent it.

Constructors

IsoSessionKey(Uint8List value, Uint8List? checkValue)
const

Properties

checkValue → Uint8List?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited