pinKeyIndex property
int
get
pinKeyIndex
The key slot the security module uses when it encrypts a PIN.
Implementation
static int get pinKeyIndex => config.sessionKeyIndexSetting.ppkIndex;
The key slot the security module uses when it encrypts a PIN.
static int get pinKeyIndex => config.sessionKeyIndexSetting.ppkIndex;