reset static method
Drops the open connection so the next send reconnects with new settings.
Implementation
static Future<void> reset() async {
await _link?.dispose();
_link = null;
}
Drops the open connection so the next send reconnects with new settings.
static Future<void> reset() async {
await _link?.dispose();
_link = null;
}