message property
String
get
message
The text the host wants shown to the customer.
Implementation
String get message => tag(PrimitiveTags.errorMessage)?.trim() ?? "";
The text the host wants shown to the customer.
String get message => tag(PrimitiveTags.errorMessage)?.trim() ?? "";