rejectCode property
int?
get
rejectCode
Set when the link refused the message before the host saw it.
Implementation
int? get rejectCode => raw.rejectCode;
Set when the link refused the message before the host saw it.
int? get rejectCode => raw.rejectCode;