BcdValuePackager class

Packed decimal, optionally F-padded on the right for odd-length values.

Implemented types

Properties

fPadded → bool
final
hashCode → int
The hash code for this object.
no setterinherited
leftPadded → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack(Object? value) → Uint8List
override
toString() → String
A string representation of this object.
inherited
unpack(IsoBuffer buffer, int length) → Object
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

leftPad0 → const BcdValuePackager
rightPadF → const BcdValuePackager