ValuePackager class abstract
Encodes and decodes the value half of a TLV, once the tag has decided which representation it uses.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited