No description provided for @noNotesYet.
In en, this message translates to: 'No notes yet. Add a note at the current time with the + button.'
@override String get noNotesYet => 'No notes yet. Add a note at the current time with the + button.';