pickATableToBrowseOrOpenQuery property
No description provided for @pickATableToBrowseOrOpenQuery.
In en, this message translates to: 'Pick a table from the left to browse and edit its data, or open the Query tab.'
Implementation
@override
String get pickATableToBrowseOrOpenQuery => 'Pick a table from the left to browse and edit its data, or open the Query tab.';