tapTheMenuToPickATable property

  1. @override
String get tapTheMenuToPickATable
override

No description provided for @tapTheMenuToPickATable.

In en, this message translates to: 'Tap the menu to pick a table, or open the Query tab.'

Implementation

@override
String get tapTheMenuToPickATable => 'Tap the menu to pick a table, or open the Query tab.';