UArAvailability class

Constructors

UArAvailability({UArAvailabilityStatus status = UArAvailabilityStatus.unknown, UArCapabilities capabilities = const UArCapabilities(), String? message})
const
UArAvailability.fromMap(Map<Object?, Object?> map)
factory

Properties

capabilities → UArCapabilities
final
hashCode → int
The hash code for this object.
no setterinherited
isSupported → bool
no setter
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → UArAvailabilityStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited