UArBody class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
joints
→ Map<
String, UArVector3> -
World positions of the skeleton joints.
final
- pose → UArPose
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screenJoints
→ Map<
String, Offset> -
Joints projected to the view, normalised 0..1.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited