reticle property
Draws a placement ring where the screen centre meets a surface and reports it in UArFrame.centerHit.
Implementation
final bool reticle;
Draws a placement ring where the screen centre meets a surface and reports it in UArFrame.centerHit.
final bool reticle;