UArGeoPose class

Constructors

UArGeoPose({double latitude = 0, double longitude = 0, double altitude = 0, double heading = 0, double horizontalAccuracy = -1, double verticalAccuracy = -1, double headingAccuracy = -1, String state = "", UArTrackingState tracking = UArTrackingState.notAvailable, String source = "gps"})
const
UArGeoPose.fromMap(Map<Object?, Object?> map)
factory

Properties

altitude → double
final
hashCode → int
The hash code for this object.
no setterinherited
heading → double
Degrees clockwise from true north the camera faces.
final
headingAccuracy → double
final
horizontalAccuracy → double
final
isPrecise → bool
no setter
isTracking → bool
no setter
latitude → double
final
longitude → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
"vps", "geoTracking" or "gps".
final
state → String
final
tracking → UArTrackingState
final
verticalAccuracy → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited