UArHitResult class

Constructors

UArHitResult({required UArPose pose, required double distance, required UArHitType type, String? trackableId, UArPlaneType? planeType, UArPlaneClassification classification = UArPlaneClassification.none})
const
UArHitResult.fromMap(Map<Object?, Object?> map)
factory

Properties

classification → UArPlaneClassification
final
distance → double
final
hashCode → int
The hash code for this object.
no setterinherited
isCeiling → bool
no setter
isFloor → bool
no setter
isTable → bool
no setter
isWall → bool
no setter
planeType → UArPlaneType?
final
pose → UArPose
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackableId → String?
final
type → UArHitType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited