UArLightEstimate class

Constructors

UArLightEstimate({double intensity = 1, double colorTemperature = 6500, List<double> colorCorrection = const <double>[1, 1, 1, 1], UArVector3? direction, UArVector3? mainIntensity, List<double> sphericalHarmonics = const <double>[]})
const
UArLightEstimate.fromMap(Map<Object?, Object?> map)
factory

Properties

colorCorrection → List<double>
final
colorTemperature → double
final
direction → UArVector3?
final
hashCode → int
The hash code for this object.
no setterinherited
intensity → double
0..1-ish scene brightness (ARCore pixel intensity / ARKit lumens ÷ 1000).
final
isDark → bool
no setter
mainIntensity → UArVector3?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sphericalHarmonics → List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited