UArNativeViewerOptions class
Constructors
Properties
- arFirst → bool
-
Starts in the camera rather than the 3D preview.
final
- fallbackUrl → String?
-
Opened in the browser when no AR viewer is installed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iosSource → UArSource?
-
USDZ / Reality for AR Quick Look (iOS, iOS Safari).
final
- link → String?
-
A web page shown as a call-to-action inside the viewer.
final
- resizable → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → UArSource
-
GLB / glTF for Scene Viewer (Android, Android browsers).
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited