UArObjectCaptureResult class

Constructors

UArObjectCaptureResult({String? modelPath, String? imagesPath})
const
UArObjectCaptureResult.fromMap(Map<Object?, Object?> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imagesPath → String?
The captured photos, reusable for a server-side reconstruction.
final
modelPath → String?
The reconstructed USDZ.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited