UArOrbit class

Camera placement for UArMode.viewer, orbiting target.

Constructors

UArOrbit({double yaw = 30, double pitch = 15, double distance = 1.5, UArVector3 target = UArVector3.zero, double fov = 45})
const

Properties

distance → double
final
fov → double
Vertical field of view in degrees.
final
hashCode → int
The hash code for this object.
no setterinherited
pitch → double
Degrees above the horizon.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → UArVector3
final
yaw → double
Degrees around the vertical axis.
final

Methods

copyWith({double? yaw, double? pitch, double? distance, UArVector3? target, double? fov}) → UArOrbit
lerp(UArOrbit other, double t) → UArOrbit
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited