UArPermissionState class

Constructors

UArPermissionState({UArPermission camera = UArPermission.unknown, UArPermission location = UArPermission.unknown, UArPermission microphone = UArPermission.unknown})
const
UArPermissionState.fromMap(Map<Object?, Object?> map)
factory

Properties

camera → UArPermission
final
cameraGranted → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
location → UArPermission
final
locationGranted → bool
no setter
microphone → UArPermission
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited