UArProjection class
Where a tracked world point lands on the view, normalised 0..1.
Constructors
Properties
- distance → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isBehind → bool
-
no setter
- isVisible → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visibility → int
-
1 on screen, 0 in front but outside the view, -1 behind the camera.
final
- x → double
-
final
- y → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toOffset(
Size size) → Offset -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited