UArReferenceImage class

A picture the session should recognise in the real world (posters, logos, packaging, shop signs). physicalWidth is its printed width in metres.

Constructors

UArReferenceImage({required String name, required UArSource source, double physicalWidth = 0.2})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
physicalWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → UArSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited