UArRoomScanOptions class
Constructors
- UArRoomScanOptions({bool exportModel = true, bool parametric = true, String? doneLabel, String? cancelLabel})
-
const
Properties
- cancelLabel → String?
-
final
- doneLabel → String?
-
final
- exportModel → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parametric → bool
-
Exports clean boxes (walls, furniture) instead of the raw mesh.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited