UArTrackedImage class

Constructors

UArTrackedImage({required String name, required UArPose pose, int index = 0, double width = 0, double height = 0, UArTrackingState tracking = UArTrackingState.normal})
const
UArTrackedImage.fromMap(Map<Object?, Object?> map)
factory

Properties

anchorId → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
index → int
final
isTracking → bool
no setter
name → String
final
pose → UArPose
Centre of the image; local Y is the image normal, X along its width.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracking → UArTrackingState
final
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited