UArVideoOptions class

Constructors

UArVideoOptions({bool loop = true, bool muted = true, bool autoplay = true, double volume = 1})
const

Properties

autoplay → bool
final
hashCode → int
The hash code for this object.
no setterinherited
loop → bool
final
muted → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volume → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited