UArWidgetRenderer class abstract

Renders a widget off-screen into PNG bytes, for textures in the scene.

Constructors

UArWidgetRenderer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

render(Widget widget, {Size size = const Size(320, 200), double pixelRatio = 3, BuildContext? context, TextDirection? textDirection, Duration settle = const Duration(milliseconds: 50)}) → Future<Uint8List?>