UCameraChannel class abstract

Constructors

UCameraChannel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

events(int sessionId) → Stream<Map<Object?, Object?>>
frames(int sessionId) → Stream<Map<Object?, Object?>>
invoke<T>(String method, [Map<String, Object?>? arguments]) → Future<T?>
invokeList(String method, [Map<String, Object?>? arguments]) → Future<List<Object?>?>
invokeMap(String method, [Map<String, Object?>? arguments]) → Future<Map<Object?, Object?>?>
isSupported() → Future<bool>
True when the host platform implements the native camera at all.