UCameraDevice class
Constructors
-
UCameraDevice({required String id, required String name, required UCameraFacing facing, UCameraLens lens = UCameraLens.unknown, int sensorOrientation = 0, bool hasFlash = false, bool isLogical = false, List<
String> physicalDeviceIds = const <String>[], List<double> focalLengths = const <double>[], double minFocusDistance = 0, List<UCameraFormat> formats = const <UCameraFormat>[], double minZoom = 1, double maxZoom = 1, double neutralZoom = 1}) -
const
-
UCameraDevice.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- facing → UCameraFacing
-
final
-
focalLengths
→ List<
double> -
final
-
formats
→ List<
UCameraFormat> -
final
- hasFlash → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isFront → bool
-
no setter
- isLogical → bool
-
True for a multi-camera virtual device that switches lenses by zoom.
final
- largestFormat → UCameraFormat?
-
no setter
- lens → UCameraLens
-
final
- maxZoom → double
-
final
- minFocusDistance → double
-
final
- minZoom → double
-
final
- name → String
-
final
- neutralZoom → double
-
Zoom factor where a logical device sits on its main lens.
final
-
physicalDeviceIds
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensorOrientation → int
-
Clockwise rotation, in degrees, from the sensor to the device's natural
orientation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited