UCameraFormat class

One selectable output configuration reported by the device.

Constructors

UCameraFormat({required UCameraSize size, double minFps = 0, double maxFps = 0, bool isHighSpeed = false, bool supportsHdr = false, bool supportsDepth = false})
const
UCameraFormat.fromMap(Map<Object?, Object?> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isHighSpeed → bool
final
maxFps → double
final
minFps → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → UCameraSize
final
supportsDepth → bool
final
supportsHdr → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited