UCameraOrientation enum

Inheritance
Available extensions

Values

portraitUp → const UCameraOrientation
landscapeRight → const UCameraOrientation
portraitDown → const UCameraOrientation
landscapeLeft → const UCameraOrientation

Properties

degrees → int

Available on UCameraOrientation, provided by the UCameraOrientationX extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UCameraOrientation>
A constant List of the values in this enum, in order of their declaration.