UCameraPermissionState class

Camera and microphone permission state in one object.

Constructors

UCameraPermissionState({UCameraPermission camera = UCameraPermission.unknown, UCameraPermission microphone = UCameraPermission.unknown})
const
UCameraPermissionState.fromMap(Map<Object?, Object?> map)
factory

Properties

camera → UCameraPermission
final
hashCode → int
The hash code for this object.
no setterinherited
isGranted → bool
no setter
isPermanentlyDenied → bool
no setter
microphone → UCameraPermission
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited