displayRotation property
Clockwise rotation, in degrees, of the app window relative to the device's natural orientation. Zero while the app stays portrait-locked.
Implementation
final int displayRotation;
Clockwise rotation, in degrees, of the app window relative to the device's natural orientation. Zero while the app stays portrait-locked.
final int displayRotation;