UCapturedPhoto class

Constructors

UCapturedPhoto({required int width, required int height, String? path, Uint8List? bytes, UPhotoFormat format = UPhotoFormat.jpeg, int orientation = 0, bool mirrored = false, int sizeInBytes = 0, Uint8List? thumbnail, Map<String, Object?> metadata = const <String, Object?>{}})
const
UCapturedPhoto.fromMap(Map<Object?, Object?> map)
factory

Properties

bytes → Uint8List?
final
extension → String
no setter
format → UPhotoFormat
final
hasBytes → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
metadata → Map<String, Object?>
final
mirrored → bool
final
orientation → int
final
path → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeInBytes → int
final
thumbnail → Uint8List?
final
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited