UCapturedVideo class
Constructors
- UCapturedVideo({required String path, required Duration duration, int width = 0, int height = 0, int sizeInBytes = 0, UVideoContainer container = UVideoContainer.mp4, Uint8List? bytes, Uint8List? thumbnail})
-
const
-
UCapturedVideo.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- bytes → Uint8List?
-
final
- container → UVideoContainer
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeInBytes → int
-
final
- thumbnail → Uint8List?
-
final
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited