U1DReader class abstract

Constructors

U1DReader()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

maxAvgVariance → double
no setter
maxIndividualVariance → double
no setter

Static Methods

patternMatchVariance(Int32List counters, List<int> pattern, double maxIndividualVariance) → double
recordPattern(UBitArray row, int start, Int32List counters) → void
Fills counters with alternating run lengths starting at start.
recordPatternInReverse(UBitArray row, int start, Int32List counters) → void