UBitArray class

Constructors

UBitArray(int size)

Properties

bits → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final

Methods

get(int i) → bool
getNextSet(int from) → int
getNextUnset(int from) → int
isRange(int start, int end, bool value) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reversed() → UBitArray
set(int i) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMatrixRow(UBitMatrix matrix, int y) → UBitArray