UBitSource class

Constructors

UBitSource(Uint8List bytes)

Properties

available → int
no setter
byteOffset → int
no setter
bytes → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBits(int numBits) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited