UCode128Patterns class abstract

Constructors

UCode128Patterns()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

codeCodeA → const int
codeCodeB → const int
codeCodeC → const int
codeFnc1 → const int
codeFnc2 → const int
codeFnc3 → const int
codeShift → const int
codeStartA → const int
codeStartB → const int
codeStartC → const int
codeStop → const int
patterns → const List<List<int>>