UCode39Reader class

Constructors

UCode39Reader({bool usingCheckDigit = false, bool extendedMode = false})
const

Properties

extendedMode → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usingCheckDigit → bool
final

Methods

decodeRow(UBitArray row) → U1DResult?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited