UCodeFormat enum

Inheritance
Available extensions

Values

qr → const UCodeFormat
microQr → const UCodeFormat
dataMatrix → const UCodeFormat
aztec → const UCodeFormat
pdf417 → const UCodeFormat
code128 → const UCodeFormat
code39 → const UCodeFormat
code93 → const UCodeFormat
codabar → const UCodeFormat
itf → const UCodeFormat
ean13 → const UCodeFormat
ean8 → const UCodeFormat
upcA → const UCodeFormat
upcE → const UCodeFormat
unknown → const UCodeFormat

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isLinear → bool

Available on UCodeFormat, provided by the UCodeFormatX extension

no setter
isMatrix → bool

Available on UCodeFormat, provided by the UCodeFormatX extension

no setter
label → String

Available on UCodeFormat, provided by the UCodeFormatX extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UCodeFormat>
A constant List of the values in this enum, in order of their declaration.