UCodeStructuredAppend class

Constructors

UCodeStructuredAppend({required int index, required int total, required int parity})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
final
parity → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited