UCodeValue class abstract

Classifies and splits common QR payload conventions.

Constructors

UCodeValue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String text, UCodeFormat format) → Map<String, String>
typeOf(String text, UCodeFormat format) → UCodeValueType