UDataMatrixVersion class

Constructors

UDataMatrixVersion(int versionNumber, int symbolSizeRows, int symbolSizeColumns, int dataRegionSizeRows, int dataRegionSizeColumns, List<List<int>> ecBlocks)
const

Properties

dataRegionSizeColumns → int
final
dataRegionSizeRows → int
final
ecBlocks → List<List<int>>
ecCodewords, blockCount, dataCodewords or two triples for the 144x144 case.
final
ecCodewordsPerBlock → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolSizeColumns → int
final
symbolSizeRows → int
final
totalCodewords → int
no setter
totalDataCodewords → int
no setter
versionNumber → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

forDimensions(int numRows, int numColumns) → UDataMatrixVersion?

Constants

versions → const List<UDataMatrixVersion>