UGaloisField class

Constructors

UGaloisField(int size, int primitive, int generatorBase)

Properties

generatorBase → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final

Methods

exp(int a) → int
inverse(int a) → int
log(int a) → int
multiply(int a, int b) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

aztec10 → UGaloisField
final
aztec12 → UGaloisField
final
aztec6 → UGaloisField
final
aztec8 → UGaloisField
final
aztecParam → UGaloisField
final
dataMatrix → UGaloisField
final
pdf417 → UGaloisField
final
qr → UGaloisField
final

Static Methods

addOrSubtract(int a, int b) → int