UModulusPoly class abstract

Modulo-929 Reed-Solomon used by PDF417, which is not a binary field.

Constructors

UModulusPoly()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

add(int a, int b) → int
addPoly(Int32List a, Int32List b) → Int32List
coefficientOf(Int32List poly, int degree) → int
decode(Int32List received, int numEcCodewords, Int32List erasures) → int
Corrects received in place; returns the number of errors fixed.
degreeOf(Int32List poly) → int
evaluate(Int32List poly, int a) → int
exp(int a) → int
inverse(int a) → int
isZero(Int32List poly) → bool
log(int a) → int
monomial(int degree, int coefficient) → Int32List
multiply(int a, int b) → int
multiplyByMonomialPoly(Int32List poly, int degree, int coefficient) → Int32List
multiplyPoly(Int32List a, Int32List b) → Int32List
multiplyScalarPoly(Int32List poly, int scalar) → Int32List
negatePoly(Int32List poly) → Int32List
subtract(int a, int b) → int
subtractPoly(Int32List a, Int32List b) → Int32List
trim(Int32List coefficients) → Int32List