UPatternPoint class

Constructors

UPatternPoint(double x, double y, double estimatedModuleSize, [int count = 1])
const

Properties

count → int
final
estimatedModuleSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Offset
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
final
y → double
final

Methods

aboutEquals(double moduleSize, double i, double j) → bool
combine(double i, double j, double newModuleSize) → UPatternPoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

distance(UPatternPoint a, UPatternPoint b) → double