UPerspectiveTransform class

Constructors

UPerspectiveTransform(double a11, double a21, double a31, double a12, double a22, double a32, double a13, double a23, double a33)
const

Properties

a11 → double
final
a12 → double
final
a13 → double
final
a21 → double
final
a22 → double
final
a23 → double
final
a31 → double
final
a32 → double
final
a33 → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildAdjoint() → UPerspectiveTransform
mapPoint(double x, double y) → Offset
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
times(UPerspectiveTransform other) → UPerspectiveTransform
toString() → String
A string representation of this object.
inherited
transform(Float64List points) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

quadrilateralToQuadrilateral(double x0, double y0, double x1, double y1, double x2, double y2, double x3, double y3, double x0p, double y0p, double x1p, double y1p, double x2p, double y2p, double x3p, double y3p) → UPerspectiveTransform