UQrAlignmentPatternFinder class

Finds the alignment pattern near the bottom-right of larger QR symbols.

Constructors

UQrAlignmentPatternFinder(UBitMatrix image, int startX, int startY, int width, int height, double moduleSize)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
final
image → UBitMatrix
final
moduleSize → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startX → int
final
startY → int
final
width → int
final

Methods

find() → UPatternPoint?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited