UQrBitMatrixParser class

Constructors

UQrBitMatrixParser(UBitMatrix _bits)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mirrored → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

mirror() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readCodewords() → Uint8List
readFormatInformation() → UQrFormatInformation
readVersion() → UQrVersion
remask() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited