UQrDetector class

Constructors

UQrDetector(UBitMatrix image)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
image → UBitMatrix
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect({bool tryHarder = true, int maxSymbols = 8}) → List<UQrDetectorResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited