UQrEcBlocks class

Constructors

UQrEcBlocks(int ecCodewordsPerBlock, List<UQrEcb> blocks)
const

Properties

blocks → List<UQrEcb>
final
ecCodewordsPerBlock → int
final
hashCode → int
The hash code for this object.
no setterinherited
numBlocks → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalEcCodewords → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited