UQrFinderInfo class

Constructors

UQrFinderInfo(UPatternPoint bottomLeft, UPatternPoint topLeft, UPatternPoint topRight)
const

Properties

bottomLeft → UPatternPoint
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeft → UPatternPoint
final
topRight → UPatternPoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited