UQrFinderPatternFinder class
Locates the three 1:1:3:1:1 finder patterns of a QR symbol.
Constructors
- UQrFinderPatternFinder(UBitMatrix image)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → UBitMatrix
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
find(
{bool tryHarder = true, int maxSymbols = 8}) → List< UQrFinderInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited