UQrFormatInformation class

Constructors

UQrFormatInformation(UQrEcLevel errorCorrectionLevel, int dataMask)
const

Properties

dataMask → int
final
errorCorrectionLevel → UQrEcLevel
final
hashCode → int
The hash code for this object.
no setterinherited
levelIndex → int
no setter
levelName → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(int maskedFormatInfo1, int maskedFormatInfo2) → UQrFormatInformation?