UQrVersion class

Constructors

UQrVersion(int number, List<int> alignmentPatternCenters, List<UQrEcBlocks> ecBlocks)
const

Properties

alignmentPatternCenters → List<int>
final
dimension → int
no setter
ecBlocks → List<UQrEcBlocks>
Indexed by error-correction level: L, M, Q, H.
final
hashCode → int
The hash code for this object.
no setterinherited
number → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCodewords → int
no setter

Methods

buildFunctionPattern() → UBitMatrix
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decodeVersionInformation(int versionBits) → UQrVersion?
forDimension(int dimension) → UQrVersion?
forNumber(int number) → UQrVersion