UUpcEanPatterns class abstract

Constructors

UUpcEanPatterns()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

lAndGPatterns → List<List<int>>
L patterns followed by their mirrored G patterns.
final

Static Methods

checksum(String digits) → bool

Constants

endPattern → const List<int>
firstDigitEncodings → const List<int>
lPatterns → const List<List<int>>
middlePattern → const List<int>
numsysAndCheckDigit → const List<List<int>>
startEndPattern → const List<int>