UAdminPageSwitcher class abstract

Constructors

UAdminPageSwitcher()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

accounting() → void
adminUserDetail({required UUserResponse user}) → void
adminUsers() → void
apiLogs() → void
blogs() → void
contents() → void
contracts({UDormBedResponse? bed, UUserResponse? user}) → void
dormBeds({UDormRoomResponse? room, UDormResponse? dorm}) → void
dormList() → void
dormRooms({UDormResponse? dorm}) → void
financialOpsDashboard() → void
hotelRooms({UHotelResponse? hotel}) → void
hotels() → void
hotelUserDetail({required UUserResponse user}) → void
invoices({UDormBedContractResponse? contract}) → void
merchants({UUserResponse? user}) → void
parking() → void
parkingReport({UParkingResponse? parking}) → void
propertyDashboard() → void
reservations({UHotelResponse? hotel, UHotelRoomResponse? room}) → void
settings() → void
terminals({UMerchantResponse? merchant}) → void
transactions() → void
userCreateUpdate({UUserResponse? user}) Future<void>
users({required UAdminUsersPageArgs args}) → void
wallet() → void