UAdminApiLogController class
- Inheritance
-
- Object
- UBaseController
- UAdminApiLogController
Constructors
Properties
-
bucket
→ Rx<
String> -
final
- controllerEndDate → TextEditingController
-
finalinherited
- controllerStartDate → TextEditingController
-
finalinherited
- endDate ↔ DateTime?
-
getter/setter pairinherited
-
formKey
→ GlobalKey<
FormState> -
finalinherited
- fromCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddressCtrl → TextEditingController
-
final
- isFa → bool
-
no setterinherited
-
list
→ RxList<
UApiLogResponse> -
final
- maxDurationCtrl → TextEditingController
-
final
-
methodFilter
→ Rxn<
TagApiLog> -
final
- minDurationCtrl → TextEditingController
-
final
- onlyErrors → RxBool
-
final
- onlyExceptions → RxBool
-
final
-
orderBy
→ Rx<
TagOrderBy> -
final
- orderByCreatedAt ↔ bool
-
getter/setter pairinherited
- orderByCreatedAtDesc ↔ bool
-
getter/setter pairinherited
-
osMetrics
→ Rxn<
UOsMetricsResponse> -
final
- osMetricsState → RxState
-
final
- pageNumber ↔ RxInt
-
getter/setter pairinherited
- pageSize ↔ int
-
getter/setter pairinherited
- pathContainsCtrl → TextEditingController
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate ↔ DateTime?
-
getter/setter pairinherited
- state → RxState
-
finalinherited
- state2 ↔ RxState
-
getter/setter pairinherited
-
stats
→ Rxn<
UApiLogStatsResponse> -
final
- statusCodeCtrl → TextEditingController
-
final
-
tagOrderBy
↔ Rx<
TagOrderBy> -
getter/setter pairinherited
- toCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- totalCount ↔ int
-
getter/setter pairinherited
- totalPages ↔ RxInt
-
getter/setter pairinherited
- traceIdCtrl → TextEditingController
-
final
- userIdCtrl → TextEditingController
-
final
Methods
-
applyFilters(
) → void -
clearFilters(
) → void -
dispose(
) → void -
errorCallBack(
String? message, void reload()) → void -
inherited
-
exportCsv(
dynamic onOk(String csv)) → void -
firstPage(
) → void -
inherited
-
init(
) → Future< void> -
loadOsMetrics(
) → Future< void> -
loadStats(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
okCallback(
String? message, void reload()) → void -
inherited
-
openDetail(
UApiLogResponse item, dynamic onOk(UApiLogResponse detail)) → void -
refreshAll(
) → Future< void> -
refreshList(
) → void -
reloadFirstPage(
void read()) → void -
inherited
-
search(
) → Future< void> -
setBucket(
String b) → void -
setError(
[String? message]) → void -
inherited
-
setListState(
{required bool isEmpty}) → void -
inherited
-
setTotalPages(
int totalCount) → void -
inherited
-
startOsMetricsPolling(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited