UAdminContentLinkForm class

One editable row of a content's links.

Constructors

UAdminContentLinkForm([UContentLink? m])

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconBase64 ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleController → TextEditingController
final
urlController → TextEditingController
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toModel() → UContentLink
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited