UAdminGroup class

Constructors

UAdminGroup({required String title, required IconData icon, List<UAdminModule> modules = const <UAdminModule>[], List<UAdminGroup> groups = const <UAdminGroup>[], String? id, String? header, List<TagUser>? roles, bool expanded = false})

Properties

expanded bool
final
groups List<UAdminGroup>
final
hashCode int
The hash code for this object.
no setterinherited
final
icon IconData
final
id String?
final
modules List<UAdminModule>
final
resolvedId String
no setter
roles List<TagUser>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntries() List<UMenuEntry>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited