UAdminMediaSync class abstract

Applies an UAdminMediaDraft: deletes removed photos, uploads new ones and moves the cover mark.

Constructors

UAdminMediaSync()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

apply({required UAdminMediaDraft draft, required List<UMediaResponse> existing, String? hotelId, String? hotelRoomId, String? dormId, String? dormRoomId, String? dormBedId}) → Future<void>