UAdminMoadiController class
- Inheritance
-
- Object
- UBaseController
- UAdminMoadiController
Constructors
Properties
- controllerEndDate → TextEditingController
-
finalinherited
- controllerStartDate → TextEditingController
-
finalinherited
- economicCodeFilter → TextEditingController
-
final
- endDate ↔ DateTime?
-
getter/setter pairinherited
-
formKey
→ GlobalKey<
FormState> -
finalinherited
- fromCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- fromCreatedController → TextEditingController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFa → bool
-
no setterinherited
-
list
↔ List<
UMoadiResponse> -
getter/setter pair
- nameFilter → TextEditingController
-
final
- nationalCodeFilter → TextEditingController
-
final
- orderByCreatedAt ↔ bool
-
getter/setter pairinherited
- orderByCreatedAtDesc ↔ bool
-
getter/setter pairinherited
- pageNumber ↔ RxInt
-
getter/setter pairinherited
- pageSize ↔ int
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate ↔ DateTime?
-
getter/setter pairinherited
- state → RxState
-
finalinherited
- state2 ↔ RxState
-
getter/setter pairinherited
-
status
→ Rxn<
TagMoadi> -
final
-
tagOrderBy
↔ Rx<
TagOrderBy> -
getter/setter pairinherited
- toCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- toCreatedController → TextEditingController
-
final
- totalCount ↔ int
-
getter/setter pairinherited
- totalPages ↔ RxInt
-
getter/setter pairinherited
- uniqueTaxCodeFilter → TextEditingController
-
final
-
user
→ Rxn<
UUserResponse> -
final
Methods
-
applyFilters(
) → void -
approve(
UMoadiResponse i) → void -
clearFilters(
) → void -
delete(
UMoadiResponse i) → void -
errorCallBack(
String? message, void reload()) → void -
inherited
-
firstPage(
) → void -
inherited
-
init(
{UUserResponse? user}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
okCallback(
String? message, void reload()) → void -
inherited
-
read(
) → Future< void> -
readUsers(
String query) → Future< List< UUserResponse> > -
reject(
UMoadiResponse i, String? reason) → void -
reloadFirstPage(
void read()) → void -
inherited
-
setError(
[String? message]) → void -
inherited
-
setListState(
{required bool isEmpty}) → void -
inherited
-
setTotalPages(
int totalCount) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited