UAdminModule class

Constructors

UAdminModule({required String title, required IconData icon, required Widget page(), IconData? selectedIcon, List<TagUser>? roles})

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
page Widget Function()
final
roles List<TagUser>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon IconData?
final
title String
final
visible bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toItem() UMenuItem
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited