UAdminParkingReportController class

Inheritance

Properties

controllerEndDate TextEditingController
finalinherited
controllerStartDate TextEditingController
finalinherited
creatorFilter Rxn<UUserResponse>
final
endDate DateTime?
getter/setter pairinherited
formKey GlobalKey<FormState>
finalinherited
fromCreatedAt DateTime?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isFa bool
no setterinherited
list List<UParkingReportResponse>
getter/setter pair
orderByCreatedAt bool
getter/setter pairinherited
orderByCreatedAtDesc bool
getter/setter pairinherited
pageNumber RxInt
getter/setter pairinherited
pageSize int
getter/setter pairinherited
parking UParkingResponse?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
getter/setter pairinherited
state RxState
finalinherited
state2 RxState
getter/setter pairinherited
tagOrderBy Rx<TagOrderBy>
getter/setter pairinherited
toCreatedAt DateTime?
getter/setter pairinherited
totalAmount double
no setter
totalCount int
getter/setter pairinherited
totalPages RxInt
getter/setter pairinherited

Methods

applyFilters() → void
clearFilters() → void
delete(UParkingReportResponse i) → void
errorCallBack(String? message, void reload()) → void
inherited
firstPage() → void
inherited
init({UParkingResponse? parking}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
okCallback(String? message, void reload()) → void
inherited
read() Future<void>
reloadFirstPage(void read()) → void
inherited
setError([String? message]) → void
inherited
setListState({required bool isEmpty}) → void
inherited
setTotalPages(int totalCount) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited