UAdminPlaceDetails class abstract

Constructors

UAdminPlaceDetails()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dorm(UDormResponse item, {VoidCallback? onDone}) → Future<void>
dormBed(UDormBedResponse item, {VoidCallback? onDone}) → Future<void>
dormRoom(UDormRoomResponse item, {VoidCallback? onDone}) → Future<void>
hotel(UHotelResponse item, {VoidCallback? onDone}) → Future<void>
hotelRoom(UHotelRoomResponse item, {VoidCallback? onDone}) → Future<void>