UAdminReservationController class
- Inheritance
-
- Object
- UBaseController
- UAdminReservationController
Constructors
Properties
- checkInFilter ↔ DateTime?
-
getter/setter pair
- checkOutFilter ↔ DateTime?
-
getter/setter pair
- controllerEndDate → TextEditingController
-
finalinherited
- controllerStartDate → TextEditingController
-
finalinherited
- endDate ↔ DateTime?
-
getter/setter pairinherited
-
formKey
→ GlobalKey<
FormState> -
finalinherited
- fromCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- guestFilter → TextEditingController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hotel ↔ UHotelResponse?
-
getter/setter pair
- hotelFilter ↔ UHotelResponse?
-
getter/setter pair
- isFa → bool
-
no setterinherited
-
list
↔ List<
UHotelReservationResponse> -
getter/setter pair
- orderByCreatedAt ↔ bool
-
getter/setter pairinherited
- orderByCreatedAtDesc ↔ bool
-
getter/setter pairinherited
- pageNumber ↔ RxInt
-
getter/setter pairinherited
- pageSize ↔ int
-
getter/setter pairinherited
- room ↔ UHotelRoomResponse?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate ↔ DateTime?
-
getter/setter pairinherited
- state → RxState
-
finalinherited
- state2 ↔ RxState
-
getter/setter pairinherited
- statusFilter ↔ UAdminReservationStatusFilter
-
getter/setter pair
-
tagOrderBy
↔ Rx<
TagOrderBy> -
getter/setter pairinherited
- toCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- totalCount ↔ int
-
getter/setter pairinherited
- totalPages ↔ RxInt
-
getter/setter pairinherited
Methods
-
applyFilters(
) → void -
cancel(
UHotelReservationResponse i) → void -
checkIn(
UHotelReservationResponse i) → void -
checkOut(
UHotelReservationResponse i) → void -
clearFilters(
) → void -
confirm(
UHotelReservationResponse i) → void -
create(
{required UHotelReservationCreateParams p}) → void -
delete(
UHotelReservationResponse i) → void -
errorCallBack(
String? message, void reload()) → void -
inherited
-
firstPage(
) → void -
inherited
-
init(
{UHotelResponse? hotel, UHotelRoomResponse? room}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
okCallback(
String? message, void reload()) → void -
inherited
-
payInvoice(
UHotelInvoiceResponse inv) → void -
read(
) → Future< void> -
readHotels(
String query) → Future< List< UHotelResponse> > -
readRooms(
String query) → Future< List< UHotelRoomResponse> > -
readUsers(
String query) → Future< List< UUserResponse> > -
reloadFirstPage(
void read()) → void -
inherited
-
setError(
[String? message]) → void -
inherited
-
setListState(
{required bool isEmpty}) → void -
inherited
-
setStatus(
UAdminReservationStatusFilter f) → void -
setTotalPages(
int totalCount) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unpaidInvoiceOf(
UHotelReservationResponse i) → UHotelInvoiceResponse? -
update(
{required UHotelReservationUpdateParams p}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited