maxContentWidth property
Widest the content is allowed to grow. Past this the page centres itself instead of stretching a table across a 2560px monitor.
Implementation
final double maxContentWidth;
Widest the content is allowed to grow. Past this the page centres itself instead of stretching a table across a 2560px monitor.
final double maxContentWidth;