UAdminTable class abstract

Constructors

UAdminTable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cell(String text, {int flex = 1}) Widget
headerCell(String title, {int flex = 1}) Widget
leadingIcon(BuildContext context, IconData icon, {Color? color}) Widget
mobileCard(BuildContext context, {required String title, required List<UAdminField> fields, Widget? leading, IconData? icon, String? subtitle, Widget? badge, Widget? trailing, VoidCallback? onTap}) Widget
mobileTile(BuildContext context, {required int index, required IconData icon, required String title, required List<Widget> subtitle, Widget? trailing, VoidCallback? onTap}) Widget
rowColor(BuildContext context, int index) Color
statusChip(BuildContext context, {required String label, required Color color}) Widget

Constants

rowPadding → const EdgeInsets