UAdminUserDetailController class

Properties

hashCode int
The hash code for this object.
no setterinherited
isFullyVerified bool
no setter
loadingProgress Rx<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state RxState
final
user UUserResponse
getter/setter pair

Methods

approve() → void
init({required UUserResponse user}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() Future<void>
reject({required UUserUpdateParams p}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited