UBaseController class abstract

Implementers

Constructors

UBaseController()

Properties

controllerEndDate TextEditingController
final
controllerStartDate TextEditingController
final
endDate DateTime?
getter/setter pair
formKey GlobalKey<FormState>
final
fromCreatedAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isFa bool
no setter
orderByCreatedAt bool
getter/setter pair
orderByCreatedAtDesc bool
getter/setter pair
pageNumber RxInt
getter/setter pair
pageSize int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
getter/setter pair
state RxState
final
state2 RxState
getter/setter pair
tagOrderBy Rx<TagOrderBy>
getter/setter pair
toCreatedAt DateTime?
getter/setter pair
totalCount int
getter/setter pair
totalPages RxInt
getter/setter pair

Methods

errorCallBack(String? message, void reload()) → void
firstPage() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
okCallback(String? message, void reload()) → void
reloadFirstPage(void read()) → void
setError([String? message]) → void
setListState({required bool isEmpty}) → void
setTotalPages(int totalCount) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited