ActiveNotification class

Details of an active notification.

Constructors

ActiveNotification({int? id, String? groupKey, String? channelId, String? title, String? body, String? payload, String? tag, String? bigText})
Constructs an instance of ActiveNotification.
const

Properties

bigText → String?
The notification's longer text displayed using big text style.
final
body → String?
The notification's body.
final
channelId → String?
The notification's channel id.
final
groupKey → String?
The notification's group.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
The notification's id.
final
payload → String?
The notification's payload.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
The notification's tag.
final
title → String?
The notification's title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited