openAppNotificationSettings method

  1. @override
Future<bool?> openAppNotificationSettings()
override

Opens the operating system notification settings screen for this app.

On Android, this attempts to open the app's notification settings screen and falls back to the app details screen if needed.

Returns whether an activity could be launched.

Implementation

@override
Future<bool?> openAppNotificationSettings() async =>
    await _channel.invokeMethod<bool>('openAppNotificationSettings');