AsciiHexInterpreter class

Binary data written as two ASCII hex characters per byte.

Implemented types

Constructors

AsciiHexInterpreter()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

interpret(Uint8List data, IsoBuffer buffer) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
uninterpret(IsoBuffer buffer, int length) → Uint8List
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

instance → const AsciiHexInterpreter