AsciiPrefixer class

Length as ASCII digits: LL, LLL, LLLL.

Implemented types

Constructors

AsciiPrefixer(int digits)
const

Properties

digits → int
final
hashCode → int
The hash code for this object.
no setterinherited
packedLength → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeLength(IsoBuffer buffer) → int
override
encodeLength(int length, IsoBuffer buffer) → int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

l → const AsciiPrefixer
ll → const AsciiPrefixer
lll → const AsciiPrefixer
llll → const AsciiPrefixer