AssetTileProvider class

Fetch tiles from the app's shipped assets, where the tile URL is a path within the asset store

Uses AssetImage internally.

All tiles must be listed as assets as normal in the pubspec.yaml config file.

If TileLayer.fallbackUrl is specified, a custom CachingAssetBundle is used to retrieve the assets - this bundle is approximatley 23% slower than the default bundle, and as such, specifying TileLayer.fallbackUrl should be avoided when using this provider.

Inheritance

Constructors

AssetTileProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
Custom HTTP headers that may be sent with each tile request
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsCancelLoading → bool
Indicates to flutter_map internals whether to call getImage (when false) or getImageWithCancelLoadingSupport
no setterinherited

Methods

dispose() → void
Called when the TileLayer is disposed
inherited
generateReplacementMap(String urlTemplate, TileCoordinates coordinates, TileLayer options) → Map<String, String>
Generate the Map of placeholders to replacements, to be used in populateTemplatePlaceholders
inherited
getImage(TileCoordinates coordinates, TileLayer options) → AssetImage
Retrieve a tile as an image, based on its coordinates and the TileLayer
override
getImageWithCancelLoadingSupport(TileCoordinates coordinates, TileLayer options, Future<void> cancelLoading) → ImageProvider<Object>
Retrieve a tile as an image, based on its coordinates and the TileLayer
inherited
getTileFallbackUrl(TileCoordinates coordinates, TileLayer options) → String?
Generate a fallback URL for a tile, based on its coordinates and the TileLayer
inherited
getTileUrl(TileCoordinates coordinates, TileLayer options) → String
Generate a primary URL for a tile, based on its coordinates and the TileLayer
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
populateTemplatePlaceholders(String urlTemplate, TileCoordinates coordinates, TileLayer options) → String
Replaces placeholders in the form templatePlaceholderElement with their corresponding values
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited