color property
The color to use when painting the barcode box.
Defaults to Colors.red, with an opacity of 30%.
Implementation
final Color color;
The color to use when painting the barcode box.
Defaults to Colors.red, with an opacity of 30%.
final Color color;