BaseDeviceInfo class

The base class for platform's device info.

Constructors

BaseDeviceInfo(Map<String, dynamic> data)

Properties

data → Map<String, dynamic>
Device information data Warning: The returned Map may not be JSON-encodable.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
For legacy purposes
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited