filterQuality property
The FilterQuality of the image, used to define how high quality the overlay image should have on the map.
Defaults to FilterQuality.medium.
Implementation
final FilterQuality filterQuality;
The FilterQuality of the image, used to define how high quality the overlay image should have on the map.
Defaults to FilterQuality.medium.
final FilterQuality filterQuality;