BigPictureStyleInformation class

Used to pass the content for an Android notification displayed using the big picture style.

Inheritance

Constructors

BigPictureStyleInformation(AndroidBitmap<Object> bigPicture, {String? contentTitle, String? summaryText, bool htmlFormatContentTitle = false, bool htmlFormatSummaryText = false, AndroidBitmap<Object>? largeIcon, bool htmlFormatContent = false, bool htmlFormatTitle = false, bool hideExpandedLargeIcon = false, bool showBigPictureWhenCollapsed = false})
Constructs an instance of BigPictureStyleInformation.
const

Properties

bigPicture → AndroidBitmap<Object>
The bitmap to be used as the payload for the BigPicture notification.
final
contentTitle → String?
Overrides ContentTitle in the big form of the template.
final
hashCode → int
The hash code for this object.
no setterinherited
hideExpandedLargeIcon → bool
Hides the large icon when showing the expanded notification.
final
htmlFormatContent → bool
Specifies if formatting should be applied to the content through HTML markup.
finalinherited
htmlFormatContentTitle → bool
Specifies if the overridden ContentTitle should have formatting applied through HTML markup.
final
htmlFormatSummaryText → bool
Specifies if formatting should be applied to the first line of text after the detail section in the big form of the template.
final
htmlFormatTitle → bool
Specifies if formatting should be applied to the title through HTML markup.
finalinherited
largeIcon → AndroidBitmap<Object>?
The bitmap that will override the large icon when the big notification is shown.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBigPictureWhenCollapsed → bool
Shows the big picture as a thumbnail in the collapsed notification.
final
summaryText → String?
Set the first line of text after the detail section in the big form of the template.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited