CameraDescription class

Properties of a camera device.

Annotations

Constructors

CameraDescription({required String name, required CameraLensDirection lensDirection, required int sensorOrientation, CameraLensType lensType = CameraLensType.unknown})
Creates a new camera description with the given properties.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
lensDirection → CameraLensDirection
The direction the camera is facing.
final
lensType → CameraLensType
The type of lens the camera has.
final
name → String
The name of the camera device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensorOrientation → int
Clockwise angle through which the output image needs to be rotated to be upright on the device screen in its native orientation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override