CardHolderAccountInfoTags class abstract

E9 — cardholder account info, with E9.E0 accounts and E9.E1 coupons.

Constructors

CardHolderAccountInfoTags()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

tagFormatMap → Map<String, ValuePackager>
no setter

Constants

accountHostId → const int
accountId → const int
accountInfo → const int
accountTitle → const int
accountType → const int
accountTypeCode → const int
addAmounts → const int
couponCode → const int
couponDesc → const int
couponId → const int
couponItems → const int
couponName → const int
darikBalance → const int
darikBaseAmount → const int
darikDownPaymentRate → const int
darikDownPaymentRateType → const int
darikId → const int
darikInstallmentCount → const int
darikInstallmentType → const int
darikMaxInstallmentCount → const int
darikTitle → const int
debitAmount → const int
debitCurrency → const int
familyMemberCount → const int
root → const int
vasOrgCode → const int
vasOrgName → const int
vasOrgUnitCode → const int