ContactInfo class

A person's or organization's business card. For example a VCARD.

Constructors

ContactInfo({List<Address> addresses = const <Address>[], List<Email> emails = const <Email>[], PersonName? name, String? organization, List<Phone> phones = const <Phone>[], String? title, List<String> urls = const <String>[]})
Create a new ContactInfo instance.
const
ContactInfo.fromNative(Map<Object?, Object?> data)
Create a new ContactInfo instance from a map.
factory

Properties

addresses → List<Address>
The list of addresses for the person or organisation.
final
emails → List<Email>
The list of email addresses for the person or organisation.
final
hashCode → int
The hash code for this object.
no setterinherited
name → PersonName?
The name of the contact person.
final
organization → String?
The name of the organization.
final
phones → List<Phone>
The available phone numbers for the contact person or organisation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The contact person's title.
final
urls → List<String>
The urls associated with the contact person or organisation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited