ContainCameraLatitude class

Constrains the edges of the camera to within latitudes a and b

See CameraConstraint for more information.

Inheritance
Annotations

Properties

a → double
One edge latitude
final
b → double
Other edge latitude
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

constrain(MapCamera camera) → MapCamera?
Create a new constrained camera based off the current camera
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override