errorHandler property

ExceptionCallback errorHandler
final

A handler called when an exception is thrown from position stream or heading stream. This is for customizing the behavior of the plugin when an exception occurs.

The handler should return null to indicate that the exception is already handled, or return an Exception (or its subclass) to indicate that the exception is not handled. If the returned exception is a plugin-recognized exception type, it will be handled by this plugin.

Defaults to defaultErrorHandler.

Implementation

final ExceptionCallback errorHandler;