DarwinNotificationAttachment class

Represents an attachment for a notification on Darwin-based operation systems such as iOS and macOS

Constructors

DarwinNotificationAttachment(String filePath, {String? identifier, bool? hideThumbnail, DarwinNotificationAttachmentThumbnailClippingRect? thumbnailClippingRect})
Constructs an instance of DarwinNotificationAttachment.
const

Properties

filePath → String
The local file path to the attachment.
final
hashCode → int
The hash code for this object.
no setterinherited
hideThumbnail → bool?
Should the attachment be considered for the notification thumbnail?
final
identifier → String?
The unique identifier for the attachment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailClippingRect → DarwinNotificationAttachmentThumbnailClippingRect?
The clipping rectangle for the thumbnail image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited