DarwinNotificationDetails class

Configures notification details specific to Darwin-based operation systems such as iOS and macOS

Constructors

DarwinNotificationDetails({bool? presentAlert, bool? presentBadge, bool? presentSound, bool? presentBanner, bool? presentList, String? sound, int? badgeNumber, List<DarwinNotificationAttachment>? attachments, String? subtitle, String? threadIdentifier, String? categoryIdentifier, InterruptionLevel? interruptionLevel, double? criticalSoundVolume, NotificationDismissedIsolate? dismissIsolate})
Constructs an instance of DarwinNotificationDetails.
const

Properties

attachments → List<DarwinNotificationAttachment>?
Specifies the list of attachments included with the notification.
final
badgeNumber → int?
Specify the number to display as the app icon's badge when the notification arrives.
final
categoryIdentifier → String?
The identifier of the app-defined category object.
final
criticalSoundVolume → double?
The volume for playing the critical alert sound.
final
dismissIsolate → NotificationDismissedIsolate?
The isolate a dismissal is reported on, or null to not report it.
final
hashCode → int
The hash code for this object.
no setterinherited
interruptionLevel → InterruptionLevel?
The interruption level that indicates the priority and delivery timing of a notification.
final
presentAlert → bool?
Indicates if an alert should be display when the notification is triggered while app is in the foreground.
final
presentBadge → bool?
Indicates if badge value should be applied when the notification is triggered while app is in the foreground.
final
presentBanner → bool?
Indicates if the notification should be presented as a banner when the notification is triggered while app is in the foreground.
final
presentList → bool?
Indicates if the notification should be shown in the notification centre when the notification is triggered while app is in the foreground.
final
presentSound → bool?
Indicates if a sound should be played when the notification is triggered while app is in the foreground.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sound → String?
Specifies the name of the file to play for the notification.
final
subtitle → String?
Specifies the secondary description.
final
threadIdentifier → String?
Specifies the thread identifier that can be used to group notifications together.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited