dismissIsolate property

NotificationDismissedIsolate? dismissIsolate
final

The isolate a dismissal is reported on, or null to not report it.

Requires the notification's category to be configured with the customDismissAction option. When set, swiping the notification away triggers a NotificationResponse of type NotificationResponseType.notificationDismissed on that isolate. macOS has no background isolate so it always reports on the main isolate.

Implementation

final NotificationDismissedIsolate? dismissIsolate;