DesktopWindowOptions class abstract

Configuration options common to desktop platforms (e.g. Linux and Windows).

Constructors

DesktopWindowOptions({bool lockParentWindow = false})
Creates an instance of DesktopWindowOptions.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lockParentWindow bool
Whether to lock the parent window modally when showing the file picker dialog.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited