lockParentWindow property
Whether to lock the parent window modally when showing the file picker dialog.
Implementation
final bool lockParentWindow;
Whether to lock the parent window modally when showing the file picker dialog.
final bool lockParentWindow;