Email class

An email message from a 'MAILTO:' or similar QRCode type.

Constructors

Email({String? address, String? body, String? subject, EmailType type = EmailType.unknown})
Construct a new Email instance.
const
Email.fromNative(Map<Object?, Object?> data)
Construct an Email from the given data.
factory

Properties

address → String?
The email address.
final
body → String?
The body of the email.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
The subject of the email.
final
type → EmailType
The type of the email.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited