FilePickerPlatform class abstract

The interface that implementations of file_picker must implement.

Inheritance
  • Object
  • PlatformInterface
  • FilePickerPlatform

Constructors

FilePickerPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTemporaryFiles() Future<void>
Asks the underlying platform to remove any temporary files created by this plugin.
getDirectoryPath({String? dialogTitle, String? initialDirectory, AndroidOptions androidOptions = const AndroidOptions(), WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) Future<String?>
Pick a single directory using the native file picker.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickFile({String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions, dynamic onFileLoading(FilePickerStatus)?, int compressionQuality = 0, AndroidOptions androidOptions = const AndroidOptions(), WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) Future<PlatformFile?>
Pick a single file using the native file picker.
pickFileAndDirectoryPaths({String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions}) Future<List<String>>
Pick files and directories using the native file picker.
pickFiles({String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions, dynamic onFileLoading(FilePickerStatus)?, int compressionQuality = 0, AndroidOptions androidOptions = const AndroidOptions(), WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) Future<List<PlatformFile>>
Pick multiple files using the native file picker.
saveFile({required String fileName, required Uint8List bytes, required String mimeType, String? dialogTitle, String? initialDirectory, dynamic onFileSaving(FilePickerStatus)?, WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) Future<Uri?>
Save the given bytes to a file with the given fileName, using the native save file dialog.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FilePickerPlatform
getter/setter pair