getDirectoryPath method

Future<String?> getDirectoryPath({
  1. String? dialogTitle,
  2. String? initialDirectory,
  3. AndroidOptions androidOptions = const AndroidOptions(),
  4. WindowsOptions windowsOptions = const WindowsOptions(),
  5. LinuxOptions linuxOptions = const LinuxOptions(),
  6. WebOptions webOptions = const WebOptions(),
})

Pick a single directory using the native file picker.

The dialogTitle, if provided, will be used as the title for the directory picker dialog. The initialDirectory, if provided, will be used as the initial directory path for the directory picker.

The androidOptions, windowsOptions, linuxOptions, and webOptions parameters allow platform-specific configurations for the directory picker.

Returns the absolute path of the selected directory, or null if the user canceled the operation.

Implementation

Future<String?> getDirectoryPath({
  String? dialogTitle,
  String? initialDirectory,
  AndroidOptions androidOptions = const AndroidOptions(),
  WindowsOptions windowsOptions = const WindowsOptions(),
  LinuxOptions linuxOptions = const LinuxOptions(),
  WebOptions webOptions = const WebOptions(),
}) async {
  throw UnimplementedError('getDirectoryPath() has not been implemented.');
}