pickFileAndDirectoryPaths method

Future<List<String>> pickFileAndDirectoryPaths({
  1. String? dialogTitle,
  2. String? initialDirectory,
  3. FileType type = FileType.any,
  4. List<String>? allowedExtensions,
})

Pick files and directories using the native file picker.

The dialogTitle, if provided, will be used as the title for the picker dialog. The initialDirectory, if provided, will be used as the initial directory path for the picker. The type parameter specifies the type of files to be picked and defaults to FileType.any. The allowedExtensions parameter, if provided, restricts selection to specified file extensions when type is set to FileType.custom.

Returns a list of absolute paths for the selected files and directories, or an empty list if canceled.

Implementation

Future<List<String>> pickFileAndDirectoryPaths({
  String? dialogTitle,
  String? initialDirectory,
  FileType type = FileType.any,
  List<String>? allowedExtensions,
}) async {
  throw UnimplementedError(
    'pickFileAndDirectoryPaths() has not been implemented.',
  );
}