FitBounds class

The CameraFit should fit inside a given LatLngBounds.

Inheritance
Annotations

Properties

bounds → LatLngBounds
The bounds which the camera should contain once it is fitted.
final
forceIntegerZoomLevel → bool
Whether the zoom level of the resulting fit should be rounded to the nearest integer level.
final
hashCode → int
The hash code for this object.
no setterinherited
maxZoom → double?
The inclusive upper zoom limit used for the resulting fit.
final
minZoom → double
The inclusive lower zoom limit used for the resulting fit.
final
padding → EdgeInsets
Adds a constant/pixel-based padding to the normal fit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fit(MapCamera camera) → MapCamera
Returns a new MapCamera which fits this classes configuration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited