FitInsideBounds class

A CameraFit that should get be within given LatLngBounds.

Inheritance
Annotations

Properties

bounds → LatLngBounds
The bounds which the camera should fit inside once it is fitted.
final
forceIntegerZoomLevel → bool
Whether the zoom level of the resulting fit should be rounded to the nearest integer level.
final
hashCode → int
The hash code for this object.
no setterinherited
maxZoom → double?
The inclusive upper zoom limit used for the resulting fit.
final
minZoom → double
The inclusive lower zoom limit used for the resulting fit.
final
padding → EdgeInsets
Adds a constant/pixel-based padding to the normal fit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fit(MapCamera camera) → MapCamera
Create a new fitted camera based off the current camera
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited