periodicallyShow method

Future<void> periodicallyShow({
  1. required int id,
  2. String? title,
  3. String? body,
  4. required RepeatInterval repeatInterval,
})

Periodically show a notification using the specified interval.

For example, specifying a hourly interval means the first time the notification will be an hour after the method has been called and then every hour after that.

Implementation

Future<void> periodicallyShow({
  required int id,
  String? title,
  String? body,
  required RepeatInterval repeatInterval,
}) {
  throw UnimplementedError('periodicallyShow() has not been implemented');
}