periodicallyShowWithDuration method

Future<void> periodicallyShowWithDuration({
  1. required int id,
  2. String? title,
  3. String? body,
  4. required Duration repeatDurationInterval,
})

Periodically show a notification using the specified custom duration interval.

For example, specifying a 5 minutes repeat duration interval means the first time the notification will be an 5 minutes after the method has been called and then every 5 minutes after that.

repeatDurationInterval must be at least one minute.

Implementation

Future<void> periodicallyShowWithDuration({
  required int id,
  String? title,
  String? body,
  required Duration repeatDurationInterval,
}) {
  throw UnimplementedError(
    'periodicallyShowWithDuration() has not been implemented',
  );
}