show method

Future<void> show({
  1. required int id,
  2. String? title,
  3. String? body,
  4. String? payload,
})

Show a notification with an optional payload that will be passed back to the app when a notification is tapped on.

Implementation

Future<void> show({
  required int id,
  String? title,
  String? body,
  String? payload,
}) async {
  throw UnimplementedError('show() has not been implemented');
}