openAppNotificationSettings method
Opens the system settings UI where the user can manage notification permissions for the app.
On iOS, this will attempt to open the app's notification settings page and fall back to opening the app's Settings page when needed.
On platforms that don't support this API, an UnimplementedError will be thrown.
Implementation
Future<bool?> openAppNotificationSettings() {
if (kIsWeb) {
throw UnimplementedError(
'openAppNotificationSettings() is not supported on web',
);
}
return FlutterLocalNotificationsPlatform.instance
.openAppNotificationSettings();
}