periodicallyShow method

  1. @override
Future<void> periodicallyShow({
  1. required int id,
  2. String? title,
  3. String? body,
  4. String? payload,
  5. required RepeatInterval repeatInterval,
  6. WindowsNotificationDetails? notificationDetails,
})
override

Periodically show a notification using the specified interval.

For example, specifying a hourly interval means the first time the notification will be an hour after the method has been called and then every hour after that.

Implementation

@override
Future<void> periodicallyShow({
  required int id,
  String? title,
  String? body,
  String? payload,
  required RepeatInterval repeatInterval,
  WindowsNotificationDetails? notificationDetails,
}) async {}