GeoPoint class

GPS coordinates from a GEO: or similar QRCode type.

Constructors

GeoPoint({required double latitude, required double longitude})
Construct a new GeoPoint instance.
const
GeoPoint.fromNative(Map<Object?, Object?> data)
Construct a GeoPoint from the given data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → double
The latitude of the coordinate.
final
longitude → double
The longitude of the coordinate.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited