HostConnectionInfo class
Where and how to reach the host. Ported from HostConnectionInfo.
Constructors
- HostConnectionInfo({required String hostIp, required int hostPort, bool ssl = false, int readTimeoutSeconds = 120, int connectTimeoutSeconds = 5, String? sslPublicKey, String? sslPrivateKey, String? sslPrivateKeyPassword, bool? apn, HostConnectionInfo? tms})
-
HostConnectionInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apn → bool?
-
final
- connectTimeoutSeconds → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hostIp → String
-
final
- hostPort → int
-
final
- readTimeoutSeconds → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssl → bool
-
final
- sslPrivateKey → String?
-
Base64 PKCS#12 holding the client certificate and key.
final
- sslPrivateKeyPassword → String?
-
Base64 of the PKCS#12 password.
final
- sslPublicKey → String?
-
Base64 PEM of the host certificate to trust.
final
- tms → HostConnectionInfo?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override