periodicallyShowWithDuration method

  1. @override
Future<void> periodicallyShowWithDuration({
  1. required int id,
  2. String? title,
  3. String? body,
  4. required Duration repeatDurationInterval,
  5. DarwinNotificationDetails? notificationDetails,
  6. String? payload,
})
override

Periodically show a notification using the specified custom duration interval.

For example, specifying a 5 minutes repeat duration interval means the first time the notification will be an 5 minutes after the method has been called and then every 5 minutes after that.

repeatDurationInterval must be at least one minute.

Implementation

@override
Future<void> periodicallyShowWithDuration({
  required int id,
  String? title,
  String? body,
  required Duration repeatDurationInterval,
  DarwinNotificationDetails? notificationDetails,
  String? payload,
}) async {
  validateId(id);
  validateRepeatDurationInterval(repeatDurationInterval);
  await _channel
      .invokeMethod('periodicallyShowWithDuration', <String, Object?>{
        'id': id,
        'title': title,
        'body': body,
        'calledAt': clock.now().millisecondsSinceEpoch,
        'repeatIntervalMilliseconds': repeatDurationInterval.inMilliseconds,
        'platformSpecifics': notificationDetails?.toMap(),
        'payload': payload ?? '',
      });
}