IllegalCharacterInFileNameException class

An exception that is thrown when a file name contains characters that are not allowed for the underlying platform.

Implemented types

Constructors

IllegalCharacterInFileNameException(String message)
Creates an instance of IllegalCharacterInFileNameException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited