web property
Settings for web.
It is nullable, because we don't want to force users to specify settings for platforms that they don't target.
Implementation
final WebInitializationSettings? web;
Settings for web.
It is nullable, because we don't want to force users to specify settings for platforms that they don't target.
final WebInitializationSettings? web;