flingAnimationDampingRatio property
The damping ratio for the fling animation spring simulation
This controls how the fling animation decelerates after a drag gesture. Lower values result in less damping (more momentum, bouncier). Higher values result in more damping (stops quicker, less bouncy).
Defaults to 5.0.
Implementation
final double flingAnimationDampingRatio;