JavaScriptConsoleMessage class

Represents a console message written to the JavaScript console.

Annotations

Constructors

JavaScriptConsoleMessage({required JavaScriptLogLevel level, required String message})
Creates a JavaScriptConsoleMessage.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
level → JavaScriptLogLevel
The severity of a JavaScript log message.
final
message → String
The message written to the console.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited