JavaScriptExecutionException class

An error thrown or rejected by an asynchronous JavaScript invocation.

Implemented types

Constructors

JavaScriptExecutionException({required String message, String? name, String? javaScriptStackTrace})
Creates a JavaScript execution exception.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
javaScriptStackTrace → String?
The JavaScript stack trace, when available.
final
message → String
The error message reported by the JavaScript engine.
final
name → String?
The JavaScript error name, such as TypeError, when available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited