copyWith method
Creates a copy of this object, but with the given fields replaced with the new values.
Implementation
LinuxNotificationLocation copyWith({int? x, int? y}) =>
LinuxNotificationLocation(x ?? this.x, y ?? this.y);
Creates a copy of this object, but with the given fields replaced with the new values.
LinuxNotificationLocation copyWith({int? x, int? y}) =>
LinuxNotificationLocation(x ?? this.x, y ?? this.y);