acceptLabel property
The label for the accept button of the file chooser dialog.
See the accept_label option in the XDG Desktop Portal FileChooser docs.
Implementation
final String? acceptLabel;
The label for the accept button of the file chooser dialog.
See the accept_label option in the XDG Desktop Portal FileChooser docs.
final String? acceptLabel;