LoanKeyTags class abstract

EA — loans, with EA.E0 installments.

Constructors

LoanKeyTags()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

tagFormatMap → Map<String, ValuePackager>
no setter

Constants

installmentAmount → const int
installmentCount → const int
installmentDate → const int
installmentId → const int
installments → const int
loanId → const int
root → const int