LocationSettings class

Represents the abstract LocationSettings class with which you can configure platform specific settings.

Constructors

LocationSettings({LocationAccuracy accuracy = LocationAccuracy.best, int distanceFilter = 0, Duration? timeLimit})
Initializes a new LocationSettings instance with default values.
const

Properties

accuracy → LocationAccuracy
Defines the desired accuracy that should be used to determine the location data.
final
distanceFilter → int
The minimum distance (measured in meters) a device must move horizontally before an update event is generated.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeLimit → Duration?
The timeLimit parameter allows you to specify a timeout interval (by default no time limit is configured).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes the PlatformSpecificSettings to a map message
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited