LottieImageAsset class

Constructors

LottieImageAsset({required int width, required int height, required String id, required String fileName, required String dirName})

Properties

dirName → String
final
fileName → String
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
id → String
final
loadedImage ↔ Image?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited