LottieProvider class abstract

Constructors

LottieProvider({LottieImageProviderFactory? imageProviderFactory, LottieDecoder? decoder, bool? backgroundLoading})

Properties

backgroundLoading → bool
final
decoder → LottieDecoder?
final
hashCode → int
The hash code for this object.
no setterinherited
imageProviderFactory → LottieImageProviderFactory?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getImageProvider(LottieImageAsset lottieImage) → ImageProvider<Object>?
load({BuildContext? context}) → Future<LottieComposition>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited