openAppNotificationSettings method
Opens the system settings UI where the user can manage notification permissions for the app.
Falls back to opening the system settings notifications pane if the app's notifications settings page cannot be opened.
Returns whether the settings page could be opened.
Implementation
@override
Future<bool?> openAppNotificationSettings() async =>
await _channel.invokeMethod<bool>('openAppNotificationSettings');