periodicallyShow method
Future<void>
periodicallyShow({
- required int id,
- String? title,
- String? body,
- required RepeatInterval repeatInterval,
- DarwinNotificationDetails? notificationDetails,
- String? payload,
override
Periodically show a notification using the specified interval.
For example, specifying a hourly interval means the first time the notification will be an hour after the method has been called and then every hour after that.
Implementation
@override
Future<void> periodicallyShow({
required int id,
String? title,
String? body,
required RepeatInterval repeatInterval,
DarwinNotificationDetails? notificationDetails,
String? payload,
}) async {
validateId(id);
await _channel.invokeMethod('periodicallyShow', <String, Object?>{
'id': id,
'title': title,
'body': body,
'calledAt': clock.now().millisecondsSinceEpoch,
'repeatInterval': repeatInterval.index,
'platformSpecifics': notificationDetails?.toMap(),
'payload': payload ?? '',
});
}