MapEventRotateEnd class

Event which is fired when rotate gesture has ended

Inheritance
Annotations

Constructors

MapEventRotateEnd({required MapEventSource source, required MapCamera camera})
Create a new map event that represents the end of a map rotation.
const

Properties

camera → MapCamera
The map camera after the event.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → MapEventSource
Who / what issued the event.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited