MemoryLottie class

Inheritance
Annotations

Constructors

MemoryLottie(Uint8List bytes, {LottieImageProviderFactory? imageProviderFactory, LottieDecoder? decoder, bool? backgroundLoading})

Properties

backgroundLoading → bool
finalinherited
bytes → Uint8List
final
decoder → LottieDecoder?
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
imageProviderFactory → LottieImageProviderFactory?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getImageProvider(LottieImageAsset lottieImage) → ImageProvider<Object>?
inherited
load({BuildContext? context}) → Future<LottieComposition>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override