MessagingStyleInformation class

Used to pass the content for an Android notification displayed using the messaging style.

Inheritance

Constructors

MessagingStyleInformation(Person person, {String? conversationTitle, bool? groupConversation, List<Message>? messages, bool htmlFormatContent = false, bool htmlFormatTitle = false})
Constructs an instance of MessagingStyleInformation.

Properties

conversationTitle → String?
The title to be displayed on this conversation.
final
groupConversation → bool?
Whether this conversation notification represents a group.
final
hashCode → int
The hash code for this object.
no setterinherited
htmlFormatContent → bool
Specifies if formatting should be applied to the content through HTML markup.
finalinherited
htmlFormatTitle → bool
Specifies if formatting should be applied to the title through HTML markup.
finalinherited
messages → List<Message>?
Messages to be displayed by this notification
final
person → Person
The person displayed for any messages that are sent by the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited