methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel(
'miguelruivo.flutter.plugins.filepicker',
StandardMethodCodec(),
);
The method channel used to interact with the native platform.
@visibleForTesting
final methodChannel = const MethodChannel(
'miguelruivo.flutter.plugins.filepicker',
StandardMethodCodec(),
);