registerWith static method
void
registerWith()
Registers this class as the default instance of FilePickerPlatform.
Implementation
static void registerWith() {
FilePickerPlatform.instance = MethodChannelFilePicker();
}
Registers this class as the default instance of FilePickerPlatform.
static void registerWith() {
FilePickerPlatform.instance = MethodChannelFilePicker();
}