lensType property

CameraLensType lensType
final

The lens type for the camera.

This allows selection between normal, wide, and zoom lenses on devices with multiple cameras.

Defaults to CameraLensType.any, which uses the first available camera for the given facing direction.

Currently only supported on iOS and Android.

Implementation

final CameraLensType lensType;