getSupportedLenses method

Future<Set<CameraLensType>> getSupportedLenses({
  1. CameraFacing? facing,
})

Get the set of supported camera lens types for the current device.

Returns a set of CameraLensType values that are available on the device.

Returns an empty set if the device has no cameras. On platforms that do not support querying specific lens types, returns a set containing only CameraLensType.any if cameras are available.

This method can be called before starting the scanner.

Implementation

Future<Set<CameraLensType>> getSupportedLenses({
  CameraFacing? facing,
}) {
  throw UnimplementedError('getSupportedLenses() has not been implemented.');
}