PdfComboBoxFormField class

Represents the combo box form field.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<String>
Gets the items of the PdfComboBoxFormField.
no setter
name → String
Gets the name of the PdfFormField.
no setterinherited
pageNumber → int
Gets the page number of the PdfFormField.
no setterinherited
readOnly ↔ bool
Gets or sets a value indicating whether the PdfFormField is read-only.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItem ↔ String
Gets or sets a selected item of the PdfComboBoxFormField.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited