PdfFormField class abstract

Represents the form field.

Constructors

PdfFormField()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Gets the name of the PdfFormField.
no setter
pageNumber → int
Gets the page number of the PdfFormField.
no setter
readOnly ↔ bool
Gets or sets a value indicating whether the PdfFormField is read-only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited