PdfFormFieldFocusChangeDetails class

Holds the details for the SfPdfViewer.onFormFieldFocusChange callback, such as formField and hasFocus.

Constructors

PdfFormFieldFocusChangeDetails(PdfFormField _formField, bool _hasFocus)
Creates details for SfPdfViewer.onFormFieldFocusChange callback.

Properties

formField → PdfFormField
Returns the form field object that has focus changes.
no setter
hasFocus → bool
Indicates whether the form field has focus or not.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited