PendingNotificationRequest class

Details of a pending notification that has not been delivered.

Constructors

PendingNotificationRequest(int id, String? title, String? body, String? payload)
Constructs an instance of PendingNotificationRequest.
const

Properties

body → String?
The notification's body.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The notification's id.
final
payload → String?
The notification's payload.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The notification's title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited