path property
String?
get
path
The local file path of the underlying file, or null if not on local disk.
Implementation
String? get path => uri.scheme == 'file' ? uri.toFilePath() : null;
The local file path of the underlying file, or null if not on local disk.
String? get path => uri.scheme == 'file' ? uri.toFilePath() : null;