readAsBytes abstract method
Read the bytes of the file as a single chunk.
Prefer readAsByteStream for large files.
Implementation
Future<Uint8List> readAsBytes();
Read the bytes of the file as a single chunk.
Prefer readAsByteStream for large files.
Future<Uint8List> readAsBytes();