labelPlacementCalculator property
The calculator to use to determine the position of the Polygon.label
Labels are not drawn if there is not enough space.
Important
If polygons may be over the anti-meridan boundary, PolygonLabelPlacementCalculator.simpleMultiWorldCentroid must be used - other calculators will produce unexpected results.
Pre-provided calculators are available as constructors on PolygonLabelPlacementCalculator. See the documentation on each for advantages & disadvantages of each implementation.
Defaults to PolygonLabelPlacementCalculator.centroid (CentroidCalculator).
Implementation
final PolygonLabelPlacementCalculator labelPlacementCalculator;