verticalSpeed property
The vertical speed at which the device is traveling in meters per second.
A positive value indicates ascending motion and a negative value indicates descending motion.
The vertical speed is not available on all devices. In these cases the value is 0.0.
Implementation
final double verticalSpeed;