ReportSaleTags class abstract

E7 — sale report totals, with E7.E0 per-good rows.

Constructors

ReportSaleTags()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

tagFormatMap → Map<String, ValuePackager>
no setter

Constants

customerTotalAmount → const int
customerTotalNumber → const int
firstTransactionDate → const int
goodCount → const int
goodId → const int
goodLastModifiedDate → const int
goodName → const int
goodTotalAmount → const int
goodTotalDiscountAmount → const int
goodTotalPaymentAmount → const int
lastModifiedDate → const int
lastTransactionDate → const int
legalCustomerTotalAmount → const int
legalCustomerTotalNumber → const int
reportFromDate → const int
reportToDate → const int
root → const int
saleGoods → const int
settlementAmount → const int
settlementDate → const int
totalAmount → const int
totalDiscountAmount → const int
totalPaymentAmount → const int