transformFilterQuality property
The FilterQuality of the transformed image.
See Transform.filterQuality for more information.
See filterQuality for the quality of the image before transformation.
When non-null (as by default), the bitmap render result of the transformation is cached by Flutter. This may improve performance, but can cause flickering on zooming when the raster cache is at its limits.
Defaults to FilterQuality.medium.
Implementation
final FilterQuality? transformFilterQuality;