ScrollPositionChange class

Defines the parameters of the scroll position change callback.

Constructors

ScrollPositionChange(double x, double y)
Creates a ScrollPositionChange.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
The value of the horizontal offset with the origin being at the leftmost of the WebView.
final
y → double
The value of the vertical offset with the origin being at the topmost of the WebView.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited