ShareParams class

Constructors

ShareParams({String? text, String? subject, String? title, XFile? previewThumbnail, Rect? sharePositionOrigin, Uri? uri, List<XFile>? files, List<String>? fileNameOverrides, bool downloadFallbackEnabled = true, bool mailToFallbackEnabled = true, List<CupertinoActivityType>? excludedCupertinoActivities})

Properties

downloadFallbackEnabled → bool
Whether to fall back to downloading files if share fails on web.
final
excludedCupertinoActivities → List<CupertinoActivityType>?
Exclude services on iOS and macOS that you think are not suitable for your content.
final
fileNameOverrides → List<String>?
Override the names of shared files.
final
files → List<XFile>?
Share multiple files, can be used in combination with text
final
hashCode → int
The hash code for this object.
no setterinherited
mailToFallbackEnabled → bool
Whether to fall back to sending an email if share fails on web.
final
previewThumbnail → XFile?
Preview thumbnail
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharePositionOrigin → Rect?
The optional sharePositionOrigin parameter can be used to specify a global origin rect to anchor the share sheet to a widget user interacts with on iPads and Macs. It has no effect on other devices.
final
subject → String?
Used as email subject where supported (e.g. EXTRA_SUBJECT on Android)
final
text → String?
The text to share
final
title → String?
Used as share sheet title where supported
final
uri → Uri?
Share a URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited