sharePositionOrigin property

Rect? sharePositionOrigin
final

The optional sharePositionOrigin parameter can be used to specify a global origin rect to anchor the share sheet to a widget user interacts with on iPads and Macs. It has no effect on other devices.

If this parameter not provided on iPads the popover anchors to the center of the screen instead of throwing. Providing an accurate rect is still recommended for better UX.

  • Supported platforms: iPad and Mac Parameter ignored on other platforms.

Implementation

final Rect? sharePositionOrigin;