ShareResult class

The result of a share to determine what action the user has taken.

status provides an easy way to determine how the share-sheet was handled by the user, while raw provides possible access to the action selected.

Constructors

ShareResult(String raw, ShareResultStatus status)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
raw → String
The raw return value from the share.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ShareResultStatus
The action the user has taken
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

unavailable → const ShareResult