SquigglyAnnotation class

Represents the squiggly annotation on the text contents in the page.

Inheritance

Constructors

SquigglyAnnotation({required List<PdfTextLine> textBoundsCollection})
Initializes a new instance of SquigglyAnnotation class.

Properties

author ↔ String?
The author of the annotation.
getter/setter pairinherited
color ↔ Color
The color of the Annotation.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isLocked ↔ bool
The lock state of the Annotation.
getter/setter pairinherited
name ↔ String?
The name of the annotation.
getter/setter pairinherited
opacity ↔ double
The opacity of the Annotation.
getter/setter pairinherited
pageNumber → int
The page number of the annotation.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String?
The subject of the annotation.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited