cameraLensType property

CameraLensType cameraLensType
final

The preferred lens type for the camera.

This allows selection between normal, wide, and zoom lenses on devices with multiple cameras.

When set to CameraLensType.any, the first available camera for the given cameraDirection will be used.

Implementation

final CameraLensType cameraLensType;