TileCoordinates class

Tile coordinates identify the position of the tile position for slippy map tiles. The z coordinate represents the zoom level where the zoom level of 0 fits the complete world while bigger z values are using accordingly to the zoom level of the MapCamera.

For more information see the docs https://docs.fleaflet.dev/getting-started/explanation#slippy-map-convention.

The tile coordinates are based on maths' Point class but extended with the zoom level.

Inheritance
Annotations

Constructors

TileCoordinates(int x, int y, int z)
Create a new TileCoordinates instance.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
magnitude → double
Get the straight line (Euclidean) distance between the origin (0, 0) and this point.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → int
finalinherited
y → int
finalinherited
z → int
The zoom level of the tile coordinates.
final

Methods

distanceTo(Point<num> other) → double
Returns the distance between this and other.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
squaredDistanceTo(Point<int> other) → int
Returns the squared distance between this and other.
inherited
toString() → String
A string representation of this object.
override

Operators

operator *(num factor) → Point<int>
Scale this point by factor as if it were a vector.
inherited
operator +(Point<int> other) → Point<int>
Add other to this, as if both points were vectors.
inherited
operator -(Point<int> other) → Point<int>
Subtract other from this, as if both points were vectors.
inherited
operator ==(Object other) → bool
Whether other is a point with the same coordinates as this point.
override