TorchState enum

The state of the flashlight.

Inheritance
Available extensions

Values

auto → const TorchState

The flashlight turns on automatically in low light conditions.

This is currently only supported on iOS and MacOS.

const TorchState(2)
off → const TorchState

The flashlight is off.

const TorchState(0)
on → const TorchState

The flashlight is on.

const TorchState(1)
unavailable → const TorchState

The flashlight is unavailable.

const TorchState(-1)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue → int
The raw value for the torch state.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TorchState>
A constant List of the values in this enum, in order of their declaration.