UArValue class
Internal: a typed value exchanged with the native AR engine.
Constructors
-
UArValue({UArSessionState state = UArSessionState.uninitialized, UArTrackingState tracking = UArTrackingState.notAvailable, UArTrackingReason trackingReason = UArTrackingReason.initializing, UArCapabilities capabilities = const UArCapabilities(), UArConfig config = const UArConfig(), Map<
String, UArPlane> planes = const <String, UArPlane>{}, Map<String, UArAnchor> anchors = const <String, UArAnchor>{}, Map<String, UArNode> nodes = const <String, UArNode>{}, Map<String, UArTrackedImage> images = const <String, UArTrackedImage>{}, Map<String, UArFace> faces = const <String, UArFace>{}, UArBody? body, UArFrame frame = const UArFrame(), int? textureId, String? viewType, bool isRecording = false, bool isXrActive = false, UArException? error}) -
const
Properties
-
anchors
→ Map<
String, UArAnchor> -
final
- body → UArBody?
-
final
- capabilities → UArCapabilities
-
final
- config → UArConfig
-
final
- error → UArException?
-
final
-
faces
→ Map<
String, UArFace> -
final
- frame → UArFrame
-
final
- geo → UArGeoPose?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasHorizontalPlane → bool
-
no setter
- hasPlanes → bool
-
no setter
- hasVerticalPlane → bool
-
no setter
-
images
→ Map<
String, UArTrackedImage> -
final
- isRecording → bool
-
final
- isRunning → bool
-
no setter
- isTracking → bool
-
no setter
- isXrActive → bool
-
On the web: an immersive WebXR / sensor session is running.
final
- light → UArLightEstimate?
-
no setter
-
nodes
→ Map<
String, UArNode> -
final
-
planes
→ Map<
String, UArPlane> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → UArSessionState
-
final
- textureId → int?
-
final
- tracking → UArTrackingState
-
final
- trackingReason → UArTrackingReason
-
final
- viewType → String?
-
final
Methods
-
copyWith(
{UArSessionState? state, UArTrackingState? tracking, UArTrackingReason? trackingReason, UArCapabilities? capabilities, UArConfig? config, Map< String, UArPlane> ? planes, Map<String, UArAnchor> ? anchors, Map<String, UArNode> ? nodes, Map<String, UArTrackedImage> ? images, Map<String, UArFace> ? faces, UArBody? body, bool clearBody = false, UArFrame? frame, int? textureId, String? viewType, bool? isRecording, bool? isXrActive, UArException? error, bool clearError = false}) → UArValue -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited