UChecksum class
Expected hash to verify a finished download.
Constructors
- UChecksum(UHashAlgorithm algorithm, String value)
-
const
-
UChecksum.fromJson(Map<
String, dynamic> json) -
Reads it from JSON.
factory
- UChecksum.md5(String value)
-
Expect this MD5 hex.
const
- UChecksum.sha256(String value)
-
Expect this SHA-256 hex.
const
Properties
- algorithm → UHashAlgorithm
-
Hash algorithm.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Hex digest, case-insensitive.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - As JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited