UCity class

A city.

Constructors

UCity({required String code, required String nameEn, required String nameFa})
const

Properties

code → String
final
hashCode → int
The hash code for this object.
no setterinherited
nameEn → String
final
nameFa → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited