UCountries class abstract

Every country with provinces and cities (Iran in full). UCountries.iran(), UCountries.byIsoCode("DE")

Constructors

UCountries()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

countries ↔ List<UCountry>
getter/setter pair
iranProvinces → List<UProvince>
no setter

Static Methods

byDialCode(String? dialCode) → UCountry?
byIsoCode(String? isoCode) → UCountry?
cityByCode(String? code) → UCity?
cityFullName(String? cityCode) → String?
codeType(String? code) → UCodeType
countryByCode(String? code) → UCountry?
countryCodeOf(String? code) → String?
infoByCode(String? code) → UCountryCityInfo
iran() → UCountry
parentCodeOf(String? code) → String?
provinceByCode(String? code) → UProvince?
provinceCodeOf(String? code) → String?