UCountryCityInfo class

Country + province + city picked together.

Constructors

UCountryCityInfo({UCountry? country, UProvince? province, UCity? city})
const

Properties

city → UCity?
final
country → UCountry?
final
hashCode → int
The hash code for this object.
no setterinherited
province → UProvince?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited