UDashManifest class

Parsed DASH manifest.

Constructors

UDashManifest({required List<UDashPeriod> periods, bool isDynamic = false, Duration duration = Duration.zero, Duration minBufferTime = Duration.zero, String? baseUrl, Duration? minimumUpdatePeriod})
const

Properties

baseUrl → String?
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
isDynamic → bool
final
isLive → bool
no setter
minBufferTime → Duration
final
minimumUpdatePeriod → Duration?
final
periods → List<UDashPeriod>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTracks() → List<UMediaTrack>

Operators

operator ==(Object other) → bool
The equality operator.
inherited