UDashSegmentTemplate class

DASH segment template.

Constructors

UDashSegmentTemplate({String? media, String? initialization, int timescale = 1, int duration = 0, int startNumber = 1, List<List<int>> timeline = const <List<int>>[], int presentationTimeOffset = 0})
const

Properties

duration → int
final
hashCode → int
The hash code for this object.
no setterinherited
hasTimeline → bool
no setter
initialization → String?
final
media → String?
final
presentationTimeOffset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startNumber → int
final
timeline → List<List<int>>
final
timescale → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited