UDocBookmark class

A bookmarked page (PDF) or reading position (EPUB).

Annotations

Constructors

UDocBookmark({required String id, required int pageIndex, required DateTime createdAt, String title = "", String note = "", Color color = const Color(0xFFE53935), int blockIndex = -1, double progress = -1})
const
UDocBookmark.fromJson(Map<String, Object?> json)
factory

Properties

blockIndex → int
final
color → Color
final
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
note → String
final
pageIndex → int
final
progress → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

copyWith({String? title, String? note, Color? color}) → UDocBookmark
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited