UDocDrawTool enum
Active tool of a UDocShapeLayer. none leaves the surface to the reader.
Values
- none → const UDocDrawTool
- select → const UDocDrawTool
- pen → const UDocDrawTool
- highlighter → const UDocDrawTool
- line → const UDocDrawTool
- arrow → const UDocDrawTool
- doubleArrow → const UDocDrawTool
- rectangle → const UDocDrawTool
- roundedRectangle → const UDocDrawTool
- ellipse → const UDocDrawTool
- areaHighlight → const UDocDrawTool
- textBox → const UDocDrawTool
- stickyNote → const UDocDrawTool
- eraser → const UDocDrawTool
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UDocDrawTool> - A constant List of the values in this enum, in order of their declaration.