UDocMarkupPainter class abstract final

Paints markup geometry. Shared by the PDF page overlay and the EPUB text overlay.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

badge(Canvas canvas, Offset center, Color color, double size) → void
A small folded-corner sticky note centred at center.
outline(Canvas canvas, List<Rect> rects) → void
Selection outline around every rect of a markup.
paint(Canvas canvas, UDocMarkupKind kind, List<Rect> rects, Color color, {bool selected = false, bool hasNote = false, bool rtl = false, bool drawBadge = true}) → void