UDocPalette class abstract final

Colors offered for highlights and notes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

iconOf(UDocMarkupKind kind) → IconData
labelOf(UDocMarkupKind kind) → String

Constants

colors → const List<Color>