origin property
Where this surface starts inside the full one (an EPUB paragraph continued on a later page).
Implementation
final Offset origin;
Where this surface starts inside the full one (an EPUB paragraph continued on a later page).
final Offset origin;