UDocTextPage class
All text of a page with positions (for search and selection).
Constructors
-
UDocTextPage({required int pageIndex, required List<
UDocTextRun> runs, required String text, required Size size}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- pageIndex → int
-
final
- reliability → double
-
Share of runs whose geometry is trustworthy (1 = everything precise).
no setter
-
runs
→ List<
UDocTextRun> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
final
- text → String
-
final
Methods
-
lineAround(
int offset) → (int, int)? -
Full line (run) boundaries around
offset. -
locate(
String needle, {int near = -1}) → (int, int)? -
Finds
needleon the page, first exactly, then Persian/Arabic-normalised. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offsetAt(
Offset point, {double maxDistance = 48}) → int? -
The logical offset nearest to
point, or null when nothing is withinmaxDistance. -
rectForRange(
int start, int end) → Rect? -
rectsForRange(
int start, int end, {UDocTextGeometry geometry = UDocTextGeometry.auto}) → List< Rect> -
runStart(
int runIndex) → int -
Page-text offset of the run that starts at
runIndex. -
textFor(
int start, int end) → String -
toString(
) → String -
A string representation of this object.
inherited
-
wordAround(
int offset) → (int, int)? -
Word boundaries around
offset(start inclusive, end exclusive).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const UDocTextPage