UDocWatermark class

Repeated user identification drawn over document pages (e.g. for course material).

Annotations

Constructors

UDocWatermark({required List<String> lines, double opacity = 0.14, Color color = const Color(0xFF000000), double fontSize = 14, int perPage = 2, bool randomAngle = true, double angle = -0.5, int seed = 0})
const

Properties

angle → double
final
color → Color
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
lines → List<String>
final
opacity → double
final
perPage → int
final
randomAngle → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seed → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited