UDownloadDestination.saveAs constructor
const
UDownloadDestination.saveAs()
Asks the user where to save once the download finishes.
Implementation
const UDownloadDestination.saveAs() : this._(UDownloadTarget.saveAs);
Asks the user where to save once the download finishes.
const UDownloadDestination.saveAs() : this._(UDownloadTarget.saveAs);