UDrmConfig class

DRM license settings.

Constructors

UDrmConfig({required UDrmScheme scheme, String? licenseUrl, Map<String, String> headers = const <String, String>{}, Map<String, String> clearKeys = const <String, String>{}, String? offlineLicenseId, bool multiSession = false})
const

Properties

clearKeys → Map<String, String>
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
licenseUrl → String?
final
multiSession → bool
final
offlineLicenseId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → UDrmScheme
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited