UEpubPage class

One laid-out page.

Constructors

UEpubPage({required int spineIndex, required int pageIndex, required List<UEpubBlock> blocks, required int startBlock, List<UEpubSlice> slices = const <UEpubSlice>[]})
const

Properties

blocks → List<UEpubBlock>
final
hashCode → int
The hash code for this object.
no setterinherited
pageIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slices → List<UEpubSlice>
Exact block ranges on this page (filled by UEpubPaginator.paginateSlices).
final
spineIndex → int
final
startBlock → int
final

Methods

contains(int blockIndex, int offset) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited