UEpubSlice class

A contiguous piece of one block: the whole block, or the part that fits on a page.

Constructors

UEpubSlice({required int blockIndex, int start = 0, int end = -1})
const

Properties

blockIndex → int
final
end → int
Exclusive end offset, or -1 for "to the end of the block".
final
hashCode → int
The hash code for this object.
no setterinherited
isWhole → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final

Methods

endIn(UEpubBlock block) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited