UEpubSpineItem class

A chapter in reading order.

Constructors

UEpubSpineItem({required String idref, required String href, bool linear = true, String properties = ""})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
href → String
final
idref → String
final
linear → bool
final
properties → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited