notificationTitle property
When set, a notification is shown on the transition even if the app is not running.
Implementation
final String? notificationTitle;
When set, a notification is shown on the transition even if the app is not running.
final String? notificationTitle;