UHeading class

Compass reading: degrees from north, accuracy.

Annotations

Constructors

UHeading({required double magnetic, required DateTime time, double? trueNorth, double? accuracy})
const
UHeading.fromMap(Map<Object?, Object?> m)
Reads it from the native map.
factory

Properties

accuracy → double?
Uncertainty in degrees.
final
degrees → double
The best available heading.
no setter
hashCode → int
The hash code for this object.
no setterinherited
magnetic → double
Degrees from magnetic north.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → DateTime
When it was measured.
final
trueNorth → double?
Degrees from true (geographic) north, when known.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited