UHlsMasterPlaylist class

HLS master playlist.

Constructors

UHlsMasterPlaylist({required List<UHlsVariant> variants, required List<UHlsRendition> renditions, bool independentSegments = false})
const

Properties

audioRenditions → List<UHlsRendition>
no setter
hashCode → int
The hash code for this object.
no setterinherited
independentSegments → bool
final
renditions → List<UHlsRendition>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleRenditions → List<UHlsRendition>
no setter
variants → List<UHlsVariant>
final

Methods

bestUnder(int maxHeight) → UHlsVariant?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited