UHlsPlaylist class

Parsed HLS playlist (master or media).

Constructors

UHlsPlaylist({UHlsMasterPlaylist? master, UHlsMediaPlaylist? media})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMaster → bool
no setter
master → UHlsMasterPlaylist?
final
media → UHlsMediaPlaylist?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited