UHlsRendition class

HLS alternative audio/subtitle track.

Constructors

UHlsRendition({required String type, required String groupId, required String name, String? language, String? uri, bool isDefault = false, bool autoSelect = false, bool forced = false, int? channels})
const

Properties

autoSelect → bool
final
channels → int?
final
forced → bool
final
groupId → String
final
hashCode → int
The hash code for this object.
no setterinherited
isDefault → bool
final
language → String?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
uri → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited