ULaunchChannel class abstract final

Engine behind ULaunch; use ULaunch instead.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

inAppClosed → Stream<void>
no setter
Links received while the app is running.
no setter

Static Methods

authenticate(String url, {required String callbackScheme, bool ephemeral = false, Duration timeout = const Duration(minutes: 5)}) → Future<Uri?>
Opens url for sign-in and returns the redirect back to callbackScheme (or null if cancelled).
call(String number) → Future<bool>
canOpen(String url) → Future<bool>
closeInApp() → Future<bool>
directions(double latitude, double longitude, {UMapApp app = UMapApp.system, UTravelMode mode = UTravelMode.driving}) → Future<bool>
dispose() → Future<void>
Stops listening for links and in-app browser events.
email({List<String> to = const <String>[], List<String> cc = const <String>[], List<String> bcc = const <String>[], String? subject, String? body, bool isHtml = false, List<String> attachments = const <String>[]}) → Future<UComposeResult>
The link that launched the app (deep link, universal / app link, custom scheme), once.
isInstalled(String id) → Future<bool>
open(String url, {ULaunchMode mode = ULaunchMode.platformDefault, Map<String, String> headers = const <String, String>{}, String? androidPackage, int? toolbarColor, int? controlColor, bool showTitle = true, bool readerMode = false, String? webWindowName}) → Future<bool>
openApp(String id) → Future<bool>
openChat(UMessenger messenger, String target, {String? text}) → Future<bool>
openSettings(USettingsPage page, {String? channelId}) → Future<bool>
openStore({UAppStore store = UAppStore.auto, String? appId, bool review = false}) → Future<bool>
requestReview() → Future<bool>
showOnMap(double latitude, double longitude, {String? label, UMapApp app = UMapApp.system}) → Future<bool>
sms({required List<String> to, String? body, List<String> attachments = const <String>[]}) → Future<UComposeResult>