UMediaFit enum

Video fit: contain, cover, fill, 16:9, 4:3…

Inheritance
Available extensions

Values

contain → const UMediaFit
cover → const UMediaFit
fill → const UMediaFit
fitWidth → const UMediaFit
fitHeight → const UMediaFit
none → const UMediaFit
ratio16x9 → const UMediaFit
ratio4x3 → const UMediaFit
ratio21x9 → const UMediaFit
ratio1x1 → const UMediaFit
original → const UMediaFit

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UMediaFit>
A constant List of the values in this enum, in order of their declaration.