UMediaValue class

Player state snapshot: state, position, duration, buffered, volume, speed, tracks.

Constructors

UMediaValue({UMediaState state = UMediaState.idle, Duration position = Duration.zero, Duration duration = Duration.zero, Duration bufferedPosition = Duration.zero, List<UBufferedRange> buffered = const <UBufferedRange>[], bool isLive = false, Duration liveOffset = Duration.zero, double speed = 1, double volume = 1, bool muted = false, int width = 0, int height = 0, int rotationDegrees = 0, List<UMediaTrack> tracks = const <UMediaTrack>[], int currentIndex = 0, int queueLength = 0, bool shuffle = false, URepeatMode repeat = URepeatMode.off, UPipState pip = UPipState.unavailable, UMediaMetadata? metadata, UMediaError? error})
const

Properties

aspectRatio → double
no setter
buffered → List<UBufferedRange>
final
bufferedPosition → Duration
final
currentIndex → int
final
duration → Duration
final
error → UMediaError?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasVideo → bool
no setter
height → int
final
isBuffering → bool
no setter
isLive → bool
final
isPlaying → bool
no setter
isReady → bool
no setter
liveOffset → Duration
final
metadata → UMediaMetadata?
final
muted → bool
final
pip → UPipState
final
position → Duration
final
progress → double
no setter
queueLength → int
final
repeat → URepeatMode
final
rotationDegrees → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffle → bool
final
speed → double
final
state → UMediaState
final
tracks → List<UMediaTrack>
final
volume → double
final
width → int
final

Methods

copyWith({UMediaState? state, Duration? position, Duration? duration, Duration? bufferedPosition, List<UBufferedRange>? buffered, bool? isLive, Duration? liveOffset, double? speed, double? volume, bool? muted, int? width, int? height, int? rotationDegrees, List<UMediaTrack>? tracks, int? currentIndex, int? queueLength, bool? shuffle, URepeatMode? repeat, UPipState? pip, UMediaMetadata? metadata, UMediaError? error, bool clearError = false}) → UMediaValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectedTrack(UMediaTrackType type) → UMediaTrack?
toString() → String
A string representation of this object.
inherited
tracksOf(UMediaTrackType type) → List<UMediaTrack>

Operators

operator ==(Object other) → bool
The equality operator.
inherited