UNotificationInfo class

A scheduled notification that has not fired yet, or one currently shown.

Annotations

Constructors

UNotificationInfo({required int id, String? title, String? body, String? group, DateTime? next, Map<String, Object?>? payload})
const
UNotificationInfo.fromMap(Map<Object?, Object?> m)
Reads it from the native map.
factory

Properties

body → String?
Text.
final
group → String?
Group key.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
Notification id.
final
next → DateTime?
When a scheduled notification fires next.
final
payload → Map<String, Object?>?
Payload.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited