UPdfPositionedGlyph class

A glyph as positioned on the page, before being grouped into text runs.

Constructors

UPdfPositionedGlyph({required String text, required Rect rect, double fontSize = 0, String fontName = "", bool isSpace = false, bool logical = false})
const

Properties

fontName → String
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
isSpace → bool
final
logical → bool
Text is already in logical order (from /ActualText) and must not be mirrored.
final
rect → Rect
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited