UPdfTrueType class

Internal: TrueType font.

Implemented types

Properties

cff ↔ UPdfCff?
getter/setter pair
glyphCount → int
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitsPerEm → int
no setteroverride

Methods

advance(int glyphId) → double
override
glyphForCid(int cid) → int
override
glyphForMacRoman(int code) → int
glyphForName(String name) → int
override
glyphForUnicode(int codePoint) → int
override
glyphPath(int glyphId) → Path?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(Uint8List bytes) → UPdfTrueType?