UPdfType1 class

Internal: Type 1 font.

Implemented types

Properties

builtinEncoding → List<String>
no setter
glyphCount → int
no setteroverride
glyphNames → List<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitsPerEm → int
no setteroverride

Methods

advance(int glyphId) → double
override
advanceForName(String name) → double
glyphForCid(int cid) → int
override
glyphForName(String name) → int
override
glyphForUnicode(int codePoint) → int
override
glyphPath(int glyphId) → Path?
override
glyphPathForName(String name) → Path?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(Uint8List bytes) → UPdfType1?