UPlaylistStore class
Saved playlists (see UMedia).
- Inheritance
-
- Object
- ChangeNotifier
- UPlaylistStore
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
playlists
→ List<
UPlaylist> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
addTracks(
String id, List< String> paths) → Future<void> -
create(
String name, {List< String> paths = const <String>[]}) → Future<UPlaylist> -
delete(
String id) → Future< void> -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
exportM3u(
UPlaylist playlist, String directoryPath) → Future< File?> -
importM3u(
String path) → Future< UPlaylist?> -
load(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeTrack(
String id, String path) → Future< void> -
rename(
String id, String name) → Future< void> -
reorder(
String id, int from, int to) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
tracksOf(
UPlaylist playlist) → List< UTrackRecord>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → UPlaylistStore
-
final