USettingsPage enum

System settings pages for ULaunch.settings (app, notifications, location, wifi, bluetooth, battery…).

Inheritance
Available extensions

Values

app → const USettingsPage
notifications → const USettingsPage
notificationChannel → const USettingsPage
location → const USettingsPage
wifi → const USettingsPage
bluetooth → const USettingsPage
battery → const USettingsPage
display → const USettingsPage
sound → const USettingsPage
dateTime → const USettingsPage
language → const USettingsPage
security → const USettingsPage
nfc → const USettingsPage
dataUsage → const USettingsPage
accessibility → const USettingsPage
developer → const USettingsPage
storage → const USettingsPage
vpn → const USettingsPage
airplaneMode → const USettingsPage
apps → const USettingsPage
exactAlarms → const USettingsPage
overlay → const USettingsPage
allFilesAccess → const USettingsPage
installUnknownApps → const USettingsPage
usageAccess → const USettingsPage
defaultApps → const USettingsPage
fullScreenIntents → const USettingsPage

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<USettingsPage>
A constant List of the values in this enum, in order of their declaration.