Engine behind UShare; use UShare instead.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
received
→ Stream<
UReceivedShare> -
Shares received while the app runs.
no setter
Static Methods
- Engine call behind UShare.canShareTo.
-
dispose(
) → Future< void> -
initial(
) → Future< UReceivedShare?> - What was shared into the app when it was launched by a share (once).
- Engine call behind UShare.share.
- Engine call behind UShare.to.