UShareTarget enum

App for UShare.to: whatsapp, telegram, eitaa, rubika, bale, soroush, instagram, x, email, sms…

Inheritance
Available extensions

Values

whatsapp → const UShareTarget
telegram → const UShareTarget
eitaa → const UShareTarget
rubika → const UShareTarget
bale → const UShareTarget
soroush → const UShareTarget
instagram → const UShareTarget
x → const UShareTarget
email → const UShareTarget
sms → const UShareTarget

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UShareTarget>
A constant List of the values in this enum, in order of their declaration.