USubtitleSpan class

Styled text inside a cue.

Constructors

USubtitleSpan(String text, {bool bold = false, bool italic = false, bool underline = false, bool strikethrough = false, Color? color, double? fontScale})
const

Properties

bold → bool
final
color → Color?
final
fontScale → double?
final
hashCode → int
The hash code for this object.
no setterinherited
isPlain → bool
no setter
italic → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strikethrough → bool
final
text → String
final
underline → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited