UVisit class

A visit (arrival / departure at a place), iOS only.

Annotations

Constructors

UVisit({required double latitude, required double longitude, double? accuracy, DateTime? arrival, DateTime? departure})
const
UVisit.fromMap(Map<Object?, Object?> m)
Reads it from the native map.
factory

Properties

accuracy → double?
Accuracy in metres.
final
arrival → DateTime?
When the user arrived.
final
departure → DateTime?
Null while the user is still there.
final
hashCode → int
The hash code for this object.
no setterinherited
latitude → double
Latitude of the place.
final
longitude → double
Longitude of the place.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited