VasKeyTags class abstract

E2 — value added services, with E2.E0 items.

Constructors

VasKeyTags()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

tagFormatMap → Map<String, ValuePackager>
no setter

Constants

itemId → const int
itemName → const int
items → const int
itemType → const int
itemValue → const int
itemValueSecure → const int
root → const int
vasAuthCode → const int
vasId → const int
vasName → const int
vasOrgCode → const int
vasOrgName → const int
vasOrgType → const int
vasOrgUnitCode → const int