formatHint property
Android only. Will override the platform's generic file format detection with whatever is set here.
Implementation
final platform_interface.VideoFormat? formatHint;
Android only. Will override the platform's generic file format detection with whatever is set here.
final platform_interface.VideoFormat? formatHint;