VideoPlayerWebOptions class

VideoPlayerWebOptions can be optionally used to set additional web settings

Annotations

Constructors

VideoPlayerWebOptions({VideoPlayerWebOptionsControls controls = const VideoPlayerWebOptionsControls.disabled(), bool allowContextMenu = true, bool allowRemotePlayback = true, Uri? poster})
VideoPlayerWebOptions can be optionally used to set additional web settings
const

Properties

allowContextMenu → bool
Whether context menu (right click) is allowed
final
allowRemotePlayback → bool
Whether remote playback is allowed
final
controls → VideoPlayerWebOptionsControls
Additional settings for how control options are displayed
final
hashCode → int
The hash code for this object.
no setterinherited
poster → Uri?
The URL of the poster image to be displayed before the video starts
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited