VideoPlayerWebOptionsControls class

VideoPlayerWebOptions can be used to set how control options are displayed

Annotations

Constructors

VideoPlayerWebOptionsControls.disabled()
Disables control options. Default behavior.
const
VideoPlayerWebOptionsControls.enabled({bool allowDownload = true, bool allowFullscreen = true, bool allowPlaybackRate = true, bool allowPictureInPicture = true})
Enables controls and sets how the options are displayed
const

Properties

allowDownload → bool
Whether downloaded control is displayed
final
allowFullscreen → bool
Whether fullscreen control is enabled
final
allowPictureInPicture → bool
Whether picture in picture control is displayed
final
allowPlaybackRate → bool
Whether playback rate control is displayed
final
controlsList → String
A string representation of disallowed controls
no setter
enabled → bool
Whether native controls are enabled
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited