VideoProgressColors class

Used to configure the VideoProgressIndicator widget's colors for how it describes the video's status.

The widget uses default colors that are customizable through this class.

Constructors

VideoProgressColors({Color playedColor = const Color.fromRGBO(255, 0, 0, 0.7), Color bufferedColor = const Color.fromRGBO(50, 50, 200, 0.2), Color backgroundColor = const Color.fromRGBO(200, 200, 200, 0.5)})
Any property can be set to any color. They each have defaults.
const

Properties

backgroundColor → Color
backgroundColor defaults to gray at 50% opacity. This is the background color behind both playedColor and bufferedColor to denote the total size of the video compared to either of those values.
final
bufferedColor → Color
bufferedColor defaults to blue at 20% opacity. This fills up a portion of VideoProgressIndicator to represent how much of the video has buffered so far.
final
hashCode → int
The hash code for this object.
no setterinherited
playedColor → Color
playedColor defaults to red at 70% opacity. This fills up a portion of the VideoProgressIndicator to represent how much of the video has played so far.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited