bitrate property
Bitrate of the video track in bits per second.
May be null if not available from the platform.
Implementation
final int? bitrate;
Bitrate of the video track in bits per second.
May be null if not available from the platform.
final int? bitrate;