codec property
Video codec used (e.g., "avc1", "hevc", "vp9").
May be null if not available from the platform.
Implementation
final String? codec;
Video codec used (e.g., "avc1", "hevc", "vp9").
May be null if not available from the platform.
final String? codec;