label property
Human-readable label for the track (e.g., "1080p", "720p").
May be null if not available from the platform.
Implementation
final String? label;
Human-readable label for the track (e.g., "1080p", "720p").
May be null if not available from the platform.
final String? label;