Vincenty class

Implemented types

Constructors

Vincenty()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

distance(LatLng p1, LatLng p2) → double
Calculates distance with Vincenty algorithm.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(LatLng from, double distanceInMeter, double bearing) → LatLng
Vincenty inverse calculation
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited