WebFlutterLocalNotificationsPlugin class

A stub implementation of the web plugin, for non-web platforms.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
permissionStatus WebNotificationPermission
Returns the current permission status.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel({required int id}) Future<void>
Cancels/removes the notification with the specified id.
override
cancelAll() Future<void>
Cancels/removes all notifications. This applies to notifications that have been scheduled and those that have already been presented.
override
cancelAllPendingNotifications() Future<void>
Cancels/removes all pending notifications.
override
getActiveNotifications() Future<List<ActiveNotification>>
Returns the list of active notifications shown by the application that haven't been dismissed/removed.
override
getNotificationAppLaunchDetails() Future<NotificationAppLaunchDetails?>
Returns info on if a notification had been used to launch the application.
override
initialize({DidReceiveNotificationResponseCallback? onDidReceiveNotificationResponse}) Future<bool?>
Initializes the plugin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppNotificationSettings() Future<bool?>
Opens the system settings UI where the user can manage notification permissions for the app.
inherited
pendingNotificationRequests() Future<List<PendingNotificationRequest>>
Returns a list of notifications pending to be delivered/shown
override
periodicallyShow({required int id, String? title, String? body, required RepeatInterval repeatInterval}) Future<void>
Periodically show a notification using the specified interval.
inherited
periodicallyShowWithDuration({required int id, String? title, String? body, required Duration repeatDurationInterval}) Future<void>
Periodically show a notification using the specified custom duration interval.
inherited
requestNotificationsPermission() Future<bool?>
Requests notification permission from the browser.
show({required int id, String? title, String? body, String? payload, WebNotificationDetails? notificationDetails}) Future<void>
Show a notification with an optional payload that will be passed back to the app when a notification is tapped on.
override
toString() String
A string representation of this object.
inherited
zonedSchedule({required int id, String? title, String? body, required TZDateTime scheduledDate, String? payload, DateTimeComponents? matchDateTimeComponents, WebNotificationDetails? notificationDetails}) Future<void>
Schedules a notification to be shown at the specified date and time relative to a specific time zone.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isSupported bool
Whether the browser supports the Notification API.
no setter