cancel method
Cancels/removes the notification with the specified id.
This applies to notifications that have been scheduled and those that have already been presented.
Implementation
@override
Future<void> cancel({required int id}) async {}
Cancels/removes the notification with the specified id.
This applies to notifications that have been scheduled and those that have already been presented.
@override
Future<void> cancel({required int id}) async {}