requestNotificationsPermission method
Requests notification permission from the browser.
Be sure to only request permissions in response to a user gesture, or it may be automatically rejected.
Implementation
Future<bool?> requestNotificationsPermission() async => false;