zonedSchedule method

  1. @override
Future<void> zonedSchedule({
  1. required int id,
  2. String? title,
  3. String? body,
  4. required TZDateTime scheduledDate,
  5. String? payload,
  6. DateTimeComponents? matchDateTimeComponents,
  7. WebNotificationDetails? notificationDetails,
})
override

Schedules a notification to be shown at the specified date and time relative to a specific time zone.

Implementation

@override
Future<void> zonedSchedule({
  required int id,
  String? title,
  String? body,
  required tz.TZDateTime scheduledDate,
  String? payload,
  DateTimeComponents? matchDateTimeComponents,
  WebNotificationDetails? notificationDetails,
}) async {}