renotify property

bool renotify
final

Whether the user should be notified if this notification is replaced.

If this is false, the new notification will replace this one silently. If this is true, the device will notify the user any time the notification is updated.

For example, when updating a loading notification, you want each update to occur silently. But if you have a notification that represents a chat thread, you'd want it to update when a new message is sent.

Implementation

final bool renotify;