requireInteraction property
Whether the notification should remain visible until manually dismissed.
Implementation
final bool requireInteraction;
Whether the notification should remain visible until manually dismissed.
final bool requireInteraction;