timestamp property
The timestamp of the event that caused this notification.
This doesn't always have to be the time the notification was sent. For exmaple, if the notification represents a message that was sent a while ago, you can back-date this timestamp to when the message was originally sent instead of when it was received.
Implementation
final DateTime? timestamp;