WebNotificationPermission enum
The permission status for web notifications.
See: https://developer.mozilla.org/en-US/docs/Web/API/Notification/permission
Values
- granted → const WebNotificationPermission
-
User explicitly allowed notifications.
const WebNotificationPermission('granted') - denied → const WebNotificationPermission
-
User explicitly blocked notifications (may be permanent).
const WebNotificationPermission('denied') - defaultPermissions → const WebNotificationPermission
-
User hasn't decided yet.
const WebNotificationPermission('default')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
The string representation of the permission.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String status) → WebNotificationPermission - Returns the corresponding WebNotificationPermission from a string given by the browser's Notification API.
Constants
-
values
→ const List<
WebNotificationPermission> - A constant List of the values in this enum, in order of their declaration.