WebVTTCaptionFile class

Represents a ClosedCaptionFile, parsed from the WebVTT file format. See: https://en.wikipedia.org/wiki/WebVTT

Inheritance

Constructors

WebVTTCaptionFile(String fileContents)
Parses a string into a ClosedCaptionFile, assuming fileContents is in the WebVTT file format.

Properties

captions → List<Caption>
The full list of captions from a given file.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited