failures property
Data categories that could not be cleared and their diagnostic messages.
Implementation
final Map<WebViewDataType, String> failures;
Data categories that could not be cleared and their diagnostic messages.
final Map<WebViewDataType, String> failures;