unsupportedDataTypes property
Data categories that the current platform cannot clear through this API.
Implementation
final Set<WebViewDataType> unsupportedDataTypes;
Data categories that the current platform cannot clear through this API.
final Set<WebViewDataType> unsupportedDataTypes;