WebViewDataType enum

A category of persistent or session website data used by WebViews.

Inheritance
Available extensions

Values

cookies → const WebViewDataType

HTTP cookies.

cache → const WebViewDataType

Network and offline caches exposed by the platform website-data API.

localStorage → const WebViewDataType

HTML local storage.

sessionStorage → const WebViewDataType

HTML session storage.

indexedDb → const WebViewDataType

IndexedDB databases.

webSql → const WebViewDataType

WebSQL databases on engines that still support them.

cacheStorage → const WebViewDataType

Cache Storage entries not already included by the native cache category.

serviceWorkers → const WebViewDataType

Service worker registrations.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WebViewDataType>
A constant List of the values in this enum, in order of their declaration.