WindowsOptions class

The options for the Windows file picker.

Inheritance

Constructors

WindowsOptions({bool lockParentWindow = false})
Creates an instance of WindowsOptions.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lockParentWindow bool
Whether to lock the parent window modally when showing the file picker dialog.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited