viewInsets property
EdgeInsets
get
viewInsets
Space taken by the keyboard and other system UI.
Implementation
EdgeInsets get viewInsets => MediaQuery.viewInsetsOf(this);
Space taken by the keyboard and other system UI.
EdgeInsets get viewInsets => MediaQuery.viewInsetsOf(this);