alternative method
New list with main removed and replace added at the end. tags.alternative("old", "new")
Implementation
List<T> alternative(T main, T replace) => toList()
..remove(main)
..add(replace);
New list with main removed and replace added at the end. tags.alternative("old", "new")
List<T> alternative(T main, T replace) => toList()
..remove(main)
..add(replace);