setText method
Replaces the text and puts the cursor at the end. controller.setText("hello")
Implementation
void setText(String value) => this.value = TextEditingValue(
text: value,
selection: TextSelection.collapsed(offset: value.length),
);
Replaces the text and puts the cursor at the end. controller.setText("hello")
void setText(String value) => this.value = TextEditingValue(
text: value,
selection: TextSelection.collapsed(offset: value.length),
);