UHasher class

Incremental message digest. Call add any number of times, then close once.

Constructors

UHasher(UHashAlgorithm algorithm)

Properties

algorithm → UHashAlgorithm
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> data) → void
close() → Uint8List
closeHex() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hex(UHashAlgorithm algorithm, List<int> data) → String
One-shot convenience for small inputs.