UDownloadSegment class

A byte range fetched by one connection. end is exclusive; -1 when the size is unknown.

Constructors

UDownloadSegment(int start, int end, [int? position])
UDownloadSegment.fromJson(List json)
factory

Properties

end ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDone → bool
no setter
position ↔ int
getter/setter pair
remaining → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited