isResumable property
bool
get
isResumable
Resuming continues from the saved offset instead of starting over.
Implementation
bool get isResumable => acceptsRanges && received > 0;
Resuming continues from the saved offset instead of starting over.
bool get isResumable => acceptsRanges && received > 0;