state property
UDownloadStatus
get
state
Kept for code written against the media download manager.
Implementation
UDownloadStatus get state => status;
Kept for code written against the media download manager.
UDownloadStatus get state => status;