utils/files/u_download_platform library

Classes

UDownloadPlatform
Where a finished download is handed to the user.
UDownloadTransport
UHttpResponse
UTransportOptions

Exceptions / Errors

UTransportException
Raised by a transport for failures that are not HTTP statuses.