UHttpResponse class

Constructors

UHttpResponse({required int statusCode, required Map<String, String> headers, required Stream<Uint8List> body, required void abort()})

Properties

abort → void Function()
Tears down the connection immediately; the body stream then ends with an error or closes.
final
body → Stream<Uint8List>
final
contentLength → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
Lower-cased header names.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited