abort property
void Function()
abort
final
Tears down the connection immediately; the body stream then ends with an error or closes.
Implementation
final void Function() abort;
Tears down the connection immediately; the body stream then ends with an error or closes.
final void Function() abort;