UTransportException class

Raised by a transport for failures that are not HTTP statuses.

Implemented types

Constructors

UTransportException(String kind, [String? message])
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → String
"network", "timeout", "certificate", "aborted".
final
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited