UVaultHeader class

Constructors

UVaultHeader({required int algorithmId, required int chunkSize, required Uint8List noncePrefix, required Uint8List wrappedKey})

Properties

algorithmId → int
final
chunkSize → int
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
noncePrefix → Uint8List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sealedChunkSize → int
no setter
wrappedKey → Uint8List
final

Methods

encode() → Uint8List
nonce(int index, {required bool last}) → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plainLength(int fileLength) → int
Plaintext length of a vault file whose total size is fileLength.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Uint8List bytes) → UVaultHeader