UApp class abstract

Constructors

UApp()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

androidDeviceInfo ↔ AndroidDeviceInfo
getter/setter pair
buildNumber ↔ String
getter/setter pair
deviceInfo ↔ DeviceInfoPlugin
getter/setter pair
iosDeviceInfo ↔ IosDeviceInfo
getter/setter pair
isAndroid → bool
no setter
isDarkMode → bool
no setter
isDesktop → bool
no setter
isEmbedded → bool
no setter
isFuchsia → bool
no setter
isIos → bool
no setter
isLinux → bool
no setter
isMacOs → bool
no setter
isMobile → bool
no setter
isWeb → bool
no setter
isWindows → bool
no setter
linuxDeviceInfo ↔ LinuxDeviceInfo
getter/setter pair
macOsDeviceInfo ↔ MacOsDeviceInfo
getter/setter pair
name ↔ String
getter/setter pair
packageInfo ↔ PackageInfo
getter/setter pair
packageName ↔ String
getter/setter pair
queryParameters → Map<String, String>
no setter
version ↔ String
getter/setter pair
webBrowserInfo ↔ WebBrowserInfo
getter/setter pair
windowsDeviceInfo ↔ WindowsDeviceInfo
getter/setter pair

Static Methods

deviceId() → String
initDeviceInfo() → Future<void>
isDarkTheme() → bool
isDesktopSize() → bool
isLandscape() → bool
isMobileSize() → bool
isPhone() → bool
isPortrait() → bool
isTablet() → bool
isTabletSize() → bool
locale() → String
toDarkMode() → void
toLightMode() → void
updateLocale(Locale locale) → void