isDarkMode property
bool
get
isDarkMode
True when the app is showing the dark theme.
Implementation
static bool get isDarkMode => UAppState.isDarkMode;
True when the app is showing the dark theme.
static bool get isDarkMode => UAppState.isDarkMode;