isLandscape static method
True when the screen is wider than tall (needs a built app, uses navigatorKey).
Implementation
static bool isLandscape() => MediaQuery.of(navigatorKey.currentContext!).orientation == Orientation.landscape;
True when the screen is wider than tall (needs a built app, uses navigatorKey).
static bool isLandscape() => MediaQuery.of(navigatorKey.currentContext!).orientation == Orientation.landscape;