justUpdated property
bool
get
justUpdated
True when the app was updated since the last launch.
Implementation
static bool get justUpdated => UPackage.justUpdated;
True when the app was updated since the last launch.
static bool get justUpdated => UPackage.justUpdated;