UAppState class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isDarkMode → bool
-
no setter
-
locale
→ ValueNotifier<
Locale> -
final
-
themeMode
→ ValueNotifier<
ThemeMode> -
final
Static Methods
-
changeThemeMode(
ThemeMode mode) → void -
updateLocale(
Locale value) → void