UAuth class abstract

Constructors

UAuth()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

canRefresh → bool
no setter
epoch → int
no setter
hasRefreshToken → bool
no setter
isRefreshTokenExpired → bool
no setter
isSessionEnded → bool
no setter
isSignedIn → bool
no setter

Static Methods

accessTokenExpiresAt() → DateTime?
clear() → Future<void>
diagnostics() → String
ensureFreshToken() → Future<void>
handleAuthFailure() → Future<void>
isAccessTokenExpired() → bool
isTokenIssuingEndpoint(String endpoint) → bool
onTokensIssued() → void
refresh() → Future<bool>
signOut() → Future<void>