epoch property
int
get
epoch
Counter bumped on every login/logout; lets requests started before a logout ignore their result.
Implementation
static int get epoch => _epoch;
Counter bumped on every login/logout; lets requests started before a logout ignore their result.
static int get epoch => _epoch;