UConstants class abstract

Constructors

UConstants()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isDarkMode ↔ String
getter/setter pair
locale ↔ String
getter/setter pair
refreshToken ↔ String
getter/setter pair
refreshTokenExpiresAt ↔ String
getter/setter pair
token ↔ String
getter/setter pair
userId ↔ String
getter/setter pair