UIcons class abstract

Brand icons bundled with u (SVG asset paths). SvgPicture.asset(UIcons.telegram, package: "u")

Constructors

UIcons()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

instagram → const String
Instagram logo.
phone → const String
Phone icon.
telegram → const String
Telegram logo.
website → const String
Website/globe icon.
whatsapp → const String
WhatsApp logo.