Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
csvToJson(String csv, {String delimiter = ",", bool pretty = false})
→ String
-
-
decodeJson(String json)
→ dynamic
-
-
encodeJson(Object? value, {bool pretty = false, int indent = 2})
→ String
-
-
jsonToCsv(String json, {String delimiter = ","})
→ String
-
-
jsonToXml(String json, {String rootName = "root", bool pretty = true})
→ String
-
-
mapToQueryString(Map<String, dynamic> map)
→ String
-
-
minifyJson(String json)
→ String
-
-
prettyJson(String json, {int indent = 2})
→ String
-
-
queryStringToMap(String query)
→ Map<String, String>
-
-
valueToXml(Object? value, {String rootName = "root", bool pretty = true})
→ String
-
-
xmlToJson(String xml, {bool pretty = false, bool includeRoot = true})
→ String
-