UFile class abstract

Constructors

UFile()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

cropImage({Uint8List? bytes, String? filePath, UCropOptions options = const UCropOptions(), dynamic action(UFileData file)?}) → Future<UFileData?>
isImageExtension(String? extension) → bool
openCamera({UCameraOptions options = const UCameraOptions(), dynamic action(List<UFileData>)?}) → Future<List<UFileData>>
pickFile({FileType fileType = FileType.any, List<String>? allowedExtensions, UCropOptions? crop, dynamic action(UFileData?)?}) → Future<UFileData?>
pickFiles({bool allowMultiple = true, FileType fileType = FileType.any, List<String>? allowedExtensions, UCropOptions? crop, dynamic action(List<UFileData>)?}) → Future<List<UFileData>>
pickImage({UImageSource source = UImageSource.gallery, bool selfie = false, bool allowMultiple = false, int? maxCount, UCropOptions? crop, UCameraOptions? cameraOptions, dynamic action(List<UFileData>)?}) → Future<List<UFileData>>
pickSingleImage({UImageSource source = UImageSource.gallery, bool selfie = false, int? imageQuality, UCropOptions? crop, UCameraOptions? cameraOptions, dynamic action(UFileData?)?}) → Future<UFileData?>
pickVideo({UImageSource source = UImageSource.gallery, UCameraOptions options = const UCameraOptions(), dynamic action(UFileData?)?}) → Future<UFileData?>
recordVideo({UCameraOptions options = const UCameraOptions(), dynamic action(UFileData?)?}) → Future<UFileData?>
showFilePicker({dynamic action(List<UFileData>)?, FileType fileType = FileType.any, bool allowMultiple = false, List<String>? allowedExtensions, UCropOptions? crop}) → Future<List<UFileData>>
showImagePicker({required UImageSource source, bool allowMultiple = false, bool isSelfie = false, UCropOptions? crop, dynamic action(List<UFileData>)?}) → Future<List<UFileData>>
takePhoto({bool selfie = false, UCropOptions? crop, UCameraOptions? options, dynamic action(UFileData?)?}) → Future<UFileData?>
takePhotos({int maxCount = 0, bool selfie = false, UCropOptions? crop, UCameraOptions? options, dynamic action(List<UFileData>)?}) → Future<List<UFileData>>
writeToFile(Uint8List data, {String extension = "tmp"}) → Future<File>

Constants

imageExtensions → const Set<String>