trimCache static method
Shrinks the cache bucket to its size limit now.
Implementation
static Future<void> trimCache() => UFileStorage.trimCache();
Shrinks the cache bucket to its size limit now.
static Future<void> trimCache() => UFileStorage.trimCache();