UFileData class

Constructors

UFileData({String? path, Uint8List? bytes, String? extension, String? url, String? id, List<int>? tags, List<UFileData>? children})

Properties

bytes → Uint8List?
final
children → List<UFileData>?
final
extension → String?
final
hasBytes → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isImage → bool
no setter
name → String?
no setter
path → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeInBytes → int?
no setter
tags → List<int>?
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited