onAuthFailed property
Runs once when the session can no longer be refreshed, e.g. go to login. UHttpClient.onAuthFailed = () async => UNavigator.offAll(LoginPage())
Implementation
static Future<void> Function()? onAuthFailed;
Runs once when the session can no longer be refreshed, e.g. go to login. UHttpClient.onAuthFailed = () async => UNavigator.offAll(LoginPage())
static Future<void> Function()? onAuthFailed;