UHttpClientResponse class

Constructors

UHttpClientResponse({String? response, String? error, String? exception})

Properties

error String?
final
exception String?
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
no setter
isException bool
no setter
isSuccessful bool
no setter
response String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited