map static method
Shows a place in Neshan, Balad, Google Maps, Waze, Apple Maps or the default map app (web: Google Maps). ULaunch.map(35.7, 51.4, label: "Office", app: UMapApp.neshan)
Implementation
static Future<bool> map(double latitude, double longitude, {String? label, UMapApp app = UMapApp.system}) => ULaunchChannel.showOnMap(latitude, longitude, label: label, app: app);