UFileStorage class abstract

Constructors

UFileStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allFilesStorageInfo() Map<String, int>
clear() Future<void>
copyFile(String sourceKey, String destinationKey) Future<void>
fileExists(String key) bool
fileSize(String key) Future<int>
getBytes(String key) Future<Uint8List?>
getBytesSync(String key) Uint8List?
getDatKeys() Future<List<String>>
getDatPaths() Future<List<String>>
getJson(String key) Future<Map<String, dynamic>?>
getKeys() Future<List<String>>
getString(String key) Future<String?>
init() Future<void>
Initializes file storage directories.
remove(String key) Future<void>
set(String key, String value) Future<void>
setBytes(String key, List<int> bytes) Future<void>
setJson(String key, Map<String, dynamic> jsonData) Future<void>
totalStorageUsed() int