ULocalStorage class abstract

Constructors

ULocalStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() Future<void>
containsKey(String key) bool
getAll() Map<String, dynamic>
getBool(String key) bool?
getDouble(String key) double?
getIfNotExpired(String key) → dynamic
getInt(String key) int?
getKeys() Set<String>
getLocale() String?
getRefreshToken() String?
getString(String key, {(String, String)? encryptKeyIv}) String?
getStringList(String key) List<String>?
getToken() String?
getUserId() String?
hasToken() bool
init() Future<void>
isDarkMode() bool
remove(String key) Future<void>
set(String key, dynamic value, {Duration? expireTime, (String, String)? encryptKeyIv}) → void
setBatch(Map<String, dynamic> keyValuePairs) Future<void>
setDarkMode(bool isDarkMode) → void
setLocale(String value) → void
setRefreshToken(String value) → void
setToken(String value, {Duration? expireTime}) → void
setUserId(String userId) → void