nowPlaying property
UMediaController?
get
nowPlaying
The player that currently has audio focus, or null.
Implementation
static UMediaController? get nowPlaying => UMediaSession.holder;
The player that currently has audio focus, or null.
static UMediaController? get nowPlaying => UMediaSession.holder;