canPop property
bool
get
canPop
True when there is a page to go back to.
Implementation
static bool get canPop => Navigator.of(context).canPop();
True when there is a page to go back to.
static bool get canPop => Navigator.of(context).canPop();