launchEvent static method
The tap that opened the app, or null when it was opened normally. final e = await UNotification.launchEvent();
Implementation
static Future<UNotificationEvent?> launchEvent() => UNotifyChannel.launchEvent();
The tap that opened the app, or null when it was opened normally. final e = await UNotification.launchEvent();
static Future<UNotificationEvent?> launchEvent() => UNotifyChannel.launchEvent();