UOtp class abstract
Constructors
- UOtp()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateAdminOtp(
String posSerial, int length) → String -
generateOtp(
String posSerial, int length) → String -
generateVerhoeff(
String num) → String -
verifyAdminOtp(
String posSerial, String otp) → bool -
verifyOtp(
String posSerial, String otp) → bool