UOperator class

Iranian mobile operator (همراه اول، ایرانسل، رایتل…).

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
Operator name in Persian.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

irancell → const UOperator
Irancell.
mci → const UOperator
Hamrah-e Aval (MCI).
rightTel → const UOperator
RighTel.
samanTel → const UOperator
SamanTel.
shatelMobile → const UOperator
Shatel Mobile.
taliya → const UOperator
Taliya.