RxList<E> class

Inheritance
Mixed-in types
Available extensions

Constructors

RxList([List<E>? initial])

Properties

first ↔ E
The first element.
getter/setter pairinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hasConnectivity bool

Available on List<ConnectivityResult>, provided by the ConnectivityResultListX extension

Returns whether any active network connection exists.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<E>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last ↔ E
The last element.
getter/setter pairinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length int
The number of objects in this list.
getter/setter pairoverride
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
numbers List<int>

Available on Iterable<T>, provided by the NumericEnumExtension extension

no setter
obs RxList<E>

Available on List<E>, provided by the RxListExt extension

no setter
obs RxList<E>

Available on List<E>?, provided by the RxnListExt extension

no setter
reversed Iterable<E>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
titlesEn List<String>

Available on Iterable<T>, provided by the NumericEnumExtension extension

no setter
titlesFa List<String>

Available on Iterable<T>, provided by the NumericEnumExtension extension

no setter
toJS JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSIterable JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
toJSProxyOrRef JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
value List<E>
getter/setter pairinherited
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E element) → void
Adds value to the end of this list, extending the length by one.
override
addAll(Iterable<E> iterable) → void
Appends all objects of iterable to the end of this list.
override
addAllAndReturn(Iterable<T> t) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

addAndReturn(T t) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
alternative(T main, T replace) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

any(bool test(E element)) bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() Map<int, E>
An unmodifiable Map view of this list.
inherited
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
assign(E item) → void
assignAll(Iterable<E> items) → void
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
byTag(TagMedia tag) List<UMediaResponse>

Available on Iterable<UMediaResponse>, provided by the MediaListExtension extension

byTag(TagContent tag) List<UContentResponse>

Available on Iterable<UContentResponse>, provided by the ContentListExtension extension

call([List<E>? newValue]) List<E>
override
cast<R>() List<R>
Returns a view of this list as a list of R instances.
inherited
clear() → void
Removes all objects from this list; the length of the list becomes zero.
override
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
containsAll(Iterable<T> list) bool

Available on Iterable<T>?, provided by the NullableIterableExtensions extension

containsAll(Iterable<T> list) bool

Available on Iterable<T>, provided by the GenericIterableExtensions extension

containsAny(Iterable<T> list) bool

Available on Iterable<T>, provided by the GenericIterableExtensions extension

dispose() → void
Discards any resources used by the object.
inherited
elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(E element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(E element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [E? fill]) → void
Overwrites a range of elements with fillValue.
inherited
firstByTag(TagContent tag) UContentResponse?

Available on Iterable<UContentResponse>, provided by the ContentListExtension extension

firstByTag(TagMedia tag) UMediaResponse?

Available on Iterable<UMediaResponse>, provided by the MediaListExtension extension

firstOrDefault({T? defaultValue}) → T?

Available on Iterable<T>, provided by the GenericIterableExtensions extension

firstWhere(bool test(E element), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereByTagOrNull(int tag) UCategoryResponse?

Available on Iterable<UCategoryResponse>?, provided by the NullableCategoryListExtension extension

firstWhereByTagOrNull(int tag) UWalletResponse?

Available on Iterable<UWalletResponse>?, provided by the NullableWalletListExtension extension

firstWhereByTagOrNull(int tag) UCategoryResponse?

Available on Iterable<UCategoryResponse>, provided by the CategoryListExtension extension

firstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the GenericIterableExtensions extension

fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<E> other) Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(E element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
forEachIndexed(void action(int index, T element)) → void

Available on Iterable<T>, provided by the GenericIterableExtensions extension

fromNumber(int id) → T?

Available on Iterable<T>, provided by the NumericEnumExtension extension

fromNumericIdOrThrow(int id) → T

Available on Iterable<T>, provided by the NumericEnumExtension extension

getFirstIfExist() → T?

Available on Iterable<T>, provided by the GenericIterableExtensions extension

getRange(int start, int end) Iterable<E>
Creates an Iterable that iterates over a range of elements.
inherited
indexOf(Object? element, [int start = 0]) int
The first index of element in this list.
inherited
indexWhere(bool test(E element), [int start = 0]) int
The first index in the list that satisfies the provided test.
inherited
insert(int index, E element) → void
Inserts element at position index in this list.
override
insertAll(int index, Iterable<E> iterable) → void
Inserts all objects of iterable at position index in this list.
override
insertAndReturn(int index, T t) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

insertFirstReturn(T item) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

isNotNullOrEmpty() bool

Available on Iterable<T>?, provided by the NullableIterableExtensions extension

isNullOrEmpty() bool

Available on Iterable<T>?, provided by the NullableIterableExtensions extension

join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(Object? element, [int? start]) int
The last index of element in this list.
inherited
lastIndexWhere(bool test(E element), [int? start]) int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(E element), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
map<T>(T f(E element)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapIndexed<E>(E f(int index, T item)) Iterable<E>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
primary() UWalletResponse

Available on Iterable<UWalletResponse>?, provided by the NullableWalletListExtension extension

reduce(E combine(E previousValue, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
refresh() → void
inherited
remove(Object? element) bool
Removes the first occurrence of value from this list.
override
removeAt(int index) → E
Removes the object at position index from this list.
override
removeLast() → E
Removes and returns the last object in this list.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeRange(int start, int end) → void
Removes a range of elements from the list.
override
removeWhere(bool test(E element)) → void
Removes all objects from this list that satisfy test.
override
replaceRange(int start, int end, Iterable<E> newContents) → void
Replaces a range of elements with the elements of replacements.
inherited
retainWhere(bool test(E element)) → void
Removes all objects from this list that fail to satisfy test.
override
setAll(int index, Iterable<E> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<E> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
inherited
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
singleWhere(bool test(E element), {E orElse()?}) → E
The single element that satisfies test.
inherited
skip(int count) Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E element)) Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
sort([int compare(E a, E b)?]) → void
Sorts this list according to the order specified by the compare function.
override
sublist(int start, [int? end]) List<E>
Returns a new list containing the elements between start and end.
inherited
take(int count) Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeIfPossible(int range) Iterable<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

takeWhile(bool test(E element)) Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<E>
Creates a List containing the elements of this Iterable.
inherited
toMapList() List<Map<String, dynamic>>

Available on Iterable<T>, provided by the NumericEnumExtension extension

toSet() Set<E>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
A string representation of this object.
inherited
where(bool test(E element)) Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereByTag(int tag) List<UCategoryResponse>

Available on Iterable<UCategoryResponse>?, provided by the NullableCategoryListExtension extension

whereByTag(int tag) List<UCategoryResponse>

Available on Iterable<UCategoryResponse>, provided by the CategoryListExtension extension

whereByTag(int tag) List<UWalletResponse>

Available on Iterable<UWalletResponse>?, provided by the NullableWalletListExtension extension

whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<E> other) List<E>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) → E
The object at the given index in the list.
override
operator []=(int index, E element) → void
Sets the value at the given index in the list to value.
override