RxSet<E> class

Inheritance
Mixed-in types
Available extensions

Constructors

RxSet([Set<E>? initial])

Properties

first → E
The first element.
no setterinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<E>
An iterator that iterates over the elements of this set.
no setteroverride
last → E
The last element.
no setterinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length int
The number of elements in this Iterable.
no setteroverride
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
numbers List<int>

Available on Iterable<T>, provided by the NumericEnumExtension extension

no setter
obs RxSet<E>

Available on Set<E>?, provided by the RxnSetExt extension

no setter
obs RxSet<E>

Available on Set<E>, provided by the RxSetExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
titlesEn List<String>

Available on Iterable<T>, provided by the NumericEnumExtension extension

no setter
titlesFa List<String>

Available on Iterable<T>, provided by the NumericEnumExtension extension

no setter
toJSIterable JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
value Set<E>
getter/setter pairinherited
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E value) bool
Adds value to the set.
override
addAll(Iterable<E> elements) → void
Adds all elements to this set.
override
addAllAndReturn(Iterable<T> t) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

addAndReturn(T t) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
alternative(T main, T replace) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

any(bool test(E value)) bool
Checks whether any element of this iterable satisfies test.
inherited
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
assignAll(Iterable<E> items) → void
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
byTag(TagMedia tag) List<UMediaResponse>

Available on Iterable<UMediaResponse>, provided by the MediaListExtension extension

byTag(TagContent tag) List<UContentResponse>

Available on Iterable<UContentResponse>, provided by the ContentListExtension extension

call([Set<E>? newValue]) Set<E>
override
cast<R>() Set<R>
Provides a view of this set as a set of R instances.
inherited
clear() → void
Removes all elements from the set.
override
contains(Object? element) bool
Whether value is in the set.
override
containsAll(Iterable<Object?> other) bool
Whether this set contains all the elements of other.
inherited
containsAll(Iterable<T> list) bool

Available on Iterable<T>?, provided by the NullableIterableExtensions extension

containsAll(Iterable<T> list) bool

Available on Iterable<T>, provided by the GenericIterableExtensions extension

containsAny(Iterable<T> list) bool

Available on Iterable<T>, provided by the GenericIterableExtensions extension

difference(Set<Object?> other) Set<E>
Creates a new set with the elements of this that are not in other.
inherited
dispose() → void
Discards any resources used by the object.
inherited
elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool f(E value)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(E element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstByTag(TagMedia tag) UMediaResponse?

Available on Iterable<UMediaResponse>, provided by the MediaListExtension extension

firstByTag(TagContent tag) UContentResponse?

Available on Iterable<UContentResponse>, provided by the ContentListExtension extension

firstOrDefault({T? defaultValue}) → T?

Available on Iterable<T>, provided by the GenericIterableExtensions extension

firstWhere(bool test(E value), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereByTagOrNull(int tag) UCategoryResponse?

Available on Iterable<UCategoryResponse>?, provided by the NullableCategoryListExtension extension

firstWhereByTagOrNull(int tag) UWalletResponse?

Available on Iterable<UWalletResponse>?, provided by the NullableWalletListExtension extension

firstWhereByTagOrNull(int tag) UCategoryResponse?

Available on Iterable<UCategoryResponse>, provided by the CategoryListExtension extension

firstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the GenericIterableExtensions extension

fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<E> other) Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void f(E element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
forEachIndexed(void action(int index, T element)) → void

Available on Iterable<T>, provided by the GenericIterableExtensions extension

fromNumber(int id) → T?

Available on Iterable<T>, provided by the NumericEnumExtension extension

fromNumericIdOrThrow(int id) → T

Available on Iterable<T>, provided by the NumericEnumExtension extension

getFirstIfExist() → T?

Available on Iterable<T>, provided by the GenericIterableExtensions extension

insertAndReturn(int index, T t) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

insertFirstReturn(T item) List<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

intersection(Set<Object?> other) Set<E>
Creates a new set which is the intersection between this set and other.
inherited
isNotNullOrEmpty() bool

Available on Iterable<T>?, provided by the NullableIterableExtensions extension

isNullOrEmpty() bool

Available on Iterable<T>?, provided by the NullableIterableExtensions extension

join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(E value), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
lookup(Object? element) → E?
If an object equal to object is in the set, return it.
override
map<T>(T f(E element)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapIndexed<E>(E f(int index, T item)) Iterable<E>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
primary() UWalletResponse

Available on Iterable<UWalletResponse>?, provided by the NullableWalletListExtension extension

reduce(E combine(E value, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
refresh() → void
inherited
remove(Object? value) bool
Removes value from the set.
override
removeAll(Iterable<Object?> elements) → void
Removes each element of elements from this set.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWhere(bool test(E value)) → void
Removes all elements of this set that satisfy test.
override
retainAll(Iterable<Object?> elements) → void
Removes all elements of this set that are not elements in elements.
override
retainWhere(bool test(E value)) → void
Removes all elements of this set that fail to satisfy test.
override
singleWhere(bool test(E value), {E orElse()?}) → E
The single element that satisfies test.
inherited
skip(int n) Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E value)) Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int n) Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeIfPossible(int range) Iterable<T>

Available on Iterable<T>, provided by the GenericIterableExtensions extension

takeWhile(bool test(E value)) Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<E>
Creates a List containing the elements of this Iterable.
inherited
toMapList() List<Map<String, dynamic>>

Available on Iterable<T>, provided by the NumericEnumExtension extension

toSet() Set<E>
Creates a Set with the same elements and behavior as this Set.
override
toString() String
A string representation of this object.
inherited
union(Set<E> other) Set<E>
Creates a new set which contains all the elements of this set and other.
inherited
where(bool f(E value)) Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereByTag(int tag) List<UCategoryResponse>

Available on Iterable<UCategoryResponse>?, provided by the NullableCategoryListExtension extension

whereByTag(int tag) List<UWalletResponse>

Available on Iterable<UWalletResponse>?, provided by the NullableWalletListExtension extension

whereByTag(int tag) List<UCategoryResponse>

Available on Iterable<UCategoryResponse>, provided by the CategoryListExtension extension

whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited