length property
The number of elements in this Iterable.
Counting all elements may involve iterating through all elements and can
therefore be slow.
Some iterables have a more efficient way to find the number of elements.
These must override the default implementation of length.
Implementation
@override
int get length {
_RxObserver.active?.read.add(this);
return _value.length;
}