UPageState enum
Values
- initial → const UPageState
- loading → const UPageState
- loaded → const UPageState
- error → const UPageState
- empty → const UPageState
- paging → const UPageState
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UPageState> - A constant List of the values in this enum, in order of their declaration.