call method
T
call(
- T newValue
Sets the value like a function and returns it. count(5)
Implementation
T call(T newValue) {
value = newValue;
return _value;
}
Sets the value like a function and returns it. count(5)
T call(T newValue) {
value = newValue;
return _value;
}