URxMap<K, V> class
Observable Map; changes rebuild UObx. final URxMap<String, int> cart = <String, int>{}.obs;
- Inheritance
-
- Object
- ChangeNotifier
- URx<
Map< K, V> > - URxMap
- Mixed-in types
-
- MapMixin<
K, V>
- MapMixin<
- Available extensions
Properties
-
entries
→ Iterable<
MapEntry< K, V> > -
The map entries of this Map.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
-
keys
→ Iterable<
K> -
The keys of this Map.
no setteroverride
- length → int
-
The number of key/value pairs in the map.
no setterinherited
-
obs
→ URxMap<
K, V> -
Available on Map<
Wraps this map in a URxMap.K, V> , provided by the RxMapExt extensionno setter -
obs
→ URxMap<
K, V> -
Available on Map<
Wraps this map (or an empty one) in a URxMap.K, V> ?, provided by the RxnMapExt extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
↔ Map<
K, V> -
The current value; setting it notifies listeners when it changed.
count.value++getter/setter pairinherited -
values
→ Iterable<
V> -
The values of this Map.
no setterinherited
Methods
-
add(
K key, V value) → Map< K, V> -
Available on Map<
New map withK, V> , provided by the MapAddExtension extensionkeyset tovalue.params.add("page", 2) -
addAll(
Map< K, V> other) → void -
Adds all key/value pairs of
otherto this map.override -
addEntries(
Iterable< MapEntry< newEntries) → voidK, V> > -
Adds all key/value pairs of
newEntriesto this map.override -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
assignAll(
Map< K, V> items) → void - Replaces every entry and notifies once.
-
call(
[Map< K, V> ? newValue]) → Map<K, V> -
Sets the value like a function and returns it.
count(5)override -
cast<
RK, RV> () → Map< RK, RV> -
Provides a view of this map as having
RKkeys andRVinstances, if necessary.inherited -
clear(
) → void -
Removes all entries from the map.
override
-
containsKey(
Object? key) → bool -
Whether this map contains the given
key.inherited -
containsValue(
Object? value) → bool -
Whether this map contains the given
value.inherited -
deepMerge(
Map< K, V> other) → Map<K, V> -
Available on Map<
New map whereK, V> , provided by the MapAddExtension extensionotherwins and nested maps are merged too.defaults.deepMerge(overrides) -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
forEach(
void action(K key, V value)) → void -
Applies
actionto each key/value pair of the map.inherited -
getOr<
T> (K key, T fallback) → T -
Available on Map<
Value ofK, V> , provided by the MapAddExtension extensionkeyas T, orfallbackwhen missing or another type.json.getOr<String>("name", "") -
map<
K2, V2> (MapEntry< K2, V2> transform(K key, V value)) → Map<K2, V2> -
Returns a new map where all entries of this map are transformed by
the given
convertfunction.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
omit(
Iterable< K> keys) → Map<K, V> -
Available on Map<
New map without the listed keys.K, V> , provided by the MapAddExtension extensionuser.omit(["password"]) -
pick(
Iterable< K> keys) → Map<K, V> -
Available on Map<
New map with only the listed keys.K, V> , provided by the MapAddExtension extensionuser.pick(["id", "name"]) -
putIfAbsent(
K key, V ifAbsent()) → V -
Look up the value of
key, or add a new entry if it isn't there.inherited -
refresh(
) → void -
Notifies listeners without changing the value (after mutating an object inside).
inherited
-
remove(
Object? key) → V? -
Removes
keyand its associated value, if present, from the map.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeNulls(
) → Map< K, V> -
Available on Map<
New map without null values (handy before sending JSON).K, V> , provided by the MapAddExtension extensionbody.removeNulls() -
removeWhere(
bool test(K key, V value)) → void -
Removes all entries of this map that satisfy the given
test.override -
toString(
) → String -
A string representation of this object.
inherited
-
update(
K key, V update(V value), {V ifAbsent()?}) → V -
Updates the value for the provided
key.inherited -
updateAll(
V update(K key, V value)) → void -
Updates all values.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → V? -
The value for the given
key, ornullifkeyis not in the map.override -
operator []=(
K key, V value) → void -
Associates the
keywith the givenvalue.override