URxState class

Inheritance

Constructors

URxState([UPageState initial = UPageState.initial])

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ UPageState
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
call(UPageState newValue) → UPageState
inherited
dispose() → void
Discards any resources used by the object.
inherited
emptying() → UPageState
error() → UPageState
initial() → UPageState
isEmpty() → bool
isError() → bool
isInitial() → bool
isLoaded() → bool
isLoading() → bool
isPaging() → bool
loaded() → UPageState
loading() → UPageState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
paging() → UPageState
refresh() → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited