UDate class abstract

Implemented types
Implementers

Constructors

UDate()
const

Properties

day → int
no setter
formatter → UDateFormatter
no setter
hashCode → int
The hash code for this object.
no setteroverride
hour → int
no setter
julianDayNumber → int
no setter
millisecond → int
no setter
minute → int
no setter
month → int
no setter
monthLength → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
no setter
time → Duration
no setter
weekDay → int
no setter
year → int
no setter

Methods

add({int years = 0, int months = 0, int days = 0, int hours = 0, int minutes = 0, int seconds = 0, int milliseconds = 0}) → UDate
compareTo(UDate other) → int
Compares this object to another object.
override
copy({int? year, int? month, int? day, int? hour, int? minute, int? second, int? millisecond}) → UDate
distanceTo(UDate other) → int
isLeapYear() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDateTime() → DateTime
toString() → String
A string representation of this object.
inherited
toUtcDateTime() → DateTime

Operators

operator +(int days) → UDate
operator -(int days) → UDate
operator <(UDate other) → bool
operator <=(UDate other) → bool
operator ==(Object other) → bool
The equality operator.
override
operator >(UDate other) → bool
operator >=(UDate other) → bool

Constants

maxJDN → const int
minJDN → const int