UDateFormatter class abstract

Implementers

Constructors

UDateFormatter(UDate date)
const

Properties

d → String
no setter
date → UDate
final
dd → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
m → String
no setter
mm → String
no setter
mN → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wN → String
no setter
y → String
no setter
yy → String
no setter
yyyy → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPersian(String input) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited