UGregorian class

Inheritance

Constructors

UGregorian(int year, [int month = 1, int day = 1, int hour = 0, int minute = 0, int second = 0, int millisecond = 0])
factory
UGregorian.fromDateTime(DateTime dt)
factory
UGregorian.fromJulianDayNumber(int jdn, [int hour = 0, int minute = 0, int second = 0, int millisecond = 0])
factory
UGregorian.now()
factory

Properties

day → int
final
formatter → UGregorianFormatter
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hour → int
final
julianDayNumber → int
final
millisecond → int
final
minute → int
final
month → int
final
monthLength → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
final
time → Duration
no setterinherited
weekDay → int
no setteroverride
year → int
final

Methods

add({int years = 0, int months = 0, int days = 0, int hours = 0, int minutes = 0, int seconds = 0, int milliseconds = 0}) → UGregorian
override
addDays(int days) → UGregorian
compareTo(UDate other) → int
Compares this object to another object.
inherited
copy({int? year, int? month, int? day, int? hour, int? minute, int? second, int? millisecond}) → UGregorian
override
distanceTo(UDate other) → int
inherited
isLeapYear() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDateTime() → DateTime
override
toJalali() → UJalali
toString() → String
A string representation of this object.
override
toUtcDateTime() → DateTime
override

Operators

operator +(int days) → UGregorian
override
operator -(int days) → UGregorian
override
operator <(UDate other) → bool
inherited
operator <=(UDate other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(UDate other) → bool
inherited
operator >=(UDate other) → bool
inherited

Constants

max → const UGregorian
min → const UGregorian