UGregorianFormatter class

Inheritance

Constructors

UGregorianFormatter(UGregorian date)
const

Properties

d → String
no setterinherited
date → UDate
finalinherited
dd → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
m → String
no setterinherited
mm → String
no setterinherited
mN → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wN → String
no setteroverride
y → String
no setterinherited
yy → String
no setterinherited
yyyy → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPersian(String input) → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited