Os class

Constructors

Os({int? min, int? current, String? link1, String? link2, String? link1Title, String? link2Title})
Os.fromMap(Map<String, dynamic> json)
factory

Properties

current int?
final
hashCode int
The hash code for this object.
no setterinherited
link1 String?
final
link1Title String?
final
link2 String?
final
link2Title String?
final
min int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited