UOs class

Update info of one platform: builds below min must update, below current may update.

Constructors

UOs({int? min, int? current, String? link1, String? link2, String? link1Title, String? link2Title})
Update info of one platform.
UOs.fromMap(Map<String, dynamic> json)
Parses a decoded JSON map.
factory

Properties

current → int?
Latest build number (older builds are offered an update).
final
hashCode → int
The hash code for this object.
no setterinherited
link1 → String?
First download link (e.g. Google Play).
final
link1Title → String?
Button text for link1.
final
link2 → String?
Second download link (e.g. Bazaar or direct APK).
final
link2Title → String?
Button text for link2.
final
min → int?
Lowest build number still allowed (older builds are forced to update).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Back to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited