UUpdateDialog class

Shows "Update available / required" from UAppSettingsResponse.appVersions, comparing build numbers. UUpdateDialog.checkAndShow(U.appSettings.appVersions, () => UNavigator.offAll(HomePage()))

Constructors

UUpdateDialog()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkAndShow(List<UAppVersionResponse> versions, VoidCallback onSkipOrNotAvailable) → Future<void>
Shows the dialog when needed; onSkipOrNotAvailable runs when there is nothing to do, or the user taps Later / Skip this version.