uuidV6 static method
Like v1 but the time comes first so ids sort by creation (v6). UUUID.uuidV6()
Implementation
static String uuidV6() => _format(_timeBased(reordered: true));
Like v1 but the time comes first so ids sort by creation (v6). UUUID.uuidV6()
static String uuidV6() => _format(_timeBased(reordered: true));