UPwa class abstract

Constructors

UPwa()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

canPromptIosInstall bool
no setter
isAndroidBrowser bool
no setter
isIosBrowser bool
no setter
isIosSafari bool
no setter
isIphoneBrowser bool
no setter
isStandalone bool
no setter

Static Methods

promptIosInstall({bool force = false, String? title, String? step1, String? step2, String? step3, String? safariHint, String? doneLabel}) Future<void>