cachedBuild static method

Future<UWebBuild?> cachedBuild()

The build the browser would serve from its own HTTP cache, which is what this tab is running.

Implementation

static Future<UWebBuild?> cachedBuild() => _build("force-cache");