timeout property
How long a probe of the server may take before it is treated as "nothing new".
Implementation
static Duration timeout = const Duration(seconds: 10);
How long a probe of the server may take before it is treated as "nothing new".
static Duration timeout = const Duration(seconds: 10);