baseUrl static method
Absolute URL the app is deployed under, always with a trailing slash.
Implementation
static String baseUrl() {
final String base = web.document.baseURI;
return base.endsWith("/") ? base : "$base/";
}
Absolute URL the app is deployed under, always with a trailing slash.
static String baseUrl() {
final String base = web.document.baseURI;
return base.endsWith("/") ? base : "$base/";
}