documentUrl static method
Absolute URL of the document currently shown, including query and fragment.
Implementation
static String documentUrl() => web.window.location.href;
Absolute URL of the document currently shown, including query and fragment.
static String documentUrl() => web.window.location.href;