isEmbedded static method
True when the page runs inside an iframe or a native WebView user-agent.
Implementation
static bool isEmbedded() => _isInIframe() || _isWebViewUserAgent();
True when the page runs inside an iframe or a native WebView user-agent.
static bool isEmbedded() => _isInIframe() || _isWebViewUserAgent();