isStandalone static method
True when the site is running as an installed PWA (launched from the home screen).
Implementation
static bool isStandalone() => _iosLegacyStandalone() || _displayModeStandalone();
True when the site is running as an installed PWA (launched from the home screen).
static bool isStandalone() => _iosLegacyStandalone() || _displayModeStandalone();