UWebBridge class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
activeServiceWorkerUrl(
) → String? -
baseUrl(
) → String -
clearCaches(
) → Future< void> -
documentUrl(
) → String -
fetch(
String url, String cacheMode) → Future< String?> -
isEmbedded(
) → bool -
isStandalone(
) → bool -
listenMessage(
void onMessage(String origin, Map< String, dynamic> data)) → void Function() -
listenVisible(
void onVisible()) → void Function() -
reload(
String? url) → void -
revalidate(
List< String> urls) → Future<void> -
serviceWorkerHasPendingUpdate(
) → Future< bool> -
unregisterServiceWorkers(
) → Future< void> -
userAgent(
) → String