UBadgePosition class

Where the badge sits on the child.

Constructors

UBadgePosition({double? top, double? end, double? bottom, double? start, bool isCenter = false})
const
UBadgePosition.bottomEnd({double bottom = -8, double end = -10})
Bottom-end corner.
factory
UBadgePosition.bottomStart({double bottom = -8, double start = -10})
Bottom-start corner.
factory
UBadgePosition.center()
In the middle.
factory
UBadgePosition.topEnd({double top = -8, double end = -10})
Top-end corner (default).
factory
UBadgePosition.topStart({double top = -5, double start = -10})
Top-start corner.
factory

Properties

bottom → double?
Distance from the bottom when positioned in a Stack.
final
end → double?
Distance from the end edge.
final
hashCode → int
The hash code for this object.
no setterinherited
isCenter → bool
True when centered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → double?
Distance from the start edge.
final
top → double?
Distance from the top when positioned in a Stack.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited