UCachedByteSource class
- Inheritance
-
- Object
- UDocByteSource
- UCachedByteSource
Constructors
- UCachedByteSource(UDocByteSource inner, {int maxBytes = uDocSourceCacheBytes})
Properties
- cachedBytes → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setteroverride
- inner → UDocByteSource
-
final
- isSeekable → bool
-
no setteroverride
- kind → UDocSourceKind
-
no setteroverride
- length → int
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clampCount(
int offset, int count) → int -
inherited
-
close(
) → Future< void> -
override
-
dropCache(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
peek(
int offset, int count) → Uint8List? -
prefetch(
int offset, int count) → Future< void> -
read(
int offset, int count) → Future< Uint8List> -
override
-
readAll(
{int cap = uDocMaxAllocation}) → Future< Uint8List> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited