UDocLibrary class
- Inheritance
-
- Object
- ChangeNotifier
- UDocLibrary
Properties
- count → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isLoaded → bool
-
no setter
- isScanning → bool
-
no setter
-
records
→ List<
UDocRecord> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannedCount → int
-
no setter
- scanTotal → int
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
byFingerprint(
String fingerprint) → UDocRecord? -
byPath(
String path) → UDocRecord? -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
load(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
query(
{String? text, UDocKind? kind, bool favoritesOnly = false, String? collection}) → List< UDocRecord> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeRecord(
String fingerprint) → void -
save(
) → Future< void> -
scan(
List< String> directories, {bool recursive = true}) → Future<void> -
toggleFavorite(
String fingerprint) → void -
toString(
) → String -
A string representation of this object.
inherited
-
upsert(
UDocRecord record) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → UDocLibrary
-
final
Constants
-
extensions
→ const List<
String>