UDocRecord class
Constructors
-
UDocRecord({required String fingerprint, required String path, required UDocKind kind, required int sizeBytes, required DateTime addedAt, UDocMetadata metadata = const UDocMetadata(), String? coverPath, DateTime? lastOpenedAt, bool favorite = false, List<
String> collections = const <String>[]}) -
const
-
UDocRecord.fromJson(Map<
String, Object?> json) -
factory
Properties
- addedAt → DateTime
-
final
-
collections
→ List<
String> -
final
- coverPath → String?
-
final
- displayTitle → String
-
no setter
- favorite → bool
-
final
- fileName → String
-
no setter
- fingerprint → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → UDocKind
-
final
- lastOpenedAt → DateTime?
-
final
- metadata → UDocMetadata
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
final
Methods
-
copyWith(
{UDocMetadata? metadata, String? coverPath, DateTime? lastOpenedAt, bool? favorite, List< String> ? collections}) → UDocRecord -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited