UEpubArchive class
Properties
-
entries
→ Map<
String, UEpubZipEntry> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → UCachedByteSource
-
final
Methods
-
close(
) → Future< void> -
has(
String name) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String name) → Future< Uint8List> -
readText(
String name) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
open(
UCachedByteSource source) → Future< UEpubArchive>