UEpubBlock class
Constructors
-
UEpubBlock({required UEpubBlockKind kind, List<
UEpubSpan> spans = const <UEpubSpan>[], String? imageHref, int level = 0, TextAlign? align, double indent = 0, double marginTop = 0, double marginBottom = 0, String listMarker = "", String? anchorId, bool rtl = false, List<List< cells = const <List<UEpubSpan>>[]})UEpubSpan> > -
const
Properties
- align → TextAlign?
-
final
- anchorId → String?
-
final
-
cells
→ List<
List< UEpubSpan> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageHref → String?
-
final
- indent → double
-
final
- isEmpty → bool
-
no setter
- kind → UEpubBlockKind
-
final
- level → int
-
final
- listMarker → String
-
final
- marginBottom → double
-
final
- marginTop → double
-
final
- rtl → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spans
→ List<
UEpubSpan> -
final
- text → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited