UEpubBlockBuilder class
Constructors
- UEpubBlockBuilder({required UEpubStyleSheet sheet, required String baseHref, required UEpubBook book})
Properties
- baseHref → String
-
final
-
blocks
→ List<
UEpubBlock> -
final
- book → UEpubBook
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- plainText → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sheet → UEpubStyleSheet
-
final
- title ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
walk(
UEpubNode node) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited