UEpubNode class
Properties
-
attributes
→ Map<
String, String> -
final
-
children
→ List<
UEpubNode> -
final
-
classes
→ List<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- isText → bool
-
no setter
- parent ↔ UEpubNode?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
final
- text → String
-
final
- textContent → String
-
no setter
Methods
-
findAll(
String tag, {int depth = 0}) → Iterable< UEpubNode> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited