UEpubPaginator class
Constructors
- UEpubPaginator({required UEpubTypography typography, required Size size, required TextScaler textScaler})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
final
- textScaler → TextScaler
-
final
- typography → UEpubTypography
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paginate(
UEpubChapter chapter) → List< UEpubPage> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited