UEpubPosition class
Constructors
- UEpubPosition({required int spineIndex, int blockIndex = 0, int charOffset = 0})
-
const
Properties
- blockIndex → int
-
final
- charOffset → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spineIndex → int
-
final
Methods
-
encode(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
String? value) → UEpubPosition?