UPdfEncryption class
Properties
- authenticated → bool
-
final
- encryptMetadata → bool
-
final
- fileKey → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyLength → int
-
final
- ownerAuthenticated → bool
-
final
- permissionFlags → int
-
final
- permissions → UDocPermissions
-
no setter
- revision → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamMethod → UPdfCryptMethod
-
final
- stringMethod → UPdfCryptMethod
-
final
- version → int
-
final
Methods
-
decrypt(
Uint8List data, int objectNumber, int generation, {required bool isString}) → Uint8List -
encrypt(
Uint8List data, int objectNumber, int generation, {required bool isString, Uint8List? iv}) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
UPdfDict encrypt, Uint8List firstId, String password) → UPdfEncryption?