UPdfPage class
Constructors
Properties
- box → Rect
-
no setter
- cropBox → Rect
-
final
- dict → UPdfDict
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- mediaBox → Rect
-
final
- ref → UPdfRef?
-
final
- resources → UPdfDict?
-
final
- rotatedSize → Size
-
no setter
- rotation → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited