UPdfSyntax class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isDelimiter(
int byte) → bool -
isDigit(
int byte) → bool -
isRegular(
int byte) → bool -
isWhitespace(
int byte) → bool -
parseObject(
UDocCursor cursor, {int depth = 0}) → Object? -
readHexString(
UDocCursor cursor) → UPdfString -
readKeyword(
UDocCursor cursor) → String -
readLiteralString(
UDocCursor cursor) → UPdfString -
readName(
UDocCursor cursor) → String -
readNumber(
UDocCursor cursor) → num -
skipWhitespace(
UDocCursor cursor) → void