UPdfXrefEntry class
Constructors
- UPdfXrefEntry({required int type, required int first, required int second})
-
const
Properties
- first → int
-
final
- generation → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexInStream → int
-
no setter
- isCompressed → bool
-
no setter
- isFree → bool
-
no setter
- offset → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second → int
-
final
- streamNumber → int
-
no setter
- type → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited