Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
-
fromImages(List<Uint8List> images, {Size? pageSize, double margin = 0})
→ Future<Uint8List?>
-
-
merge(List<UPdfDocument> documents, {UDocMetadata? metadata})
→ Future<Uint8List?>
-
-
mergeFiles(List<String> paths, {UDocMetadata? metadata})
→ Future<Uint8List?>
-
-
nUp(UPdfDocument document, {int columns = 2, int rows = 1, Size sheet = const Size(841.89, 595.28), double gap = 8})
→ Future<Uint8List?>
-
-
split(UPdfDocument document, {int pagesPerFile = 1})
→ Future<List<Uint8List>>
-