UPdfRedactor class
Constructors
- UPdfRedactor(UPdfEdit edit)
Properties
- document → UPdfDocument
-
no setter
- edit → UPdfEdit
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
int pageIndex, List< Rect> areas, {bool paintBlack = true, Color fill = const Color(0xFF000000)}) → Future<int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited