UPdfCMap class
Constructors
-
UPdfCMap({required List<
UPdfCodespace> codespaces, required Map<int, int> singles, required List<UPdfCidRange> ranges, bool vertical = false, int identityBytes = 0})
Properties
-
codespaces
→ List<
UPdfCodespace> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identityBytes → int
-
final
- isIdentity → bool
-
no setter
-
ranges
→ List<
UPdfCidRange> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
singles
→ Map<
int, int> -
final
- vertical → bool
-
final
Methods
-
cidFor(
int code) → int -
codeLengthAt(
Uint8List bytes, int offset) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited