UPdfSampledFunction class
- Implemented types
Constructors
Properties
- bitsPerSample → int
-
final
-
decode
→ List<
double> ? -
final
-
domain
→ List<
double> -
final
-
encode
→ List<
double> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputCount → int
-
no setter
-
range
→ List<
double> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samples → Uint8List
-
final
-
size
→ List<
int> -
final
Methods
-
evaluate(
List< double> inputs) → List<double> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited