UPdfStandardNames class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
cffStandardStrings
→ List<
String> -
no setter
-
glyphNameToUnicode
→ Map<
String, int> -
no setter
-
macGlyphNames
→ List<
String> -
no setter
-
macRomanEncoding
→ List<
String> -
no setter
-
standardEncoding
→ List<
String> -
no setter
-
winAnsiEncoding
→ List<
String> -
no setter
Static Methods
-
unicodeForGlyphName(
String name) → int