UFlipCardController class
Flips a UFlipCard from code.
Constructors
Properties
- controller → AnimationController?
-
Its animation.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ UFlipCardState?
-
The connected card.
getter/setter pair
Methods
-
hint(
{Duration? duration, Duration? total}) → Future< void> - Tilts and returns to hint that it can flip.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
skew(
double amount, {Duration? duration, Curve? curve}) → Future< void> - Tilts the card part way (a teaser).
-
toggleCard(
) → Future< void> - Flips with animation.
-
toggleCardWithoutAnimation(
) → void - Flips instantly.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited