UExternalSubtitle class
Constructors
- UExternalSubtitle({required String uri, String? label, String? language, USubtitleFormat? format, String? encoding, bool isDefault = false})
-
const
Properties
- encoding → String?
-
final
- format → USubtitleFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDefault → bool
-
final
- label → String?
-
final
- language → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited