UNetworkSource class final
- Inheritance
-
- Object
- UMediaSource
- UNetworkSource
Constructors
-
UNetworkSource(String url, {String? id, UMediaMetadata? metadata, Map<
String, String> headers = const <String, String>{}, String? userAgent, UStreamProtocol? protocol, Duration? startPosition, Duration? endPosition, List<UExternalSubtitle> externalSubtitles = const <UExternalSubtitle>[], UDrmConfig? drm})
Properties
- drm → UDrmConfig?
-
finalinherited
- endPosition → Duration?
-
finalinherited
-
externalSubtitles
→ List<
UExternalSubtitle> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
- id → String
-
finalinherited
- kind → UMediaSourceKind
-
no setteroverride
- metadata → UMediaMetadata?
-
finalinherited
- protocol → UStreamProtocol?
-
final
- resolvedProtocol → UStreamProtocol
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startPosition → Duration?
-
finalinherited
- url → String
-
final
- userAgent → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited