UTrackRecord class
Constructors
- UTrackRecord({required String path, required String title, required String artist, required String album, String? albumArtist, String? genre, int? year, int? trackNumber, int? discNumber, int durationMs = 0, int sizeBytes = 0, int addedAt = 0, int artworkOffset = 0, int artworkLength = 0, String? artworkMime})
-
UTrackRecord.fromJson(Map<
String, Object?> json) -
factory
Properties
- addedAt → int
-
final
- album → String
-
final
- albumArtist → String?
-
final
- artist → String
-
final
- artwork → UArtworkRef?
-
no setter
- artworkLength → int
-
final
- artworkMime → String?
-
final
- artworkOffset → int
-
final
- discNumber → int?
-
final
- duration → Duration
-
no setter
- durationMs → int
-
final
- fileName → String
-
no setter
- folder → String
-
no setter
- genre → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → UMediaMetadata
-
no setter
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchKey → String
-
final
- sizeBytes → int
-
final
- source → UMediaSource
-
no setter
- title → String
-
final
- trackNumber → int?
-
final
- year → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited