UProcessController class
Loads, fills and sends the steps of a server-driven process (KYC, onboarding).
Constructors
- UProcessController({VoidCallback? onCompleted})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCompleted → VoidCallback?
-
Called when the input is complete.
final
- processId ↔ String
-
Id of the process.
getter/setter pair
-
processStep
→ URxn<
UProcessStepGet> -
Current step from the server.
final
- processStepSend ↔ UProcessStepSend
-
Answers of the current step.
getter/setter pair
- progress → URxInt
-
Upload progress 0-100.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → URxState
-
Loading state.
final
Methods
-
dismiss(
) → void - Closes the process page.
-
init(
{required String processId}) → void - Starts a process by id.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → void - Loads the current step.
-
send(
) → void - Sends the current step's answers.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited