UArPlace class
Constructors
-
UArPlace({required String id, required double latitude, required double longitude, required String title, String? subtitle, String? imageUrl, IconData? icon, double heightAboveGround = 2, UArSource? model, double modelSize = 1.5, Map<String, Object?> data = const <String, Object?>{}})
-
const
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited