UArPlace class
A real-world place for UArGeoView: coordinates, title, optional 3D model.
Constructors
Properties
-
data
→ Map<
String, Object?> -
The data to show.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightAboveGround → double
-
Where the card floats, in metres above the ground.
final
- icon → IconData?
-
Icon shown with it.
final
- id → String
-
Unique id.
final
- imageUrl → String?
-
Image address.
final
- latitude → double
-
Latitude.
final
- longitude → double
-
Longitude.
final
- model → UArSource?
-
Optional 3D pin or sign drawn at the place.
final
- modelSize → double
-
Size of its 3D model in metres.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Second line of text.
final
- title → String
-
Title text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited