UArPlacedItem class
Constructors
- UArPlacedItem({required String nodeId, required String anchorId, required UArPlaceable item, required UArHitResult hit, UArNodeInfo? info})
-
const
Properties
- anchorId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hit → UArHitResult
-
final
- info → UArNodeInfo?
-
final
- item → UArPlaceable
-
final
- nodeId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited