UArPlacedItem class
An item the user placed: its node, anchor, hit point and size.
Constructors
- UArPlacedItem({required String nodeId, required String anchorId, required UArPlaceable item, required UArHitResult hit, UArNodeInfo? info})
-
const
Properties
- anchorId → String
-
Id of the AR anchor.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hit → UArHitResult
-
Where it was placed.
final
- info → UArNodeInfo?
-
Model size/bounds after loading.
final
- item → UArPlaceable
-
Which item was placed.
final
- nodeId → String
-
Id of the 3D node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited