UArSceneOptions class
Constructors
- UArSceneOptions({UArPlacementMode placementMode = UArPlacementMode.tap, int maxPlacements = 0, bool replaceWhenFull = true, bool selectOnPlace = true, bool enableDrag = true, bool enableRotate = true, bool enableScale = true, double minScale = 0.2, double maxScale = 5, bool showHints = true, bool showGestureHint = true, bool showItemPicker = true, bool showToolbar = true, bool enableSnapshot = true, bool enableRecording = true, bool enableReset = true, bool enableDelete = true, bool showCloseButton = true, bool haptics = true})
-
const
Properties
- enableDelete → bool
-
final
- enableDrag → bool
-
final
- enableRecording → bool
-
final
- enableReset → bool
-
final
- enableRotate → bool
-
final
- enableScale → bool
-
final
- enableSnapshot → bool
-
final
- haptics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxPlacements → int
-
final
- maxScale → double
-
final
- minScale → double
-
final
- placementMode → UArPlacementMode
-
final
- replaceWhenFull → bool
-
When maxPlacements is reached, the oldest is moved instead of refusing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectOnPlace → bool
-
final
-
Opens the share sheet after a snapshot or recording when no callback is given.
final
- showCloseButton → bool
-
final
- showGestureHint → bool
-
final
- showHints → bool
-
final
- showItemPicker → bool
-
final
- showToolbar → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited