UArStyle class

Colours and shapes of the built-in chrome. Null values follow the app theme.

Constructors

UArStyle({Color? accentColor, Color? onAccentColor, Color? surfaceColor, Color? onSurfaceColor, Color? hintBackground, Color? hintForeground, double borderRadius = 16, EdgeInsets padding = const EdgeInsets.all(16), bool blur = true})
const

Properties

accentColor → Color?
Highlight color (defaults to the theme's primary).
final
blur → bool
Blurs panel backgrounds.
final
borderRadius → double
Corner radius.
final
hashCode → int
The hash code for this object.
no setterinherited
hintBackground → Color?
Hint bubble background.
final
hintForeground → Color?
Hint bubble text color.
final
onAccentColor → Color?
Text and icons drawn on accentColor.
final
onSurfaceColor → Color?
Panel text/icon color.
final
padding → EdgeInsets
Space inside, around the content.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surfaceColor → Color?
Panel background.
final

Methods

accent(BuildContext context) → Color
Accent color resolved from the theme.
hintBg(BuildContext context) → Color
Hint background resolved from the theme.
hintFg(BuildContext context) → Color
Hint text color resolved from the theme.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccent(BuildContext context) → Color
Color on top of the accent.
onSurface(BuildContext context) → Color
Panel text color resolved from the theme.
surface(BuildContext context) → Color
Panel color resolved from the theme.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited