Barcode class abstract

Implementers

Constructors

Barcode()
const
Barcode.fromType(BarcodeType type)
factory

Properties

charSet Iterable<int>
no setter
hashCode int
The hash code for this object.
no setterinherited
maxLength int
no setter
minLength int
no setter
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(String data) bool
isValidBytes(Uint8List data) bool
make(String data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
makeBytes(Uint8List data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) Iterable<BarcodeElement>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
toSvg(String data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
toSvgBytes(Uint8List data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) String
verify(String data) → void
verifyBytes(Uint8List data) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

aztec({int minECCPercent = BarcodeAztec.defaultEcPercent, int userSpecifiedLayers = BarcodeAztec.defaultLayers}) Barcode
codabar({BarcodeCodabarStartStop start = BarcodeCodabarStartStop.A, BarcodeCodabarStartStop stop = BarcodeCodabarStartStop.B, bool printStartStop = false, bool explicitStartStop = false}) Barcode
code128({bool useCode128A = true, bool useCode128B = true, bool useCode128C = true, bool escapes = false}) Barcode
code39({bool drawSpacers = true}) Barcode
code93() Barcode
dataMatrix() Barcode
ean13({bool drawEndChar = false}) Barcode
ean2() Barcode
ean5() Barcode
ean8({bool drawSpacers = false}) Barcode
gs128({bool useCode128A = true, bool useCode128B = true, bool useCode128C = true, bool escapes = false, bool addSpaceAfterParenthesis = true, bool keepParenthesis = false}) Barcode
isbn({bool drawEndChar = false, bool drawIsbn = true}) Barcode
itf({bool addChecksum = false, bool zeroPrepend = false, bool drawBorder = false, double? borderWidth, double? quietWidth, int? fixedLength}) Barcode
itf14({bool drawBorder = true, double? borderWidth, double? quietWidth}) Barcode
itf16({bool drawBorder = true, double? borderWidth, double? quietWidth}) Barcode
pdf417({Pdf417SecurityLevel securityLevel = Pdf417SecurityLevel.level2, double moduleHeight = 2.0, double preferredRatio = 3.0}) Barcode
postnet() Barcode
qrCode({int? typeNumber, BarcodeQRCorrectionLevel errorCorrectLevel = BarcodeQRCorrectionLevel.low}) Barcode
rm4scc() Barcode
telepen() Barcode
upcA() Barcode
upcE({bool fallback = false}) Barcode