BarcodeBar class

Inheritance

Constructors

BarcodeBar({required double left, required double top, required double width, required double height, required bool black})
const

Properties

black → bool
final
bottom → double
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
finalinherited
left → double
finalinherited
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
finalinherited
width → double
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited