BarcodeCode128 class

Inheritance

Constructors

BarcodeCode128({required bool useCode128A, required bool useCode128B, required bool useCode128C, required bool isGS1, required bool escapes, required bool keepParenthesis, required bool addSpaceAfterParenthesis})
const

Properties

addSpaceAfterParenthesis → bool
final
charSet → Iterable<int>
no setteroverride
escapes → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isGS1 → bool
final
keepParenthesis → bool
final
maxLength → int
no setterinherited
minLength → int
no setterinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useCode128A → bool
final
useCode128B → bool
final
useCode128C → bool
final

Methods

adaptData(String data, [bool text = false]) → String
add(int data, int count) → Iterable<bool>
inherited
convert(String data) → Iterable<bool>
override
getHeight(int index, int count, double width, double height, double fontHeight, double textPadding, bool drawText) → double
inherited
getText(String data) → String
inherited
isValid(String data) → bool
inherited
isValidBytes(Uint8List data) → bool
inherited
make(String data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) → Iterable<BarcodeElement>
inherited
makeBytes(Uint8List data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) → Iterable<BarcodeElement>
inherited
makeText(String data, double width, double height, double fontHeight, double textPadding, double lineWidth) → Iterable<BarcodeElement>
override
marginLeft(bool drawText, double width, double height, double fontHeight, double textPadding) → double
inherited
marginRight(bool drawText, double width, double height, double fontHeight, double textPadding) → double
inherited
marginTop(bool drawText, double width, double height, double fontHeight, double textPadding) → double
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shortestCode(List<int> data) → Iterable<int>
toHex(String data) → String
inherited
toString() → String
A string representation of this object.
inherited
toSvg(String data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) → String
inherited
toSvgBytes(Uint8List data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = "monospace", double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) → String
inherited
verify(String data) → void
inherited
verifyBytes(Uint8List data) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited