BarcodeMaps class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
codabar
→ const Map<int, int>
-
-
codabarLen
→ const Map<int, int>
-
-
code39
→ const Map<int, int>
-
-
code39Len
→ const int
-
-
code39StartStop
→ const int
-
-
code93
→ const Map<int, int>
-
-
code93Dollar
→ const int
-
-
code93Len
→ const int
-
-
code93Percent
→ const int
-
-
code93Plus
→ const int
-
-
code93ReverseStop
→ const int
-
-
code93Slash
→ const int
-
-
code93StartStop
→ const int
-
-
code128
→ const Map<int, int>
-
-
code128A
→ const Map<int, int>
-
-
code128B
→ const Map<int, int>
-
-
code128C
→ const Map<int, int>
-
-
code128CodeA
→ const int
-
-
code128CodeB
→ const int
-
-
code128CodeC
→ const int
-
-
code128FNC1
→ const int
-
-
code128FNC1String
→ const String
-
-
code128FNC2
→ const int
-
-
code128FNC2String
→ const String
-
-
code128FNC3
→ const int
-
-
code128FNC3String
→ const String
-
-
code128FNC4
→ const int
-
-
code128FNC4String
→ const String
-
-
code128Len
→ const int
-
-
code128ReverseStop
→ const int
-
-
code128ShiftA
→ const int
-
-
code128ShiftB
→ const int
-
-
code128StartCodeA
→ const int
-
-
code128StartCodeB
→ const int
-
-
code128StartCodeC
→ const int
-
-
code128Stop
→ const int
-
-
code128StopPattern
→ const int
-
-
ean
→ const Map<int, List<int>>
-
-
ean5Checksum
→ const Map<int, int>
-
-
eanCenter
→ const int
-
-
eanCenterEan2
→ const int
-
-
eanEndUpcE
→ const int
-
-
eanFirst
→ const Map<int, int>
-
-
eanStartEan2
→ const int
-
-
eanStartEnd
→ const int
-
-
itf
→ const Map<int, int>
-
-
itfEnd
→ const int
-
-
itfStart
→ const int
-
-
postnet
→ const Map<int, int>
-
-
postnetLen
→ const int
-
-
postnetStartStop
→ const int
-
-
rm4scc
→ const Map<int, int>
-
-
rm4sccLen
→ const int
-
-
rm4sccStart
→ const int
-
-
rm4sccStop
→ const int
-
-
telepen
→ const List<int>
-
-
telepenEnd
→ const int
-
-
telepenLen
→ const int
-
-
telepenStart
→ const int
-
-
upce
→ const Map<int, int>
-