menu
u package
documentation
components/u_barcode.dart
QrBitBuffer class
QrBitBuffer class
dark_mode
light_mode
QrBitBuffer
class
final
Constructors
QrBitBuffer
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
length
→
int
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
getByte
(
int
index
)
→
int
getBytes
(
int
offset
,
int
length
)
→
Uint8List
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put
(
int
number
,
int
length
)
→ void
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
u package
documentation
components/u_barcode
QrBitBuffer class
u_barcode library