QrEci class final

Implemented types

Constructors

QrEci(int value)
factory

Properties

bitLength int
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
length int
no setteroverride
mode QrMode
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(QrBitBuffer buffer) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited