QrImage class final

Constructors

QrImage(QrCode qrCode)
factory
QrImage.withMaskPattern(QrCode qrCode, int maskPattern)

Properties

errorCorrectLevel QrErrorCorrectLevel
final
hashCode int
The hash code for this object.
no setterinherited
maskPattern int
final
moduleCount int
final
qrModules List<List<bool?>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeNumber int
final

Methods

isDark(int row, int col) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited