UCamera class abstract
One-call helpers that mirror UFile.showImagePicker.
Constructors
- UCamera()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
devices(
) → Future< List< UCameraDevice> > -
open(
{UCameraOptions options = const UCameraOptions(), dynamic action(List< UFileData> )?}) → Future<List< UFileData> > - Opens the full camera page and returns everything captured.
-
permission(
) → Future< UCameraPermissionState> -
recordVideo(
{UCameraOptions options = const UCameraOptions(), dynamic action(UFileData?)?}) → Future< UFileData?> -
requestPermission(
{bool audio = false}) → Future< UCameraPermissionState> -
takePhoto(
{UCameraOptions options = const UCameraOptions(), dynamic action(UFileData?)?}) → Future< UFileData?> -
takePhotos(
{int maxCount = 0, UCameraOptions options = const UCameraOptions(), dynamic action(List< UFileData> )?}) → Future<List< UFileData> > -
Captures several photos in one session;
maxCount0 means unlimited.