UCameraLabels class
Optional label overrides; anything left null falls back to l10n.
Constructors
Properties
- cancel → String?
-
"Cancel" text.
final
- done → String?
-
"Done" text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- noCameraMessage → String?
-
Shown when there is no camera.
final
- permissionMessage → String?
-
Shown when permission is denied.
final
- retake → String?
-
"Retake" text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- use → String?
-
"Use photo" text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited