UCameraOptions class

Full configuration for UCameraPage. Sensible defaults enable the common camera-app feature set; turn individual controls off as needed.

Constructors

UCameraOptions({UCameraMode mode = UCameraMode.photo, bool allowMultiple = false, int maxCount = 0, ResolutionPreset resolution = ResolutionPreset.high, bool startFront = false, bool enableFlash = true, bool enableCameraSwitch = true, bool enableGrid = true, bool enablePinchZoom = true, bool enableZoomSlider = false, bool enableTapToFocus = true, bool enableExposure = true, bool enableSelfTimer = true, bool enableAudio = true, bool confirmCapture = true, bool mirrorFrontPreview = false, Duration? videoMaxDuration, Color? accentColor, UCameraLabels? labels})
const

Properties

accentColor Color?
final
allowMultiple bool
final
confirmCapture bool
final
enableAudio bool
final
enableCameraSwitch bool
final
enableExposure bool
final
enableFlash bool
final
enableGrid bool
final
enablePinchZoom bool
final
enableSelfTimer bool
final
enableTapToFocus bool
final
enableZoomSlider bool
final
hashCode int
The hash code for this object.
no setterinherited
labels UCameraLabels?
final
maxCount int
Max photos in multi mode; 0 means unlimited.
final
mirrorFrontPreview bool
final
mode UCameraMode
final
resolution ResolutionPreset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startFront bool
final
videoMaxDuration Duration?
final

Methods

copyWith({UCameraMode? mode, bool? allowMultiple, int? maxCount, bool? startFront}) UCameraOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited