UCandle class
One open/high/low/close candle. UCandle(open: 10, high: 12, low: 9, close: 11, label: "Mon")
Constructors
Properties
- bullish → bool
-
True when it closed higher than it opened.
no setter
- close → double
-
Closing price.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- high → double
-
Highest price.
final
- label → String?
-
Label text.
final
- low → double
-
Lowest price.
final
- open → double
-
Opening price.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited