UChartStyle class
Shared, fully-optional styling for every chart. Any field left null is resolved from the active ColorScheme/TextTheme at build time.
Constructors
-
UChartStyle({List<
Color> ? palette, Color? backgroundColor, Color? gridColor, Color? axisColor, Color? labelColor, double labelFontSize = 11, bool showGrid = true, bool showAxis = true, bool showLabels = true, bool showLegend = true, bool showValues = false, bool animate = true, Duration animationDuration = const Duration(milliseconds: 900), Curve animationCurve = Curves.easeOutCubic, EdgeInsets padding = const EdgeInsets.all(12), int gridDivisions = 5, double cornerRadius = 6, String valueFormatter(double value)?}) -
const
Properties
- animate → bool
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- axisColor → Color?
-
final
- backgroundColor → Color?
-
final
- cornerRadius → double
-
final
- gridColor → Color?
-
final
- gridDivisions → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelColor → Color?
-
final
- labelFontSize → double
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAxis → bool
-
final
- showGrid → bool
-
final
- showLabels → bool
-
final
- showLegend → bool
-
final
- showValues → bool
-
final
- valueFormatter → String Function(double value)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited