UPointSeries class

A named group of points for scatter/bubble charts. UPointSeries(name: "A", points: [UChartPoint(x: 1, y: 2)])

Constructors

UPointSeries({required List<UChartPoint> points, String? name, Color? color})
const

Properties

color → Color?
Main color (defaults to the theme).
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
Name.
final
points → List<UChartPoint>
The points.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited