USlice class
One slice of a pie, donut, funnel or treemap. USlice(label: "Food", value: 40)
Properties
- color → Color?
-
Main color (defaults to the theme).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
Label text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
Slice size (any positive number; shares are computed).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited