UWaterfallItem class

One step of a waterfall chart. When isTotal is true the bar is drawn from the baseline instead of stacking on the running total.

Constructors

UWaterfallItem({required double value, String? label, bool isTotal = false, Color? color})
const

Properties

color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
isTotal → bool
final
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited