UGaugeStyle class

Shared, fully-optional styling for every gauge. Null fields resolve from the active theme at build time.

Constructors

UGaugeStyle({Color? trackColor, Color? fillColor, Color? needleColor, Color? tickColor, Color? labelColor, Color? valueColor, double? thickness, bool showTicks = true, bool showLabels = true, bool showValue = true, bool animate = true, Duration animationDuration = const Duration(milliseconds: 1100), Curve animationCurve = Curves.easeOutCubic})
const

Properties

animate bool
final
animationCurve Curve
final
animationDuration Duration
final
fillColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
labelColor Color?
final
needleColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabels bool
final
showTicks bool
final
showValue bool
final
thickness double?
final
tickColor Color?
final
trackColor Color?
final
valueColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited