onChecklistChanged property
When set, checklist items become tappable and report (index, checked)
where index counts checklist items from the top of the document.
Implementation
final void Function(int index, bool checked)? onChecklistChanged;
When set, checklist items become tappable and report (index, checked)
where index counts checklist items from the top of the document.
final void Function(int index, bool checked)? onChecklistChanged;