UEqualizer class
Constructors
- UEqualizer(UMediaController controller)
Properties
- controller → UMediaController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Future< UEqualizerState> -
setBand(
int index, double gainDb) → Future< void> -
setBassBoost(
double strength) → Future< void> -
setEnabled(
bool enabled) → Future< void> -
setLoudness(
double gainDb) → Future< void> -
setPreset(
String preset) → Future< void> -
setVirtualizer(
double strength) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited