UPdfEditController class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addNote(int pageIndex, Offset devicePoint, String contents)
→ Future<bool>
-
-
addPageNumbers({double fontSize = 10, int startAt = 1, bool rightAligned = true})
→ Future<bool>
-
-
addTextBox(int pageIndex, Offset devicePoint, String contents, {double width = 200, double height = 60})
→ Future<bool>
-
-
addWatermark(String text, {double fontSize = 48, Color color = const Color(0x33000000), double rotation = 45})
→ Future<bool>
-
-
allAnnotations()
→ Future<List<UPdfAnnotationInfo>>
-
-
annotateSelection(UDocSelection selection, UDocTextPage text)
→ Future<bool>
-
-
annotationAt(int pageIndex, Offset devicePoint)
→ Future<UPdfAnnotationInfo?>
-
-
annotationsOn(int pageIndex)
→ Future<List<UPdfAnnotationInfo>>
-
-
applyPendingRedactions()
→ Future<int>
-
-
applyRedactions(int pageIndex, List<Rect> areas)
→ Future<int>
-
-
attach()
→ void
-
-
beginStroke(int pageIndex, Offset devicePoint)
→ void
-
-
deleteAnnotation(int pageIndex, int objectNumber)
→ Future<bool>
-
-
deletePage(int pageIndex)
→ Future<bool>
-
-
devicePointToPdf(UDocPageInfo info, Offset point)
→ Offset
-
-
deviceRectToPdf(UDocPageInfo info, Rect rect)
→ Rect
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
duplicatePage(int pageIndex)
→ Future<bool>
-
-
endStroke(int pageIndex)
→ Future<void>
-
-
eraseAt(int pageIndex, Offset devicePoint)
→ Future<bool>
-
-
exportPages(List<int> indices)
→ Future<Uint8List?>
-
-
extendStroke(int pageIndex, Offset devicePoint)
→ void
-
-
flatten({bool widgetsOnly = false})
→ Future<int>
-
-
insertBlankPage(int at)
→ Future<bool>
-
-
liveStroke(int pageIndex)
→ List<Offset>
-
-
mergeFile(String path)
→ Future<bool>
-
-
movePage(int from, int to)
→ Future<bool>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
rotatePage(int pageIndex, int degrees)
→ Future<bool>
-
-
saveOptimized(String path)
→ Future<bool>
-
-
saveTo(String path)
→ Future<bool>
-
-
saveToBytes()
→ Future<Uint8List?>
-
-
setAuthor(String author)
→ void
-
-
setColor(Color color)
→ void
-
-
setCrop(int pageIndex, Rect box)
→ Future<bool>
-
-
setFontSize(double size)
→ void
-
-
setInkColor(Color color)
→ void
-
-
setMetadata(UDocMetadata metadata)
→ Future<bool>
-
-
setOpacity(double opacity)
→ void
-
-
setStrokeWidth(double width)
→ void
-
-
setTool(UPdfTool tool)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
undo()
→ Future<void>
-
-
updateAnnotation(int pageIndex, int objectNumber, {Rect? rect, Color? color, double? opacity, String? contents})
→ Future<bool>
-