UPdfViewerState class
State of UPdfViewer; use a GlobalKey to control it (pages, zoom, annotations).
- Inheritance
-
- Object
- State<
UPdfViewer> - UPdfViewerState
Constructors
Properties
- annotations → UDocAnnotationController
-
Markup controller.
no setter
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- controller → UPdfController
-
The PDF controller.
no setter
- currentPage → int
-
Current page (0-based).
no setter
- drawing → UDocDrawController
-
Drawing controller.
no setter
- editor → UPdfEditController?
-
Edit controller (when editing).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → UPdfViewer
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
applyState(
VoidCallback action) → void -
Runs
actionand rebuilds. -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant UPdfViewer oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
jumpToPage(
int pageIndex, {bool animated = true, double? pageY}) → void -
Scrolls to
pageIndex;pageYis an optional offset inside the page in page units. -
nextPage(
) → void - Goes to the next page.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previousPage(
) → void - Goes to the previous page.
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
setZoom(
double zoom) → void - Sets the zoom.
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleDrawing(
[bool? open]) → void - Opens or closes the drawing toolbar.
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- geometryKey → const String
- Markups whose rects were computed with older text geometry are re-placed from their text.
- geometryVersion → const int
- Version of the saved text geometry format.