UEditorBlock class
One block in the editor document.
Constructors
- UEditorBlock({required UBlockType type, URichTextController? controller, FocusNode? focusNode, String? imageUrl, String? imageAlt, double? imageWidth, TextAlign align = TextAlign.start, int indent = 0, bool checked = false, String? language, UTableData? table})
-
UEditorBlock.text(UBlockType type, {String text = "", List<
UStyleSpan> ? spans, TextAlign align = TextAlign.start, int indent = 0, bool checked = false, String? language}) -
Convenience factory for a text block seeded with
textandspans.factory
Properties
- align ↔ TextAlign
-
Text alignment.
getter/setter pair
- checked ↔ bool
-
Checklist item done.
getter/setter pair
- controller ↔ URichTextController?
-
Text controller of a text block.
getter/setter pair
- focusNode ↔ FocusNode?
-
Focus of a text block.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique id.
final
- imageAlt ↔ String?
-
Image alt text.
getter/setter pair
- imageUrl ↔ String?
-
Image address of an image block.
getter/setter pair
- imageWidth ↔ double?
-
Image width.
getter/setter pair
- indent ↔ int
-
Indent level.
getter/setter pair
- isList → bool
-
True for bulleted/numbered/check lists.
no setter
- isText → bool
-
True for blocks with editable text.
no setter
- language ↔ String?
-
Code block language.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table ↔ UTableData?
-
Table data of a table block.
getter/setter pair
- type ↔ UBlockType
-
Paragraph, heading, list, quote, code, image, table…
getter/setter pair
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited