UEditorBlock class

One block in the editor document.

Constructors

UEditorBlock({required UBlockType type, URichTextController? controller, FocusNode? focusNode, String? imageUrl, String? imageAlt, double? imageWidth, TextAlign align = TextAlign.start, int indent = 0, bool checked = false, String? language, UTableData? table})
UEditorBlock.text(UBlockType type, {String text = "", List<UStyleSpan>? spans, TextAlign align = TextAlign.start, int indent = 0, bool checked = false, String? language})
Convenience factory for a text block seeded with text and spans.
factory

Properties

align TextAlign
getter/setter pair
checked bool
getter/setter pair
controller URichTextController?
getter/setter pair
focusNode FocusNode?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
imageAlt String?
getter/setter pair
imageUrl String?
getter/setter pair
imageWidth double?
getter/setter pair
indent int
getter/setter pair
isList bool
no setter
isText bool
no setter
language String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table UTableData?
getter/setter pair
type UBlockType
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited