UFindReplaceRequest class

The result of the find & replace dialog.

Constructors

UFindReplaceRequest({required String find, required String replace, bool matchCase = false, bool replaceAll = true})

Properties

find String
final
hashCode int
The hash code for this object.
no setterinherited
matchCase bool
final
replace String
final
replaceAll bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited