UStyleSpan class

A single inline style span over the range [start, end) of a text block. value carries the payload for value-attributes: int (ARGB) for UInlineAttr.color and UInlineAttr.highlight, double for UInlineAttr.fontSize, and String for UInlineAttr.fontFamily (family name) and UInlineAttr.link (href). It is null for boolean attributes.

Constructors

UStyleSpan({required int start, required int end, required UInlineAttr attr, Object? value})

Properties

attr → UInlineAttr
final
end ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isBoolean → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ int
getter/setter pair
value → Object?
final

Methods

copy() → UStyleSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited