UTableData class
The cells of a UBlockType.table block. Cells hold plain text.
Constructors
-
UTableData({required List<
List< rows, bool hasHeader = true})String> > - UTableData.empty({int rows = 3, int columns = 3})
-
Creates an empty table of
rowsxcolumns.factory
Properties
- columnCount → int
-
Number of columns.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasHeader ↔ bool
-
First row is a header.
getter/setter pair
- rowCount → int
-
Number of rows.
no setter
-
rows
→ List<
List< String> > -
Cell texts by row.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addColumn(
) → void - Adds an empty column.
-
addRow(
) → void - Adds an empty row.
-
copy(
) → UTableData - A copy.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeColumn(
int index) → void - Removes a column.
-
removeRow(
int index) → void - Removes a row.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited