UTableData class

The cells of a UBlockType.table block. Cells hold plain text.

Constructors

UTableData({required List<List<String>> rows, bool hasHeader = true})
UTableData.empty({int rows = 3, int columns = 3})
Creates an empty table of rows x columns.
factory

Properties

columnCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
hasHeader bool
getter/setter pair
rowCount int
no setter
rows List<List<String>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addColumn() → void
addRow() → void
copy() UTableData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeColumn(int index) → void
removeRow(int index) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited