UMenuGroup class
Collapsible group of items. UMenuGroup(id: "settings", title: "Settings", icon: Icons.settings, children: [UMenuItem(id: "profile", title: "Profile", icon: Icons.person)])
- Inheritance
-
- Object
- UMenuEntry
- UMenuGroup
Constructors
-
UMenuGroup({required String id, required String title, required IconData icon, required List<
UMenuEntry> children, bool initiallyExpanded = false}) -
const
Properties
-
children
→ List<
UMenuEntry> -
Child widgets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
Icon shown with it.
final
- id → String
-
Unique id.
final
- initiallyExpanded → bool
-
Starts open.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Title text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited