UMenuItem class
One side-menu row. UMenuItem(id: "users", title: "Users", icon: Icons.people)
- Inheritance
-
- Object
- UMenuEntry
- UMenuItem
Constructors
Properties
- badge → String?
-
Small badge text, e.g. "3".
final
- badgeColor → Color?
-
Badge color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
Icon shown with it.
final
- id → String
-
Unique id.
final
- onTap → VoidCallback?
-
Called when tapped.
final
- pinnable → bool
-
Can be pinned to the top.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIcon → IconData?
-
Icon when selected.
final
- title → String
-
Title text.
final
- tooltip → String?
-
Text shown on long press / mouse hover.
final
- trailing → Widget?
-
Widget at the end.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited