UMenuItem class

Inheritance

Constructors

UMenuItem({required String id, required String title, required IconData icon, IconData? selectedIcon, VoidCallback? onTap, String? badge, Color? badgeColor, Widget? trailing, bool pinnable = true, String? tooltip})
const

Properties

badge → String?
final
badgeColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
id → String
final
onTap → VoidCallback?
final
pinnable → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon → IconData?
final
title → String
final
tooltip → String?
final
trailing → Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited