USideMenuTheme class
Constructors
-
USideMenuTheme({required Color backgroundColor, required Color selectedItemColor, required Color hoverColor, required Color indicatorColor, required Color selectedTextColor, required Color unselectedTextColor, required Color selectedIconColor, required Color unselectedIconColor, required Color scrimColor, required Color dividerColor, double expandedWidth = 280, double railWidth = 84, Gradient? backgroundGradient, TextStyle? itemTextStyle, TextStyle? headerTextStyle, double iconSize = 22, double itemHeight = 50, double itemSpacing = 4, EdgeInsets itemPadding = const EdgeInsets.symmetric(horizontal: 12), BorderRadius itemRadius = const BorderRadius.all(Radius.circular(14)), USideMenuIndicatorStyle indicatorStyle = USideMenuIndicatorStyle.bar, Duration animationDuration = const Duration(milliseconds: 600), Curve animationCurve = Curves.easeOutCubic, bool enableHoverElevation = true, List<
BoxShadow> ? shadow}) -
const
- USideMenuTheme.from(BuildContext context)
-
factory
Properties
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- backgroundColor → Color
-
final
- backgroundGradient → Gradient?
-
final
- dividerColor → Color
-
final
- enableHoverElevation → bool
-
final
- expandedWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerTextStyle → TextStyle?
-
final
- hoverColor → Color
-
final
- iconSize → double
-
final
- indicatorColor → Color
-
final
- indicatorStyle → USideMenuIndicatorStyle
-
final
- itemHeight → double
-
final
- itemPadding → EdgeInsets
-
final
- itemRadius → BorderRadius
-
final
- itemSpacing → double
-
final
- itemTextStyle → TextStyle?
-
final
- railWidth → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrimColor → Color
-
final
- selectedIconColor → Color
-
final
- selectedItemColor → Color
-
final
- selectedTextColor → Color
-
final
-
shadow
→ List<
BoxShadow> ? -
final
- unselectedIconColor → Color
-
final
- unselectedTextColor → Color
-
final
Methods
-
copyWith(
{double? expandedWidth, double? railWidth, Color? backgroundColor, Gradient? backgroundGradient, Color? selectedItemColor, Color? hoverColor, Color? indicatorColor, Color? selectedTextColor, Color? unselectedTextColor, Color? selectedIconColor, Color? unselectedIconColor, TextStyle? itemTextStyle, TextStyle? headerTextStyle, double? iconSize, double? itemHeight, double? itemSpacing, EdgeInsets? itemPadding, BorderRadius? itemRadius, USideMenuIndicatorStyle? indicatorStyle, Duration? animationDuration, Curve? animationCurve, bool? enableHoverElevation, List< BoxShadow> ? shadow, Color? scrimColor, Color? dividerColor}) → USideMenuTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited