UTabBarTheme class
Colors and sizes of UTabBar; UTabBarTheme.from(context) follows the app theme.
Constructors
- UTabBarTheme({required Color backgroundColor, required Color selectedTabColor, required Color hoverTabColor, required Color unselectedTabColor, required Color selectedTextColor, required Color unselectedTextColor, required Color indicatorColor, required Color controlColor, Gradient? backgroundGradient, double height = 52, double tabHeight = 38, double minTabWidth = 120, double maxTabWidth = 220, double gap = 6, BorderRadius tabRadius = const BorderRadius.all(Radius.circular(12)), Duration animationDuration = const Duration(milliseconds: 260), Curve animationCurve = Curves.easeOutCubic, bool showSelectedUnderline = true})
-
const
- UTabBarTheme.from(BuildContext context)
-
Theme built from the app's colors.
factory
Properties
- animationCurve → Curve
-
Animation curve.
final
- animationDuration → Duration
-
Length of the animation.
final
- backgroundColor → Color
-
Background color.
final
- backgroundGradient → Gradient?
-
Bar background gradient.
final
- controlColor → Color
-
Close/menu icon color.
final
- gap → double
-
Gap between tabs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Height in logical pixels (null = size to content).
final
- hoverTabColor → Color
-
Tab background on mouse hover.
final
- indicatorColor → Color
-
Indicator color.
final
- maxTabWidth → double
-
Widest tab.
final
- minTabWidth → double
-
Narrowest tab.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedTabColor → Color
-
Selected tab background.
final
- selectedTextColor → Color
-
Selected tab text color.
final
- showSelectedUnderline → bool
-
Underlines the selected tab.
final
- tabHeight → double
-
Tab height.
final
- tabRadius → BorderRadius
-
Tab corner radius.
final
- unselectedTabColor → Color
-
Tab background.
final
- unselectedTextColor → Color
-
Tab text color.
final
Methods
-
copyWith(
{Color? backgroundColor, Gradient? backgroundGradient, Color? selectedTabColor, Color? hoverTabColor, Color? unselectedTabColor, Color? selectedTextColor, Color? unselectedTextColor, Color? indicatorColor, Color? controlColor, double? height, double? tabHeight, double? minTabWidth, double? maxTabWidth, double? gap, BorderRadius? tabRadius, Duration? animationDuration, Curve? animationCurve, bool? showSelectedUnderline}) → UTabBarTheme - Copy with some fields changed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited