UTabBarTheme class

Constructors

UTabBarTheme({required Color backgroundColor, required Color selectedTabColor, required Color hoverTabColor, required Color unselectedTabColor, required Color selectedTextColor, required Color unselectedTextColor, required Color indicatorColor, required Color controlColor, Gradient? backgroundGradient, double height = 52, double tabHeight = 38, double minTabWidth = 120, double maxTabWidth = 220, double gap = 6, BorderRadius tabRadius = const BorderRadius.all(Radius.circular(12)), Duration animationDuration = const Duration(milliseconds: 260), Curve animationCurve = Curves.easeOutCubic, bool showSelectedUnderline = true})
const
UTabBarTheme.from(BuildContext context)
factory

Properties

animationCurve → Curve
final
animationDuration → Duration
final
backgroundColor → Color
final
backgroundGradient → Gradient?
final
controlColor → Color
final
gap → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
hoverTabColor → Color
final
indicatorColor → Color
final
maxTabWidth → double
final
minTabWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedTabColor → Color
final
selectedTextColor → Color
final
showSelectedUnderline → bool
final
tabHeight → double
final
tabRadius → BorderRadius
final
unselectedTabColor → Color
final
unselectedTextColor → Color
final

Methods

copyWith({Color? backgroundColor, Gradient? backgroundGradient, Color? selectedTabColor, Color? hoverTabColor, Color? unselectedTabColor, Color? selectedTextColor, Color? unselectedTextColor, Color? indicatorColor, Color? controlColor, double? height, double? tabHeight, double? minTabWidth, double? maxTabWidth, double? gap, BorderRadius? tabRadius, Duration? animationDuration, Curve? animationCurve, bool? showSelectedUnderline}) → UTabBarTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited