USubtitleStyleConfig class
Constructors
- USubtitleStyleConfig({double fontSize = 18, Color color = const Color(0xFFFFFFFF), Color outlineColor = const Color(0xFF000000), double outlineWidth = 2.5, Color backgroundColor = const Color(0x00000000), FontWeight fontWeight = FontWeight.w600, String? fontFamily, String? rtlFontFamily = "Vazir", double bottomPadding = 24, double horizontalPadding = 24, double lineHeight = 1.3, bool shadow = true, bool honorAssStyling = true, int maxLines = 4})
-
const
Properties
- backgroundColor → Color
-
final
- bottomPadding → double
-
final
- color → Color
-
final
- fontFamily → String?
-
final
- fontSize → double
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- honorAssStyling → bool
-
final
- horizontalPadding → double
-
final
- lineHeight → double
-
final
- maxLines → int
-
final
- outlineColor → Color
-
final
- outlineWidth → double
-
final
- rtlFontFamily → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → bool
-
final
Methods
-
copyWith(
{double? fontSize, Color? color, double? outlineWidth, double? bottomPadding, Color? backgroundColor}) → USubtitleStyleConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited