UVideoGestureConfig class
Constructors
- UVideoGestureConfig({bool tapToToggleControls = true, bool doubleTapSeek = true, Duration doubleTapStep = const Duration(seconds: 10), bool horizontalScrub = true, bool verticalVolume = true, bool verticalBrightness = true, bool longPressSpeed = true, double longPressSpeedValue = 2, bool pinchZoom = true, bool swipeDownToDismiss = true, double dismissVelocity = 1200, bool haptics = true})
-
const
Properties
- dismissVelocity → double
-
final
- doubleTapSeek → bool
-
final
- doubleTapStep → Duration
-
final
- haptics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasVertical → bool
-
no setter
- horizontalScrub → bool
-
final
- longPressSpeed → bool
-
final
- longPressSpeedValue → double
-
final
- pinchZoom → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- swipeDownToDismiss → bool
-
final
- tapToToggleControls → bool
-
final
- verticalBrightness → bool
-
final
- verticalVolume → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- none → const UVideoGestureConfig