UVideoMarker class

Constructors

UVideoMarker({required Duration start, Duration? end, String? label, Color? color, bool skippable = false})
const

Properties

color → Color?
final
end → Duration?
final
hashCode → int
The hash code for this object.
no setterinherited
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippable → bool
final
start → Duration
final

Methods

contains(Duration position) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited