ChargeInternetReserveResponse class
Constructors
- ChargeInternetReserveResponse({int? reserve, String? serverDateTime, bool? status, int? code, String? message, String? reference, String? traceId, int? affectiveAmount, String? help, String? messageSource, String? pin})
- ChargeInternetReserveResponse.fromJson(String str)
-
factory
-
ChargeInternetReserveResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- affectiveAmount → int?
-
final
- code → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- help → String?
-
final
- message → String?
-
final
- messageSource → String?
-
final
- pin → String?
-
final
- reference → String?
-
final
- reserve → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverDateTime → String?
-
final
- status → bool?
-
final
- traceId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited