DependencyRule class
Field dependency configuration
Constructors
- DependencyRule({required String dependsOnField, required String dependsOnValue, ComparisonOperator operator = ComparisonOperator.equals, String? optionsApiEndpoint, String? apiMethod = "GET"})
-
DependencyRule.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apiMethod → String?
-
final
- dependsOnField → String
-
final
- dependsOnValue → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operator → ComparisonOperator
-
final
- optionsApiEndpoint → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited