GetBalanceResponse class
Constructors
- GetBalanceResponse({int? reserve, String? serverDateTime, bool? status, int? code, String? message, int? balance, int? wallet, int? credit, int? limit, String? help, String? messageSource, String? extCode})
- GetBalanceResponse.fromJson(String str)
-
factory
-
GetBalanceResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- balance → int?
-
final
- code → int?
-
final
- credit → int?
-
final
- extCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- help → String?
-
final
- limit → int?
-
final
- message → String?
-
final
- messageSource → String?
-
final
- reserve → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverDateTime → String?
-
final
- status → bool?
-
final
- wallet → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited