MerchantService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create({required UMerchantCreateParams p, required dynamic onOk(UResponse<String> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UResponse<String>?, UEmptyResponse?, String?)>
-
-
delete({required UIdParams p, required dynamic onOk(UEmptyResponse e)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UEmptyResponse?, UEmptyResponse?, String?)>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
read({required UMerchantReadParams p, required dynamic onOk(UResponse<List<UMerchantResponse>> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UResponse<List<UMerchantResponse>>?, UEmptyResponse?, String?)>
-
-
readById({required UIdParams p, required dynamic onOk(UResponse<UMerchantResponse> r)?, required dynamic onError(UEmptyResponse e)?, required dynamic onException(String e)?})
→ Future<(UResponse<UMerchantResponse>?, UEmptyResponse?, String?)>
-
-
toString()
→ String
-
A string representation of this object.
inherited