MoadiJsonData class
Constructors
- MoadiJsonData({String? detail1, String? detail2, String? uuid, int? registerStep, String? createdType, int? ownerId, bool? activeContract, int? invoicesCount, int? invoicesSuccessCount, String? lastContractStatus, String? rejectReason})
- MoadiJsonData.fromJson(String str)
-
factory
-
MoadiJsonData.fromMap(Map<
String, dynamic> json) -
factory
Properties
- activeContract → bool?
-
final
- createdType → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoicesCount → int?
-
final
- invoicesSuccessCount → int?
-
final
- lastContractStatus → String?
-
final
- ownerId → int?
-
final
- registerStep → int?
-
final
- rejectReason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited