PnService class

Constructors

PnService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth({required Map<String, dynamic> body, void onResponse(int status, String body)?, void onException(String e)?}) Future<UHttpClientResponse>
createMerchant({required Map<String, dynamic> body, void onResponse(int status, String body)?, void onException(String e)?}) Future<UHttpClientResponse>
createTerminal({required Map<String, dynamic> body, void onResponse(int status, String body)?, void onException(String e)?}) Future<UHttpClientResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readTerminalSupportPassword({required Map<String, dynamic> body, void onResponse(int status, String body)?, void onException(String e)?}) Future<UHttpClientResponse>
toString() String
A string representation of this object.
inherited
userStatus({required Map<String, dynamic> body, void onResponse(int status, String body)?, void onException(String e)?}) Future<UHttpClientResponse>
zipCodeToAddress({required Map<String, dynamic> body, void onResponse(int status, String body)?, void onException(String e)?}) Future<UHttpClientResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited