UAddressJson class
Constructors
- UAddressJson({String? detail1, String? detail2, String? title, String? province, String? township, String? street, String? street2, String? localityName, String? houseNumber, String? floor, String? description, String? buildingName, String? localityType, String? sideFloor, String? subLocality, String? village})
- UAddressJson.fromJson(String str)
-
factory
-
UAddressJson.fromMap(Map<
String, dynamic> json) -
factory
Properties
- buildingName → String?
-
final
- description → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- floor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- houseNumber → String?
-
final
- localityName → String?
-
final
- localityType → String?
-
final
- province → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sideFloor → String?
-
final
- street → String?
-
final
- street2 → String?
-
final
- subLocality → String?
-
final
- title → String?
-
final
- township → String?
-
final
- village → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited