UApiLogResponse class

Constructors

UApiLogResponse({required String id, required DateTime createdAt, required UApiLogJson jsonData, required List<int> tags, required String creatorId, required String path, required int statusCode, required int durationMs, required List<String> adminUserIds, UUserResponse? creator, String? userId, String? ipAddress})
UApiLogResponse.fromJson(String str)
factory
UApiLogResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
createdAt DateTime
final
creator UUserResponse?
final
creatorId String
final
durationMs int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
ipAddress String?
final
jsonData UApiLogJson
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
tags List<int>
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited