UBankAccountReadParams class
Constructors
-
UBankAccountReadParams({required BankAccountSelectorArgs? selectorArgs, int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<
int> ? tags, List<String> ? ids, String? creatorId, String? cardNumber, String? accountNumber, String? iBanNumber, String? bankName, String? ownerName, int? orderBy}) - UBankAccountReadParams.fromJson(String str)
-
factory
-
UBankAccountReadParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- accountNumber → String?
-
final
- bankName → String?
-
final
- cardNumber → String?
-
final
- creatorId → String?
-
final
- fromCreatedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iBanNumber → String?
-
final
-
ids
→ List<
String> ? -
final
- orderBy → int?
-
final
- ownerName → String?
-
final
- pageNumber → int?
-
final
- pageSize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectorArgs → BankAccountSelectorArgs?
-
final
-
final
- toCreatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited