UBillInfoResponse class
Constructors
-
UBillInfoResponse({required String billId, required String paymentId, required List<
String> warnings, required bool isValid, String? caseCode, String? companyCode, String? serviceType, String? checkDigit, String? companyName, String? serviceName, int? billAmount, int? yearDigit, int? periodCode, int? controlDigit1, int? controlDigit2}) - UBillInfoResponse.fromJson(String str)
-
factory
-
UBillInfoResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- billAmount → int?
-
final
- billId → String
-
final
- caseCode → String?
-
final
- checkDigit → String?
-
final
- companyCode → String?
-
final
- companyName → String?
-
final
- controlDigit1 → int?
-
final
- controlDigit2 → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
final
- paymentId → String
-
final
- periodCode → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceName → String?
-
final
- serviceType → String?
-
final
-
warnings
→ List<
String> -
final
- yearDigit → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited