UCategoryCreateParams class
Constructors
-
UCategoryCreateParams({required String title, required List<
int> tags, String? id, String? subtitle, String? parentId, int? order, String? address, String? phoneNumber, String? code, String? location, String? type, String? link, String? detail1, String? detail2, String? creatorId, List<String> ? adminUserIds, List<UCategoryCreateParams> ? children, List<String> ? media}) - UCategoryCreateParams.fromJson(String str)
-
factory
-
UCategoryCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- address → String?
-
final
-
adminUserIds
→ List<
String> ? -
final
-
children
→ List<
UCategoryCreateParams> ? -
final
- code → String?
-
final
- creatorId → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- link → String?
-
final
- location → String?
-
final
-
media
→ List<
String> ? -
final
- order → int?
-
final
- parentId → String?
-
final
- phoneNumber → String?
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
-
final
- title → String
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited