UCommentCreateParams class
Constructors
-
UCommentCreateParams({required String description, required double score, required List<
int> tags, int? reaction, String? parentId, String? productId, String? blogId, String? userId, String? creatorId, String? detail1, String? detail2, String? id, List<String> ? adminUserIds}) - UCommentCreateParams.fromJson(String str)
-
factory
-
UCommentCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> ? -
final
- blogId → String?
-
final
- creatorId → String?
-
final
- description → String
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- parentId → String?
-
final
- productId → String?
-
final
- reaction → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
final
-
final
- userId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited