UContentJson class

Constructors

UContentJson({String? title, String? detail1, String? detail2, String? imageBase64, String? iconBase64, String? buttonText, String? buttonLink, String? link, int? order, String? instagram, String? telegram, String? whatsapp, String? phone, String? subTitle, String? description, List<UContentLink> links = const <UContentLink>[], List<UContentItem> items = const <UContentItem>[]})
UContentJson.fromJson(String str)
factory
UContentJson.fromMap(Map<String, dynamic> json)
factory

Properties

final
buttonText String?
final
description String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
iconBase64 String?
final
imageBase64 String?
final
instagram String?
final
items List<UContentItem>
final
final
final
order int?
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTitle String?
final
telegram String?
final
title String?
final
whatsapp String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited