UContentUpdateParams class
Constructors
-
UContentUpdateParams({required String id, String? title, String? detail1, String? detail2, String? imageBase64, String? iconBase64, String? buttonText, String? buttonLink, String? link, int? order, String? instagram, List<
int> ? addTags, List<int> ? removeTags, List<int> ? tags, List<String> ? adminUserIds, List<String> ? addAdminUserIds, List<String> ? removeAdminUserIds, String? description, String? subTitle, String? telegram, String? whatsapp, String? phone, List<UContentLink> ? links, List<UContentItem> ? items, String? creatorId, List<String> ? media}) - UContentUpdateParams.fromJson(String str)
-
factory
-
UContentUpdateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
addAdminUserIds
→ List<
String> ? -
final
-
addTags
→ List<
int> ? -
final
-
adminUserIds
→ List<
String> ? -
final
-
final
-
final
- creatorId → String?
-
final
- description → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconBase64 → String?
-
final
- id → String
-
final
- imageBase64 → String?
-
final
- instagram → String?
-
final
-
items
→ List<
UContentItem> ? -
final
- link → String?
-
final
-
links
→ List<
UContentLink> ? -
final
-
media
→ List<
String> ? -
final
- order → int?
-
final
- phone → String?
-
final
-
removeAdminUserIds
→ List<
String> ? -
final
-
removeTags
→ List<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subTitle → String?
-
final
-
final
- telegram → String?
-
final
- title → String?
-
final
- whatsapp → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited