UDbColumnResponse class
Constructors
- UDbColumnResponse({required String name, required String dataType, required bool isNullable, required bool isPrimaryKey, required int ordinalPosition, String? defaultValue})
-
UDbColumnResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- dataType → String
-
final
- defaultValue → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNullable → bool
-
final
- isPrimaryKey → bool
-
final
- name → String
-
final
- ordinalPosition → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited