UDbQueryResultResponse class
Constructors
-
UDbQueryResultResponse({required List<
String> columns, required List<String?> columnTypes, required List<Map< rows, required int rowCount, required int executionMs, required bool truncated, int? affectedRows, String? primaryKeyColumn})String, String?> > -
UDbQueryResultResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- affectedRows → int?
-
final
-
columns
→ List<
String> -
final
-
columnTypes
→ List<
String?> -
final
- executionMs → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryKeyColumn → String?
-
final
- rowCount → int
-
final
-
rows
→ List<
Map< String, String?> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truncated → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited