UDbTableSchemaResponse class

Constructors

UDbTableSchemaResponse({required String schema, required String table, required List<UDbColumnResponse> columns, required List<UDbIndexResponse> indexes, required List<UDbForeignKeyResponse> foreignKeys, required List<String> primaryKeys})
UDbTableSchemaResponse.fromMap(Map<String, dynamic> json)
factory

Properties

columns List<UDbColumnResponse>
final
foreignKeys List<UDbForeignKeyResponse>
final
hashCode int
The hash code for this object.
no setterinherited
indexes List<UDbIndexResponse>
final
primaryKeys List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema String
final
table String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited