UDormBedContractCreateParams class
Constructors
-
UDormBedContractCreateParams({required List<
int> tags, required DateTime startDate, required DateTime endDate, required String userId, required String bedId, String? id, double? deposit, double? rent, int? penaltyPrecentEveryDate, String? detail1, String? detail2, String? creatorId, List<String> ? adminUserIds}) - UDormBedContractCreateParams.fromJson(String str)
-
factory
-
UDormBedContractCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> ? -
final
- bedId → String
-
final
- creatorId → String?
-
final
- deposit → double?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- endDate → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- penaltyPrecentEveryDate → int?
-
final
- rent → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime
-
final
-
final
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited