UDrivingLicenceDetailResponse class
Constructors
- UDrivingLicenceDetailResponse({String? nationalCode, String? firstName, String? lastName, String? requestDate, String? title, String? confirmDate, String? rahvarStatus, String? packetNo, String? barcode, String? printNnumber, String? printDate, String? validYears, bool isCached = false, DateTime? cachedAt, DateTime? cacheExpiresAt})
- UDrivingLicenceDetailResponse.fromJson(String str)
-
factory
-
UDrivingLicenceDetailResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- barcode → String?
-
final
- cachedAt → DateTime?
-
final
- cacheExpiresAt → DateTime?
-
final
- confirmDate → String?
-
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCached → bool
-
final
- lastName → String?
-
final
- nationalCode → String?
-
final
- packetNo → String?
-
final
- printDate → String?
-
final
- printNnumber → String?
-
final
- rahvarStatus → String?
-
final
- requestDate → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- validYears → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited