UFileManagerEntryResponse class
Constructors
- UFileManagerEntryResponse({required String name, required String path, required bool isDirectory, required int size, required DateTime modifiedAt, String? extension, String? url})
- UFileManagerEntryResponse.fromJson(String str)
-
factory
-
UFileManagerEntryResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- extension → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirectory → bool
-
final
- modifiedAt → DateTime
-
final
- name → String
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
final
- url → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited