UFreewayTollsResponse class
Constructors
-
UFreewayTollsResponse({String? totalPrice, List<
UFreewayTollsItem> ? items, bool isCached = false, DateTime? cachedAt, DateTime? cacheExpiresAt}) - UFreewayTollsResponse.fromJson(String str)
-
factory
-
UFreewayTollsResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- cachedAt → DateTime?
-
final
- cacheExpiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCached → bool
-
final
-
items
→ List<
UFreewayTollsItem> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPrice → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited