UHotelInvoiceResponse class

Available extensions

Constructors

UHotelInvoiceResponse({required String id, required DateTime createdAt, required UHotelInvoiceJson jsonData, required List<int> tags, required DateTime dueDate, required double debtAmount, required double creditorAmount, required double paidAmount, required double penaltyAmount, required List<String> adminUserIds, UUserResponse? creator, String? creatorId, String? reservationId, UHotelReservationResponse? reservation})
UHotelInvoiceResponse.fromJson(String str)
factory
UHotelInvoiceResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds → List<String>
final
createdAt → DateTime
final
creator → UUserResponse?
final
creatorId → String?
final
creditorAmount → double
final
debtAmount → double
final
dueDate → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isOverdue → bool

Available on UHotelInvoiceResponse, provided by the UHotelInvoiceStatusX extension

no setter
isPaid → bool

Available on UHotelInvoiceResponse, provided by the UHotelInvoiceStatusX extension

no setter
jsonData → UHotelInvoiceJson
final
netDue → double

Available on UHotelInvoiceResponse, provided by the UHotelInvoiceStatusX extension

no setter
paidAmount → double
final
penaltyAmount → double
final
reservation → UHotelReservationResponse?
final
reservationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited