UHotelReservationJson class
Constructors
- UHotelReservationJson({String? detail1, String? detail2, String? guestName, String? guestPhone, String? notes, int? nightCount})
- UHotelReservationJson.fromJson(String str)
-
factory
-
UHotelReservationJson.fromMap(Map<
String, dynamic> json) -
factory
Properties
- detail1 → String?
-
final
- detail2 → String?
-
final
- guestName → String?
-
final
- guestPhone → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nightCount → int?
-
final
- notes → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited