UHotelReservationResponse class
- Available extensions
Constructors
-
UHotelReservationResponse({required String id, required DateTime createdAt, required UHotelReservationJson jsonData, required List<
int> tags, required DateTime checkInDate, required DateTime checkOutDate, required int guestCount, required double totalPrice, required String userId, required String roomId, required String hotelId, required bool isActive, required List<String> adminUserIds, UUserResponse? creator, String? creatorId, UUserResponse? user, UHotelRoomResponse? room, UHotelResponse? hotel, List<UHotelInvoiceResponse> ? invoices}) - UHotelReservationResponse.fromJson(String str)
-
factory
-
UHotelReservationResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> -
final
- checkInDate → DateTime
-
final
- checkOutDate → DateTime
-
final
- createdAt → DateTime
-
final
- creator → UUserResponse?
-
final
- creatorId → String?
-
final
- guestCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hotel → UHotelResponse?
-
final
- hotelId → String
-
final
- id → String
-
final
-
invoices
→ List<
UHotelInvoiceResponse> ? -
final
- isActive → bool
-
final
- isCancelled → bool
-
Available on UHotelReservationResponse, provided by the UHotelReservationStatusX extension
no setter - jsonData → UHotelReservationJson
-
final
- room → UHotelRoomResponse?
-
final
- roomId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TagHotelReservation?
-
Available on UHotelReservationResponse, provided by the UHotelReservationStatusX extension
no setter -
final
- totalPrice → double
-
final
- user → UUserResponse?
-
final
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited