UHotelResponse class
Constructors
-
UHotelResponse({required String id, required DateTime createdAt, required UHotelJson jsonData, required List<
int> tags, required String title, required String cityCode, int stars = 0, String? address, String? phoneNumber, String? email, List<String> adminUserIds = const <String>[], UUserResponse? creator, String? creatorId, List<UHotelRoomResponse> ? rooms, List<UHotelReservationResponse> ? reservations, List<UMediaResponse> ? media}) - UHotelResponse.fromJson(String str)
-
factory
-
UHotelResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
- address → String?
-
final
-
adminUserIds
→ List<
String> -
final
- cityCode → String
-
final
- createdAt → DateTime
-
final
- creator → UUserResponse?
-
final
- creatorId → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- jsonData → UHotelJson
-
final
-
media
→ List<
UMediaResponse> ? -
final
- phoneNumber → String?
-
final
-
reservations
→ List<
UHotelReservationResponse> ? -
final
-
rooms
→ List<
UHotelRoomResponse> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stars → int
-
final
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited