UHotelRoomCreateParams class

Constructors

UHotelRoomCreateParams({required List<int> tags, required String title, required int capacity, required double pricePerNight, required String hotelId, String? roomNumber, int quantity = 1, bool isAvailable = true, String? description, String? bedType, double? sizeSquareMeters, int? floor, List<String>? amenities, String? detail1, String? detail2, String? id, String? creatorId, List<String>? adminUserIds})
UHotelRoomCreateParams.fromJson(String str)
factory
UHotelRoomCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
amenities List<String>?
final
bedType String?
final
capacity int
final
creatorId String?
final
description String?
final
detail1 String?
final
detail2 String?
final
floor int?
final
hashCode int
The hash code for this object.
no setterinherited
hotelId String
final
id String?
final
isAvailable bool
final
pricePerNight double
final
quantity int
final
roomNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeSquareMeters double?
final
tags List<int>
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited