UHotelRoomJson class
Constructors
-
UHotelRoomJson({String? detail1, String? detail2, String? description, String? bedType, double? sizeSquareMeters, int? floor, List<
String> amenities = const <String>[]}) - UHotelRoomJson.fromJson(String str)
-
factory
-
UHotelRoomJson.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
amenities
→ List<
String> -
final
- bedType → String?
-
final
- description → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- floor → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeSquareMeters → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited