UMediaUpdateParams class
Constructors
-
UMediaUpdateParams({required String id, List<
int> ? addTags, List<int> ? removeTags, String? title, String? description, String? userId, String? contentId, String? commentId, String? categoryId, String? productId, String? blogId, String? detail1, String? detail2, List<int> ? tags, List<String> ? adminUserIds, List<String> ? addAdminUserIds, List<String> ? removeAdminUserIds, String? hotelId, String? hotelRoomId, String? dormId, String? dormRoomId, String? dormBedId}) - UMediaUpdateParams.fromJson(String str)
-
factory
-
UMediaUpdateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
addAdminUserIds
→ List<
String> ? -
final
-
addTags
→ List<
int> ? -
final
-
adminUserIds
→ List<
String> ? -
final
- blogId → String?
-
final
- categoryId → String?
-
final
- commentId → String?
-
final
- contentId → String?
-
final
- description → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- dormBedId → String?
-
final
- dormId → String?
-
final
- dormRoomId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hotelId → String?
-
final
- hotelRoomId → String?
-
final
- id → String
-
final
- productId → String?
-
final
-
removeAdminUserIds
→ List<
String> ? -
final
-
removeTags
→ List<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- title → String?
-
final
- userId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited