UMerchantCreateParams class

Constructors

UMerchantCreateParams({required List<int> tags, required String zipCode, required String cityCode, required String address, required String title, required String landline, required String nationalCode, required String ownerPhoneNumber, required String ownerName, required String phoneNumber, required String mcc, String? detail1, String? detail2, String? id, String? creatorId, String? businessTitle, String? userId, String? bankAccountId, List<String>? adminUserIds})
UMerchantCreateParams.fromJson(String str)
factory
UMerchantCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

address String
final
adminUserIds List<String>?
final
bankAccountId String?
final
businessTitle String?
final
cityCode String
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
landline String
final
mcc String
final
nationalCode String
final
ownerName String
final
ownerPhoneNumber String
final
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
title String
final
userId String?
final
zipCode String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited