UParkingCreateParams class
Constructors
-
UParkingCreateParams({required String title, required double entrancePrice, required double hourlyPrice, required double dailyPrice, required List<
int> tags, String? detail1, String? detail2, String? id, String? creatorId, List<String> ? adminUserIds}) - UParkingCreateParams.fromJson(String str)
-
factory
-
UParkingCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> ? -
final
- creatorId → String?
-
final
- dailyPrice → double
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- entrancePrice → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hourlyPrice → double
-
final
- id → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited