UParkingReportUpdateParams class

Constructors

UParkingReportUpdateParams({required String id, String? creatorId, String? vehicleId, String? parkingId, DateTime? startDate, DateTime? endDate, double? amount, List<int>? addTags, List<int>? removeTags, String? detail1, String? detail2, List<int>? tags, List<String>? adminUserIds, List<String>? addAdminUserIds, List<String>? removeAdminUserIds})
UParkingReportUpdateParams.fromJson(String str)
factory
UParkingReportUpdateParams.fromMap(Map<String, dynamic> json)
factory

Properties

addAdminUserIds List<String>?
final
addTags List<int>?
final
adminUserIds List<String>?
final
amount double?
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
parkingId String?
final
removeAdminUserIds List<String>?
final
removeTags List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
final
tags List<int>?
final
vehicleId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited