UProcessField class
Constructors
-
UProcessField({required String label, required TagFieldType type, required bool required, required String key, String? rejectionReason, String? text1, String? value, UTextFieldConfig? textFieldConfig, UFileConfig? fileConfig, UDropDownConfig? dropDownConfig, List<
UOption> ? options}) - UProcessField.fromJson(String str)
-
factory
-
UProcessField.fromMap(Map<
String, dynamic> json) -
factory
Properties
- dropDownConfig → UDropDownConfig?
-
final
- fileConfig → UFileConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- label → String
-
final
-
options
→ List<
UOption> ? -
final
- rejectionReason ↔ String?
-
getter/setter pair
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text1 ↔ String?
-
getter/setter pair
- textFieldConfig → UTextFieldConfig?
-
final
- type → TagFieldType
-
final
- value ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited