UProcessStepGet class
Constructors
-
UProcessStepGet({required String id, required String title, required String description, bool isScrollable = false, List<
UProcessField> ? fields, String? message, UMessageBox? messageBox, List<UProcessStepStatus> steps = const <UProcessStepStatus>[]}) - UProcessStepGet.fromJson(String str)
-
factory
-
UProcessStepGet.fromMap(Map<
String, dynamic> json) -
factory
Properties
- description → String
-
final
-
fields
→ List<
UProcessField> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isScrollable → bool
-
final
- message → String?
-
final
- messageBox → UMessageBox?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<
UProcessStepStatus> -
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited