UProductCreateParams class
Constructors
-
UProductCreateParams({required String title, required List<
int> tags, String? code, String? subtitle, String? description, String? actionType, String? actionTitle, String? actionUri, String? slug, String? type, String? content, double? latitude, double? longitude, int? stock, String? details, List<String> ? categories, String? parentId, String? creatorId, int? point, String? phoneNumber, String? address, String? detail1, String? detail2, String? id, List<String> ? adminUserIds, int? order, List<UProductCreateParams> ? children, List<String> ? media}) - UProductCreateParams.fromJson(String str)
-
factory
-
UProductCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- actionTitle → String?
-
final
- actionType → String?
-
final
- actionUri → String?
-
final
- address → String?
-
final
-
adminUserIds
→ List<
String> ? -
final
-
categories
→ List<
String> ? -
final
-
children
→ List<
UProductCreateParams> ? -
final
- code → String?
-
final
- content → String?
-
final
- creatorId → String?
-
final
- description → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- details → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- latitude → double?
-
final
- longitude → double?
-
final
-
media
→ List<
String> ? -
final
- order → int?
-
final
- parentId → String?
-
final
- phoneNumber → String?
-
final
- point → int?
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String?
-
final
- stock → int?
-
final
- subtitle → String?
-
final
-
final
- title → String
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited