UProductJson class
Constructors
- UProductJson({String? actionType, String? actionTitle, String? actionUri, String? details, String? phoneNumber, String? address, String? detail1, String? detail2})
- UProductJson.fromJson(String str)
-
factory
-
UProductJson.fromMap(Map<
String, dynamic> json) -
factory
Properties
- actionTitle → String?
-
final
- actionType → String?
-
final
- actionUri → String?
-
final
- address → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- details → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneNumber → String?
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited