URecentContractItem class
Constructors
- URecentContractItem({required String id, required String bedTitle, required String dormTitle, required DateTime startDate, required DateTime endDate, required double rent, required DateTime createdAt, String? userName})
- URecentContractItem.fromJson(String str)
-
factory
-
URecentContractItem.fromMap(Map<
String, dynamic> json) -
factory
Properties
- bedTitle → String
-
final
- createdAt → DateTime
-
final
- dormTitle → String
-
final
- endDate → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- rent → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime
-
final
- userName → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited