URecentTxnItem class

Constructors

URecentTxnItem({required String id, required double amount, required String trackingNumber, required List<String> tags, required DateTime createdAt, String? userName})
URecentTxnItem.fromJson(String str)
factory
URecentTxnItem.fromMap(Map<String, dynamic> json)
factory

Properties

amount → double
final
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
final
trackingNumber → String
final
userName → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited