URegisterParams class

Constructors

URegisterParams({required String userName, required String password, required List<int> tags, String? email, String? phoneNumber, String? firstName, String? lastName, String? nationalCode})
URegisterParams.fromJson(String str)
factory
URegisterParams.fromMap(Map<String, dynamic> json)
factory

Properties

email String?
final
firstName String?
final
hashCode int
The hash code for this object.
no setterinherited
lastName String?
final
nationalCode String?
final
password String
final
phoneNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
userName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited