UTxnCreateParams class

Constructors

UTxnCreateParams({required double amount, required String trackingNumber, required List<int> tags, String? id, String? detail1, String? detail2, String? creatorId, List<String>? adminUserIds})
UTxnCreateParams.fromJson(String str)
factory
UTxnCreateParams.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>?
final
amount double
final
creatorId String?
final
detail1 String?
final
detail2 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final
trackingNumber String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited