UUserCreateParams class
Constructors
-
UUserCreateParams({required String userName, required String password, required List<
int> tags, String? phoneNumber, String? email, String? landLine, String? firstName, String? lastName, String? nationalCode, String? bio, DateTime? birthdate, double? weight, double? height, String? fatherName, String? fcmToken, List<String> ? categories, String? nationalCardFront, String? nationalCardBack, String? birthCertificateFirst, String? birthCertificateSecond, String? birthCertificateThird, String? birthCertificateForth, String? birthCertificateFifth, String? visualAuthentication, String? eSignature, String? detail1, String? detail2, String? id, String? creatorId, List<String> ? adminUserIds}) - UUserCreateParams.fromJson(String str)
-
factory
-
UUserCreateParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> ? -
final
- bio → String?
-
final
- birthCertificateFifth → String?
-
final
- birthCertificateFirst → String?
-
final
- birthCertificateForth → String?
-
final
- birthCertificateSecond → String?
-
final
- birthCertificateThird → String?
-
final
- birthdate → DateTime?
-
final
-
categories
→ List<
String> ? -
final
- creatorId → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- email → String?
-
final
- eSignature → String?
-
final
- fatherName → String?
-
final
- fcmToken → String?
-
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- id → String?
-
final
- landLine → String?
-
final
- lastName → String?
-
final
- nationalCardBack → String?
-
final
- nationalCardFront → String?
-
final
- nationalCode → String?
-
final
- password → String
-
final
- phoneNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- userName → String
-
final
- visualAuthentication → String?
-
final
- weight → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited