UUserJson class
Constructors
- UUserJson({String? fcmToken, double? weight, double? height, String? fatherName, String? nationalCardFrontRejectionReason, String? nationalCardBackRejectionReason, String? birthCertificateFirstRejectionReason, String? birthCertificateSecondRejectionReason, String? birthCertificateThirdRejectionReason, String? birthCertificateForthRejectionReason, String? birthCertificateFifthRejectionReason, String? visualAuthenticationRejectionReason, String? eSignatureRejectionReason, String? detail1, String? detail2})
- UUserJson.fromJson(String str)
-
factory
-
UUserJson.fromMap(Map<
String, dynamic> json) -
factory
Properties
- birthCertificateFifthRejectionReason → String?
-
final
- birthCertificateFirstRejectionReason → String?
-
final
- birthCertificateForthRejectionReason → String?
-
final
- birthCertificateSecondRejectionReason → String?
-
final
- birthCertificateThirdRejectionReason → String?
-
final
- detail1 → String?
-
final
- detail2 → String?
-
final
- eSignatureRejectionReason → String?
-
final
- fatherName → String?
-
final
- fcmToken → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- nationalCardBackRejectionReason → String?
-
final
- nationalCardFrontRejectionReason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visualAuthenticationRejectionReason → String?
-
final
- weight → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited