UUserReadParams class

Constructors

UUserReadParams({String? query, String? userName, String? landLine, String? firstName, String? lastName, String? nationalCode, String? phoneNumber, String? email, String? bio, DateTime? startBirthDate, DateTime? endBirthDate, List<String>? categories, int? pageSize, int? pageNumber, DateTime? fromCreatedAt, DateTime? toCreatedAt, List<int>? tags, UserSelectorArgs? selectorArgs, int? orderBy, List<String>? ids, String? creatorId})
UUserReadParams.fromJson(String str)
factory
UUserReadParams.fromMap(Map<String, dynamic> json)
factory

Properties

bio String?
final
categories List<String>?
final
creatorId String?
final
email String?
final
endBirthDate DateTime?
final
firstName String?
final
fromCreatedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ids List<String>?
final
landLine String?
final
lastName String?
final
nationalCode String?
final
orderBy int?
final
pageNumber int?
final
pageSize int?
final
phoneNumber String?
final
query String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorArgs UserSelectorArgs?
final
startBirthDate DateTime?
final
tags List<int>?
final
toCreatedAt DateTime?
final
userName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited