UUserResponse class
- Available extensions
Constructors
-
UUserResponse({required String id, required DateTime createdAt, required UUserJson jsonData, required List<
int> tags, required String userName, required List<String> adminUserIds, String? landLine, String? phoneNumber, String? email, String? firstName, String? lastName, String? nationalCode, String? bio, DateTime? birthdate, List<UCategoryResponse> ? categories, List<UMediaResponse> ? media, List<UAddressResponse> ? addresses, List<UMerchantResponse> ? merchants, List<UWalletResponse> ? wallets, List<UTxnResponse> ? txns, List<UBankAccountResponse> ? bankAccounts, List<USimCardResponse> ? simCards, String? nationalCardFront, String? nationalCardBack, String? birthCertificateFirst, String? birthCertificateSecond, String? birthCertificateThird, String? birthCertificateForth, String? birthCertificateFifth, String? visualAuthentication, String? eSignature, UUserResponse? creator, String? creatorId}) - UUserResponse.fromJson(String str)
-
factory
-
UUserResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
addresses
→ List<
UAddressResponse> ? -
final
-
adminUserIds
→ List<
String> -
final
-
bankAccounts
→ List<
UBankAccountResponse> ? -
final
- bio → String?
-
final
- birthCertificateFifth → String?
-
final
- birthCertificateFirst → String?
-
final
- birthCertificateForth → String?
-
final
- birthCertificateSecond → String?
-
final
- birthCertificateThird → String?
-
final
- birthdate → DateTime?
-
final
-
categories
→ List<
UCategoryResponse> ? -
final
- createdAt → DateTime
-
final
- creator → UUserResponse?
-
final
- creatorId → String?
-
final
- displayName → String
-
Available on UUserResponse, provided by the TagListExtension extension
no setter - email → String?
-
final
- eSignature → String?
-
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- jsonData → UUserJson
-
final
- landLine → String?
-
final
- lastName → String?
-
final
-
media
→ List<
UMediaResponse> ? -
final
-
merchants
→ List<
UMerchantResponse> ? -
final
- nationalCardBack → String?
-
final
- nationalCardFront → String?
-
final
- nationalCode → String?
-
final
- phoneNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
simCards
→ List<
USimCardResponse> ? -
final
-
final
-
txns
→ List<
UTxnResponse> ? -
final
- userName → String
-
final
- visualAuthentication → String?
-
final
-
wallets
→ List<
UWalletResponse> ? -
final
Methods
-
hasPermission(
TagUser permission) → bool -
Available on UUserResponse, provided by the TagListExtension extension
-
isFemaleMale(
) → bool -
Available on UUserResponse, provided by the TagListExtension extension
-
isFullAdmin(
) → bool -
Available on UUserResponse, provided by the TagListExtension extension
-
isMale(
) → bool -
Available on UUserResponse, provided by the TagListExtension extension
-
isSubAdmin(
) → bool -
Available on UUserResponse, provided by the TagListExtension extension
-
isSuperAdmin(
) → bool -
Available on UUserResponse, provided by the TagListExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited