UWalletResponse class

Constructors

UWalletResponse({required String id, required List<int> tags, required UBaseJson jsonData, required double balance, required String creatorId, required List<String> adminUserIds, DateTime? createdAt, UUserResponse? creator})
UWalletResponse.fromJson(String str)
factory
UWalletResponse.fromMap(Map<String, dynamic> json)
factory

Properties

adminUserIds List<String>
final
balance double
final
createdAt DateTime?
final
creator UUserResponse?
final
creatorId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jsonData UBaseJson
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited