UWalletTransferParams class
Constructors
-
UWalletTransferParams({required String receiverId, required double amount, required List<
int> tagWalletTxn, String? senderId, String? detail1}) - UWalletTransferParams.fromJson(String str)
-
factory
-
UWalletTransferParams.fromMap(Map<
String, dynamic> json) -
factory
Properties
- amount → double
-
final
- detail1 → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- receiverId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → String?
-
final
-
tagWalletTxn
→ List<
int> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited