UWalletTxnResponse class
- Available extensions
Constructors
-
UWalletTxnResponse({required String id, required List<
int> tags, required UBaseJson jsonData, required DateTime createdAt, required double amount, required String senderId, required String receiverId, required List<String> adminUserIds, UUserResponse? sender, UUserResponse? receiver, UUserResponse? creator, String? creatorId}) - UWalletTxnResponse.fromJson(String str)
-
factory
-
UWalletTxnResponse.fromMap(Map<
String, dynamic> json) -
factory
Properties
-
adminUserIds
→ List<
String> -
final
- amount → double
-
final
- createdAt → DateTime
-
final
- creator → UUserResponse?
-
final
- creatorId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
Available on UWalletTxnResponse, provided by the NullableWalletExtension extension
no setter - id → String
-
final
- jsonData → UBaseJson
-
final
- receiver → UUserResponse?
-
final
- receiverId → String
-
final
- reference → String?
-
Available on UWalletTxnResponse, provided by the NullableWalletExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → UUserResponse?
-
final
- senderId → String
-
final
- tag → TagWalletTxn?
-
Available on UWalletTxnResponse, provided by the NullableWalletExtension extension
no setter -
final
Methods
-
isOutgoing(
{String? userId}) → bool -
Available on UWalletTxnResponse, provided by the NullableWalletExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
title(
) → String -
Available on UWalletTxnResponse, provided by the NullableWalletExtension extension
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited