UserFlowStep class
Represents a single step in the multi-step wizard
Constructors
-
UserFlowStep({required String stepId, required int number, required String title, required List<
UserFlowField> fields, required List<UserFlowFileRequirement> files, String? description, String? icon, String? backgroundImageUrl, List<FieldGroup> ? fieldGroups}) -
UserFlowStep.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backgroundImageUrl → String?
-
final
- description → String?
-
final
-
fieldGroups
→ List<
FieldGroup> ? -
final
-
fields
→ List<
UserFlowField> -
final
-
files
→ List<
UserFlowFileRequirement> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
-
final
- number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepId → String
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited