ValidationRules class
Validation rules for a field
Constructors
- ValidationRules({int? minLength, int? maxLength, int? min, int? max, int? exactLength, String? regexPattern, String? regexErrorMessage, String? matchField, String? customErrorMessage, String? customValidatorFunction, String? minDate, String? maxDate, bool disableFutureDates = false, bool disablePastDates = false})
-
ValidationRules.fromJson(Map<
String, dynamic> json) -
factory
Properties
- customErrorMessage → String?
-
final
- customValidatorFunction → String?
-
final
- disableFutureDates → bool
-
final
- disablePastDates → bool
-
final
- exactLength → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matchField → String?
-
final
- max → int?
-
final
- maxDate → String?
-
final
- maxLength → int?
-
final
- min → int?
-
final
- minDate → String?
-
final
- minLength → int?
-
final
- regexErrorMessage → String?
-
final
- regexPattern → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited