VisibilityRule class

Visibility rule for fields

Constructors

VisibilityRule({required String dependsOnField, required String dependsOnValue, ComparisonOperator operator = ComparisonOperator.equals, List<VisibilityRule>? multipleConditions, LogicalOperator logicalOperator = LogicalOperator.and})
VisibilityRule.fromJson(Map<String, dynamic> json)
factory

Properties

dependsOnField String
final
dependsOnValue String
final
hashCode int
The hash code for this object.
no setterinherited
logicalOperator LogicalOperator
final
multipleConditions List<VisibilityRule>?
final
operator ComparisonOperator
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited