TagApiLog enum

Inheritance
Mixed-in types
Available extensions

Values

get_ → const TagApiLog
const TagApiLog("GET", "GET", 101)
post → const TagApiLog
const TagApiLog("POST", "POST", 102)
put → const TagApiLog
const TagApiLog("PUT", "PUT", 103)
patch → const TagApiLog
const TagApiLog("PATCH", "PATCH", 104)
delete → const TagApiLog
const TagApiLog("DELETE", "DELETE", 105)
other → const TagApiLog
const TagApiLog("سایر", "Other", 106)
success → const TagApiLog
const TagApiLog("موفق", "Success", 201)
clientError → const TagApiLog
const TagApiLog("خطای کلاینت", "Client Error", 202)
serverError → const TagApiLog
const TagApiLog("خطای سرور", "Server Error", 203)
hasException → const TagApiLog
const TagApiLog("دارای استثنا", "Has Exception", 301)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle → String
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleEn → String
final
titleFa → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TagApiLog>
A constant List of the values in this enum, in order of their declaration.