TagProduct enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- product → const TagProduct
-
const TagProduct("محصول", "Product", 101) - content → const TagProduct
-
const TagProduct("محتوا", "Content", 102) - blog → const TagProduct
-
const TagProduct("وبلاگ", "Blog", 103) - case_ → const TagProduct
-
const TagProduct("کیس", "Case", 104) - dorm → const TagProduct
-
const TagProduct("خوابگاه", "Dorm", 105) - room → const TagProduct
-
const TagProduct("اتاق", "Room", 106) - bed → const TagProduct
-
const TagProduct("تخت", "Bed", 107) - new_ → const TagProduct
-
const TagProduct("جدید", "New", 201) - kindOfNew → const TagProduct
-
const TagProduct("نو", "Kind of New", 202) - used → const TagProduct
-
const TagProduct("دست دوم", "Used", 203) - released → const TagProduct
-
const TagProduct("منتشر شده", "Released", 301) - expired → const TagProduct
-
const TagProduct("منقضی شده", "Expired", 302) - inQueue → const TagProduct
-
const TagProduct("در حال بررسی", "In Queue", 303) - deleted → const TagProduct
-
const TagProduct("حذف شده", "Deleted", 304) - notAccepted → const TagProduct
-
const TagProduct("تایید نشده", "Not Accepted", 305) - awaitingPayment → const TagProduct
-
const TagProduct("در انتظار پرداخت", "Awaiting Payment", 306) - room1 → const TagProduct
-
const TagProduct("اتاق ۱ تخته", "1 Bed Room", 401) - room2 → const TagProduct
-
const TagProduct("اتاق ۲ تخته", "2 Bed Room", 402) - room3 → const TagProduct
-
const TagProduct("اتاق ۳ تخته", "3 Bed Room", 403) - room4 → const TagProduct
-
const TagProduct("اتاق ۴ تخته", "4 Bed Room", 404) - room5 → const TagProduct
-
const TagProduct("اتاق ۵ تخته", "5 Bed Room", 405) - room6 → const TagProduct
-
const TagProduct("اتاق ۶ تخته", "6 Bed Room", 406) - room7 → const TagProduct
-
const TagProduct("اتاق ۷ تخته", "7 Bed Room", 407) - room8 → const TagProduct
-
const TagProduct("اتاق ۸ تخته", "8 Bed Room", 408) - room9 → const TagProduct
-
const TagProduct("اتاق ۹ تخته", "9 Bed Room", 409) - room10 → const TagProduct
-
const TagProduct("اتاق ۱۰ تخته", "10 Bed Room", 410)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- localizedTitle → String
-
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleEn → String
-
final
- titleFa → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagProduct> - A constant List of the values in this enum, in order of their declaration.