TagWalletTxn enum

Inheritance
Mixed-in types
Available extensions

Values

charge → const TagWalletTxn
const TagWalletTxn("شارژ کیف پول", "Wallet Top-up", 101)
transfer → const TagWalletTxn
const TagWalletTxn("انتقال وجه", "Money Transfer", 102)
mobileAndNationalCodeVerification → const TagWalletTxn
const TagWalletTxn("اعتبارسنجی موبایل و کد ملی", "Mobile & National ID Match", 201)
zipCodeToAddressDetail → const TagWalletTxn
const TagWalletTxn("استعلام کد پستی", "Postal Code to Address", 202)
vehicleViolationsDetail → const TagWalletTxn
const TagWalletTxn("استعلام خلافی خودرو", "Vehicle Violations", 203)
drivingLicenceStatus → const TagWalletTxn
const TagWalletTxn("استعلام وضعیت گواهینامه", "Driving Licence Status", 204)
licencePlateDetail → const TagWalletTxn
const TagWalletTxn("استعلام سوابق پلاک", "Licence Plate History", 205)
drivingLicenceNegativePoint → const TagWalletTxn
const TagWalletTxn("استعلام نمره منفی گواهینامه", "Licence Negative Points", 206)
iBanToBankAccountDetail → const TagWalletTxn
const TagWalletTxn("استعلام شبا به حساب بانکی", "IBAN to Bank Account", 207)
freewayTolls → const TagWalletTxn
const TagWalletTxn("استعلام عوارض آزادراه", "Freeway Tolls", 208)
merchantCreationFee → const TagWalletTxn
const TagWalletTxn("هزینه ایجاد پذیرنده", "Merchant Creation Fee", 209)
chargeSimPin → const TagWalletTxn
const TagWalletTxn("خرید شارژ پین سیم‌کارت", "SIM Charge (PIN)", 301)
chargeSimTopup → const TagWalletTxn
const TagWalletTxn("شارژ مستقیم سیم‌کارت", "SIM Top-up", 302)
internetSim → const TagWalletTxn
const TagWalletTxn("خرید بسته اینترنت", "Internet Package", 303)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
localizedTitle String
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleEn String
final
titleFa String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TagWalletTxn>
A constant List of the values in this enum, in order of their declaration.