IsoFrameReader class
Reassembles length-prefixed frames from a byte stream that may split or merge them arbitrarily.
Constructors
- IsoFrameReader({int lengthBytes = 2})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lengthBytes → int
-
Width of the length prefix. Two big-endian bytes is the common case.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
List< int> chunk) → List<Uint8List> - Feeds received bytes in and returns whatever complete frame payloads (header plus body, without the length prefix) are now available.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited