HostConfig class
Everything about this terminal's relationship with the acquirer that does
not change per transaction. Ported from HostConfig.
Constructors
-
HostConfig({required String nii, required String bin, required String version, required TerminalInitKeySetting initKeySetting, required TerminalSessionKeyIndexSetting sessionKeyIndexSetting, required Map<
String, HostConnectionInfo> allConnectionInfo, String? activeConnectionType, String sourceId = "1122", String destinationId = "3344", int defaultTxnTimeoutSeconds = 10}) -
HostConfig.fromJson(Map<
String, dynamic> json) -
The Apos_android asset stores
niiandbinas JSON numbers, and carries noversion, so every scalar is read leniently.factory
Properties
- activeConnectionType ↔ String?
-
getter/setter pair
-
allConnectionInfo
→ Map<
String, HostConnectionInfo> -
final
- bin → String
-
Acquiring institution id, ISO field 32.
final
- defaultTxnTimeoutSeconds → int
-
final
- destinationId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initKeySetting → TerminalInitKeySetting
-
final
- nii → String
-
Network international identifier, ISO field 24.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionKeyIndexSetting → TerminalSessionKeyIndexSetting
-
final
- sourceId → String
-
Link header source and destination, four BCD digits each.
final
- version → String
-
Application version, sent as TLV tag C1.
final
Methods
-
activeConnectionInfo(
) → HostConnectionInfo -
checkInit(
) → void -
fetchApnHostConnection(
) → HostConnectionInfo? -
fetchTmsHostConnection(
) → HostConnectionInfo? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited