TerminalLogicalInfo class
Terminal and merchant identity as the host reported it at logon. Ported from
TerminalLogicalInfo.
Constructors
- TerminalLogicalInfo({required String terminalId, required String merchantId, String? centerTerminalId, String? merchantName, String? merchantPostalCode, String? merchantPhone})
-
TerminalLogicalInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- centerTerminalId ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantId → String
-
final
- merchantName ↔ String?
-
getter/setter pair
- merchantPhone ↔ String?
-
getter/setter pair
- merchantPostalCode ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminalId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited