PanUtil class abstract
PAN handling ported from the Java PanUtil.
Constructors
- PanUtil()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cardNumberFromTrack2(
String track2) → String -
isDomestic(
String track2, String domesticBin) → bool -
maskPan(
String panOrTrack2, String? panLast4Digit) → String? -
maskPanInternal(
String? pan) → String?