IsoPrefixer class abstract
Writes and reads the length that precedes a variable-length field.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- packedLength → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodeLength(
IsoBuffer buffer) → int -
encodeLength(
int length, IsoBuffer buffer) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited