UArAnchor class
Constructors
- UArAnchor({required String id, required UArPose pose, UArAnchorType type = UArAnchorType.world, UArTrackingState tracking = UArTrackingState.normal, String? name, String? cloudId, String? trackableId})
-
const
-
UArAnchor.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- cloudId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String?
-
final
- pose → UArPose
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackableId → String?
-
final
- tracking → UArTrackingState
-
final
- type → UArAnchorType
-
final
Methods
-
copyWith(
{UArPose? pose, UArTrackingState? tracking, String? cloudId}) → UArAnchor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited