UArFace class
Constructors
Properties
- anchorId → String
-
no setter
-
blendShapes
→ Map<
String, double> -
ARKit blend shapes, 0..1 (eyeBlinkLeft, jawOpen, mouthSmileLeft, …).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- lookAt → UArVector3?
-
final
- pose → UArPose
-
final
-
regions
→ Map<
String, UArPose> -
noseTip, foreheadLeft, foreheadRight (Android); leftEye, rightEye (iOS).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shape(
String name) → double -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited