UArMaterial class
Constructors
Properties
- color → Color
-
final
- doubleSided → bool
-
final
- emissive → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metallic → double
-
final
- occluder → bool
-
Invisible, but hides whatever is behind it — cut-outs, portals, walls.
final
- opacity → double
-
final
- renderOnTop → bool
-
Ignores depth so the node always draws over the scene (HUD-style labels).
final
- roughness → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- texture → UArSource?
-
final
- unlit → bool
-
final
Methods
-
copyWith(
{Color? color, double? metallic, double? roughness, double? opacity, Color? emissive, UArSource? texture, bool? unlit, bool? doubleSided, bool? occluder, bool? renderOnTop}) → UArMaterial -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited