UArPlane class
Constructors
-
UArPlane({required String id, required UArPlaneType type, required UArPose pose, UArPlaneClassification classification = UArPlaneClassification.none, double width = 0, double length = 0, List<
Offset> polygon = const <Offset>[], UArTrackingState tracking = UArTrackingState.normal, String? subsumedBy}) -
const
-
UArPlane.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- area → double
-
no setter
- classification → UArPlaneClassification
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isHorizontal → bool
-
no setter
- isVertical → bool
-
no setter
- length → double
-
final
-
polygon
→ List<
Offset> -
Outline in the plane's local X/Z, metres.
final
- pose → UArPose
-
Centre of the plane; its local Y axis is the surface normal.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subsumedBy → String?
-
final
- tracking → UArTrackingState
-
final
- type → UArPlaneType
-
final
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited