UArPose class
A rigid transform: where something is and which way it faces, in metres.
Constructors
- UArPose({UArVector3 position = UArVector3.zero, UArQuaternion rotation = UArQuaternion.identity})
-
const
- UArPose.fromList(Object? raw)
-
factory
- UArPose.translation(double x, double y, double z)
-
factory
Properties
- forward → UArVector3
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- inverse → UArPose
-
no setter
- position → UArVector3
-
final
- right → UArVector3
-
no setter
- rotation → UArQuaternion
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- up → UArVector3
-
no setter
- upright → UArPose
-
Same position, rotated only around world Y so it stays upright.
no setter
Methods
-
lerp(
UArPose other, double t) → UArPose -
multiply(
UArPose other) → UArPose -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toList(
) → List< double> -
toString(
) → String -
A string representation of this object.
override
-
transformDirection(
UArVector3 direction) → UArVector3 -
transformPoint(
UArVector3 point) → UArVector3 -
translated(
UArVector3 offset) → UArPose -
withRotation(
UArQuaternion value) → UArPose
Operators
-
operator *(
UArPose other) → UArPose -
operator ==(
Object other) → bool -
The equality operator.
override