UArQuaternion class
Constructors
- UArQuaternion(double x, double y, double z, double w)
-
const
- UArQuaternion.axisAngle(UArVector3 axis, double radians)
-
factory
- UArQuaternion.euler({double yaw = 0, double pitch = 0, double roll = 0})
-
Yaw (Y), then pitch (X), then roll (Z), all in degrees.
factory
- UArQuaternion.fromBasis(UArVector3 xAxis, UArVector3 yAxis, UArVector3 zAxis)
-
factory
-
UArQuaternion.fromList(List<
double> list, [int offset = 0]) -
factory
- UArQuaternion.lookRotation(UArVector3 forward, [UArVector3 up = UArVector3.up])
-
Rotation whose -Z axis points along
forward.factory - UArQuaternion.pitch(double radians)
-
factory
- UArQuaternion.roll(double radians)
-
factory
- UArQuaternion.yaw(double radians)
-
factory
Properties
- conjugate → UArQuaternion
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- normalized → UArQuaternion
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- w → double
-
final
- x → double
-
final
- y → double
-
final
- yawAngle → double
-
Heading of the rotated -Z axis around world Y, in radians.
no setter
- z → double
-
final
Methods
-
multiply(
UArQuaternion o) → UArQuaternion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rotate(
UArVector3 v) → UArVector3 -
slerp(
UArQuaternion other, double t) → UArQuaternion -
toList(
) → List< double> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator *(
UArQuaternion other) → UArQuaternion -
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- identity → const UArQuaternion