UArRecording class
Constructors
- UArRecording({String? path, Uint8List? bytes, String mimeType = "video/mp4", Duration duration = Duration.zero})
-
const
-
UArRecording.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- bytes → Uint8List?
-
Filled on the web, where there is no file system.
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String
-
final
- path → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited