UArRoomItem class
Properties
-
area
→ double
-
no setter
-
category
→ String
-
For objects: bed, sofa, table, storage, refrigerator, …
final
-
confidence
→ String
-
final
-
dimensions
→ UArVector3
-
Width, height, depth in metres.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
kind
→ String
-
wall, door, window, opening, floor or object.
final
-
pose
→ UArPose
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited