UArRoomScanResult class
Constructors
-
UArRoomScanResult({String? usdzPath, String? jsonPath, List<
UArRoomItem> items = const <UArRoomItem>[]}) -
const
-
UArRoomScanResult.fromMap(Map<
Object?, Object?> map) -
factory
Properties
-
doors
→ List<
UArRoomItem> -
no setter
- floorArea → double
-
Floor area in square metres, from the scanned floor or the walls' footprint.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
UArRoomItem> -
final
- jsonPath → String?
-
final
-
objects
→ List<
UArRoomItem> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usdzPath → String?
-
final
-
walls
→ List<
UArRoomItem> -
no setter
-
windows
→ List<
UArRoomItem> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited