UArSource class
Where a model, image, video or reference image comes from.
Constructors
- UArSource.asset(String asset, {String? extension})
-
A Flutter asset declared in the host app's pubspec.
factory
- UArSource.bytes(Uint8List bytes, {String extension = "glb"})
-
factory
- UArSource.file(String path, {String? extension})
-
factory
- UArSource.url(String url, {String? extension})
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited