UArVector3 class
Constructors
- UArVector3(double x, double y, double z)
-
const
- UArVector3.all(double value)
-
factory
-
UArVector3.fromList(List<
double> list, [int offset = 0]) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- horizontalLength → double
-
no setter
- length → double
-
no setter
- normalized → UArVector3
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x → double
-
final
- y → double
-
final
- z → double
-
final
Methods
-
cross(
UArVector3 other) → UArVector3 -
distanceTo(
UArVector3 other) → double -
dot(
UArVector3 other) → double -
lerp(
UArVector3 other, double t) → UArVector3 -
multiply(
UArVector3 other) → UArVector3 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toList(
) → List< double> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator *(
double factor) → UArVector3 -
operator +(
UArVector3 other) → UArVector3 -
operator -(
UArVector3 other) → UArVector3 -
operator ==(
Object other) → bool -
The equality operator.
override
-
operator unary-(
) → UArVector3
Constants
- forward → const UArVector3
- one → const UArVector3
- right → const UArVector3
- up → const UArVector3
- zero → const UArVector3