UCameraCapabilities class
What the currently open session can actually do. Drive UI from this rather than from the platform name.
Constructors
-
UCameraCapabilities({bool flash = false, bool torch = false, UCameraRange zoom = UCameraRange.unsupported, UCameraRange exposureOffset = UCameraRange.unsupported, UCameraRange iso = UCameraRange.unsupported, UCameraRange exposureDuration = UCameraRange.unsupported, UCameraRange focusDistance = UCameraRange.unsupported, UCameraRange temperature = UCameraRange.unsupported, bool focusPoint = false, bool exposurePoint = false, bool manualFocus = false, bool manualExposure = false, bool whiteBalance = false, List<
UStabilizationMode> stabilization = const <UStabilizationMode>[], bool hdr = false, bool nightMode = false, bool rawCapture = false, bool depthCapture = false, bool videoRecording = false, bool pauseRecording = false, bool audioRecording = false, bool imageStream = false, bool platformScanning = false, bool multiCamera = false, bool pictureInPicture = false, bool lensSwitching = false, bool orientationLock = false, bool snapshot = false, List<UVideoCodec> videoCodecs = const <UVideoCodec>[], List<UPhotoFormat> photoFormats = const <UPhotoFormat>[], List<UFrameFormat> frameFormats = const <UFrameFormat>[], UCameraSize? maxPhotoSize, UCameraSize? maxVideoSize, double maxFps = 30}) -
const
-
UCameraCapabilities.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- audioRecording → bool
-
final
- depthCapture → bool
-
final
- exposureDuration → UCameraRange
-
final
- exposureOffset → UCameraRange
-
final
- exposurePoint → bool
-
final
- flash → bool
-
final
- focusDistance → UCameraRange
-
final
- focusPoint → bool
-
final
-
frameFormats
→ List<
UFrameFormat> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hdr → bool
-
final
- imageStream → bool
-
final
- iso → UCameraRange
-
final
- lensSwitching → bool
-
final
- manualExposure → bool
-
final
- manualFocus → bool
-
final
- maxFps → double
-
final
- maxPhotoSize → UCameraSize?
-
final
- maxVideoSize → UCameraSize?
-
final
- multiCamera → bool
-
final
- nightMode → bool
-
final
- orientationLock → bool
-
final
- pauseRecording → bool
-
final
-
photoFormats
→ List<
UPhotoFormat> -
final
- pictureInPicture → bool
-
final
- platformScanning → bool
-
final
- rawCapture → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshot → bool
-
final
-
stabilization
→ List<
UStabilizationMode> -
final
- temperature → UCameraRange
-
final
- torch → bool
-
final
-
videoCodecs
→ List<
UVideoCodec> -
final
- videoRecording → bool
-
final
- whiteBalance → bool
-
final
- zoom → UCameraRange
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- none → const UCameraCapabilities