UCameraRange class
A numeric capability range. supported is false when the platform cannot change the value at all.
Constructors
- UCameraRange(double min, double max, {double step = 0, bool supported = true})
-
const
- UCameraRange.fromMap(Object? raw)
-
factory
Properties
Methods
-
clamp(
double value) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- unsupported → const UCameraRange