UBitMatrix class
A 1-bit image. true means a dark module.
Constructors
- UBitMatrix(int width, int height)
- UBitMatrix.fromBits(int width, int height, Uint8List bits)
Properties
Methods
-
copy(
) → UBitMatrix -
enclosingRectangle(
) → List< int> ? - Bounding box of the dark modules, or null when the matrix is blank.
-
flip(
int x, int y) → void -
get(
int x, int y) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rotate180(
) → UBitMatrix -
rotate90(
) → UBitMatrix -
set(
int x, int y, [bool value = true]) → void -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited