UDataMatrixBitMatrixParser class
Strips the alignment patterns and reads the codewords of a sampled symbol.
Constructors
- UDataMatrixBitMatrixParser(UBitMatrix bitMatrix)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → UDataMatrixVersion
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readCodewords(
) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited