UGfPoly class
Reed-Solomon over a power-of-two field (QR, Data Matrix, Aztec).
Constructors
- UGfPoly(UGaloisField field, Int32List coefficients)
Properties
- coefficients → Int32List
-
no setter
- degree → int
-
no setter
- field → UGaloisField
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isZero → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addOrSubtract(
UGfPoly other) → UGfPoly -
coefficient(
int degree) → int -
divide(
UGfPoly other) → List< UGfPoly> -
evaluate(
int a) → int -
multiply(
UGfPoly other) → UGfPoly -
multiplyByMonomial(
int degree, int coefficient) → UGfPoly -
multiplyScalar(
int scalar) → UGfPoly -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
monomial(
UGaloisField field, int degree, int coefficient) → UGfPoly -
one(
UGaloisField field) → UGfPoly -
zero(
UGaloisField field) → UGfPoly