UPdf417Row class
Constructors
Properties
-
codewords
→ List<
int> -
final
- columnsCount → int
-
final
- ecLevel → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rowNumber → int
-
final
- rowsCount → int
-
-1 when this row's indicators do not carry the value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited