Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Properties
-
byPattern
→ Map<int, int>
-
pattern -> cluster * 1000 + codeword value.
no setter
Static Methods
-
lookup(int pattern, {int maxDistance = 2})
→ int
-
Returns cluster * 1000 + codeword for
pattern, or -1 when nothing fits.