UPerspectiveTransform class
Constructors
Properties
- a11 → double
-
final
- a12 → double
-
final
- a13 → double
-
final
- a21 → double
-
final
- a22 → double
-
final
- a23 → double
-
final
- a31 → double
-
final
- a32 → double
-
final
- a33 → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildAdjoint(
) → UPerspectiveTransform -
mapPoint(
double x, double y) → Offset -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
times(
UPerspectiveTransform other) → UPerspectiveTransform -
toString(
) → String -
A string representation of this object.
inherited
-
transform(
Float64List points) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited