UQrDataBlock class
Constructors
- UQrDataBlock(int numDataCodewords, Uint8List codewords)
Properties
- codewords → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numDataCodewords → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
split(
Uint8List rawCodewords, UQrVersion version, UQrFormatInformation formatInfo) → List< UQrDataBlock>