UWhiteRectangleDetector class
Finds a white-bordered rectangle containing a symbol, used as the starting point for the Data Matrix and PDF417 detectors.
Constructors
- UWhiteRectangleDetector(UBitMatrix image, {int initSize = 10, int? x, int? y})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → UBitMatrix
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detect(
) → List< Offset> ? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited