USystemDownloadStatus class
Status of a download handed to the OS (Android DownloadManager, Apple background URLSession, Windows BITS).
Constructors
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- path → String?
-
final
- received → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String
-
One of queued, running, paused, completed, failed.
final
- total → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited