UAdminAccountingController class
Constructors
Properties
- fromController → TextEditingController
-
final
- fromDate ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
report
→ Rxn<
UAccountingReportResponse> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → RxState
-
final
- toController → TextEditingController
-
final
- toDate ↔ DateTime?
-
getter/setter pair
-
user
→ Rxn<
UUserResponse> -
final
Methods
-
clear(
) → void -
init(
) → Future< void> -
load(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited