UAdminAction class

Constructors

UAdminAction({required String label, required IconData icon, required VoidCallback onTap, List<TagUser>? roles, bool visible = true, bool destructive = false, Color? color})

Properties

allowed bool
no setter
color Color?
final
destructive bool
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
label String
final
onTap VoidCallback
final
roles List<TagUser>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited