UAdminActionContext<T> class
Constructors
-
UAdminActionContext(T item, UAdminActionHandlers<
T> _handlers)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- item → T
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
{List< TagUser> ? roles}) → UAdminAction -
detail(
{String? label, IconData icon = Icons.info_outline, List< TagUser> ? roles}) → UAdminAction -
edit(
{List< TagUser> ? roles}) → UAdminAction -
extra(
String key, {required String label, required IconData icon, bool destructive = false, bool visible = true, Color? color, List< TagUser> ? roles}) → UAdminAction -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited