UAdminActionHandlers<T> class
Constructors
-
UAdminActionHandlers({void onEdit(T item)?, void onDelete(T item)?, void onDetail(T item)?, })
-
Properties
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
onDelete
→ void Function(T item)?
-
final
-
onDetail
→ void Function(T item)?
-
final
-
onEdit
→ void Function(T item)?
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited