UAdminConfig class
Constructors
- UAdminConfig({required String appName, required String baseUrl, required Color primaryColor, required String logo, required UAdminModule dashboard(), String apiKey = "", String? loginBackground, String? font, Locale defaultLocale = const Locale("fa")})
Properties
- apiKey → String
-
final
- appName → String
-
final
- baseUrl → String
-
final
- dashboard → UAdminModule Function()
-
final
- defaultLocale → Locale
-
final
- font → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loginBackground → String?
-
final
- logo → String
-
final
-
final
- primaryColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited