UAdminHotelUserDetailController class
Constructors
- UAdminHotelUserDetailController({required UUserResponse user})
Properties
- activeContractsCount → int
-
no setter
-
contracts
→ RxList<
UDormBedContractResponse> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
merchants
→ List<
UMerchantResponse> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → RxState
-
final
- totalOutstanding → double
-
no setter
- totalWalletBalance → double
-
no setter
- user ↔ UUserResponse
-
getter/setter pair
-
wallets
→ List<
UWalletResponse> -
no setter
Methods
-
init(
) → Future< void> -
invoicesOf(
UDormBedContractResponse c) → List< UDormBedInvoiceResponse> -
lifecycleOf(
UDormBedContractResponse c) → UAdminContractLifecycle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
outstandingOf(
UDormBedContractResponse c) → double -
read(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
unpaidCountOf(
UDormBedContractResponse c) → int
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited