Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
adminUserDetail(UUserResponse u, {List<TagUser>? roles})
→ UAdminAction
-
-
bedContracts(UDormBedResponse b, {List<TagUser>? roles})
→ UAdminAction
-
-
contractInvoices(UDormBedContractResponse c, {List<TagUser>? roles})
→ UAdminAction
-
-
contractTenant(UUserResponse u, {List<TagUser>? roles})
→ UAdminAction
-
-
dormBeds(UDormResponse d, {List<TagUser>? roles})
→ UAdminAction
-
-
dormRooms(UDormResponse d, {List<TagUser>? roles})
→ UAdminAction
-
-
hotelReservations(UHotelResponse h, {List<TagUser>? roles})
→ UAdminAction
-
-
hotelRooms(UHotelResponse h, {List<TagUser>? roles})
→ UAdminAction
-
-
hotelUserDetail(UUserResponse u, {List<TagUser>? roles})
→ UAdminAction
-
-
merchantTerminals(UMerchantResponse m, {List<TagUser>? roles})
→ UAdminAction
-
-
parkingReport(UParkingResponse p, {List<TagUser>? roles})
→ UAdminAction
-
-
roomBeds(UDormRoomResponse r, {List<TagUser>? roles})
→ UAdminAction
-
-
roomReservations(UHotelRoomResponse r, {List<TagUser>? roles})
→ UAdminAction
-
-
userContracts(UUserResponse u, {List<TagUser>? roles})
→ UAdminAction
-
-
userMerchants(UUserResponse u, {List<TagUser>? roles})
→ UAdminAction
-