UAdminModules class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
accounting(
{List< TagUser> ? roles}) → UAdminModule -
adminUsers(
{List< TagUser> ? roles, UAdminActionBuilder<UUserResponse> ? actions}) → UAdminModule -
apiLogs(
{List< TagUser> ? roles}) → UAdminModule -
appSettings(
{List< TagUser> ? roles}) → UAdminModule -
barcodeGenerator(
{List< TagUser> ? roles}) → UAdminModule -
blogs(
{List< TagUser> ? roles}) → UAdminModule -
contents(
{List< TagUser> ? roles}) → UAdminModule -
contracts(
{List< TagUser> ? roles}) → UAdminModule -
cryptoTester(
{List< TagUser> ? roles}) → UAdminModule -
dbAdmin(
{List< TagUser> ? roles}) → UAdminModule -
dormBeds(
{List< TagUser> ? roles}) → UAdminModule -
dormRooms(
{List< TagUser> ? roles}) → UAdminModule -
dorms(
{List< TagUser> ? roles}) → UAdminModule -
fileManager(
{List< TagUser> ? roles}) → UAdminModule -
financialOpsDashboard(
{List< TagUser> ? roles}) → UAdminModule -
hotelRooms(
{List< TagUser> ? roles}) → UAdminModule -
hotels(
{List< TagUser> ? roles}) → UAdminModule -
invoices(
{List< TagUser> ? roles}) → UAdminModule -
merchants(
{List< TagUser> ? roles, UAdminActionBuilder<UMerchantResponse> ? actions}) → UAdminModule -
moadis(
{List< TagUser> ? roles, UAdminActionBuilder<UMoadiResponse> ? actions}) → UAdminModule -
parking(
{List< TagUser> ? roles, UAdminActionBuilder<UParkingResponse> ? actions}) → UAdminModule -
parkingReport(
{List< TagUser> ? roles}) → UAdminModule -
pnApiTester(
{List< TagUser> ? roles}) → UAdminModule -
propertyDashboard(
{List< TagUser> ? roles}) → UAdminModule -
reservations(
{List< TagUser> ? roles}) → UAdminModule -
settings(
{List< TagUser> ? roles}) → UAdminModule -
storage(
{List< TagUser> ? roles}) → UAdminModule -
terminals(
{List< TagUser> ? roles, UAdminActionBuilder<UTerminalResponse> ? actions}) → UAdminModule -
transactions(
{List< TagUser> ? roles}) → UAdminModule -
users(
{List< TagUser> ? roles}) → UAdminModule -
wallet(
{List< TagUser> ? roles}) → UAdminModule