UAdminTheme class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- black → const Color
- blue → const MaterialColor
- blueGrey → const MaterialColor
- green → const MaterialColor
- grey → const MaterialColor
- indigo → const MaterialColor
- orange → const MaterialColor
- pink → const MaterialColor
-
primaries
→ const List<
MaterialColor> - primary → const Color
- red → const MaterialColor
- transparent → const Color
- white → const Color
- white24 → const Color
- yellow → const MaterialColor