UAdminWalletController class
- Inheritance
-
- Object
- UBaseController
- UAdminWalletController
Constructors
Properties
- controllerEndDate → TextEditingController
-
finalinherited
- controllerStartDate → TextEditingController
-
finalinherited
- endDate ↔ DateTime?
-
getter/setter pairinherited
-
formKey
→ GlobalKey<
FormState> -
finalinherited
- fromCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFa → bool
-
no setterinherited
- orderByCreatedAt ↔ bool
-
getter/setter pairinherited
- orderByCreatedAtDesc ↔ bool
-
getter/setter pairinherited
- pageNumber ↔ RxInt
-
getter/setter pairinherited
- pageSize ↔ int
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedUser
→ Rxn<
UUserResponse> -
final
- startDate ↔ DateTime?
-
getter/setter pairinherited
- state → RxState
-
finalinherited
- state2 ↔ RxState
-
getter/setter pairinherited
-
summary
→ Rxn<
UAccountingReportResponse> -
final
-
tagOrderBy
↔ Rx<
TagOrderBy> -
getter/setter pairinherited
- toCreatedAt ↔ DateTime?
-
getter/setter pairinherited
- totalBalance → double
-
no setter
- totalCount ↔ int
-
getter/setter pairinherited
- totalPages ↔ RxInt
-
getter/setter pairinherited
-
txns
→ RxList<
UWalletTxnResponse> -
final
-
wallets
→ RxList<
UWalletResponse> -
final
Methods
-
charge(
double amount) → void -
errorCallBack(
String? message, void reload()) → void -
inherited
-
firstPage(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
okCallback(
String? message, void reload()) → void -
inherited
-
read(
) → Future< void> -
reloadFirstPage(
void read()) → void -
inherited
-
selectUser(
UUserResponse? u) → void -
setError(
[String? message]) → void -
inherited
-
setListState(
{required bool isEmpty}) → void -
inherited
-
setTotalPages(
int totalCount) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transfer(
{required String receiverId, required double amount, String? detail}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited