showBigPictureWhenCollapsed property
Shows the big picture as a thumbnail in the collapsed notification.
This property is only applicable to Android versions 12.0 or newer.
Implementation
final bool showBigPictureWhenCollapsed;
Shows the big picture as a thumbnail in the collapsed notification.
This property is only applicable to Android versions 12.0 or newer.
final bool showBigPictureWhenCollapsed;