DarwinOptions class

Platform-specific options for file picking on Apple platforms.

Constructors

DarwinOptions({DarwinAssetRepresentationMode assetRepresentationMode = DarwinAssetRepresentationMode.automatic, String? acceptLabel})
const

Properties

acceptLabel → String?
The label for the confirm button of the file dialog.
final
assetRepresentationMode → DarwinAssetRepresentationMode
The preferred representation for media selected from the iOS photo library.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(int compressionQuality) → void
Throws an ArgumentError if this configuration conflicts with compressionQuality.

Operators

operator ==(Object other) → bool
The equality operator.
inherited