DidReceiveNotificationResponseCallback typedef
DidReceiveNotificationResponseCallback =
void Function(NotificationResponse details)
Signature of callback triggered on main isolate when a user taps on a notification or a notification action.
Implementation
typedef DidReceiveNotificationResponseCallback =
void Function(NotificationResponse details);