skipEntitlementsChecks method
Asks the underlying platform to skip the App Sandbox entitlement checks performed before showing a dialog.
Default implementation is a no-op for platforms that do not perform entitlement checks.
Implementation
Future<void> skipEntitlementsChecks() async {}