periodicallyShow method
Future<void>
periodicallyShow({
- required int id,
- String? title,
- String? body,
- required RepeatInterval repeatInterval,
Periodically show a notification using the specified interval.
For example, specifying a hourly interval means the first time the notification will be an hour after the method has been called and then every hour after that.
Implementation
Future<void> periodicallyShow({
required int id,
String? title,
String? body,
required RepeatInterval repeatInterval,
}) {
throw UnimplementedError('periodicallyShow() has not been implemented');
}