show method
Show a notification with an optional payload that will be passed back to the app when a notification is tapped on.
Implementation
Future<void> show({
required int id,
String? title,
String? body,
String? payload,
}) async {
throw UnimplementedError('show() has not been implemented');
}