periodicallyShow method
Future<void>
periodicallyShow({
- required int id,
- String? title,
- String? body,
- String? payload,
- required RepeatInterval repeatInterval,
- WindowsNotificationDetails? notificationDetails,
override
Periodically show a notification using the specified interval.
For example, specifying a hourly interval means the first time the notification will be an hour after the method has been called and then every hour after that.
Implementation
@override
Future<void> periodicallyShow({
required int id,
String? title,
String? body,
String? payload,
required RepeatInterval repeatInterval,
WindowsNotificationDetails? notificationDetails,
}) async {}