show method
Future<void>
show({
- required int id,
- String? title,
- String? body,
- DarwinNotificationDetails? notificationDetails,
- String? payload,
override
Show a notification with an optional payload that will be passed back to the app when a notification is tapped on.
Implementation
@override
Future<void> show({
required int id,
String? title,
String? body,
DarwinNotificationDetails? notificationDetails,
String? payload,
}) {
validateId(id);
return _channel.invokeMethod('show', <String, Object?>{
'id': id,
'title': title,
'body': body,
'payload': payload ?? '',
'platformSpecifics': notificationDetails?.toMap(),
});
}