IllegalCharacterInFileNameException class
An exception that is thrown when a file name contains characters that are not allowed for the underlying platform.
- Implemented types
Constructors
- IllegalCharacterInFileNameException(String message)
-
Creates an instance of IllegalCharacterInFileNameException.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited