JavaScriptInvocationParams class
Parameters for invoking an asynchronous JavaScript function.
- Annotations
Constructors
Properties
-
arguments
→ Map<
String, Object?> -
Named arguments exposed as local variables to functionBody.
final
- functionBody → String
-
The body of the anonymous asynchronous JavaScript function.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
The maximum time allowed for the invocation to complete.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited