LinuxOptions class
The options for the Linux file picker.
- Inheritance
-
- Object
- DesktopWindowOptions
- LinuxOptions
Constructors
- LinuxOptions({String? acceptLabel, bool lockParentWindow = false})
-
Creates an instance of LinuxOptions.
const
Properties
- acceptLabel → String?
-
The label for the accept button of the file chooser dialog.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockParentWindow → bool
-
Whether to lock the parent window modally when showing the file picker dialog.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited