MethodChannelFilePicker class
An implementation of FilePickerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FilePickerPlatform
- MethodChannelFilePicker
Constructors
Properties
- eventChannel → EventChannel
-
The event channel used to receive real-time updates from the native platform.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearTemporaryFiles(
) → Future< void> -
Asks the underlying platform to remove any temporary files created by this plugin.
inherited
-
getDirectoryPath(
{String? dialogTitle, String? initialDirectory, AndroidOptions androidOptions = const AndroidOptions(), WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) → Future< String?> -
Pick a single directory using the native file picker.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickFile(
{String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List< String> ? allowedExtensions, dynamic onFileLoading(FilePickerStatus)?, int compressionQuality = 0, AndroidOptions androidOptions = const AndroidOptions(), WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) → Future<PlatformFile?> -
Pick a single file using the native file picker.
inherited
-
pickFileAndDirectoryPaths(
{String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List< String> ? allowedExtensions}) → Future<List< String> > -
Pick files and directories using the native file picker.
inherited
-
pickFiles(
{String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List< String> ? allowedExtensions, dynamic onFileLoading(FilePickerStatus)?, int compressionQuality = 0, AndroidOptions androidOptions = const AndroidOptions(), WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) → Future<List< PlatformFile> > -
Pick multiple files using the native file picker.
inherited
-
saveFile(
{required String fileName, required Uint8List bytes, required String mimeType, String? dialogTitle, String? initialDirectory, dynamic onFileSaving(FilePickerStatus)?, WindowsOptions windowsOptions = const WindowsOptions(), LinuxOptions linuxOptions = const LinuxOptions(), WebOptions webOptions = const WebOptions()}) → Future< Uri?> -
Save the given
bytesto a file with the givenfileName, using the native save file dialog.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void - Registers this class as the default instance of FilePickerPlatform.