activeWebReader property
WebBarcodeReader?
get
activeWebReader
The barcode reader that is currently active on web,
or null when no scanner is running or the platform is not web.
Implementation
WebBarcodeReader? get activeWebReader => null;