UArAnchorType enum

Anchor kind: world, plane, image, face, geo.

Inheritance
Available extensions

Values

world → const UArAnchorType
plane → const UArAnchorType
point → const UArAnchorType
image → const UArAnchorType
face → const UArAnchorType
geo → const UArAnchorType
terrain → const UArAnchorType
rooftop → const UArAnchorType
cloud → const UArAnchorType
object → const UArAnchorType
body → const UArAnchorType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UArAnchorType>
A constant List of the values in this enum, in order of their declaration.