UArtworkRef class
Where artwork comes from (URL, file tag, bytes).
Constructors
- UArtworkRef.embedded({required String? filePath, required int offset, required int length, String? mimeType})
-
const
- UArtworkRef.uri(String? uri)
-
const
Properties
- cacheKey → String
-
no setter
- filePath → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmbedded → bool
-
no setter
- isEmpty → bool
-
no setter
- length → int
-
final
- mimeType → String?
-
final
- offset → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited