Paints drawing shapes (pen, arrow, box…).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
hitTest(
UDocShape shape, UDocShapeGeometry geometry, Offset pixel, {double slop = 8}) → bool -
Whether
pixeltouchesshape. -
paint(
Canvas canvas, UDocShape shape, UDocShapeGeometry geometry, {bool selected = false, bool hideText = false}) → void -
pixelBounds(
UDocShape shape, UDocShapeGeometry geometry) → Rect - Bounds in pixels, including text that grew beyond the drawn box.
-
stickySize(
UDocShapeGeometry geometry) → double -
textPainter(
UDocShape shape, UDocShapeGeometry geometry, double maxWidth) → TextPainter