UEpubSlice class
A contiguous piece of one block: the whole block, or the part that fits on a page.
Constructors
- UEpubSlice({required int blockIndex, int start = 0, int end = -1})
-
const
Properties
Methods
-
endIn(
UEpubBlock block) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited