UGeofence class
A circle to watch for enter/exit. UGeofence(id: "home", latitude: 35.7, longitude: 51.4, radius: 200)
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Your id for this area.
final
- latitude → double
-
Center latitude.
final
- longitude → double
-
Center longitude.
final
- notificationText → String?
-
Shows this notification on enter/exit even when the app is closed.
final
- notificationTitle → String?
-
When set, a notification is shown on the transition even if the app is not running.
final
- onEnter → bool
-
Reports entering.
final
- onExit → bool
-
Reports leaving.
final
- radius → double
-
Metres; the OS enforces a minimum of ~100 m for reliable triggers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - As a map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited