UHlsMediaPlaylist class
HLS media playlist.
Constructors
-
UHlsMediaPlaylist({required List<
UHlsSegment> segments, required Duration targetDuration, required int mediaSequence, required bool isEndList, String? initUrl, int version = 3}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initUrl → String?
-
final
- isEndList → bool
-
final
- isLive → bool
-
no setter
- mediaSequence → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
segments
→ List<
UHlsSegment> -
final
- targetDuration → Duration
-
final
- totalDuration → Duration
-
no setter
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited