UHlsSegment class
HLS media segment.
Constructors
Properties
- byteRangeLength → int?
-
final
- byteRangeOffset → int?
-
final
- discontinuity → bool
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initUrl → String?
-
final
- key → UHlsKey?
-
final
- programDateTime → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
final
- title → String?
-
final
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited