menu
u package
documentation
utilities.dart
UPlaylist class
UPlaylist class
dark_mode
light_mode
UPlaylist
class
A saved playlist.
Constructors
UPlaylist
({
required
String
id
,
required
String
name
,
required
List
<
String
>
paths
,
int
createdAt
=
0
,
int
updatedAt
=
0
})
UPlaylist.fromJson
(
Map
<
String
,
Object
?
>
json
)
factory
Properties
createdAt
→
int
final
hashCode
→
int
The hash code for this object.
no setter
inherited
id
→
String
final
length
→
int
no setter
name
→
String
final
paths
→
List
<
String
>
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
updatedAt
→
int
final
Methods
copyWith
(
{
String
?
name
,
List
<
String
>
?
paths
})
→
UPlaylist
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
Object
?
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
u package
documentation
utilities
UPlaylist class
utilities library