UReceivedShare class
What another app shared into this one.
- Annotations
Constructors
-
const
-
Reads it from the native map.
factory
Properties
-
files
→ List<
UShareFile> -
Shared files (copied into the app's cache).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
True when nothing was shared.
no setter
- link → Uri?
-
The shared text when it is a single link.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String?
-
Shared subject.
final
- text → String?
-
Shared text or link.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited