USubtitleCue class

One subtitle line with start/end times.

Constructors

USubtitleCue({required Duration start, required Duration end, required List<USubtitleSpan> spans, required String text, int alignment = 2, Offset? position, int layer = 0, String? styleName})
const

Properties

alignment → int
final
end → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
isRtl → bool
no setter
layer → int
final
position → Offset?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spans → List<USubtitleSpan>
final
start → Duration
final
styleName → String?
final
text → String
final

Methods

contains(Duration time) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited