show method
Future<void>
show({
- required int id,
- String? title,
- String? body,
- String? payload,
- WebNotificationDetails? notificationDetails,
override
Show a notification with an optional payload that will be passed back to the app when a notification is tapped on.
Implementation
@override
Future<void> show({
required int id,
String? title,
String? body,
String? payload,
WebNotificationDetails? notificationDetails,
}) async {}