WebNotificationAction class
A means for a user to interact with a web notification.
See: options.actions
Note: This is not standard yet, see: https://developer.mozilla.org/en-US/docs/Web/API/ServiceWorkerRegistration/showNotification#browser_compatibility Notably, Firefox and Safari do not support this yet.
Constructors
- WebNotificationAction({required String action, required String title, Uri? icon})
-
A const constructor.
const
Properties
- action → String
-
A developer-facing string representing this action.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Uri?
-
An optional icon to display next to the action.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
A user-facing string to be shown next to this action.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited