WebNotificationDetails class
The web-specific details of a notification.
See: https://developer.mozilla.org/en-US/docs/Web/API/Notification
Note: The tag field is reserved for the notification ID.
Constructors
-
WebNotificationDetails({List<
WebNotificationAction> actions = const <WebNotificationAction>[], WebNotificationDirection direction = WebNotificationDirection.auto, Uri? badgeUrl, Uri? iconUrl, String? lang, bool requireInteraction = false, bool isSilent = false, Uri? imageUrl, bool renotify = false, DateTime? timestamp}) -
A const constructor.
const
Properties
-
actions
→ List<
WebNotificationAction> -
A list of actions to send with the notification.
final
- badgeUrl → Uri?
-
An optional URL to a monochrome icon to show next to the title.
final
- direction → WebNotificationDirection
-
The text direction of the notification.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconUrl → Uri?
-
An optional URL to an image to show as the app icon.
final
- imageUrl → Uri?
-
An optional URL to an image to show in the notification.
final
- isSilent → bool
-
Whether the notification should be silent.
final
- lang → String?
-
The language code of the notification's content, eg
en-US.final - renotify → bool
-
Whether the user should be notified if this notification is replaced.
final
- requireInteraction → bool
-
Whether the notification should remain visible until manually dismissed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime?
-
The timestamp of the event that caused this notification.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited