WebNotificationDirection enum
The text direction of a web notification.
Note: This may be ignored by browsers. See the docs
Values
- auto → const WebNotificationDirection
-
Adopt the browser's setting.
const WebNotificationDirection('auto') - leftToRight → const WebNotificationDirection
-
Left to right.
const WebNotificationDirection('ltr') - rightToLeft → const WebNotificationDirection
-
Right to left.
const WebNotificationDirection('rtl')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- jsValue → String
-
A string value to pass to JavaScript functions.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WebNotificationDirection> - A constant List of the values in this enum, in order of their declaration.