WebViewDataManager class
Manages website data shared by WebViews in the current platform data store.
Constructors
- WebViewDataManager()
- Creates a manager for the default persistent WebView data store.
- WebViewDataManager.fromPlatform(PlatformWebViewDataManager platform)
-
Creates a manager backed by
platform. - WebViewDataManager.fromPlatformCreationParams(PlatformWebViewDataManagerCreationParams params)
- Creates a manager from platform-specific creation parameters.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → PlatformWebViewDataManager
-
The platform implementation used by this manager.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAllWebsiteData(
) → Future< WebViewDataClearingResult> - Clears website data from the store used by normal WebViews.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited