UChaCha20Poly1305 class
RFC 8439 ChaCha20-Poly1305 over raw bytes. Output of seal is ciphertext ‖ tag(16).
Native only — see the file header.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
Uint8List nonce, Uint8List cipherAndTag, [Uint8List? aad]) → Uint8List -
seal(
Uint8List nonce, Uint8List plain, [Uint8List? aad]) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- nonceLength → const int
- tagLength → const int