UChecksum class
Constructors
- UChecksum(UHashAlgorithm algorithm, String value)
-
const
-
UChecksum.fromJson(Map<
String, dynamic> json) -
factory
- UChecksum.md5(String value)
-
const
- UChecksum.sha256(String value)
-
const
Properties
- algorithm → UHashAlgorithm
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Hex digest, case-insensitive.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited