File-name helpers: Content-Disposition parsing, sanitising, extensions and categories.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
categoryOf(
String name) → UDownloadCategory -
extensionForMime(
String? mimeType) → String? -
extensionOf(
String name) → String -
fromContentDisposition(
String? header) → String? -
RFC 6266: prefers
filename*=UTF-8''…overfilename="…". -
mimeForExtension(
String extension) → String? -
resolve(
{String? requested, String? contentDisposition, Uri? uri, String? mimeType}) → String -
sanitize(
String name) → String -
Makes
namesafe on every file system: no separators or reserved characters, no Windows device names, no leading dots, and at most 180 characters.