UTransportOptions class
Constructors
Properties
- connectTimeout → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConnectionsPerHost → int
-
final
-
pinnedCertificateSha256
→ Set<
String> -
Hex SHA-256 of accepted leaf certificates (DER). Empty disables pinning (native only).
final
- proxy → String?
-
"host:port" of an HTTP proxy (native only).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAgent → String?
-
final
- withCredentials → bool
-
Send cookies on cross-origin requests (web only).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited