UStorageEntry class
Constructors
-
UStorageEntry({required String key, required UStorageBucket bucket, required String file, required int size, required DateTime created, required DateTime accessed, DateTime? expires, String? mimeType, String? sha256, Map<
String, String> tags = const <String, String>{}}) -
UStorageEntry.fromJson(Map<
String, dynamic> json, UStorageBucket bucket) -
factory
Properties
- accessed ↔ DateTime
-
getter/setter pair
- bucket → UStorageBucket
-
final
- created → DateTime
-
final
- expires ↔ DateTime?
-
getter/setter pair
- file → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEncrypted → bool
-
no setter
- isExpired → bool
-
no setter
- key → String
-
final
- mimeType ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 ↔ String?
-
getter/setter pair
- size ↔ int
-
getter/setter pair
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited