UEncryption class abstract
Zero-dependency cryptography helpers: authenticated encryption, symmetric ciphers, one-way hashes, key derivation, reversible encoders and classical ciphers. All local; no method touches the network. Prefer seal/open for real secrets — they authenticate and detect tampering.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
adler32(
String text) → int -
aesDecrypt(
{required String base64Encrypted, required String key, required String iv, UAesMode mode = UAesMode.cbc, bool padding = true, UByteEncoding keyEncoding = UByteEncoding.utf8, UByteEncoding ivEncoding = UByteEncoding.utf8}) → String -
aesEncrypt(
{required String plainText, required String key, required String iv, UAesMode mode = UAesMode.cbc, bool padding = true, UByteEncoding keyEncoding = UByteEncoding.utf8, UByteEncoding ivEncoding = UByteEncoding.utf8}) → String -
ascii85DecodeText(
String value) → String -
ascii85EncodeText(
String text) → String -
base32Decode(
String input) → List< int> -
base32DecodeText(
String value) → String -
base32Encode(
List< int> bytes) → String -
base32EncodeText(
String text) → String -
base32HexDecodeText(
String value) → String -
base32HexEncodeText(
String text) → String -
base45DecodeText(
String value) → String -
base45EncodeText(
String text) → String -
base58Check(
List< int> payload) → String -
base58Decode(
String value) → List< int> -
base58DecodeText(
String value) → String -
base58Encode(
List< int> bytes) → String -
base58EncodeText(
String text) → String -
base64DecodeText(
String value) → String -
base64EncodeText(
String text) → String -
base64UrlDecodeText(
String value) → String -
base64UrlEncodeText(
String text) → String -
blake2bHash(
String text, {int bytes = 64}) → String -
caesarShift(
String text, int shift) → String -
chacha20Decrypt(
{required String base64Encrypted, required String key, required String nonce, UByteEncoding keyEncoding = UByteEncoding.utf8, UByteEncoding nonceEncoding = UByteEncoding.utf8}) → String -
chacha20Encrypt(
{required String plainText, required String key, required String nonce, UByteEncoding keyEncoding = UByteEncoding.utf8, UByteEncoding nonceEncoding = UByteEncoding.utf8}) → String -
chacha20Poly1305Decrypt(
{required String base64Cipher, required String key, String? aad, UByteEncoding keyEncoding = UByteEncoding.base64}) → String -
chacha20Poly1305Encrypt(
{required String plainText, required String key, String? aad, UByteEncoding keyEncoding = UByteEncoding.base64}) → String - Authenticated encryption with ChaCha20-Poly1305 (fully web-safe).
-
constantTimeEquals(
String a, String b) → bool -
crc16(
String text) → int -
crc32(
String text) → int -
decryptUint8List(
{required String base64Encrypted, required String key, required String iv}) → Uint8List -
encryptUint8List(
{required Uint8List data, required String key, required String iv}) → String - AES-256-CBC/PKCS7 with UTF-8 key (32 chars) and IV (16 chars).
-
fernetDecrypt(
{required String base64Encrypted, required String key, UByteEncoding keyEncoding = UByteEncoding.base64}) → String -
fernetEncrypt(
{required String plainText, required String key, UByteEncoding keyEncoding = UByteEncoding.base64}) → String -
fnv1a32(
String text) → int -
hexDecodeText(
String value) → String -
hexEncode(
List< int> bytes) → String -
hexEncodeText(
String text) → String -
hexToBytes(
String hex) → List< int> -
hkdf(
{required String secret, String salt = "", String info = "", int length = 32, bool asHex = false}) → String -
hmacSha1(
String text, String key) → String -
hmacSha256(
String text, String key) → String -
hmacSha512(
String text, String key) → String -
keccak256Hash(
String text) → String -
md4Hash(
String text) → String -
md5Hash(
String text) → String -
morseDecode(
String code) → String -
morseEncode(
String text) → String -
open(
{required String base64Cipher, required String key, String? aad, UByteEncoding keyEncoding = UByteEncoding.base64}) → String -
pbkdf2(
{required String password, required String salt, int iterations = 100000, int length = 32, UByteEncoding saltEncoding = UByteEncoding.utf8, bool asHex = false}) → String -
randomHex(
{int bytes = 16}) → String -
randomIv(
{int bytes = 16}) → String -
randomKey(
{int bytes = 32}) → String -
rc4Decrypt(
{required String base64Encrypted, required String key, UByteEncoding keyEncoding = UByteEncoding.utf8}) → String -
rc4Encrypt(
{required String plainText, required String key, UByteEncoding keyEncoding = UByteEncoding.utf8}) → String -
ripemd160Hash(
String text) → String -
rot13(
String text) → String -
rot47(
String text) → String -
salsa20Decrypt(
{required String base64Encrypted, required String key, required String iv, UByteEncoding keyEncoding = UByteEncoding.utf8, UByteEncoding ivEncoding = UByteEncoding.utf8}) → String -
salsa20Encrypt(
{required String plainText, required String key, required String iv, UByteEncoding keyEncoding = UByteEncoding.utf8, UByteEncoding ivEncoding = UByteEncoding.utf8}) → String -
scrypt(
{required String password, required String salt, int n = 16384, int r = 8, int p = 1, int dkLen = 32, UByteEncoding saltEncoding = UByteEncoding.utf8, bool asHex = false}) → String -
seal(
{required String plainText, required String key, String? aad, UByteEncoding keyEncoding = UByteEncoding.base64}) → String -
sha1Hash(
String text) → String -
sha224Hash(
String text) → String -
sha256Hash(
String text) → String -
sha3(
String text, {int bits = 256}) → String -
sha384Hash(
String text) → String -
sha512256Hash(
String text) → String -
sha512Hash(
String text) → String -
shake128(
String text, {int bytes = 32}) → String -
shake256(
String text, {int bytes = 64}) → String -
sm3Hash(
String text) → String -
urlDecode(
String value) → String -
urlEncode(
String text) → String -
xchacha20Poly1305Decrypt(
{required String base64Cipher, required String key, String? aad, UByteEncoding keyEncoding = UByteEncoding.base64}) → String -
xchacha20Poly1305Encrypt(
{required String plainText, required String key, String? aad, UByteEncoding keyEncoding = UByteEncoding.base64}) → String -
xorDecrypt(
{required String base64Encrypted, required String key, UByteEncoding keyEncoding = UByteEncoding.utf8}) → String -
xorEncrypt(
{required String plainText, required String key, UByteEncoding keyEncoding = UByteEncoding.utf8}) → String