UCropOptions class
Constructors
-
UCropOptions({UCropShape shape = UCropShape.rectangle, double? aspectRatio, List<
UCropAspectRatio> ? aspectRatios, int? maxWidth, int? maxHeight, bool allowRotate = true, bool allowFlip = true, bool allowAdjust = true, bool allowShapeToggle = false, String? title}) -
const
Properties
- allowAdjust → bool
-
final
- allowFlip → bool
-
final
- allowRotate → bool
-
final
- allowShapeToggle → bool
-
final
- aspectRatio → double?
-
final
-
aspectRatios
→ List<
UCropAspectRatio> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxHeight → int?
-
final
- maxWidth → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → UCropShape
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited