UFile class abstract

Constructors

UFile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cropImage({Uint8List? bytes, String? filePath, UCropOptions options = const UCropOptions(), dynamic action(FileData file)?}) Future<FileData?>
isImageExtension(String? extension) bool
openCamera({UCameraOptions options = const UCameraOptions(), dynamic action(List<FileData>)?}) Future<List<FileData>>
pickFile({FileType fileType = FileType.any, List<String>? allowedExtensions, UCropOptions? crop, dynamic action(FileData?)?}) Future<FileData?>
pickFiles({bool allowMultiple = true, FileType fileType = FileType.any, List<String>? allowedExtensions, UCropOptions? crop, dynamic action(List<FileData>)?}) Future<List<FileData>>
pickImage({UImageSource source = UImageSource.gallery, bool selfie = false, bool allowMultiple = false, int? maxCount, int? imageQuality, UCropOptions? crop, UCameraOptions? cameraOptions, dynamic action(List<FileData>)?}) Future<List<FileData>>
pickSingleImage({UImageSource source = UImageSource.gallery, bool selfie = false, int? imageQuality, UCropOptions? crop, UCameraOptions? cameraOptions, dynamic action(FileData?)?}) Future<FileData?>
pickVideo({UImageSource source = UImageSource.gallery, UCameraOptions options = const UCameraOptions(), dynamic action(FileData?)?}) Future<FileData?>
Picks a video from the gallery, or records one when source is camera.
recordVideo({UCameraOptions options = const UCameraOptions(), dynamic action(FileData?)?}) Future<FileData?>
Records a single video with the in-app camera.
showFilePicker({dynamic action(List<FileData>)?, FileType fileType = FileType.any, bool allowMultiple = false, List<String>? allowedExtensions, UCropOptions? crop}) Future<List<FileData>>
showImagePicker({required UImageSource source, bool allowMultiple = false, bool isSelfie = false, int? imageQuality, UCropOptions? crop, dynamic action(List<FileData>)?}) Future<List<FileData>>
Backwards-compatible image picker. Delegates to pickImage (camera capture uses the in-app UCameraPage; gallery uses the file picker).
takePhoto({bool selfie = false, UCropOptions? crop, UCameraOptions? options, dynamic action(FileData?)?}) Future<FileData?>
takePhotos({int maxCount = 0, bool selfie = false, UCropOptions? crop, UCameraOptions? options, dynamic action(List<FileData>)?}) Future<List<FileData>>
Captures multiple photos in one camera session. maxCount 0 means unlimited.
writeToFile(Uint8List data, {String extension = "tmp"}) Future<File>

Constants

imageExtensions → const Set<String>