UDownload class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cancelDownload(
String cacheKey) → void -
downloadFile(
{required String url, required String cacheKey, required void onProgress(int progress), Duration timeout = const Duration(seconds: 60)}) → Future< Uint8List?> -
isDownloading(
String cacheKey) → bool