UBankInfo class
An Iranian bank: nickname, English and Persian name, account number from a Sheba.
Constructors
Properties
- accountNumber → String?
-
Account number (after getBankFromSheba).
final
- formattedAccountNumber → String?
-
Formatted account number (after getBankFromSheba).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAccountNumberAvailable → bool
-
True when the account number can be read from the Sheba.
final
- name → String
-
English name.
final
- nickname → String
-
Short id, e.g. "mellat".
final
- persianName → String
-
Persian name, e.g. "بانک ملت".
final
- process → UAccountNumberModel Function(String)?
-
Extracts the account number from a Sheba.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? nickname, String? name, String? persianName, bool? isAccountNumberAvailable, UAccountNumberModel process(String)?, String? accountNumber, String? formattedAccountNumber}) → UBankInfo - Copy with some fields changed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override