UBankInfo class

Constructors

UBankInfo({required String nickname, required String name, required String persianName, bool isAccountNumberAvailable = false, UAccountNumberModel process(String)?, String? accountNumber, String? formattedAccountNumber})
const

Properties

accountNumber → String?
final
formattedAccountNumber → String?
final
hashCode → int
The hash code for this object.
no setteroverride
isAccountNumberAvailable → bool
final
name → String
final
nickname → String
final
persianName → String
final
process → UAccountNumberModel Function(String)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? nickname, String? name, String? persianName, bool? isAccountNumberAvailable, UAccountNumberModel process(String)?, String? accountNumber, String? formattedAccountNumber}) → UBankInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override