UOperatorDetail class

Constructors

UOperatorDetail({required String base, required UOperator operator, List<String> provinces = const <String>[], String? model, USimCardType type = USimCardType.both})
const

Properties

base → String
final
hashCode → int
The hash code for this object.
no setteroverride
model → String?
final
name → String
no setter
operator → UOperator
final
provinces → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → USimCardType
final

Methods

copyWith({String? base, List<String>? provinces, String? model, USimCardType? type, UOperator? operator}) → UOperatorDetail
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override