UPersianTools class

Constructors

UPersianTools()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertDigits(String digits, UDigitLocale from, UDigitLocale to) → String
formatCardNumber(String cardNumber) → String?
formatPhoneNumber(String phoneNumber) → String?
getBankFromSheba(String sheba) → UBankInfo?
getBankNameFromCard(String cardNumber) → String?
getPhoneDetails(String phoneNumber) → UOperatorDetail?
hasPersian(String input, {bool complex = false}) → bool
isPersian(String input, {bool complex = false}) → bool
isShebaValid(String sheba) → bool
numberToWords(num number, {bool ordinal = false}) → String?
replaceMapValue(String input, Map<String, String> mapPattern) → String
trim(String input) → String
validateCardNumber(String cardNumber) → bool
validateNationalCode(String? input) → bool
validateTaxMemoryId(String? input) → bool
wordsToNumberString(String words, {UDigitLocale digits = UDigitLocale.en, bool addComma = false}) → String?