UPhoneNumberUtils class

Constructors

UPhoneNumberUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

countryOf(String rawInput) → UCountry?
countryOfDialCode(String? countryCode) → UCountry?
dialCodeOf(String countryCode) → String
formatE164(String e164) → String
formatMask(int length, String countryCode) → String
formatNational(String digits, {required String countryCode}) → String
inputDigits(String rawInput, {required String countryCode}) → String
isValid(String rawInput, {required String countryCode}) → bool
maxInputDigits(String countryCode) → int
maxNationalDigits(String countryCode) → int
nationalNumber(String rawInput, {required String countryCode}) → String
normalizePhone(String rawInput, {required String countryCode, bool stripLeadingZero = true}) → String
placeholder(String countryCode) → String
resolveCountry(String? value) → UCountry
sanitize(String rawInput) → String
stripTrunkPrefix(String digits, {required String countryCode}) → String
toE164(String rawInput, {required String countryCode}) → String