RxState class
- Inheritance
-
- Object
- ChangeNotifier
- Rx<
PageState> - RxState
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ PageState
-
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
call(
PageState newValue) → PageState -
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
emptying(
) → PageState -
error(
) → PageState -
initial(
) → PageState -
isEmpty(
) → bool -
isError(
) → bool -
isInitial(
) → bool -
isLoaded(
) → bool -
isLoading(
) → bool -
isPaging(
) → bool -
loaded(
) → PageState -
loading(
) → PageState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
paging(
) → PageState -
refresh(
) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited