UPageState enum

Page loading states: initial, loading, loaded, error, empty, paging (loading more).

Inheritance
Available extensions

Values

initial → const UPageState
loading → const UPageState
loaded → const UPageState
error → const UPageState
empty → const UPageState
paging → const UPageState

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isEmpty() → bool
True when loaded but empty.
isError() → bool
True after a failure.
isInitial() → bool
True before the first load.
isLoaded() → bool
True when data is shown.
isLoading() → bool
True while loading.
isPaging() → bool
True while loading the next page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<UPageState>
A constant List of the values in this enum, in order of their declaration.