UDateFormatter class abstract
Pieces of a date as text (y, yyyy, mm, mN month name, wN weekday…); get one from date.formatter.
- Implementers
Constructors
- UDateFormatter(UDate date)
-
Formatter for
date.const
Properties
- d → String
-
Day number. "5"
no setter
- date → UDate
-
The date being formatted.
final
- dd → String
-
Day padded to 2 digits. "05"
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- m → String
-
Month number. "1"
no setter
- mm → String
-
Month padded to 2 digits. "01"
no setter
- mN → String
-
Month name. "فروردین"
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wN → String
-
Weekday name. "شنبه"
no setter
- y → String
-
Year. "1403"
no setter
- yy → String
-
Last two digits of the year. "03"
no setter
- yyyy → String
-
Year padded to 4 digits.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPersian(
String input) → String - Latin digits → Persian digits.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited