UGregorianFormatter class

English month/weekday names for UGregorian.

Inheritance

Constructors

UGregorianFormatter(UGregorian date)
Formatter for a Gregorian date.
const

Properties

d → String
Day number. "5"
no setterinherited
date → UDate
The date being formatted.
finalinherited
dd → String
Day padded to 2 digits. "05"
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
m → String
Month number. "1"
no setterinherited
mm → String
Month padded to 2 digits. "01"
no setterinherited
mN → String
Month name. "فروردین"
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wN → String
Weekday name. "شنبه"
no setteroverride
y → String
Year. "1403"
no setterinherited
yy → String
Last two digits of the year. "03"
no setterinherited
yyyy → String
Year padded to 4 digits.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPersian(String input) → String
Latin digits → Persian digits.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited