UShare class abstract

Constructors

UShare()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

bytes({required Uint8List bytes, required String fileName, String? mimeType, String? text, String? subject, Rect? sharePositionOrigin}) → Future<ShareResult>
file({required String path, String? text, String? subject, String? fileName, Rect? sharePositionOrigin}) → Future<ShareResult>
files({required List<String> paths, String? text, String? subject, String? title, List<String>? fileNames, Rect? sharePositionOrigin}) → Future<ShareResult>
text({required String text, String? subject, String? title, Rect? sharePositionOrigin}) → Future<ShareResult>
wasShared(ShareResult result) → bool
widgetImage({required UWidgetToImageController controller, String fileName = "image.png", String? text, String? subject, Rect? sharePositionOrigin}) → Future<ShareResult?>
xFiles({required List<XFile> files, String? text, String? subject, String? title, Rect? sharePositionOrigin}) → Future<ShareResult>