UUpdateDialog class

Shows "Update available / required" from your server data, comparing build numbers (Android, iOS, Windows, macOS). UUpdateDialog.checkAndShow(data, () => UNavigator.offAll(HomePage()))

Constructors

UUpdateDialog()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkAndShow(UUpdateResponse serverData, VoidCallback onSkipOrNotAvailable) → Future<void>
Shows the dialog when needed; onSkipOrNotAvailable runs when there is nothing to do or the user taps Later.