UUpdateResponse class
Your server's update info per platform (min and current build numbers, download links). UUpdateResponse.fromMap(json)
Constructors
- UUpdateResponse({UOs? android, UOs? ios, UOs? windows, UOs? macos})
- Update info for each platform.
- UUpdateResponse.fromJson(String str)
-
Parses JSON text.
factory
-
UUpdateResponse.fromMap(Map<
String, dynamic> json) -
Parses a decoded JSON map.
factory
Properties
- android → UOs?
-
Android update info.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ios → UOs?
-
iOS update info.
final
- macos → UOs?
-
macOS update info.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- windows → UOs?
-
Windows update info.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Back to JSON text.
-
toMap(
) → Map< String, dynamic> - Back to a map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited